const { Callbacks } = require("jquery");

require([
  "jquery",
  "underscore",
  "splunkjs/mvc",
  "splunkjs/mvc/utils",
  "splunkjs/mvc/searchmanager",
  "splunkjs/mvc/postprocessmanager",
  "splunkjs/mvc/singleview",
  "splunkjs/mvc/simplexml/searcheventhandler",
  "/static/app/trackme/momentjs/moment.js",
  "splunkjs/mvc/simplexml/ready!",
  "splunkjs/mvc/simpleform/input/multiselect",
], function (
  $,
  _,
  mvc,
  utils,
  SearchManager,
  PostProcessManager,
  SingleView,
  SearchEventHandler,
  moment
) {
  //
  // Functions
  //

  //
  // Get comment from textaread
  //

  function getComment(inputId) {
    // Retrieve update comment if any
    var tk_comment = document.getElementById(inputId).value;

    // if is not defined, give it a value and override text box content
    if (tk_comment == "null") {
      tk_comment = "No comments for update.";
    } else if (tk_comment == "update note") {
      tk_comment = "No comment for update.";
    }
    return tk_comment;
  }

  function cssloaderremove() {
    $("#cssloader").remove();
  }

  // close all opened modals
  function closeModals() {
    $(".modal").modal("hide");
  }

  // syntax highlighting for JSON
  function syntaxHighlight(json) {
    json = json
      .replace(/&/g, "&amp;")
      .replace(/</g, "&lt;")
      .replace(/>/g, "&gt;");
    return json.replace(
      /("(\\u[a-zA-Z0-9]{4}|\\[^u]|[^\\"])*"(\s*:)?|\b(true|false|null)\b|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?)/g,
      function (match) {
        var cls = "json-preview-number";
        if (/^"/.test(match)) {
          if (/:$/.test(match)) {
            cls = "json-preview-key";
          } else {
            cls = "json-preview-string";
          }
        } else if (/true|false/.test(match)) {
          cls = "json-preview-boolean";
        } else if (/null/.test(match)) {
          cls = "json-preview-null";
        }
        return '<span class="' + cls + '">' + match + "</span>";
      }
    );
  }

  //
  // MAINTENANCE MODE
  //

  var search_maintenance_mode_mainsearch = new SearchManager(
    {
      id: "search_maintenance_mode_mainsearch",
      sample_ratio: 1,
      search: "| inputlookup trackme_maintenance_mode",
      status_buckets: 0,
      earliest_time: "-24h@h",
      cancelOnUnload: true,
      latest_time: "now",
      app: utils.getCurrentApp(),
      auto_cancel: 90,
      preview: true,
      tokenDependencies: {},
      runWhenTimeIsUndefined: false,
    },
    {
      tokens: true,
      tokenNamespace: "submitted",
    }
  );

  new SearchEventHandler({
    managerid: "search_maintenance_mode_mainsearch",
    event: "progress",
    conditions: [
      {
        attr: "match",
        value: "'result.maintenance_mode'==\"enabled\"",
        actions: [
          {
            type: "set",
            token: "maintenance_enabled",
            value: "true",
          },
          {
            type: "unset",
            token: "maintenance_scheduled",
          },
        ],
      },
      {
        attr: "match",
        value: "'result.maintenance_mode'==\"scheduled\"",
        actions: [
          {
            type: "set",
            token: "maintenance_scheduled",
            value: "true",
          },
          {
            type: "unset",
            token: "maintenance_enabled",
          },
        ],
      },
      {
        attr: "match",
        value: "'result.maintenance_mode'==\"disabled\"",
        actions: [
          {
            type: "unset",
            token: "maintenance_scheduled",
          },
          {
            type: "unset",
            token: "maintenance_enabled",
          },
        ],
      },
    ],
  });

  var search_maintenance_state = new PostProcessManager(
    {
      managerid: "search_maintenance_mode_mainsearch",
      id: "search_maintenance_state",
      search:
        'fields maintenance_mode | eval maintenance=case(match(maintenance_mode, "enabled"), 1, match(maintenance_mode, "disabled"), 0, match(maintenance_mode, "scheduled"), 2), maintenance_mode=upper(maintenance_mode) | rangemap field=maintenance low=0-0 severe=1-1 high=2-2 default=severe',
      tokenDependencies: {},
      runWhenTimeIsUndefined: false,
    },
    {
      tokens: true,
      tokenNamespace: "submitted",
    }
  );

  var search_maintenance_state_reactivation = new PostProcessManager(
    {
      managerid: "search_maintenance_mode_mainsearch",
      id: "search_maintenance_state_reactivation",
      search:
        'eval maintenance_mode_end=strftime(maintenance_mode_end, "%d %b %H:%M") | eval maintenance = "Ends on: " . maintenance_mode_end | fields maintenance',
      tokenDependencies: {},
      runWhenTimeIsUndefined: false,
    },
    {
      tokens: true,
      tokenNamespace: "submitted",
    }
  );

  var search_maintenance_state_scheduled = new PostProcessManager(
    {
      managerid: "search_maintenance_mode_mainsearch",
      id: "search_maintenance_state_scheduled",
      search:
        'eval maintenance_mode_start=strftime(maintenance_mode_start, "%d %b %H:%M"), maintenance_mode_end=strftime(maintenance_mode_end, "%d %b %H:%M") | eval maintenance = "Starts on: " . maintenance_mode_start . " / " . "Ends on: " . maintenance_mode_end | fields maintenance',
      tokenDependencies: {},
      runWhenTimeIsUndefined: false,
    },
    {
      tokens: true,
      tokenNamespace: "submitted",
    }
  );

  // views

  var element_maintenance_state = new SingleView(
    {
      id: "element_maintenance_state",
      drilldown: "none",
      colorMode: "block",
      "link.visible": "false",
      numberPrecision: "0",
      useColors: "0",
      underLabel: "MAINTENANCE MODE STATUS",
      colorBy: "value",
      height: "100",
      managerid: "search_maintenance_state",
      el: $("#element_maintenance_state"),
    },
    {
      tokens: true,
      tokenNamespace: "submitted",
    }
  ).render();

  var element_maintenance_state_reactivation = new SingleView(
    {
      id: "element_maintenance_state_reactivation",
      drilldown: "none",
      colorMode: "block",
      "link.visible": "false",
      numberPrecision: "0",
      useColors: "0",
      underLabel:
        "ESTIMATED DATE FOR AUTO-DEACTIVATION OF THE MAINTENANCE MODE",
      colorBy: "value",
      height: "60",
      managerid: "search_maintenance_state_reactivation",
      el: $("#element_maintenance_state_reactivation"),
    },
    {
      tokens: true,
      tokenNamespace: "submitted",
    }
  ).render();

  var element_maintenance_state_scheduled = new SingleView(
    {
      id: "element_maintenance_state_scheduled",
      drilldown: "none",
      colorMode: "block",
      "link.visible": "false",
      numberPrecision: "0",
      useColors: "0",
      underLabel: "MAINTENANCE MODE HAS BEEN SCHEDULED",
      colorBy: "value",
      height: "60",
      managerid: "search_maintenance_state_scheduled",
      el: $("#element_maintenance_state_scheduled"),
    },
    {
      tokens: true,
      tokenNamespace: "submitted",
    }
  ).render();

  //
  // BEGIN OPERATIONS
  //

  //
  // Handle html textarea
  //

  $(".custom-textarea").each(function () {
    var $text_group = $(this);
    $text_group.find("textarea").on("click", function () {
      var $text = $(this);
      if (this.value == this.defaultValue) this.value = "";
      $(this).blur(function () {
        if (this.value == "") this.value = this.defaultValue;
      });
    });
  });

  function get_maintenance_mode() {
    // Manage buttons states dynamically

    //
    // Verify the current status
    //

    // Endpoint URI
    var myendpoint_URl =
      "/en-US/splunkd/__raw/services/trackme/v2/maintenance/check_global_maintenance_status";

    //
    // Call TrackMe API endpoint
    //

    // API call
    $.ajax({
      url: myendpoint_URl,
      type: "GET",
      async: true,
      contentType: "application/json",
      success: function (returneddata) {
        // Refresh
        var current_maintenance_mode = returneddata["maintenance_mode"];

        // remove loader
        cssloaderremove();

        //
        if (!current_maintenance_mode) {
          $("#modal_loading_maintenance_mode_failure").modal();
          document.getElementById(
            "btn_main_enable_maintenance"
          ).disabled = true;
          document.getElementById(
            "btn_main_disable_maintenance"
          ).disabled = true;
          return;
        }

        // Dynamically manage buttons states
        if (current_maintenance_mode == "disabled") {
          // show btn enable
          $("#divEnableBtn").attr("style", "display: inherit !important");
          // hide btn disable
          $("#divDisableBtn").attr("style", "display: none !important");
          //
        } else if (current_maintenance_mode == "scheduled") {
          // hide btn enable
          $("#divEnableBtn").attr("style", "display: none !important");
          // show btn disable
          $("#divDisableBtn").attr("style", "display: inherit !important");
          //
        } else if (current_maintenance_mode == "enabled") {
          // hide btn enable
          $("#divEnableBtn").attr("style", "display: none !important");
          // show btn disable
          $("#divDisableBtn").attr("style", "display: inherit !important");
          //
        } else {
          // show btn enable
          $("#divEnableBtn").attr("style", "display: inherit !important");
          // show btn disable
          $("#divDisableBtn").attr("style", "display: inherit !important");
          //
        }

        // update content
        $("#divChildJsonPreview").html(
          '<pre class="json-preview">' +
            syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
            "</pre>"
        );

        // show json preview
        $("#divJsonPreview").css("display", "inherit");

        // auto-refresh
        setInterval(function () {
          $("#btn_refresh").click();
        }, 300000);

        //
      },
      error: function (xhr, textStatus, error) {
        $("#modal_update_collection_failure_return")
          .find(".modal-error-message p")
          .text(JSON.stringify(xhr));
        closeModals();
        $("#modal_update_collection_failure_return").modal();
      },
    });
    //
  }

  // splk-dsm refresh timer
  var IntervalId;
  var IntervalInfoId;

  function RefreshInfo() {
    clearInterval(IntervalInfoId);
    // release our intervalID from the variable
    IntervalInfoId = null;
    var myDate = new Date();
    var LastRefresh = document.getElementById("LastRefresh");
    function updateTime() {
      LastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
    }

    IntervalInfoId = setInterval(updateTime, 300000);
  }

  // splk-dsm get table
  function getMaintenanceStatus() {
    // avoid causing double interval
    clearInterval(IntervalId);
    // release our intervalID from the variable
    IntervalId = null;
    get_maintenance_mode();
    RefreshInfo();
  }

  // call now
  getMaintenanceStatus();

  //
  // REFRESH
  //

  $("#btn_refresh")
    .unbind()
    .click(function () {
      getMaintenanceStatus();
      // Update single
      search_maintenance_mode_mainsearch.startSearch();
      search_maintenance_state.startSearch();
    });

  //
  // ENABLE MAINTENANCE MODE BUTTON
  //

  // Open modal
  $("#btn_main_enable_maintenance")
    .unbind()
    .click(function () {
      // dates cannot be in the past
      var today = new Date().toISOString().slice(0, 16);
      document
        .getElementById("inputStartMaintenance")
        .setAttribute("min", today);
      document.getElementById("inputEndMaintenance").setAttribute("min", today);
      // open modal
      $("#modal_enable_maintenance").modal();
    });

  // Proceed
  $("#btn_confirm_enable_maintenance")
    .unbind()
    .click(function () {
      // Retrieve start date
      var inputStartMaintenance = document.getElementById(
        "inputStartMaintenance"
      ).value;

      // Retrieve end date
      var inputEndMaintenance = document.getElementById(
        "inputEndMaintenance"
      ).value;

      if (inputStartMaintenance && inputEndMaintenance) {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/maintenance/global_maintenance_enable";
        var record = {
          time_format: "datestring",
          maintenance_mode_start: inputStartMaintenance,
          maintenance_mode_end: inputEndMaintenance,
          update_comment: getComment("input_enable_comment"),
        };

        //
        // Call TrackMe API endpoint
        //

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Refresh

            // Update single
            search_maintenance_mode_mainsearch.startSearch();
            search_maintenance_state.startSearch();

            // hide btn enable
            $("#divEnableBtn").attr("style", "display: none !important");
            // show btn disable
            $("#divDisableBtn").attr("style", "display: inherit !important");

            // refresh info
            getMaintenanceStatus();

            // Show final modal
            var current_status = returneddata["maintenance_mode"];
            if (current_status === "enabled") {
              $("#modal_maintenance_mode_confirmed").modal();
            } else if (current_status === "scheduled") {
              $("#modal_maintenance_mode_scheduled").modal();
            }
          },
          error: function (xhr, textStatus, error) {
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      }

      // end modal calendar selection
    });

  //
  // DISABLE MAINTENANCE MODE BUTTON
  //

  // Open modal
  $("#btn_main_disable_maintenance")
    .unbind()
    .click(function () {
      $("#modal_disable_maintenance").modal();
    });

  // Proceed
  $("#btn_confirm_disable_maintenance")
    .unbind()
    .unbind()
    .click(function () {
      // Endpoint URI
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/maintenance/maintenance_disable";
      var record = {
        update_comment: getComment("input_disable_comment"),
      };

      //
      // Call TrackMe API endpoint
      //

      // API call
      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        data: JSON.stringify(record),
        success: function (returneddata) {
          // Refresh

          // Update single
          search_maintenance_mode_mainsearch.startSearch();
          search_maintenance_state.startSearch();

          // show btn enable
          $("#divEnableBtn").attr("style", "display: inherit !important");
          // disable btn disable
          $("#divDisableBtn").attr("style", "display: none !important");

          // refresh info
          getMaintenanceStatus();

          // Show final modal
          $("#modal_maintenance_mode_disabled").modal();
        },
        error: function (xhr, textStatus, error) {
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(JSON.stringify(xhr));
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });
    });

  //
  // END
  //
});
