# encoding = utf-8

import os, sys
import requests
import json
import urllib3

# disable urllib3 warnings for SSL
urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)

# set splunkhome
splunkhome = os.environ["SPLUNK_HOME"]

# append libs
sys.path.append(os.path.join(splunkhome, "etc", "apps", "trackme", "lib"))


def process_event(helper, *args, **kwargs):
    helper.log_info("Alert action trackme_auto_ack started.")

    # Retrieve the session_key
    helper.log_debug("Get session_key.")
    session_key = helper.session_key

    # Retrieve the server_uri
    helper.log_debug("Get server_uri.")
    server_uri = helper.settings["server_uri"]

    tenant_id = helper.get_param("tenant_id")
    helper.log_debug(f"tenant_id={tenant_id}")

    object_category = helper.get_param("object_category")
    helper.log_debug(f"object_category={object_category}")

    object_name = helper.get_param("object_name")
    helper.log_debug(f"object_name={object_name}")

    ack_period = helper.get_param("ack_period")
    helper.log_debug(f"ack_period={ack_period}")

    ack_type = helper.get_param("ack_type")
    helper.log_debug(f"ack_type={ack_type}")

    # endpoint url
    endpoint_url = "/services/trackme/v2/ack/ack_manage"

    # build body
    body = {
        "tenant_id": str(tenant_id),
        "action": "enable",
        "object_category": str(object_category),
        "object_list": str(object_name),
        "ack_period": str(ack_period),
        "ack_type": str(ack_type),
        "update_comment": "alert action auto-acknowledgement",
    }

    helper.log_info(
        f'tenant_id="{tenant_id}", Running TrackMe auto-acknowledgement, body="{json.dumps(body, indent=1)}"'
    )

    # build header and target
    header = {
        "Authorization": f"Splunk {session_key}",
        "Content-Type": "application/json",
    }
    target_url = f"{server_uri}/{endpoint_url}"

    # Post to Ack endpoint
    try:
        response = requests.post(
            target_url,
            headers=header,
            verify=False,
            data=json.dumps(body),
            timeout=300,
        )
        if response.status_code == 200:
            helper.log_info(
                f'tenant="{tenant_id}", response="{json.dumps(json.loads(response.text))}"'
            )
            return 0
        else:
            helper.log_error(
                f'tenant_id="{tenant_id}", TrackMe auto acknowledgement action has failed, http_error_code="{response.status_code}", data="{json.dumps(body, indent=2)}", response="{response.text}"'
            )
    except Exception as e:
        helper.log_error(
            f'tenant_id="{tenant_id}", TrackMe auto acknowledgement alert action has failed, exception="{e}"'
        )
