# encoding = utf-8

import os
import sys
import json
import time
from datetime import datetime
import splunklib.client as client
import urllib3

urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
splunkhome = os.environ["SPLUNK_HOME"]
sys.path.append(os.path.join(splunkhome, "etc", "apps", "trackme", "lib"))

from trackme_libs import trackme_reqinfo, trackme_idx_for_tenant, trackme_state_event


def get_splunk_service(helper, session_key, server_uri):
    reqinfo = trackme_reqinfo(session_key, server_uri)
    return client.connect(
        owner="nobody",
        app="trackme",
        port=reqinfo["server_rest_port"],
        token=session_key,
        timeout=300,
    )


def process_event(helper, *args, **kwargs):
    # Helper functions
    def extract_event_field(event, field, default="Unknown"):
        try:
            return event[field]
        except KeyError:
            helper.log_warn(f'Failed to extract field "{field}" from record="{event}"')
            return default

    def create_notable_record(event):
        properties = {
            k: event[k] for k in event if event[k] != "null" and not k.startswith("__")
        }
        return {
            "_time": time.time(),
            "timeStr": str(datetime.now()),
            "tenant_id": event["tenant_id"],
            "object": event["object"],
            "object_category": event["object_category"],
            "keyid": event["keyid"],
            "priority": event["priority"],
            "state": extract_event_field(event, "object_state"),
            "anomaly_reason": extract_event_field(event, "anomaly_reason"),
            "status_message": extract_event_field(event, "status_message"),
            "properties": properties,
        }

    helper.log_info("Alert action trackme_notable started.")

    session_key = helper.session_key
    server_uri = helper.settings["server_uri"]
    title = helper.get_param("title") or "trackme:notable"

    for event in helper.get_events():
        tenant_id = event["tenant_id"]
        tenant_idx = trackme_idx_for_tenant(session_key, server_uri, tenant_id)
        tenant_trackme_notable_idx = tenant_idx["trackme_notable_idx"]

        notable_record = create_notable_record(event)

        try:
            trackme_state_event(
                session_key=session_key,
                splunkd_uri=server_uri,
                tenant_id=tenant_id,
                index=tenant_trackme_notable_idx,
                sourcetype="trackme:notable",
                source=title,
                record=notable_record,
            )
            helper.log_info(
                f'tenant_id="{notable_record.get("tenant_id")}", object_category="{notable_record.get("object_category")}", object="{notable_record.get("object")}", Notable event created successfully, response="{json.dumps(notable_record, indent=2)}"'
            )
            return 0
        except Exception as e:
            helper.log_error(
                f'tenant_id="{notable_record.get("tenant_id")}", object_category="{notable_record.get("object_category")}", object="{notable_record.get("object")}", Notable event creation failure, response="{json.dumps(notable_record, indent=2)}", exception="{str(e)}"'
            )
            return 1
