
import import_declare_test

from splunktaucclib.rest_handler.endpoint import (
    field,
    validator,
    RestModel,
    MultipleModel,
)
from splunktaucclib.rest_handler import admin_external, util
from splunktaucclib.rest_handler.admin_external import AdminExternalHandler
import logging

util.remove_http_proxy_env_vars()


fields_trackme_general = [
    field.RestField(
        'trackme_default_sharing',
        required=True,
        encrypted=False,
        default='app',
        validator=None
    ), 
    field.RestField(
        'trackme_owner_default',
        required=True,
        encrypted=False,
        default='admin',
        validator=validator.Pattern(
            regex=r"""^.*$""", 
        )
    ), 
    field.RestField(
        'trackme_admin_role_default',
        required=True,
        encrypted=False,
        default='trackme_admin',
        validator=validator.Pattern(
            regex=r"""^.*$""", 
        )
    ), 
    field.RestField(
        'trackme_power_role_default',
        required=True,
        encrypted=False,
        default='trackme_power',
        validator=validator.Pattern(
            regex=r"""^.*$""", 
        )
    ), 
    field.RestField(
        'trackme_user_role_default',
        required=True,
        encrypted=False,
        default='trackme_power',
        validator=validator.Pattern(
            regex=r"""^.*$""", 
        )
    ), 
    field.RestField(
        'state_events_minimal',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'state_events_allowlist',
        required=True,
        encrypted=False,
        default='alias,anomaly_reason,keyid,object,object_category,priority,state,status_message,tenant_id',
        validator=None
    ), 
    field.RestField(
        'state_events_blocklist',
        required=True,
        encrypted=False,
        default='_raw,info_max_time,info_min_time,info_search_time,info_sid,splk_dhm_st_summary,splk_dhm_st_summary_compact,splk_dhm_st_summary_full,metric_details,object_state,tracker_runtime,previous_tracker_runtime',
        validator=None
    ), 
    field.RestField(
        'allow_admin_operations',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'enable_conf_manager_receiver',
        required=True,
        encrypted=False,
        default='0',
        validator=None
    ), 
    field.RestField(
        'trackme_ack_duration_default',
        required=True,
        encrypted=False,
        default='86400',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'trackme_ack_remove_when_green',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'trackme_future_tolerance',
        required=True,
        encrypted=False,
        default='-600',
        validator=validator.Pattern(
            regex=r"""^\-[0-9]*$""", 
        )
    ), 
    field.RestField(
        'trackme_auto_disablement_period',
        required=True,
        encrypted=False,
        default='45d',
        validator=validator.Pattern(
            regex=r"""^[0-9]*d$""", 
        )
    )
]
model_trackme_general = RestModel(fields_trackme_general, name='trackme_general')


fields_index_settings = [
    field.RestField(
        'trackme_idx_search_filter',
        required=True,
        encrypted=False,
        default='trackme_*',
        validator=validator.Pattern(
            regex=r"""^.*$""", 
        )
    ), 
    field.RestField(
        'trackme_notable_idx',
        required=True,
        encrypted=False,
        default='trackme_notable',
        validator=validator.String(
            max_len=80, 
            min_len=1, 
        )
    ), 
    field.RestField(
        'trackme_summary_idx',
        required=True,
        encrypted=False,
        default='trackme_summary',
        validator=validator.String(
            max_len=80, 
            min_len=1, 
        )
    ), 
    field.RestField(
        'trackme_metric_idx',
        required=True,
        encrypted=False,
        default='trackme_metrics',
        validator=validator.String(
            max_len=80, 
            min_len=1, 
        )
    ), 
    field.RestField(
        'trackme_audit_idx',
        required=True,
        encrypted=False,
        default='trackme_audit',
        validator=validator.String(
            max_len=80, 
            min_len=1, 
        )
    )
]
model_index_settings = RestModel(fields_index_settings, name='index_settings')


fields_trackme_theme_default = [
    field.RestField(
        'icons_state_mode',
        required=True,
        encrypted=False,
        default='brown',
        validator=None
    ), 
    field.RestField(
        'flex_width_default',
        required=True,
        encrypted=False,
        default='374',
        validator=validator.Pattern(
            regex=r"""^\d*$""", 
        )
    ), 
    field.RestField(
        'flex_show_desc',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'flex_show_summary',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'color_theme_default',
        required=True,
        encrypted=False,
        default='dodgerblue',
        validator=None
    ), 
    field.RestField(
        'color_dyn_default',
        required=True,
        encrypted=False,
        default='0',
        validator=None
    ), 
    field.RestField(
        'color_dyn_condition',
        required=True,
        encrypted=False,
        default='high_priority',
        validator=None
    ), 
    field.RestField(
        'color_theme_red_default',
        required=True,
        encrypted=False,
        default='brown',
        validator=None
    ), 
    field.RestField(
        'show_tenants_mgmt_header',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    )
]
model_trackme_theme_default = RestModel(fields_trackme_theme_default, name='trackme_theme_default')


fields_trackme_home_theme_default = [
    field.RestField(
        'icons_state_mode',
        required=True,
        encrypted=False,
        default='brown',
        validator=None
    )
]
model_trackme_home_theme_default = RestModel(fields_trackme_home_theme_default, name='trackme_home_theme_default')


fields_splk_general = [
    field.RestField(
        'splk_general_idx_filter',
        required=True,
        encrypted=False,
        default='host=*',
        validator=validator.Pattern(
            regex=r"""^.+$""", 
        )
    ), 
    field.RestField(
        'splk_general_dsm_threshold_default',
        required=True,
        encrypted=False,
        default='3600',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'splk_general_dsm_delay_default',
        required=True,
        encrypted=False,
        default='3600',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'splk_general_dhm_threshold_default',
        required=True,
        encrypted=False,
        default='3600',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'splk_general_dhm_delay_default',
        required=True,
        encrypted=False,
        default='3600',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'splk_general_mhm_threshold_default',
        required=True,
        encrypted=False,
        default='900',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'splk_general_elastic_max_concurrent',
        required=True,
        encrypted=False,
        default='3',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'splk_general_dsm_cmdb_search',
        required=True,
        encrypted=False,
        default='| inputlookup my_cmdb where (index="$data_index$" AND sourcetype="$data_sourcetype$")',
        validator=None
    ), 
    field.RestField(
        'splk_general_dhm_cmdb_search',
        required=True,
        encrypted=False,
        default='| inputlookup my_cmdb where (host="$alias$")',
        validator=None
    ), 
    field.RestField(
        'splk_general_mhm_cmdb_search',
        required=True,
        encrypted=False,
        default='| inputlookup my_cmdb where (host="$alias$")',
        validator=None
    ), 
    field.RestField(
        'splk_general_cim_cmdb_search',
        required=True,
        encrypted=False,
        default='| inputlookup my_cmdb where (object="$object$")',
        validator=None
    ), 
    field.RestField(
        'splk_general_flx_cmdb_search',
        required=True,
        encrypted=False,
        default='| inputlookup my_cmdb where (object="$object$")',
        validator=None
    ), 
    field.RestField(
        'splk_general_wlk_cmdb_search',
        required=True,
        encrypted=False,
        default='| inputlookup my_cmdb where (savedsearch_name="$savedsearch_name$")',
        validator=None
    )
]
model_splk_general = RestModel(fields_splk_general, name='splk_general')


fields_splk_data_sampling = [
    field.RestField(
        'splk_data_sampling_default_sample_record_at_discovery',
        required=True,
        encrypted=False,
        default='100',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    ), 
    field.RestField(
        'splk_data_sampling_default_sample_record_at_run',
        required=True,
        encrypted=False,
        default='50',
        validator=validator.Pattern(
            regex=r"""^[0-9]*$""", 
        )
    )
]
model_splk_data_sampling = RestModel(fields_splk_data_sampling, name='splk_data_sampling')


fields_splk_outliers_detection = [
    field.RestField(
        'splk_outliers_min_days_history',
        required=True,
        encrypted=False,
        default='7',
        validator=validator.Pattern(
            regex=r"""^\d*$""", 
        )
    ), 
    field.RestField(
        'splk_outliers_time_train_mlmodels_default',
        required=True,
        encrypted=False,
        default='604800',
        validator=validator.Pattern(
            regex=r"""^\d*$""", 
        )
    ), 
    field.RestField(
        'splk_outliers_time_monitor_mlmodels_default',
        required=True,
        encrypted=False,
        default='3600',
        validator=validator.Pattern(
            regex=r"""^\d*$""", 
        )
    ), 
    field.RestField(
        'splk_outliers_max_runtime_train_mlmodels_default',
        required=True,
        encrypted=False,
        default='900',
        validator=validator.Pattern(
            regex=r"""^\d*$""", 
        )
    ), 
    field.RestField(
        'splk_outliers_detection_disable_default',
        required=True,
        encrypted=False,
        default='0',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_calculation_default',
        required=True,
        encrypted=False,
        default='stdev',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_density_lower_threshold_default',
        required=True,
        encrypted=False,
        default='0.005',
        validator=validator.Pattern(
            regex=r"""^[\d|\.]*$""", 
        )
    ), 
    field.RestField(
        'splk_outliers_density_upper_threshold_default',
        required=True,
        encrypted=False,
        default='0.005',
        validator=validator.Pattern(
            regex=r"""^[\d|\.]*$""", 
        )
    ), 
    field.RestField(
        'splk_outliers_alert_lower_threshold_volume_default',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_alert_upper_threshold_volume_default',
        required=True,
        encrypted=False,
        default='0',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_alert_lower_threshold_latency_default',
        required=True,
        encrypted=False,
        default='0',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_alert_upper_threshold_latency_default',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_detection_period_default',
        required=True,
        encrypted=False,
        default='-30d',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_detection_timefactor_default',
        required=True,
        encrypted=False,
        default='-30d',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_detection_latency_kpi_metric_default',
        required=True,
        encrypted=False,
        default='splk.feeds.avg_latency_5m',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_detection_volume_kpi_metric_default',
        required=True,
        encrypted=False,
        default='splk.feeds.avg_eventcount_5m',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_auto_correct',
        required=True,
        encrypted=False,
        default='1',
        validator=None
    ), 
    field.RestField(
        'splk_outliers_perc_min_lowerbound_deviation_default',
        required=True,
        encrypted=False,
        default='5.0',
        validator=validator.Pattern(
            regex=r"""^\d*\.\d*$""", 
        )
    ), 
    field.RestField(
        'splk_outliers_perc_min_upperbound_deviation_default',
        required=True,
        encrypted=False,
        default='5.0',
        validator=validator.Pattern(
            regex=r"""^\d*\.\d*$""", 
        )
    )
]
model_splk_outliers_detection = RestModel(fields_splk_outliers_detection, name='splk_outliers_detection')


fields_maintenance = [
    field.RestField(
        'maintenance_kdb_exclusion_behaviour',
        required=True,
        encrypted=False,
        default='planned',
        validator=None
    )
]
model_maintenance = RestModel(fields_maintenance, name='maintenance')


fields_logging = [
    field.RestField(
        'loglevel',
        required=True,
        encrypted=False,
        default='INFO',
        validator=None
    )
]
model_logging = RestModel(fields_logging, name='logging')


endpoint = MultipleModel(
    'trackme_settings',
    models=[
        model_trackme_general, 
        model_index_settings, 
        model_trackme_theme_default, 
        model_trackme_home_theme_default, 
        model_splk_general, 
        model_splk_data_sampling, 
        model_splk_outliers_detection, 
        model_maintenance, 
        model_logging
    ],
)


if __name__ == '__main__':
    logging.getLogger().addHandler(logging.NullHandler())
    admin_external.handle(
        endpoint,
        handler=AdminExternalHandler,
    )
