#!/usr/bin/env python
# coding=utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

__author__ = "TrackMe Limited"
__copyright__ = "Copyright 2023-2024, TrackMe Limited, U.K."
__credits__ = "TrackMe Limited, U.K."
__license__ = "TrackMe Limited, all rights reserved"
__version__ = "0.1.0"
__maintainer__ = "TrackMe Limited, U.K."
__email__ = "support@trackme-solutions.com"
__status__ = "PRODUCTION"

# default vtenant account configuration settings
vtenant_account_default = {
    "ui_min_object_width": 300,
    "data_sampling_set_state": 1,
    "outliers_set_state": 1,
    "data_sampling_obfuscation": 0,
}

# dict of collections
collections_dict = dict(
    [
        (
            "trackme_dsm",
            "_key, mtime, search_mode, tenant_id, object_category, alias, data_index, data_last_lag_seen, data_last_ingestion_lag_seen, data_eventcount, data_last_lag_seen_idx, data_first_time_seen, data_last_time_seen, data_last_ingest, data_last_time_seen_idx, data_max_lag_allowed, data_max_delay_allowed, future_tolerance, data_lag_alert_kpis, monitored_state, object, data_sourcetype, data_monitoring_wdays, isUnderMonitoringDays, data_monitoring_hours_ranges, isUnderMonitoringHours, data_override_lagging_class, allow_adaptive_delay, object_state, tracker_runtime, object_previous_state, data_previous_tracker_runtime, dcount_host, min_dcount_host, min_dcount_field, min_dcount_threshold, avg_dcount_host_5m, latest_dcount_host_5m, perc95_dcount_host_5m, stdev_dcount_host_5m, isAnomaly, data_sample_lastrun, tags, tags_manual, tags_auto, latest_flip_state, latest_flip_time, priority, status_message, anomaly_reason, outliers_readiness, tenant_parent",
        ),
        (
            "trackme_dsm_elastic_shared",
            "_key, object, alias, search_constraint, search_mode, elastic_index, elastic_sourcetype, earliest, latest",
        ),
        (
            "trackme_dsm_elastic_dedicated",
            "_key, object, alias, search_constraint, search_mode, elastic_index, elastic_sourcetype, elastic_wrapper, elastic_report",
        ),
        ("trackme_dsm_hybrid_trackers", "_key, tracker_name, knowledge_objects"),
        ("trackme_dsm_allowlist", "_key, object_category, object, is_rex, action"),
        (
            "trackme_dsm_data_sampling",
            "_key, object, raw_sample, data_sampling_nr, data_sample_mtime, data_sample_feature, data_sample_iteration, data_sample_anomaly_reason, data_sample_status_colour, data_sample_anomaly_ack_status, data_sample_anomaly_ack_mtime, data_sample_anomaly_detected, data_sample_status_message, multiformat_detected, current_detected_format, current_detected_format_id, current_detected_format_dcount, previous_detected_format, previous_detected_format_id, previous_detected_format_dcount",
        ),
        (
            "trackme_dsm_data_sampling_custom_models",
            "_key, model_id, model_name, model_regex, model_type, sourcetype_scope, mtime",
        ),
        ("trackme_dsm_knowledge", "_key, object, doc_link, doc_note"),
        (
            "trackme_dsm_outliers_entity_rules",
            "_key, object_category, object, mtime, is_disabled, entities_outliers, last_exec, confidence, confidence_reason",
        ),
        (
            "trackme_dsm_outliers_entity_data",
            "_key, object_category, object, mtime, isOutlier, isOutlierReason, models_in_anomaly, models_summary",
        ),
        (
            "trackme_common_tag_policies",
            "_key, tags_policy_id, tags_policy_value, tags_policy_regex, mtime",
        ),
        (
            "trackme_cim",
            "_key, mtime, tenant_id, object, alias, monitored_state, cim_tracking_rules, cim_tracking_results, object_state, account, monitoring_wdays, isUnderMonitoringDays, monitoring_hours_ranges, isUnderMonitoringHours, tracker_name, tracker_runtime, tracker_last_duration, latest_flip_state, latest_flip_time, priority, anomaly_reason, outliers_readiness, tenant_parent",
        ),
        (
            "trackme_cim_simulation",
            "_key, tenant_id, object, alias, monitored_state, cim_tracking_rules, cim_tracking_results, object_state, account, monitoring_wdays, isUnderMonitoringDays, monitoring_hours_ranges, isUnderMonitoringHours, tracker_name, tracker_runtime, tracker_last_duration, latest_flip_state, latest_flip_time, priority, anomaly_reason",
        ),
        (
            "trackme_cim_outliers_entity_rules",
            "_key, object_category, object, entity, cim_field, mtime, is_disabled, entities_outliers, last_exec, confidence, confidence_reason",
        ),
        (
            "trackme_cim_outliers_entity_data",
            "_key, object_category, object, entity, cim_field, mtime, isOutlier, isOutlierReason, models_in_anomaly, models_summary",
        ),
        (
            "trackme_flx",
            "_key, mtime, tenant_id, group, object, object_category, object_state, object_description, alias, monitored_state, account, tracker_name, tracker_runtime, status, status_description, metrics, outliers_metrics, extra_attributes, monitoring_wdays, isUnderMonitoringDays, monitoring_hours_ranges, isUnderMonitoringHours, latest_flip_state, latest_flip_time, priority, status_message, anomaly_reason, outliers_readiness, tenant_parent, max_sec_inactive",
        ),
        (
            "trackme_flx_hybrid_trackers",
            "_key, tracker_id, tracker_name, knowledge_objects",
        ),
        (
            "trackme_flx_outliers_entity_rules",
            "_key, object_category, object, mtime, is_disabled, entities_outliers, last_exec, confidence, confidence_reason",
        ),
        (
            "trackme_flx_outliers_entity_data",
            "_key, object_category, object, mtime, isOutlier, isOutlierReason, models_in_anomaly, models_summary",
        ),
        (
            "trackme_wlk",
            "_key, mtime, tenant_id, overgroup, group, app, user, savedsearch_name, object, object_category, object_state, object_description, alias, monitored_state, account, tracker_name, tracker_runtime, status, status_description, metrics, metrics_extended, outliers_metrics, monitoring_wdays, isUnderMonitoringDays, monitoring_hours_ranges, isUnderMonitoringHours, first_seen, last_seen, sec_since_lastexec, latest_flip_state, latest_flip_time, priority, tags, status_message, anomaly_reason, outliers_readiness, tenant_parent",
        ),
        (
            "trackme_wlk_hybrid_trackers",
            "_key, tracker_id, tracker_name, knowledge_objects",
        ),
        (
            "trackme_wlk_outliers_entity_rules",
            "_key, object_category, object, mtime, is_disabled, entities_outliers, last_exec, confidence, confidence_reason",
        ),
        (
            "trackme_wlk_outliers_entity_data",
            "_key, object_category, object, mtime, isOutlier, isOutlierReason, models_in_anomaly, models_summary",
        ),
        (
            "trackme_wlk_versioning",
            "_key, mtime, object, version_dict, description, current_version_id, cron_exec_sequence_sec",
        ),
        ("trackme_wlk_orphan_status", "_key, mtime, object, user, app, orphan"),
        ("trackme_wlk_apps_enablement", "_key, mtime, app, enabled"),
        (
            "trackme_wlk_last_seen_activity",
            "_key, account, object, last_seen_scheduler, last_seen_introspection, last_seen_notable, last_seen_splunkcloud_svc",
        ),
        (
            "trackme_dhm",
            "_key, mtime, search_mode, tenant_id, object_category, object, alias, data_index, data_sourcetype, data_last_lag_seen, data_last_ingestion_lag_seen, data_eventcount, data_first_time_seen, data_last_time_seen, data_last_ingest, data_max_lag_allowed, data_max_delay_allowed, future_tolerance, data_lag_alert_kpis, monitored_state, data_monitoring_wdays, isUnderMonitoringDays, data_monitoring_hours_ranges, isUnderMonitoringHours, data_override_lagging_class, allow_adaptive_delay, object_state, tracker_runtime, object_previous_state, data_previous_tracker_runtime, splk_dhm_st_summary, splk_dhm_st_summary_full, splk_dhm_st_summary_compact, splk_dhm_st_summary_minimal, splk_dhm_alerting_policy, latest_flip_state, latest_flip_time, priority, status_message, anomaly_reason, outliers_readiness, tenant_parent",
        ),
        ("trackme_dhm_allowlist", "_key, object_category, object, action"),
        (
            "trackme_dhm_outliers_entity_rules",
            "_key, object_category, object, mtime, is_disabled, entities_outliers, last_exec, confidence, confidence_reason",
        ),
        (
            "trackme_dhm_outliers_entity_data",
            "_key, object_category, object, mtime, isOutlier, isOutlierReason, models_in_anomaly, models_summary",
        ),
        ("trackme_dhm_hybrid_trackers", "_key, tracker_name, knowledge_objects"),
        (
            "trackme_mhm",
            "_key, mtime, tenant_id, object_category, object, alias, metric_index, metric_category, metric_details, metric_details_full, metric_details_compact, metric_details_minimal, metric_last_lag_seen, metric_first_time_seen, metric_last_time_seen, metric_max_lag_allowed, monitored_state, metric_monitoring_wdays, metric_override_lagging_class, object_state, tracker_runtime, object_previous_state, metric_previous_tracker_runtime, latest_flip_state, latest_flip_time, priority, status_message, anomaly_reason, tenant_parent",
        ),
        ("trackme_mhm_allowlist", "_key, object_category, object, action"),
        (
            "trackme_common_lagging_classes",
            "_key, level, name, object, value_lag, value_delay",
        ),
        (
            "trackme_mhm_lagging_classes",
            "_key, metric_category, metric_max_lag_allowed",
        ),
        ("trackme_mhm_hybrid_trackers", "_key, tracker_name, knowledge_objects"),
        (
            "trackme_common_audit_changes",
            "_key, time, action, change_type, object, object_category, object_attrs, user, result, comment",
        ),
        (
            "trackme_common_alerts_ack",
            "_key, object, object_category, ack_mtime, ack_expiration, ack_state, ack_type, ack_comment",
        ),
        (
            "trackme_common_logical_group",
            "_key, object_group_name, object_group_min_green_percent, object_group_members, object_group_mtime",
        ),
        (
            "trackme_common_permanently_deleted_objects",
            "_key, object, object_category, ctime",
        ),
        (
            "trackme_common_datagen_cache",
            "_key, component, target, search_str, regex, addprefix, fields",
        ),
        ("trackme_common_replica_trackers", "_key, tracker_name, knowledge_objects"),
    ]
)

# DSM
collections_list_dsm = [
    "trackme_dsm",
    "trackme_dsm_elastic_shared",
    "trackme_dsm_elastic_dedicated",
    "trackme_dsm_hybrid_trackers",
    "trackme_dsm_allowlist",
    "trackme_dsm_data_sampling",
    "trackme_dsm_data_sampling_custom_models",
    "trackme_dsm_knowledge",
    "trackme_dsm_outliers_entity_rules",
    "trackme_dsm_outliers_entity_data",
    "trackme_common_tag_policies",
]

# CIM
collections_list_cim = [
    "trackme_cim",
    "trackme_cim_simulation",
    "trackme_cim_outliers_entity_rules",
    "trackme_cim_outliers_entity_data",
]

# FLX
collections_list_flx = [
    "trackme_flx",
    "trackme_flx_hybrid_trackers",
    "trackme_flx_outliers_entity_rules",
    "trackme_flx_outliers_entity_data",
]

# DHM
collections_list_dhm = [
    "trackme_dhm",
    "trackme_dhm_allowlist",
    "trackme_dhm_outliers_entity_rules",
    "trackme_dhm_outliers_entity_data",
    "trackme_dhm_hybrid_trackers",
]

# MHM
collections_list_mhm = [
    "trackme_mhm",
    "trackme_mhm_allowlist",
    "trackme_mhm_lagging_classes",
    "trackme_mhm_hybrid_trackers",
]

# WLK
collections_list_wlk = [
    "trackme_wlk",
    "trackme_wlk_hybrid_trackers",
    "trackme_wlk_outliers_entity_rules",
    "trackme_wlk_outliers_entity_data",
    "trackme_wlk_versioning",
    "trackme_wlk_orphan_status",
    "trackme_wlk_apps_enablement",
    "trackme_wlk_last_seen_activity",
]

# COMMON
collections_list_common = [
    "trackme_common_lagging_classes",
    "trackme_common_audit_changes",
    "trackme_common_alerts_ack",
    "trackme_common_logical_group",
    "trackme_common_permanently_deleted_objects",
    "trackme_common_datagen_cache",
    "trackme_common_replica_trackers",
]
