#!/usr/bin/env python
# coding=utf-8

from __future__ import absolute_import, division, print_function, unicode_literals

__author__ = "TrackMe Limited"
__copyright__ = "Copyright 2023-2024, TrackMe Limited, U.K."
__credits__ = "TrackMe Limited, U.K."
__license__ = "TrackMe Limited, all rights reserved"
__version__ = "0.1.0"
__maintainer__ = "TrackMe Limited, U.K."
__email__ = "support@trackme-solutions.com"
__status__ = "PRODUCTION"

# Standard library imports
import os
import sys

# splunk home
splunkhome = os.environ["SPLUNK_HOME"]

# append lib
sys.path.append(os.path.join(splunkhome, "etc", "apps", "trackme", "lib"))


# A simple function to clean up empty chars at the beginning of each line of a var
def remove_leading_spaces(text):
    # split the text into lines, remove leading spaces from each line, and rejoin them
    cleaned_text = "\n".join([line.lstrip() for line in text.split("\n")])
    return cleaned_text


# A simple function to decode non unicode strings
def decode_unicode(s):
    """If string contains escaped bytes, decode it."""
    if isinstance(s, bytes):  # Check if it's already bytes
        return s.decode("utf-8")

    # Check if it has the escape sequence, and if so, decode it
    if "\\x" in s:
        try:
            return (
                bytes(s, "latin-1")
                .decode("unicode_escape")
                .encode("latin-1")
                .decode("utf-8")
            )
        except:
            pass  # If any error occurs, just pass and return the original string

    return s


# Function to interpret the boolean value:
# if the value is 1 or true (case insensitive), return True, otherwise return False
def interpret_boolean(value):
    if isinstance(value, bool):
        return value
    elif isinstance(value, str):
        if value.lower() == "true" or value == "1":
            return True
        else:
            return False
    elif isinstance(value, int):
        if value == 1:
            return True
        else:
            return False
    else:
        return False
