const { Callbacks, getJSON, get } = require("jquery");

require([
  "jquery",
  "underscore",
  "splunkjs/mvc",
  "splunkjs/mvc/utils",
  "splunkjs/mvc/searchcontrolsview",
  "splunkjs/mvc/searchmanager",
  "splunkjs/mvc/postprocessmanager",
  "splunkjs/mvc/dropdownview",
  "splunkjs/mvc/multidropdownview",
  "splunkjs/mvc/tableview",
  "splunkjs/mvc/eventsviewerview",
  "splunkjs/mvc/textinputview",
  "splunkjs/mvc/singleview",
  "splunkjs/mvc/chartview",
  "splunkjs/mvc/resultslinkview",
  "splunkjs/mvc/simplexml/searcheventhandler",
  "splunkjs/mvc/visualizationregistry",
  "splunkjs/mvc/simpleform/input/linklist",
  "splunkjs/mvc/simpleform/input/text",
  "splunkjs/mvc/simpleform/input/timerange",
  "splunkjs/mvc/simpleform/input/multiselect",
  "splunkjs/mvc/simpleform/input/dropdown",
  "splunkjs/mvc/simpleform/input/checkboxgroup",
  "splunkjs/mvc/simplexml/element/table",
  "splunkjs/mvc/simplexml/element/single",
  "splunkjs/mvc/simplexml/element/event",
  "splunkjs/mvc/simplexml/element/visualization",
  "splunkjs/mvc/simpleform/formutils",
  "splunkjs/mvc/simplexml/eventhandler",
  "splunkjs/mvc/simplexml/searcheventhandler",
  "/static/app/trackme/tabulator/js/tabulator.js",
  "/static/app/trackme/momentjs/moment.js",
  "splunkjs/mvc/simplexml/ready!",
], function (
  $,
  _,
  mvc,
  utils,
  SearchControlsView,
  SearchManager,
  PostProcessManager,
  DropdownView,
  MultiDropdownView,
  TableView,
  EventsViewer,
  TextInputView,
  SingleView,
  ChartView,
  ResultsLinkView,
  SearchEventHandler,
  VisualizationRegistry,
  LinkListInput,
  TextInput,
  TimeRangeInput,
  MultiSelectInput,
  DropdownInput,
  CheckboxGroupInput,
  TableElement,
  VisualizationElement,
  SingleElement,
  EventElement,
  FormUtils,
  EventHandler,
  SearchEventHandler,
  TabulatorFull,
  moment
) {
  //
  // ajax promise for API calls
  //

  async function asyncAjax(ajaxurl, ajaxType, ajaxdata) {
    var resultCall;
    try {
      resultCall = await $.ajax({
        url: ajaxurl,
        type: ajaxType,
        data: JSON.stringify(ajaxdata),
      });
      return resultCall;
    } catch (error) {
      closeModals();
      $("#modal_update_collection_failure_return")
        .find(".modal-error-message p")
        .text(JSON.stringify(error));
      $("#modal_update_collection_failure_return").modal();
    }
  }

  var doAsync = asyncAjax(
    "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
    "GET"
  ).then(function (licenseCall) {
    var license_is_valid = licenseCall["license_is_valid"];
    var license_active_hybrid_trackers =
      licenseCall["license_active_hybrid_trackers"];
    var license_subscription_class = licenseCall["license_subscription_class"];

    // TOKENS

    var defaultTokenModel = mvc.Components.getInstance("default", {
      create: true,
    });

    var submittedTokenModel = mvc.Components.getInstance("submitted", {
      create: true,
    });

    function setToken(name, value) {
      defaultTokenModel.set(name, value);
      submittedTokenModel.set(name, value);
    }

    function getToken(name) {
      var ret = null;
      if (defaultTokenModel.get(name) != undefined) {
        ret = defaultTokenModel.get(name);
      } else if (submittedTokenModel.get(name) != undefined) {
        ret = submittedTokenModel.get(name);
      }
      return ret;
    }

    function unsetToken(name) {
      defaultTokenModel.unset(name);
      submittedTokenModel.unset(name);
    }

    //
    // tenant_id
    //

    // immediately save the origin tenant_id
    setToken("root_tenant_id", getToken("tenant_id"));

    // Update the banner tenant
    $("#infoBannerTenant").html(
      '<h1 style="margin-top: -2px;"">' + getToken("tenant_id") + "</h1>"
    );
    $("#tenant-banner-loader").css("display", "none");

    //
    // FUNCTIONS
    //

    //
    // Get comment from textaread
    //

    function getComment(inputId) {
      // Retrieve update comment if any
      var tk_comment = document.getElementById(inputId).value;

      // if is not defined, give it a value and override text box content
      if (tk_comment == "null") {
        tk_comment = "No comments for update.";
      } else if (tk_comment == "update note") {
        tk_comment = "No comment for update.";
      }
      return tk_comment;
    }

    function download(file, text) {
      //creating an invisible element
      var element = document.createElement("a");
      element.setAttribute(
        "href",
        "data:text/plain;charset=utf-8, " + encodeURIComponent(text)
      );
      element.setAttribute("download", file);

      // Above code is equivalent to
      // <a href="path of file" download="file name">

      document.body.appendChild(element);

      //onClick property
      element.click();

      document.body.removeChild(element);
    }

    //
    // check level of permissions, disable tenant creation and management if the user does not have the proper level of privileges
    //

    async function checkPrivileges() {
      var ajaxurl =
        "/en-US/splunkd/__raw/services/trackme/v2/configuration/trackme_check_privileges_level";
      var ajaxType = "GET";
      var resultCall;

      var defaultTokenModel = mvc.Components.getInstance("default", {
        create: true,
      });
      var submittedTokenModel = mvc.Components.getInstance("submitted", {
        create: true,
      });

      function setToken(name, value) {
        defaultTokenModel.set(name, value);
        submittedTokenModel.set(name, value);
      }

      try {
        resultCall = await $.ajax({
          url: ajaxurl,
          type: ajaxType,
        });
        userLevel = resultCall.user_level;
        setToken("userLevel", userLevel);

        var trackme_conf = resultCall.trackme_conf;

        // default mode for state icons compatibility
        ui_prefs_state_icons_mode =
          trackme_conf.trackme_home_theme_default.icons_state_mode;

        if (ui_prefs_state_icons_mode == "emoji") {
          setToken("show_state_icons_emoji", 1);
          setToken("show_state_icons_bootstrap", 0);
        } else if (ui_prefs_state_icons_mode == "bootstrap") {
          setToken("show_state_icons_emoji", 0);
          setToken("show_state_icons_bootstrap", 1);
        } else {
          setToken("show_state_icons_emoji", 1);
          setToken("show_state_icons_bootstrap", 0);
        }

        // hide the tenant creation access button
        if (userLevel === "user") {
          setToken("update_icon_visible", false);
          setToken("update_icon_alert_visible", false);
          //
          // splk-dsm
          //
          $("#splk_dsm_manage_btns").css("display", "none");
          $("#splk_dsm_manage_btns2").css("display", "none");
          $("#splk-dsm-table-bulk").css("display", "none");
          $("#splk-dsm-table-save").css("display", "none");
          $("#splk-dsm-table-cancel").css("display", "none");
          $("#btn_enable_monitoring").css("display", "none");
          $("#btn_disable_monitoring").css("display", "none");
          $("#btn_delete_splk_dsm").css("display", "none");
          $("#btn_modify_splk_dsm").css("display", "none");
          $("#btn_ack_splk_dsm").css("display", "none");
          //
          // splk-dhm
          //
          $("#splk_dhm_manage_btns").css("display", "none");
          $("#splk_dhm_manage_btns2").css("display", "none");
          $("#splk-dhm-table-bulk").css("display", "none");
          $("#splk-dhm-table-save").css("display", "none");
          $("#splk-dhm-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_host").css("display", "none");
          $("#btn_disable_monitoring_host").css("display", "none");
          $("#btn_delete_splk_dhm").css("display", "none");
          $("#btn_modify_splk_dhm").css("display", "none");
          $("#btn_ack_splk_dhm").css("display", "none");
          //
          // splk-mhm
          //
          $("#splk_mhm_manage_btns").css("display", "none");
          $("#splk_mhm_manage_btns2").css("display", "none");
          $("#splk-mhm-table-bulk").css("display", "none");
          $("#splk-mhm-table-save").css("display", "none");
          $("#splk-mhm-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_splk_mhm").css("display", "none");
          $("#btn_disable_monitoring_splk_mhm").css("display", "none");
          $("#btn_delete_splk_mhm").css("display", "none");
          $("#btn_modify_splk_mhm").css("display", "none");
          $("#btn_ack_splk_mhm").css("display", "none");
          //
          // splk-cim
          //
          $("#btn_manage_cim_trackers").css("display", "none");
          $("#splk-cim-table-bulk").css("display", "none");
          $("#splk-cim-table-save").css("display", "none");
          $("#splk-cim-table-cancel").css("display", "none");
          $("#btn_run_object").css("display", "none");
          $("#btn_enable_cim").css("display", "none");
          $("#btn_disable_cim").css("display", "none");
          $("#btn_delete_cim").css("display", "none");
          $("#btn_modify_cim").css("display", "none");
          $("#btn_ack_splk_cim").css("display", "none");
          $("#btn_create_cim_tracker").css("display", "none");
          //
          // splk-wlk
          //
          $("#btn_modify_hybrid_trackers_wlk_main").css("display", "none");
          $("#btn_modify_apps_wlk_main").css("display", "none");
          $("#splk-wlk-table-bulk").css("display", "none");
          $("#splk-wlk-table-save").css("display", "none");
          $("#splk-wlk-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_splk_wlk").css("display", "none");
          $("#btn_disable_monitoring_splk_wlk").css("display", "none");
          $("#btn_delete_splk_wlk").css("display", "none");
          $("#btn_modify_splk_wlk").css("display", "none");
          $("#btn_ack_splk_wlk").css("display", "none");
          //
          // splk-flx
          //
          $("#btn_modify_hybrid_trackers_flx_main").css("display", "none");
          $("#btn_run_tracker_flx").css("display", "none");
          $("#splk-flx-table-bulk").css("display", "none");
          $("#splk-flx-table-save").css("display", "none");
          $("#splk-flx-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_splk_flx").css("display", "none");
          $("#btn_disable_monitoring_splk_flx").css("display", "none");
          $("#btn_delete_splk_flx").css("display", "none");
          $("#btn_modify_splk_flx").css("display", "none");
          $("#btn_ack_splk_flx").css("display", "none");
          //
          // alerts
          //
          $("#btn_create_alert").css("display", "none");
        } else if (userLevel === "power") {
          setToken("update_icon_visible", true);
          setToken("update_icon_alert_visible", true);
          //
          // splk-dsm
          //
          $("#splk_dsm_manage_hybrid_trackers").css("display", "none");
          $("#splk_dsm_manage_elastic_trackers").css("display", "none");
          //
          // splk-dhm
          //
          $("#splk_dhm_manage_hybrid_trackers").css("display", "none");
          //
          // splk-mhm
          //
          $("#splk_mhm_manage_hybrid_trackers").css("display", "none");
          //
          // splk-cim
          //
          $("#btn_manage_cim_trackers").css("display", "none");
          $("#btn_create_cim_tracker").css("display", "none");
          //
          // splk-wlk
          //
          $("#btn_modify_hybrid_trackers_wlk_main").css("display", "none");
          //
          // splk-flx
          //
          $("#btn_modify_hybrid_trackers_flx_main").css("display", "none");
          //
          // alerts
          //
          $("#btn_create_alert").css("display", "none");
          //
          //
          //
        } else {
          setToken("update_icon_visible", true);
          setToken("update_icon_alert_visible", true);
        }
        return resultCall;
      } catch (error) {
        console.error(error);
      }
    }

    // verify user privileges level
    checkPrivileges();

    //
    // check tenant replica
    //

    async function checkReplica() {
      var ajaxurl =
        "/en-US/splunkd/__raw/services/trackme/v2/vtenants/show_tenant";
      var ajaxType = "POST";
      var resultCall;

      var defaultTokenModel = mvc.Components.getInstance("default", {
        create: true,
      });
      var submittedTokenModel = mvc.Components.getInstance("submitted", {
        create: true,
      });

      function setToken(name, value) {
        defaultTokenModel.set(name, value);
        submittedTokenModel.set(name, value);
      }

      var data = { tenant_id: getToken("tenant_id") };

      try {
        resultCall = await $.ajax({
          url: ajaxurl,
          type: ajaxType,
          data: JSON.stringify(data),
        });
        tenant_replica = resultCall.tenant_replica;
        setToken("tenant_replica", tenant_replica);
        // hide the tenant creation access button
        if (tenant_replica) {
          //
          setToken("update_icon_visible", false);
          //
          //
          // splk-dsm
          //
          // show replica
          $("#btn_modify_replica_trackers_dsm_main").css("display", "inherit");
          //
          $("#splk_dsm_manage_btns").css("display", "none");
          $("#splk_dsm_manage_btns2").css("display", "none");
          $("#splk-dsm-table-bulk").css("display", "none");
          $("#splk-dsm-table-save").css("display", "none");
          $("#splk-dsm-table-cancel").css("display", "none");
          $("#btn_enable_monitoring").css("display", "none");
          $("#btn_disable_monitoring").css("display", "none");
          $("#btn_delete_splk_dsm").css("display", "none");
          $("#btn_modify_splk_dsm").css("display", "none");
          $("#btn_ack_splk_dsm").css("display", "none");
          $("#btn_splk_dsm_manage_outliers").css("display", "none");
          //
          // splk-dhm
          //
          // show replica
          $("#btn_modify_replica_trackers_dhm_main").css("display", "inherit");
          //
          $("#splk_dhm_manage_btns").css("display", "none");
          $("#splk_dhm_manage_btns2").css("display", "none");
          $("#splk-dhm-table-bulk").css("display", "none");
          $("#splk-dhm-table-save").css("display", "none");
          $("#splk-dhm-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_host").css("display", "none");
          $("#btn_disable_monitoring_host").css("display", "none");
          $("#btn_delete_splk_dhm").css("display", "none");
          $("#btn_modify_splk_dhm").css("display", "none");
          $("#btn_ack_splk_dhm").css("display", "none");
          $("#btn_splk_dhm_manage_outliers").css("display", "none");
          //
          // splk-mhm
          //
          // show replica
          $("#btn_modify_replica_trackers_mhm_main").css("display", "inherit");
          //
          $("#splk_mhm_manage_btns").css("display", "none");
          $("#splk_mhm_manage_btns2").css("display", "none");
          $("#splk-mhm-table-bulk").css("display", "none");
          $("#splk-mhm-table-save").css("display", "none");
          $("#splk-mhm-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_splk_mhm").css("display", "none");
          $("#btn_disable_monitoring_splk_mhm").css("display", "none");
          $("#btn_delete_splk_mhm").css("display", "none");
          $("#btn_modify_splk_mhm").css("display", "none");
          $("#btn_ack_splk_mhm").css("display", "none");
          //
          // splk-cim
          //
          // show replica
          $("#btn_modify_replica_trackers_cim_main").css("display", "inherit");
          //
          $("#btn_manage_cim_trackers").css("display", "none");
          $("#splk-cim-table-bulk").css("display", "none");
          $("#splk-cim-table-save").css("display", "none");
          $("#splk-cim-table-cancel").css("display", "none");
          $("#btn_run_object").css("display", "none");
          $("#btn_enable_cim").css("display", "none");
          $("#btn_disable_cim").css("display", "none");
          $("#btn_delete_cim").css("display", "none");
          $("#btn_modify_cim").css("display", "none");
          $("#btn_ack_splk_cim").css("display", "none");
          $("#btn_splk_cim_manage_outliers").css("display", "none");
          //
          // splk-wlk
          //
          // show replica
          $("#btn_modify_replica_trackers_wlk_main").css("display", "inherit");
          //
          $("#btn_modify_hybrid_trackers_wlk_main").css("display", "none");
          $("#btn_modify_apps_wlk_main").css("display", "none");
          $("#splk-wlk-table-bulk").css("display", "none");
          $("#splk-wlk-table-save").css("display", "none");
          $("#splk-wlk-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_splk_wlk").css("display", "none");
          $("#btn_disable_monitoring_splk_wlk").css("display", "none");
          $("#btn_delete_splk_wlk").css("display", "none");
          $("#btn_modify_splk_wlk").css("display", "none");
          $("#btn_ack_splk_cim").css("display", "none");
          $("#btn_splk_wlk_manage_outliers").css("display", "none");
          //
          // splk-flx
          //
          // show replica
          $("#btn_modify_replica_trackers_flx_main").css("display", "inherit");
          //
          $("#btn_modify_hybrid_trackers_flx_main").css("display", "none");
          $("#btn_run_tracker_flx").css("display", "none");
          $("#splk-flx-table-bulk").css("display", "none");
          $("#splk-flx-table-save").css("display", "none");
          $("#splk-flx-table-cancel").css("display", "none");
          $("#btn_enable_monitoring_splk_flx").css("display", "none");
          $("#btn_disable_monitoring_splk_flx").css("display", "none");
          $("#btn_delete_splk_flx").css("display", "none");
          $("#btn_modify_splk_flx").css("display", "none");
          $("#btn_ack_splk_flx").css("display", "none");
          $("#btn_splk_flx_manage_outliers").css("display", "none");
        } else {
          setToken("update_icon_visible", true);
        }
        return resultCall;
      } catch (error) {
        console.error(error);
      }
    }

    // verify if the tenant is a replica tenant
    checkReplica();

    //
    // cssloader
    //

    function cssloader(msg) {
      $("#cssloader").remove();
      $("body").append(
        '<div id="cssloader" class="loader loader-default is-active" data-text="' +
          msg +
          '"></div>'
      );
    }

    function cssloaderremove() {
      $("#cssloader").remove();
    }

    //
    // Notify
    //

    function notify(varCss, varPosition, varHtml, vardelay) {
      require([
        "jquery",
        "/static/app/trackme/notifybar/jquery.notifyBar.js",
      ], function ($) {
        //code here
        jQuery(function () {
          jQuery.notifyBar({
            cssClass: varCss,
            position: varPosition,
            html: varHtml,
            delay: vardelay,
          });
        });
      });
    }

    //
    // Row popup formatter for Acknowledgements
    //

    // popup formatter (ack)
    var rowPopupFormatterAck = function (e, row, onRendered) {
      var data = row.getData();

      // We have the following Ack fields:
      // ack_comment, ack_expiration, ack_mtime, ack_state, ack_type

      var ack_comment = data.ack_comment;
      var ack_expiration = data.ack_expiration;
      var ack_mtime = data.ack_mtime;
      var ack_state = data.ack_state;
      var ack_type = data.ack_type;

      // if ack_expiration is not null, convert from epoch to human readable
      if (ack_expiration != "null") {
        ack_expiration = epochToHumanReadable(ack_expiration);
      } else {
        ack_expiration = "N/A";
      }

      // if ack_mtime is not null, convert from epoch to human readable
      if (ack_mtime != "null") {
        ack_mtime = epochToHumanReadable(ack_mtime);
      } else {
        ack_mtime = "N/A";
      }

      // for all fields, if null, set to N/A
      if (ack_comment == "null") {
        ack_comment = "N/A";
      }

      if (ack_expiration == "null") {
        ack_expiration = "N/A";
      }

      if (ack_mtime == "null") {
        ack_mtime = "N/A";
      }

      if (ack_state == "null") {
        ack_state = "N/A";
      }

      if (ack_type == "null") {
        ack_type = "N/A";
      }

      (container = document.createElement("div")),
        // Add all fields to the popup
        (contents =
          "<strong style='font-size:1.2em; color: #a7c7e7;'>Acknowledement Details</strong><br/>");
      contents +=
        "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
      contents +=
        "<li><strong>Acknowledgement state:</strong> " + ack_state + "</li>";
      contents +=
        "<li><strong>Acknowledgement type:</strong> " + ack_type + "</li>";
      contents +=
        "<li><strong>Acknowledgement expiration:</strong> " +
        ack_expiration +
        "</li>";
      contents +=
        "<li><strong>Acknowledgement comment:</strong> " +
        ack_comment +
        "</li>";
      contents +=
        "<li><strong>Acknowledgement last modified:</strong> " +
        ack_mtime +
        "</li>";
      contents += "</ul></div>";

      container.innerHTML = contents;

      return container;
    };

    //
    // Row popup formatter for Outliers
    //

    // popup formatter
    var rowPopupFormatterOutliers = function (e, row, onRendered) {
      var data = row.getData();

      // We have the following fields:
      // isOutlier, isOutlierReason, outliers_readiness, models_in_anomaly

      var isOutlier = data.isOutlier;
      var isOutlierReason = data.isOutlierReason;
      var outliers_readiness = data.outliers_readiness;
      var models_in_anomaly = data.models_in_anomaly;

      // Turn isOutlier from 0 to False, 1 to True
      if (isOutlier == "0") {
        isOutlier = "False";
      } else {
        isOutlier = "True";
      }

      // for all fields, if null, set to N/A
      if (isOutlierReason == "null") {
        isOutlierReason = "N/A";
      }

      if (outliers_readiness == "null") {
        outliers_readiness = "N/A";
      }

      if (models_in_anomaly == "null") {
        models_in_anomaly = "N/A";
      }

      (container = document.createElement("div")),
        // Add all fields to the popup
        (contents =
          "<strong style='font-size:1.2em; color: #a7c7e7;'>Outliers Details)</strong><br/>");
      contents +=
        "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
      contents += "<li><strong>isOutlier:</strong> " + isOutlier + "</li>";
      contents +=
        "<li><strong>Outlier Readiness:</strong> " +
        outliers_readiness +
        "</li>";
      contents +=
        "<li><strong>isOutlierReason:</strong> " + isOutlierReason + "</li>";
      contents +=
        "<li><strong>Models in Anomaly:</strong> " +
        models_in_anomaly +
        "</li>";
      contents += "</ul></div>";
      container.innerHTML = contents;
      return container;
    };

    //
    // Row popup formatter for Sampling
    //

    // popup formatter
    var rowPopupFormatterSampling = function (e, row, onRendered) {
      var data = row.getData();

      // We have the following fields:
      // SamplingIsOk (0 for False, 1 for True), data_sample_anomaly_reason

      var SamplingIsOk = data.SamplingIsOk;
      var data_sample_anomaly_reason = data.data_sample_anomaly_reason;

      // Turn SamplingIsOk from 0 to False, 1 to True
      if (SamplingIsOk == "0") {
        SamplingIsOk = "False";
      } else if (SamplingIsOk == "1") {
        SamplingIsOk = "True";
      } else {
        SamplingIsOk = "N/A";
      }

      // for all fields, if null, set to N/A
      if (data_sample_anomaly_reason == "null") {
        data_sample_anomaly_reason = "N/A";
      }

      (container = document.createElement("div")),
        // Add all fields to the popup
        (contents =
          "<strong style='font-size:1.2em; color: #a7c7e7;'>Outliers Details)</strong><br/>");
      contents +=
        "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
      contents +=
        "<li><strong>SamplingIsOk:</strong> " + SamplingIsOk + "</li>";
      contents +=
        "<li><strong>Sampling Anomaly Reason:</strong> " +
        data_sample_anomaly_reason +
        "</li>";
      contents += "</ul></div>";
      container.innerHTML = contents;
      return container;
    };

    //
    // Set bootstrap based status icons
    //

    function setEmojiStatusIcons(status) {
      switch (status) {
        case "001":
          return "🟢";
        case "002":
          return "👀 🟢";
        case "003":
          return "🟢";
        case "004":
          return "🔴";
        case "005":
          return "👀 🔴";
        case "006":
          return "🔴";
        case "007":
          return "🟠";
        case "008":
          return "👀 🟠";
        case "009":
          return "🟠";
        case "010":
          return "🔵";
        case "011":
          return "👀 🔵";
        case "012":
          return "🔵";
        case "unknown":
          return "⚪";
        default:
          return "⚫"; // Default icon for undefined status
      }
    }

    //
    // Set bootstrap based status icons
    //

    function setBootstrapStatusIcons(status) {
      switch (status) {
        case "001":
          return "<i class='bi bi-check-circle-fill icon-state-green'></i>";
        case "002":
          return "<i class='bi bi-eye-fill icon-state-green'></i>";
        case "003":
          return "<i class='bi bi-check-circle-fill icon-state-green'></i>";
        case "004":
          return "<i class='bi bi-x-circle-fill icon-state-red'></i>";
        case "005":
          return "<i class='bi bi-eye-fill icon-state-red'></i>";
        case "006":
          return "<i class='bi bi-x-circle-fill icon-state-red'></i>";
        case "007":
          return "<i class='bi bi-exclamation-triangle-fill icon-state-orange'></i>";
        case "008":
          return "<i class='bi bi-eye-fill icon-state-orange'></i>";
        case "009":
          return "<i class='bi bi-exclamation-triangle-fill icon-state-orange'></i>";
        case "010":
          return "<i class='bi bi-info-circle-fill icon-state-blue'></i>";
        case "011":
          return "<i class='bi bi-eye-fill icon-state-blue'></i>";
        case "012":
          return "<i class='bi bi-info-circle-fill icon-state-blue'></i>";
        case "unknown":
          return "<i class='bi bi-question-circle-fill icon-state-grey'></i>";
        default:
          return "<i class='bi bi-slash-circle icon-state-black'></i>"; // Default icon for undefined status
      }
    }

    //
    // Set emoji based status icons
    //

    function setEmojiAlertStatusIcons(status) {
      switch (status) {
        case "0":
          return "🟢";
        case "1":
          return "🔴";
        case "unknown":
          return "⚪";
        default:
          return "⚫"; // Default icon for undefined status
      }
    }

    //
    // Set bootstrap based status icons
    //

    function setBootstrapAlertStatusIcons(status) {
      switch (status) {
        case "0":
          return "<i class='bi bi-check-circle-fill icon-state-green'></i>";
        case "1":
          return "<i class='bi bi-x-circle-fill icon-state-red'></i>";
        case "unknown":
          return "<i class='bi bi-question-circle-fill icon-state-grey'></i>";
        default:
          return "<i class='bi bi-slash-circle icon-state-black'></i>"; // Default icon for undefined status
      }
    }

    //
    // Truncate
    //

    function truncate(str, num) {
      return str.length <= num ? str : str.slice(0, num) + "...";
    }

    //
    // Copy clipboard
    //

    function copyToClipboard(content) {
      // Copy the text inside the text field
      navigator.clipboard.writeText(content);
      notify("success", "bottom", "Copy to clipboard done!", "5");
    }

    //
    // epochtime second to human readable
    //

    function epochToHumanReadable(epoch) {
      // Convert epoch time from seconds to milliseconds
      const epochMilliseconds = epoch * 1000;

      // Create a new Date object using the epoch time value in milliseconds
      const date = new Date(epochMilliseconds);

      // Format the date as a human-readable string
      const humanReadableDate = date.toLocaleString();

      return humanReadableDate;
    }

    //
    // Invalid entry
    //

    function invalidEntry() {
      closeModals();
      $("#modal_entry_update_invalid").modal();
    }

    // disable the bulk edit button
    $("#splk-dsm-table-bulk").prop("disabled", true);

    // disable the inline save button
    $("#splk-dsm-table-save").prop("disabled", true);

    // disable the inline cancel button
    $("#splk-dsm-table-cancel").prop("disabled", true);

    // alert tabulator
    function alertHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // set the table div
        var tabulatorElement = "#" + "trackme-alerts-table";

        //Generate open icon
        var openIcon = function (cell, formatterParams) {
          return "<i class='bi bi-box-arrow-up-right'></i>";
        };

        //Generate tool icon
        var toolIcon = function (cell, formatterParams) {
          return "<i class='bi bi-tools'></i>";
        };

        // json formatter
        function csvToJsonFormatter(cell, formatterParams, onRendered) {
          cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
          return JSON.stringify(cell.getValue().split(","), null, 4).replace(
            /\\/g,
            ""
          ); //return JSON formatted cell
        }

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "id",
          layout: "fitDataStretch", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 50, //allow 50 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          height: "100%", // fixed height
          initialSort: [
            //set the initial sort order of the data
            { column: "title", dir: "asc" },
          ],

          columns: [
            {
              //create column group
              title: "Actions",
              columns: [
                // open
                {
                  formatter: openIcon,
                  width: 40,
                  hozAlign: "center",
                  cellClick: function (e, cell) {
                    // Open the entity modal
                    showAlertModal(cell.getRow().getData(), "view");
                  },
                },
                // tool
                {
                  formatter: toolIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("update_icon_alert_visible"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showAlertModal(cell.getRow().getData(), "edit");
                  },
                },
              ],
            },
            {
              //create column group
              title: "Alert details",
              columns: [
                //define the table columns
                {
                  title: "",
                  field: "disabled",
                  visible: getToken("show_state_icons_bootstrap"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setBootstrapAlertStatusIcons(status);
                  },
                },
                {
                  title: "",
                  field: "disabled",
                  visible: getToken("show_state_icons_emoji"),
                  editor: false,
                  hozAlign: "center",
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setEmojiAlertStatusIcons(status);
                  },
                },
                {
                  title: "title",
                  field: "title",
                  editor: true,
                  headerFilter: true,
                },
                {
                  title: "cron_schedule",
                  field: "cron_schedule",
                  editor: false,
                },
                {
                  title: "schedule_window",
                  field: "schedule_window",
                  editor: false,
                },
                {
                  title: "suppress_fields",
                  field: "suppress_fields",
                  editor: false,
                },
                {
                  title: "suppress_period",
                  field: "suppress_period",
                  editor: false,
                },
                {
                  title: "actions",
                  field: "actions",
                  editor: false,
                  formatter: csvToJsonFormatter,
                },
                {
                  title: "disabled",
                  field: "disabled",
                  editor: false,
                },
                {
                  title: "next_scheduled_time",
                  field: "next_scheduled_time",
                  editor: false,
                },
              ],
            },
          ],
        });

        //
        // end
        //
      });
    }

    function showAlertModal(jsonData, action) {
      var tk_alert_title = jsonData["title"];
      // Token is required for further searches
      setToken("tk_alert_title", tk_alert_title);

      var tk_alert_cron_schedule = jsonData["cron_schedule"];
      var tk_alert_schedule_window = jsonData["schedule_window"];
      var tk_alert_suppress_fields = jsonData["suppress_fields"];
      var tk_alert_suppress_period = jsonData["suppress_period"];
      var tk_alert_disabled = jsonData["disabled"];
      var tk_alert_next_scheduled_time = jsonData["next_scheduled_time"];
      var tk_alert_actions = jsonData["actions"];

      // Update the divs
      $("#child-alert-tracking-info-panel-title").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for alert: <span>' +
          tk_alert_title +
          "</span></h1>"
      );

      $("#child-alert-tracking-info-panel1").html(
        '<h3>Disabled: <span style="color: dodgerblue;">' +
          tk_alert_disabled +
          "</h3></span>" +
          '<h3>Cron Schedule: <span style="color: dodgerblue;">' +
          tk_alert_cron_schedule +
          "</h3></span>" +
          '<h3>Schedule window: <span style="color: dodgerblue;">' +
          tk_alert_schedule_window +
          "</h3></span>"
      );

      $("#child-alert-tracking-info-panel2").html(
        '<h3>Suppress fields: <span style="color: dodgerblue;">' +
          tk_alert_suppress_fields +
          "</h3></span>" +
          '<h3>Suppress period: <span style="color: dodgerblue;">' +
          tk_alert_suppress_period +
          "</h3></span>"
      );

      $("#child-alert-tracking-info-panel3").html(
        '<h3>Next scheduled time: <span style="color: dodgerblue;">' +
          tk_alert_next_scheduled_time +
          "</h3></span>" +
          '<h3>Alert actions: <span style="color: dodgerblue;">' +
          tk_alert_actions +
          "</h3></span>"
      );

      // Define the alert URL
      var alert_id = jsonData["id"];
      var url =
        "/app/trackme/alert?s=%2FservicesNS%2Fnobody%2Ftrackme%2Fsaved%2Fsearches%2F" +
        alert_id;
      var alert_url =
        location.protocol +
        "//" +
        location.hostname +
        (location.port ? ":" + location.port : "") +
        url;

      // Define the URL target
      document.getElementById("btn_url_modal_manage_alert").href = alert_url;

      // Define the history search
      var alert_search_history =
        location.protocol +
        "//" +
        location.hostname +
        (location.port ? ":" + location.port : "") +
        "/app/trackme/search" +
        '?q=search%20index%3D_audit%20action%3D"alert_fired"%20ss_app%3D"trackme"%20ss_name%3D"' +
        encodeURI(tk_alert_title) +
        '"';

      // Define the URL target
      document.getElementById("btn_url_modal_history_alert").href =
        alert_search_history;

      // Enable modal context

      if (action == "view") {
        searchAlertTriggeredOverTime.startSearch();
        searchAlertActionsTriggeredOverTimePerAlert.startSearch();
        $("#modal_manage_alerts").modal();
      } else if (action == "edit") {
        document.getElementById("btn_url_modal_manage_alert").click();
      }
    }

    // alert get table
    function getAlertTable() {
      var tk_tenant_id = getToken("tenant_id");
      alertHandlerTable(
        "/en-US/splunkd/__raw/services/trackme/v2/alerting/get_tenant_alerts",
        "POST",
        {
          tenant_id: tk_tenant_id,
        }
      );
    }

    // splk-dsm get sampling obfuscation mode
    function splkDsmGetSamplingObfuscation() {
      $(".btn_data_sampling_manage").each(function () {
        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_dsm_sampling_obfuscation_mode";

        // Create a dictionary to store the field names and values
        var record = {
          tenant_id: getToken("tenant_id"),
        };

        // spinner
        cssloader("Requested action is in progress, please wait...");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // spinner
            cssloaderremove();
            setToken("splk_dsm_obfuscation_mode", returneddata["mode"]);
          },
          error: function (xhr, textStatus, error) {
            // spinner
            cssloaderremove();
            // hide
            $("#" + spinnerDiv).css("display", "none");
            var message =
              "Failed to verify the splk-dsm data sampling obfuscation mode: " +
              xhr;
            // notify
            notify("error", "bottom", message, "5");
            // set a mode
            setToken("splk_dsm_obfuscation_mode", "disabled");
          },
        });
      });
    }

    // global auto-refresh interval
    var tableRefreshIntervalId;

    // splk-dsm tabulator
    function splkDsmHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // set the table div
        var tabulatorElement = "#" + "splk-dsm-table";

        //Generate open icon
        var openIcon = function (cell, formatterParams) {
          return "<i class='bi bi-box-arrow-up-right'></i>";
        };

        //Generate tool icon
        var toolIcon = function (cell, formatterParams) {
          return "<i class='bi bi-tools'></i>";
        };

        //Generate cmdb icon
        var cmdbIcon = function (cell, formatterParams) {
          return "<i class='bi bi-database-fill-gear'></i>";
        };

        // filters
        //Define variables for input elements

        var fieldEl = document.getElementById("splk-dsm-table-filter-field");
        var typeEl = document.getElementById("splk-dsm-table-filter-type");
        var valueEl = document.getElementById("splk-dsm-table-filter-value");
        var enabledEl = document.getElementById(
          "splk-dsm-table-filter-enabled"
        );

        // custom functions

        function customFilterRedState(data, filterEnabled) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red";
          } else {
            return (
              data.object_state == "red" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOrangeState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "orange";
          } else {
            return (
              data.object_state == "orange" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterGreenState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "green";
          } else {
            return (
              data.object_state == "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterBlueState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "blue";
          } else {
            return (
              data.object_state == "blue" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterAlertState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state != "green";
          } else {
            return (
              data.object_state != "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "high";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "high" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "medium";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "medium" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "low";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "low" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "high";
          } else {
            return data.priority == "high" && data.monitored_state == "enabled";
          }
        }

        function customFilterMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "medium";
          } else {
            return (
              data.priority == "medium" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterEnabled(data) {
          return data.monitored_state == "enabled";
        }

        function customFilterDisabled(data) {
          return data.monitored_state == "disabled";
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterLatencyTresholdAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "lag_threshold_breached";
          } else {
            return (
              data.anomaly_reason == "lag_threshold_breached" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterDelayTresholdAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "delay_threshold_breached";
          } else {
            return (
              data.anomaly_reason == "delay_threshold_breached" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterHostDcountAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "min_hosts_dcount";
          } else {
            return (
              data.anomaly_reason == "min_hosts_dcount" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOutliersAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "ml_outliers_detection";
          } else {
            return (
              data.anomaly_reason == "ml_outliers_detection" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterSamplingAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "data_sampling_anomaly";
          } else {
            return (
              data.anomaly_reason == "data_sampling_anomaly" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterFuture(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "future_over_tolerance";
          } else {
            return (
              data.anomaly_reason == "future_over_tolerance" &&
              data.monitored_state == "enabled"
            );
          }
        }

        //Trigger setFilter function with correct parameters
        function updateFilter() {
          var filterVal = fieldEl.options[fieldEl.selectedIndex].value;
          var typeVal = typeEl.options[typeEl.selectedIndex].value;

          // handle filter functions and normal filter
          var filter;
          if (filterVal == "function_high_priority") {
            filter = customFilterHighPriority;
          } else if (filterVal == "function_medium_priority") {
            filter = customFilterMediumPriority;
          } else if (filterVal == "function_low_priority") {
            filter = customFilterLowPriority;
          } else if (filterVal == "function_red_state_high_priority") {
            filter = customFilterRedStateHighPriority;
          } else if (filterVal == "function_red_state_medium_priority") {
            filter = customFilterRedStateMediumPriority;
          } else if (filterVal == "function_red_state_low_priority") {
            filter = customFilterRedStateLowPriority;
          } else if (filterVal == "function_enabled") {
            filter = customFilterEnabled;
          } else if (filterVal == "function_disabled") {
            filter = customFilterDisabled;
          } else if (filterVal == "function_lagthreshold_anomaly") {
            filter = customFilterLatencyTresholdAnomaly;
          } else if (filterVal == "function_delaythreshold_anomaly") {
            filter = customFilterDelayTresholdAnomaly;
          } else if (filterVal == "function_hostdcount_anomaly") {
            filter = customFilterHostDcountAnomaly;
          } else if (filterVal == "function_outliers_anomaly") {
            filter = customFilterOutliersAnomaly;
          } else if (filterVal == "function_sampling_anomaly") {
            filter = customFilterSamplingAnomaly;
          } else if (filterVal == "function_future") {
            filter = customFilterFuture;
          } else if (filterVal == "function_red_state") {
            filter = customFilterRedState;
          } else if (filterVal == "function_orange_state") {
            filter = customFilterOrangeState;
          } else if (filterVal == "function_green_state") {
            filter = customFilterGreenState;
          } else if (filterVal == "function_blue_state") {
            filter = customFilterBlueState;
          } else if (filterVal == "function_alert_state") {
            filter = customFilterAlertState;
          } else {
            filter = filterVal;
          }

          // disable filters conditionally
          if (
            filterVal == "function_red_state" ||
            filterVal == "function_orange_state" ||
            filterVal == "function_green_state" ||
            filterVal == "function_blue_state" ||
            filterVal == "function_alert_state" ||
            filterVal == "function_red_state_high_priority" ||
            filterVal == "function_red_state_medium_priority" ||
            filterVal == "function_red_state_low_priority" ||
            filterVal == "function_high_priority" ||
            filterVal == "function_medium_priority" ||
            filterVal == "function_low_priority" ||
            filterVal == "function_enabled" ||
            filterVal == "function_disabled" ||
            filterVal == "function_lagthreshold_anomaly" ||
            filterVal == "function_delaythreshold_anomaly" ||
            filterVal == "function_hostdcount_anomaly" ||
            filterVal == "function_outliers_anomaly" ||
            filterVal == "function_sampling_anomaly" ||
            filterVal == "function_future"
          ) {
            typeEl.disabled = true;
            valueEl.disabled = true;
          } else {
            typeEl.disabled = false;
            valueEl.disabled = false;
          }

          if (filterVal) {
            var filterEnabled = document.getElementById(
              "splk-dsm-table-filter-enabled"
            ).value;
            if (filterEnabled == "true") {
              table.setFilter(filter, typeVal, valueEl.value);
            } else {
              table.setFilter("monitored_state", "=", "enabled");
              table.addFilter(filter, typeVal, valueEl.value);
            }
          }
        }

        // Drilldown click from single all entities
        singleFormTotalSplkDsm.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dsm-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "like", value: "" },
            ]);
            // notify
            notify("success", "bottom", "Filtering on all entities.", "5");
          }
        });

        singleFormTotalSplkDsmAlerts.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dsm-table-filter-field").val("function_alert_state");
            // set filters
            table.setFilter([
              {
                field: "object_state",
                type: "in",
                value: ["red", "orange", "blue"],
              },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on enabled entities in alert (red, orange, blue).",
              "5"
            );
          }
        });

        // Drilldown click from single high priority red
        singleFormTotalSplkDsmAlertsHighPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dsm-table-filter-field").val(
              "function_red_state_high_priority"
            );
            // set filters
            table.setFilter([
              { field: "object_state", type: "=", value: "red" },
              { field: "priority", type: "=", value: "high" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on high priority red entities.",
              "5"
            );
          }
        });

        singleFormTotalSplkDsmDisabled.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dsm-table-filter-field").val("function_disabled");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "disabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on all disabled entities.",
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkDsmCountByPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dsm-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              {
                field: "priority",
                type: "like",
                value: e.data["row.priority"],
              },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on any state monitored entities with priority: " +
                e.data["row.priority"],
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkDsmCountByStateAndPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();

            // set clicked_state
            clicked_state = e.data["row.state"];

            if (
              clicked_state === "green" ||
              clicked_state === "blue" ||
              clicked_state === "orange" ||
              clicked_state === "red"
            ) {
              // update dropdown
              $("#splk-dsm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: clicked_state },
                {
                  field: "priority",
                  type: "like",
                  value: "",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on any priority monitored entities with state: " +
                  clicked_state,
                "5"
              );
            } else if (clicked_state === "red - other priority") {
              // update dropdown
              $("#splk-dsm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "in",
                  value: ["low", "medium"],
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on low or medium priority monitored entities with state: red",
                "5"
              );
            } else if (clicked_state === "red - high priority") {
              // update dropdown
              $("#splk-dsm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "=",
                  value: "high",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on high priority monitored entities with state: red",
                "5"
              );
            }
          }
        });

        //Update filters on value change
        document
          .getElementById("splk-dsm-table-filter-field")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-dsm-table-filter-type")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-dsm-table-filter-value")
          .addEventListener("keyup", updateFilter);

        //Clear filters on "Clear Filters" button click
        document
          .getElementById("splk-dsm-table-filter-clear")
          .addEventListener("click", function () {
            fieldEl.value = "data_source";
            typeEl.value = "like";
            valueEl.value = "";
            enabledEl = "false";
            table.clearFilter(true);
            table.setFilter("monitored_state", "=", "enabled");
            typeEl.disabled = false;
            valueEl.disabled = false;
            // notify
            notify(
              "success",
              "bottom",
              "Tabulator filters were reset successfully.",
              "5"
            );
          });

        // popup formatter
        var rowPopupFormatter = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Entity Details</strong><br/>";
          contents +=
            "<div style='max-height: 600px; width: 800px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
          contents +=
            "<li><strong>Entity name:</strong> " + data.object + "</li>";
          contents +=
            "<li><strong>Entity alias:</strong> " + data.alias + "</li>";
          contents +=
            "<li><strong>Index:</strong> " + data.data_index + "</li>";
          contents +=
            "<li><strong>Sourcetype:</strong> " +
            data.data_sourcetype +
            "</li>";
          contents +=
            "<li><strong>Entity keyid:</strong> " + data.keyid + "</li>";
          contents +=
            "<li><strong>State:</strong> " + data.object_state + "</li>";
          contents +=
            "<li><strong>AnomalyReason:</strong> " +
            data.anomaly_reason +
            "</li>";
          contents +=
            "<li><strong>Outliers anomaly detection state:</strong> " +
            data.OutliersStatus +
            "</li>";
          contents +=
            "<li><strong>Data sampling anomaly detection state:</strong> " +
            data.SamplingStatus +
            "</li>";
          contents +=
            "<li><strong>Acknowledgement state:</strong> " +
            data.ack_state +
            "</li>";
          contents +=
            "<li><strong>Status message:</strong> " +
            data.status_message +
            "</li>";
          contents +=
            "<li><strong>Priority:</strong> " + data.priority + "</li>";
          contents +=
            "<li><strong>Lagging summary:</strong> " +
            data.lag_summary +
            "</li>";
          contents +=
            "<li><strong>Last ingest:</strong> " + data.last_ingest + "</li>";
          contents +=
            "<li><strong>Last event:</strong> " + data.last_time + "</li>";
          contents +=
            "<li><strong>Max latency allowed:</strong> " +
            data.data_max_lag_allowed +
            " seconds</li>";
          contents +=
            "<li><strong>Max delay allowed:</strong> " +
            data.data_max_delay_allowed +
            " seconds</li>";
          contents +=
            "<li><strong>Hosts distinct count:</strong> " +
            data.dcount_host +
            "</li>";
          contents +=
            "<li><strong>Min hosts distinct count:</strong> " +
            data.min_dcount_host +
            "</li>";
          contents +=
            "<li><strong>Currently under monitoring days:</strong> " +
            data.isUnderMonitoringDays +
            "</li>";
          contents +=
            "<li><strong>Currently under monitoring hours:</strong> " +
            data.isUnderMonitoringHours +
            "</li>";
          contents +=
            "<li><strong>Date and time of last inspection:</strong> " +
            epochToHumanReadable(data.tracker_runtime) +
            "</li>";

          contents += "</ul></div>";

          container.innerHTML = contents;

          return container;
        };

        var show_state_icons_emoji = getToken("show_state_icons_emoji");
        var show_state_icons_bootsrap = getToken("show_state_icons_bootsrap");

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "keyid",
          layout: "fitDataFill", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 50, //allow 50 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          height: "100%", // fixed height
          groupBy: "data_index",
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            {
              //create column group
              title: "Actions",
              columns: [
                // open
                {
                  formatter: openIcon,
                  width: 40,
                  hozAlign: "center",
                  cellClick: function (e, cell) {
                    // Open the entity modal
                    showSplkDsmEntityModal(
                      cell.getRow().getData(),
                      "modal_manage_splk_dsm",
                      "modal"
                    );
                  },
                },
                // tool
                {
                  formatter: toolIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("update_icon_visible"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkDsmEntityModal(
                      cell.getRow().getData(),
                      "modal_modify_splk_dsm_unified",
                      "modal"
                    );
                  },
                },
                // cmdb
                {
                  formatter: cmdbIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("cmdb_lookup"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkDsmEntityModal(
                      cell.getRow().getData(),
                      "modal_cmdb_splk_dsm",
                      "modal"
                    );
                  },
                },
              ],
            },
            {
              //create column group
              title: "Identifier/state (click: rename/right click: info)",
              columns: [
                //define the table columns
                {
                  title: "object",
                  field: "object",
                  visible: false,
                },
                {
                  title: "Entity",
                  field: "alias",
                  contextPopup: rowPopupFormatter, //add click popup to row
                  minWidth: getToken("ui_min_object_width"),
                  editor: true,
                  headerFilter: true,
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_bootstrap"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setBootstrapStatusIcons(status);
                  },
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_emoji"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setEmojiStatusIcons(status);
                  },
                },
              ],
            },
            {
              //create column group
              title: "Priority and monitoring state",
              columns: [
                {
                  title: "Priority",
                  field: "priority",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["low", "medium", "high"] },
                  headerFilter: "input",
                },
                {
                  title: "Monitoring",
                  field: "monitored_state",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["disabled", "enabled"] },
                  headerFilter: "input",
                },
              ],
            },
            {
              //create column group
              title: "Current statistics and main indexing information",
              columns: [
                {
                  title: "lag (delay / latency)",
                  field: "lag_summary",
                  width: 160,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Latest event",
                  field: "last_time",
                  width: 140,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Latest ingest",
                  field: "last_ingest",
                  width: 140,
                  editor: false,
                  headerFilter: false,
                },
              ],
            },
            {
              //create column group
              title: "Thresholds and features status",
              columns: [
                {
                  title: "Delay (sec)",
                  field: "data_max_delay_allowed",
                  editor: "number",
                  editorParams: {
                    min: 0,
                    step: 300,
                    verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
                  },
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Duration",
                  field: "data_max_delay_allowed_duration",
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Latency",
                  field: "data_max_lag_allowed",
                  editor: "number",
                  editorParams: {
                    min: 0,
                    step: 300,
                    verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
                  },
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Duration",
                  field: "data_max_lag_allowed_duration",
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Class override",
                  field: "data_override_lagging_class",
                  editor: "list",
                  editorParams: { values: ["true", "false"] },
                  headerFilter: "input",
                  width: 130,
                },
                {
                  title: "Alert over",
                  field: "data_lag_alert_kpis",
                  editor: "list",
                  editorParams: {
                    values: ["all_kpis", "lag_event_kpi", "lag_ingestion_kpi"],
                  },
                  headerFilter: "input",
                  width: 130,
                },
                {
                  title: "Outliers",
                  field: "OutliersIsOk",
                  contextPopup: rowPopupFormatterOutliers, //add click popup to row
                  hozAlign: "center",
                  formatter: "tickCross",
                  width: 100,
                },
                {
                  title: "Sampling",
                  field: "SamplingIsOk",
                  contextPopup: rowPopupFormatterSampling, //add click popup to row
                  hozAlign: "center",
                  formatter: "tickCross",
                  width: 100,
                },
              ],
            },
          ],
        });

        // Set initial filters
        function setInitialFilters() {
          var filterEnabledEl = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabledEl == "true") {
            table.setFilter("monitored_state", "in", ["enabled", "disabled"]);
          } else if (filterEnabledEl == "false") {
            table.setFilter("monitored_state", "in", ["enabled"]);
          }
        }

        // reset and set filters (for listener)
        function resetAndSetInitialFilters() {
          var fieldEl = document.getElementById("splk-dsm-table-filter-field");
          var typeEl = document.getElementById("splk-dsm-table-filter-type");
          var valueEl = document.getElementById("splk-dsm-table-filter-value");
          fieldEl.value = "object";
          typeEl.value = "like";
          valueEl.value = "";
          table.clearFilter(true);
          setInitialFilters();
        }

        // Call it only once the table is built
        table.on("tableBuilt", function () {
          setInitialFilters();

          // create the change listener
          document
            .getElementById("splk-dsm-table-filter-enabled")
            .addEventListener("change", resetAndSetInitialFilters);
        });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $("#splk-dsm-table-bulk").prop("disabled", false);
            splkDsmPauseRefreshInfo();
          } else {
            $("#splk-dsm-table-bulk").prop("disabled", true);
            document.getElementById("splkDsmLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            splkDsmResumeTableRefresh();
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $("#splk-dsm-table-save").prop("disabled", false);
          $("#splk-dsm-table-cancel").prop("disabled", false);
          splkDsmPauseRefreshInfo();
        });

        // set the timer
        splkDsmRefreshInfo();

        // auto-refresh
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-dsm-table-refresh-hidden").click();
        }, 300000);

        // manual refresh
        $("#splk-dsm-table-refresh")
          .unbind()
          .click(function () {
            // notify
            notify("info", "bottom", "Please wait while refreshing...", "5");
            var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
              resultCall
            ) {
              // get current filters
              var currentFilters = table.getFilters(true);
              // clear filters
              table.clearFilter(true);
              // refresh data
              table.replaceData(resultCall);
              // re-apply filters
              table.setFilter(currentFilters);
              // notify
              notify(
                "success",
                "bottom",
                "Tabulator was refreshed successfully.",
                "5"
              );
              // refresh the timer
              splkDsmResetRefreshInfo();
            });
          });

        // auto hidden refresh
        $("#splk-dsm-table-refresh-hidden")
          .unbind()
          .click(function () {
            var doAsync = asyncAjaxNoLoader(ajaxUrl, ajaxType, ajaxData).then(
              function (resultCall) {
                // get current filters
                var currentFilters = table.getFilters(true);
                // clear filters
                table.clearFilter(true);
                // refresh data
                table.replaceData(resultCall);
                // re-apply filters
                table.setFilter(currentFilters);
                // refresh the timer
                splkDsmResetRefreshInfo();
              }
            );
          });

        // bulk edit
        $("#splk-dsm-table-bulk")
          .unbind()
          .click(function () {
            // get filters
            var allFilters = table.getFilters(true);

            // get selected rows
            var selectedData = table.getSelectedData(allFilters);

            // get data according to all filters and store in its array
            var searchData = table.searchData(allFilters);
            var searchList = [];
            for (var i = 0; i < searchData.length; i++) {
              searchList.push(searchData[i].keyid);
            }

            // loop and create a list of keys ensuring these are parts of the searched entities
            var itemList = [];
            var itemKeys = [];
            for (var i = 0; i < selectedData.length; i++) {
              if (searchList.includes(selectedData[i].keyid)) {
                itemList.push(selectedData[i].object);
                itemKeys.push(selectedData[i].keyid);
              }
            }

            // set a token for later usage
            setToken("splkDsmBulkObjs", itemList.toString());
            setToken("splkDsmBulkIds", itemKeys.toString());

            // count the number of selected entities and add to the bulk edit modal
            itemCount = itemList.length;
            $("#divDsmBulkdCount").html(
              '<h1><span style="color: #a7c7e7;">' +
                itemCount +
                " entities selected currently</span></h1>"
            );

            // open modal
            closeModals();
            $("#modal_entry_bulk_splk_dsm").modal();
          });

        // save inline edit
        $("#splk-dsm-table-save")
          .unbind()
          .click(function () {
            // disable the button
            $(this).prop("disabled", true);

            var selectedData = table.getData("active");
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              // create the JSON object
              record_object = {
                keyid: selectedData[i].keyid,
                object: selectedData[i].object,
                alias: selectedData[i].alias,
                priority: selectedData[i].priority,
                monitored_state: selectedData[i].monitored_state,
                data_override_lagging_class:
                  selectedData[i].data_override_lagging_class,
                data_lag_alert_kpis: selectedData[i].data_lag_alert_kpis,
                data_max_lag_allowed: selectedData[i].data_max_lag_allowed,
                data_max_delay_allowed: selectedData[i].data_max_delay_allowed,
              };
              // push to the array
              itemList.push(record_object);
            }
            // run the rest call
            var tk_tenant_id = getToken("tenant_id");

            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_bulk_edit";

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: tk_tenant_id,
              json_data: itemList,
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Run the search again to update the table
                searchSplkDsmMain.startSearch();
                // refresh tabulator
                $("#splk-dsm-table-refresh-hidden").click();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Entities bulk edit was performed successfully.",
                  "5"
                );
                // disable the cancel button
                $("#splk-dsm-table-cancel").prop("disabled", true);
                return;
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });

        // cancel inline edit
        $("#splk-dsm-table-cancel")
          .unbind()
          .click(function () {
            document.getElementById("splkDsmLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            // disable the button
            $(this).prop("disabled", true);
            // notify
            notify(
              "info",
              "bottom",
              "Inline changes canceled, refreshing the table.",
              "5"
            );
            // disable the save button
            $("#splk-dsm-table-save").prop("disabled", true);
            // refresh the table
            $("#splk-dsm-table-refresh-hidden").click();
            splkDsmResumeTableRefresh();
          });

        // priority: create a function to limit code repetition
        function splkDsmBulkPriority(priority) {
          var tk_tenant_id = getToken("tenant_id");
          var splkDsmBulkIds = getToken("splkDsmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dsm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_priority";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-dsm",
            keys_list: splkDsmBulkIds,
            priority: priority,
            update_comment: tk_comment,
          };

          //spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();
              // refresh tabulator
              $("#splk-dsm-table-refresh-hidden").click();
              // spinner
              cssloaderremove();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              // spinner
              cssloaderremove();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk priority high
        $("#btn_splk_dsm_bulk_priority_high")
          .unbind()
          .click(function () {
            splkDsmBulkPriority("high");
          });

        // bulk priority medium
        $("#btn_splk_dsm_bulk_priority_medium")
          .unbind()
          .click(function () {
            splkDsmBulkPriority("medium");
          });

        // bulk priority low
        $("#btn_splk_dsm_bulk_priority_low")
          .unbind()
          .click(function () {
            splkDsmBulkPriority("low");
          });

        // priority: create a function to limit code repetition
        function splkDsmBulkAck(action) {
          var tk_tenant_id = getToken("tenant_id");
          var splkDsmBulkObjs = getToken("splkDsmBulkObjs");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dsm_bulk_comment");

          // Create the endpoint URL and record
          var myendpoint_URl;
          var record;

          if (action == "enable") {
            // retrieve the Ack second value from html selector id btn_splk_dsm_bulk_priority_enable_ack_days
            var ack_days = $(
              "#btn_splk_dsm_bulk_priority_enable_ack_days"
            ).val();
            var ack_second = ack_days * 86400;
            // retrieve the Ack type value from html selector ud btn_splk_dsm_bulk_priority_enable_ack_type
            var ack_type = $(
              "#btn_splk_dsm_bulk_priority_enable_ack_type"
            ).val();
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "enable",
              object_category: "splk-dsm",
              object_list: splkDsmBulkObjs,
              ack_period: ack_second,
              ack_type: ack_type,
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          } else if (action == "disable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "disable",
              object_category: "splk-dsm",
              object_list: splkDsmBulkObjs,
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          }

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();
              // refresh tabulator
              $("#splk-dsm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk ack enable
        $("#btn_splk_dsm_bulk_priority_enable_ack")
          .unbind()
          .click(function () {
            splkDsmBulkAck("enable");
          });

        // bulk ack disable
        $("#btn_splk_dsm_bulk_priority_disable_ack")
          .unbind()
          .click(function () {
            splkDsmBulkAck("disable");
          });

        // monitoring: create a function to limit code repetition
        function splkDsmBulkMonitoring(actionTarget) {
          var tk_tenant_id = getToken("tenant_id");
          var splkDsmBulkIds = getToken("splkDsmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dsm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_monitoring";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-dsm",
            keys_list: splkDsmBulkIds,
            action: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();
              // refresh tabulator
              $("#splk-dsm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk enable
        $("#btn_splk_dsm_bulk_enable")
          .unbind()
          .click(function () {
            splkDsmBulkMonitoring("enable");
          });

        // bulk disable
        $("#btn_splk_dsm_bulk_disable")
          .unbind()
          .click(function () {
            splkDsmBulkMonitoring("disable");
          });

        // delete: create a function to limit code repetition
        function splkDsmBulkDelete(actionTarget) {
          var splkDsmBulkIds = getToken("splkDsmBulkIds");
          var tk_tenant_id = getToken("tenant_id");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dsm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_delete";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: splkDsmBulkIds,
            deletion_type: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // refresh tabulator
              $("#splk-dsm-table-refresh-hidden").click();
              var msg = "Entities bulk edit was performed successfully.";
              notify("success", "bottom", msg, "5");
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk delete temporary
        $("#btn_splk_dsm_bulk_deletion_temporary")
          .unbind()
          .click(function () {
            splkDsmBulkDelete("temporary");
          });

        // bulk delete permanent
        $("#btn_splk_dsm_bulk_deletion_permanent")
          .unbind()
          .click(function () {
            splkDsmBulkDelete("permanent");
          });

        // associate new logical group: create a function to limit code repetition
        function splkDsmBulkAssociateNewLogicalGroup() {
          var splkDsmBulkObjs = getToken("splkDsmBulkObjs");

          // this token is expected by the target
          setToken("tk_logical_group_target", splkDsmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-dsm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dsm_bulk_comment");

          // Set required tokens
          setToken("tk_start_logical_member_get", "True");

          // hide this action
          $("#btn_associate_logical_group_add_group_back").hide();
          $("#btn_associate_logical_group_back").hide();

          // Open modal
          $("#logical_group_add_group").modal();
        }

        // bulk
        $("#btn_splk_dsm_bulk_associate_new_logical_group")
          .unbind()
          .click(function () {
            splkDsmBulkAssociateNewLogicalGroup();
          });

        // associate existing logical group: create a function to limit code repetition
        function splkDsmBulkAssociateExistingLogicalGroup() {
          var splkDsmBulkObjs = getToken("splkDsmBulkObjs");

          // this token is expected by the target
          setToken("tk_logical_group_target", splkDsmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-dsm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dsm_bulk_comment");

          // Set required tokens
          setToken("tk_start_logical_member_add", "True");

          // Start search
          searchLogicalGroupTableAddMember.startSearch();

          // hide this action
          $("#btn_associate_logical_group_add_member_back").hide();

          // Open modal
          $("#logical_group_add_member").modal();
        }

        // bulk
        $("#btn_splk_dsm_bulk_associate_existing_logical_group")
          .unbind()
          .click(function () {
            splkDsmBulkAssociateExistingLogicalGroup();
          });

        // unassociate logical group: create a function to limit code repetition
        function splkDsmBulkUnassociateLogicalGroup() {
          var splkDsmBulkObjs = getToken("splkDsmBulkObjs");

          // Free the search
          setToken("tk_start_logical_member_get", "true");

          // Start the search
          searchLogicalGroupTable.startSearch();

          // this token is expected by the target
          setToken("tk_logical_group_target", splkDsmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-dsm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dsm_bulk_comment");

          // hide this action
          $("#btn_associate_logical_group_back").hide();

          // Open modal
          $("#logical_group").modal();
        }

        // bulk
        $("#btn_splk_dsm_bulk_unassociate_logical_group")
          .unbind()
          .click(function () {
            splkDsmBulkUnassociateLogicalGroup();
          });

        //
        // end
        //
      });
    }

    // splk-dsm get table
    function getSplkDsmTable() {
      var tk_tenant_id = getToken("tenant_id");
      // avoid causing double interval
      clearInterval(splkDsmIntervalId);
      splkDsmHandlerTable(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_table",
        "POST",
        { tenant_id: tk_tenant_id, key_id: "*" }
      );
    }

    // splk-dsm refresh timer
    var splkDsmIntervalId;

    function splkDsmRefreshInfo() {
      var myDate = new Date();
      var splkDsmLastRefresh = document.getElementById("splkDsmLastRefresh");
      function updateTime() {
        splkDsmLastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
      }

      splkDsmIntervalId = setInterval(updateTime, 2000);
    }

    function splkDsmResetRefreshInfo() {
      clearInterval(splkDsmIntervalId);
      // release our intervalID from the variable
      splkDsmIntervalId = null;
      splkDsmRefreshInfo();
    }

    function splkDsmPauseRefreshInfo() {
      clearInterval(splkDsmIntervalId);
      clearInterval(tableRefreshIntervalId);
      // release our intervalID from the variable
      splkDsmIntervalId = null;
      tableRefreshIntervalId = null;
      splkDsmLastRefresh.innerText =
        "auto-refresh table is paused until inline changes are saved or cancelled";
    }

    function splkDsmResumeTableRefresh() {
      if (!tableRefreshIntervalId) {
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-dsm-table-refresh-hidden").click();
        }, 300000);
      }
    }

    //
    // splk-cim tabulator
    //

    // disable the bulk edit button
    $("#splk-cim-table-bulk").prop("disabled", true);

    // disable the inline save button
    $("#splk-cim-table-save").prop("disabled", true);

    // disable the inline cancel button
    $("#splk-cim-table-cancel").prop("disabled", true);

    function splkCimHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // set the table div
        var tabulatorElement = "#" + "splk-cim-table";

        // get tenant level preference
        var ui_expand_metrics = getToken("ui_expand_metrics");
        if (ui_expand_metrics == 1) {
          var fieldEl = document.getElementById("splk-cim-table-mode");
          fieldEl.value = "full";
        }

        function jsonFormatter(cell, formatterParams, onRendered) {
          // get mode
          var modeView = document.getElementById("splk-cim-table-mode").value;
          if (modeView === "minimal") {
            return "right click for popup";
          } else {
            cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
            return JSON.stringify(JSON.parse(cell.getValue()), null, 1).replace(
              /\\/g,
              ""
            ); //return JSON formatted cell
          }
        }

        //Generate open icon
        var openIcon = function (cell, formatterParams) {
          return "<i class='bi bi-box-arrow-up-right'></i>";
        };

        //Generate tool icon
        var toolIcon = function (cell, formatterParams) {
          return "<i class='bi bi-tools'></i>";
        };

        //Generate cmdb icon
        var cmdbIcon = function (cell, formatterParams) {
          return "<i class='bi bi-database-fill-gear'></i>";
        };

        // filters
        //Define variables for input elements

        var fieldEl = document.getElementById("splk-cim-table-filter-field");
        var typeEl = document.getElementById("splk-cim-table-filter-type");
        var valueEl = document.getElementById("splk-cim-table-filter-value");
        var enabledEl = document.getElementById(
          "splk-cim-table-filter-enabled"
        );

        // listen for a change
        $("#splk-cim-table-mode").change(function () {
          var newmodeView = document.getElementById(
            "splk-cim-table-mode"
          ).value;
          table.replaceData(resultCall);
        });

        // custom functions

        function customFilterRedState(data, filterEnabled) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.monitored_state == "red";
          } else {
            return (
              data.object_state == "red" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOrangeState(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "orange";
          } else {
            return (
              data.object_state == "orange" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterGreenState(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "green";
          } else {
            return (
              data.object_state == "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterAlertState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state != "green";
          } else {
            return (
              data.object_state != "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "high";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "high" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "medium";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "medium" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "low";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "low" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "high";
          } else {
            return data.priority == "high" && data.monitored_state == "enabled";
          }
        }

        function customFilterMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "medium";
          } else {
            return (
              data.priority == "medium" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterEnabled(data) {
          return data.monitored_state == "enabled";
        }

        function customFilterDisabled(data) {
          return data.monitored_state == "disabled";
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        //Trigger setFilter function with correct parameters
        function updateFilter() {
          var filterVal = fieldEl.options[fieldEl.selectedIndex].value;
          var typeVal = typeEl.options[typeEl.selectedIndex].value;

          // handle filter functions and normal filter
          var filter;
          if (filterVal == "function_high_priority") {
            filter = customFilterHighPriority;
          } else if (filterVal == "function_medium_priority") {
            filter = customFilterMediumPriority;
          } else if (filterVal == "function_low_priority") {
            filter = customFilterLowPriority;
          } else if (filterVal == "function_red_state_high_priority") {
            filter = customFilterRedStateHighPriority;
          } else if (filterVal == "function_red_state_medium_priority") {
            filter = customFilterRedStateMediumPriority;
          } else if (filterVal == "function_red_state_low_priority") {
            filter = customFilterRedStateLowPriority;
          } else if (filterVal == "function_enabled") {
            filter = customFilterEnabled;
          } else if (filterVal == "function_disabled") {
            filter = customFilterDisabled;
          } else if (filterVal == "function_red_state") {
            filter = customFilterRedState;
          } else if (filterVal == "function_orange_state") {
            filter = customFilterOrangeState;
          } else if (filterVal == "function_green_state") {
            filter = customFilterGreenState;
          } else if (filterVal == "function_alert_state") {
            filter = customFilterAlertState;
          } else {
            filter = filterVal;
          }

          // disable filters conditionally
          if (
            filterVal == "function_red_state" ||
            filterVal == "function_orange_state" ||
            filterVal == "function_green_state" ||
            filterVal == "function_alert_state" ||
            filterVal == "function_red_state_high_priority" ||
            filterVal == "function_red_state_medium_priority" ||
            filterVal == "function_red_state_low_priority" ||
            filterVal == "function_high_priority" ||
            filterVal == "function_medium_priority" ||
            filterVal == "function_low_priority" ||
            filterVal == "function_enabled" ||
            filterVal == "function_disabled"
          ) {
            typeEl.disabled = true;
            valueEl.disabled = true;
          } else {
            typeEl.disabled = false;
            valueEl.disabled = false;
          }

          if (filterVal) {
            var filterEnabled = document.getElementById(
              "splk-cim-table-filter-enabled"
            ).value;
            if (filterEnabled == "true") {
              table.setFilter(filter, typeVal, valueEl.value);
            } else {
              table.setFilter("monitored_state", "=", "enabled");
              table.addFilter(filter, typeVal, valueEl.value);
            }
          }
        }

        // Drilldown click from single all entities
        singleFormTotalCimEntities.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-cim-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "like", value: "" },
            ]);
            // notify
            notify("success", "bottom", "Filtering on all entities.", "5");
          }
        });

        singleFormTotalCimEntitiesAlerts.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-cim-table-filter-field").val("function_red_state");
            // set filters
            table.setFilter([
              {
                field: "object_state",
                type: "in",
                value: ["red", "orange", "blue"],
              },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on enabled entities in alert (red, orange, blue).",
              "5"
            );
          }
        });

        // Drilldown click from single high priority red
        singleFormTotalCimEntitiesAlertsHighPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-cim-table-filter-field").val(
              "function_red_state_high_priority"
            );
            // set filters
            table.setFilter([
              { field: "object_state", type: "=", value: "red" },
              { field: "priority", type: "=", value: "high" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on high priority red entities.",
              "5"
            );
          }
        });

        singleFormTotalCimEntitiesDisabled.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-cim-table-filter-field").val("function_disabled");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "disabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on all disabled entities.",
              "5"
            );
          }
        });

        // donut drilldown
        DonutCimCountByPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-cim-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              {
                field: "priority",
                type: "like",
                value: e.data["row.priority"],
              },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on any state monitored entities with priority: " +
                e.data["row.priority"],
              "5"
            );
          }
        });

        // donut drilldown
        DonutCimCountByStateAndPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();

            // set clicked_state
            clicked_state = e.data["row.state"];

            if (
              clicked_state === "green" ||
              clicked_state === "blue" ||
              clicked_state === "orange" ||
              clicked_state === "red"
            ) {
              // update dropdown
              $("#splk-cim-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: clicked_state },
                {
                  field: "priority",
                  type: "like",
                  value: "",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on any priority monitored entities with state: " +
                  clicked_state,
                "5"
              );
            } else if (clicked_state === "red - other priority") {
              // update dropdown
              $("#splk-cim-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "in",
                  value: ["low", "medium"],
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on low or medium priority monitored entities with state: red",
                "5"
              );
            } else if (clicked_state === "red - high priority") {
              // update dropdown
              $("#splk-cim-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "=",
                  value: "high",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on high priority monitored entities with state: red",
                "5"
              );
            }
          }
        });

        //Update filters on value change
        document
          .getElementById("splk-cim-table-filter-field")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-cim-table-filter-type")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-cim-table-filter-value")
          .addEventListener("keyup", updateFilter);

        //Clear filters on "Clear Filters" button click
        document
          .getElementById("splk-cim-table-filter-clear")
          .addEventListener("click", function () {
            fieldEl.value = "object";
            typeEl.value = "like";
            valueEl.value = "";
            enabledEl = "false";
            table.clearFilter(true);
            table.setFilter("monitored_state", "=", "enabled");
            typeEl.disabled = false;
            valueEl.disabled = false;
            // notify
            notify(
              "success",
              "bottom",
              "Tabulator filters were reset successfully.",
              "5"
            );
          });

        // popup formatter
        var rowPopupFormatter = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Entity Details</strong><br/>";
          contents +=
            "<div style='max-height: 600px; width: 800px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
          contents +=
            "<li><strong>Entity name:</strong> " + data.object + "</li>";
          contents +=
            "<li><strong>Entity alias:</strong> " + data.alias + "</li>";
          contents += "<li><strong>Account:</strong> " + data.account + "</li>";
          contents +=
            "<li><strong>Datamodel name:</strong> " +
            data.cim_datamodel_name +
            "</li>";
          contents +=
            "<li><strong>Datamodel node:</strong> " +
            data.cim_datamodel_nodename +
            "</li>";
          contents +=
            "<li><strong>Entity keyid:</strong> " + data.keyid + "</li>";
          contents +=
            "<li><strong>State:</strong> " + data.object_state + "</li>";
          contents +=
            "<li><strong>CIM fields in alert:</strong> " +
            data.cim_fields_red +
            "</li>";
          contents +=
            "<li><strong>Acknowledgement state:</strong> " +
            data.ack_state +
            "</li>";
          contents +=
            "<li><strong>Status message:</strong> " +
            data.status_message +
            "</li>";
          contents +=
            "<li><strong>Priority:</strong> " + data.priority + "</li>";
          contents +=
            "<li><strong>Latest flip time:</strong> " +
            data.latest_flip_time +
            "</li>";
          contents +=
            "<li><strong>Latest flip state:</strong> " +
            data.latest_flip_state +
            "</li>";
          contents +=
            "<li><strong>Tracker name:</strong> " + data.tracker_name + "</li>";
          contents +=
            "<li><strong>Tracker runtime:</strong> " +
            data.tracker_runtime +
            "</li>";
          contents +=
            "<li><strong>Tracker last duration:</strong> " +
            data.tracker_last_duration +
            "</li>";
          contents +=
            "<li><strong>Date and time of last inspection:</strong> " +
            epochToHumanReadable(data.tracker_runtime) +
            "</li>";

          contents += "</ul></div>";

          container.innerHTML = contents;

          return container;
        };

        // popup formatter
        var rowPopupFormatterRulesDetails = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Rules Details (use the scrollerbar to scroll down through details)</strong><br/>";
          contents +=
            "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>" +
            JSON.stringify(JSON.parse(data.cim_tracking_rules), null, 4);
          ("</code></pre></div>");
          container.innerHTML = contents;
          return container;
        };

        // popup formatter
        var rowPopupFormatterResultsDetails = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Results Details (use the scrollerbar to scroll down through details)</strong><br/>";
          contents +=
            "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>" +
            JSON.stringify(JSON.parse(data.cim_tracking_results), null, 4);
          ("</code></pre></div>");
          container.innerHTML = contents;
          return container;
        };

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "keyid",
          layout: "fitDataFill", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 50, //allow 50 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          height: "100%", // fixed height
          groupBy: "cim_datamodel_name",
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            {
              //create column group
              title: "Actions",
              columns: [
                // open
                {
                  formatter: openIcon,
                  width: 40,
                  hozAlign: "center",
                  cellClick: function (e, cell) {
                    // Open the entity modal
                    showSplkSplkCimModal(
                      cell.getRow().getData(),
                      "modal_manage_cim",
                      "modal"
                    );
                  },
                },
                // tool
                {
                  formatter: toolIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("update_icon_visible"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkSplkCimModal(
                      cell.getRow().getData(),
                      "btn_modify_cim",
                      "click"
                    );
                  },
                },
                // cmdb
                {
                  formatter: cmdbIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("cmdb_lookup"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkSplkCimModal(
                      cell.getRow().getData(),
                      "modal_cmdb_splk_cim",
                      "modal"
                    );
                  },
                },
              ],
            },
            {
              //create column group
              title: "Identifier/state (click: rename/right click: info)",
              columns: [
                //define the table columns
                {
                  title: "object",
                  field: "object",
                  visible: false,
                },
                {
                  title: "Entity",
                  field: "alias",
                  minWidth: getToken("ui_min_object_width"),
                  contextPopup: rowPopupFormatter, //add click popup to row
                  editor: true,
                  headerFilter: true,
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_bootstrap"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setBootstrapStatusIcons(status);
                  },
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_emoji"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setEmojiStatusIcons(status);
                  },
                },
              ],
            },
            {
              //create column group
              title: "Priority and monitoring state",
              columns: [
                {
                  title: "Priority",
                  field: "priority",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["low", "medium", "high"] },
                  headerFilter: "input",
                },
                {
                  title: "Monitoring",
                  field: "monitored_state",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["disabled", "enabled"] },
                  headerFilter: "input",
                },
              ],
            },
            {
              //create column group
              title: "Tracking rules and results",
              columns: [
                {
                  title: "Rules",
                  field: "cim_tracking_rules",
                  formatter: jsonFormatter,
                  contextPopup: rowPopupFormatterRulesDetails,
                  minWidth: 350,
                  variableHeight: true,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Results",
                  field: "cim_tracking_results",
                  formatter: jsonFormatter,
                  contextPopup: rowPopupFormatterResultsDetails,
                  minWidth: 350,
                  variableHeight: true,
                  editor: false,
                  headerFilter: false,
                },
              ],
            },
            {
              //create column group
              title: "Tracker information",
              columns: [
                {
                  title: "Run time",
                  field: "tracker_runtime",
                  width: 160,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Last duration",
                  field: "tracker_last_duration",
                  width: 140,
                  editor: false,
                  headerFilter: false,
                },
              ],
            },
            {
              title: "Outliers",
              field: "OutliersIsOk",
              contextPopup: rowPopupFormatterOutliers, //add click popup to row
              hozAlign: "center",
              formatter: "tickCross",
              width: 100,
            },
          ],
        });

        // Set initial filters
        function setInitialFilters() {
          var filterEnabledEl = document.getElementById(
            "splk-cim-table-filter-enabled"
          ).value;
          if (filterEnabledEl == "true") {
            table.setFilter("monitored_state", "in", ["enabled", "disabled"]);
          } else if (filterEnabledEl == "false") {
            table.setFilter("monitored_state", "in", ["enabled"]);
          }
        }

        // reset and set filters (for listener)
        function resetAndSetInitialFilters() {
          var fieldEl = document.getElementById("splk-cim-table-filter-field");
          var typeEl = document.getElementById("splk-cim-table-filter-type");
          var valueEl = document.getElementById("splk-cim-table-filter-value");
          fieldEl.value = "object";
          typeEl.value = "like";
          valueEl.value = "";
          table.clearFilter(true);
          setInitialFilters();
        }

        // Call it only once the table is built
        table.on("tableBuilt", function () {
          setInitialFilters();

          // create the change listener
          document
            .getElementById("splk-cim-table-filter-enabled")
            .addEventListener("change", resetAndSetInitialFilters);
        });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $("#splk-cim-table-bulk").prop("disabled", false);
            splkCimPauseRefreshInfo();
          } else {
            $("#splk-cim-table-bulk").prop("disabled", true);
            document.getElementById("splkCimLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            splkCimResumeTableRefresh();
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $("#splk-cim-table-save").prop("disabled", false);
          $("#splk-cim-table-cancel").prop("disabled", false);
          splkCimPauseRefreshInfo();
        });

        // set the timer
        splkCimRefreshInfo();

        // auto-refresh
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-cim-table-refresh-hidden").click();
        }, 300000);

        // manual refresh
        $("#splk-cim-table-refresh")
          .unbind()
          .click(function () {
            // notify
            notify("info", "bottom", "Please wait while refreshing...", "5");
            var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
              resultCall
            ) {
              // get current filters
              var currentFilters = table.getFilters(true);
              // clear filters
              table.clearFilter(true);
              // refresh data
              table.replaceData(resultCall);
              // re-apply filters
              table.setFilter(currentFilters);
              // notify
              notify(
                "success",
                "bottom",
                "Tabulator was refreshed successfully.",
                "5"
              );
              // refresh the timer
              splkCimResetRefreshInfo();
            });
          });

        // auto hidden refresh
        $("#splk-cim-table-refresh-hidden")
          .unbind()
          .click(function () {
            var doAsync = asyncAjaxNoLoader(ajaxUrl, ajaxType, ajaxData).then(
              function (resultCall) {
                // get current filters
                var currentFilters = table.getFilters(true);
                // clear filters
                table.clearFilter(true);
                // refresh data
                table.replaceData(resultCall);
                // re-apply filters
                table.setFilter(currentFilters);
                // refresh the timer
                splkCimResetRefreshInfo();
              }
            );
          });

        // bulk edit
        $("#splk-cim-table-bulk")
          .unbind()
          .click(function () {
            // get filters
            var allFilters = table.getFilters(true);

            // get selected rows
            var selectedData = table.getSelectedData(allFilters);

            // get data according to all filters and store in its array
            var searchData = table.searchData(allFilters);
            var searchList = [];
            for (var i = 0; i < searchData.length; i++) {
              searchList.push(searchData[i].keyid);
            }

            // loop and create a list of keys ensuring these are parts of the searched entities
            var itemList = [];
            var itemKeys = [];
            for (var i = 0; i < selectedData.length; i++) {
              if (searchList.includes(selectedData[i].keyid)) {
                itemList.push(selectedData[i].object);
                itemKeys.push(selectedData[i].keyid);
              }
            }

            // set a token for later usage
            setToken("splkCimBulkObjs", itemList.toString());
            setToken("splkCimBulkIds", itemKeys.toString());

            // count the number of selected entities and add to the bulk edit modal
            itemCount = itemList.length;
            $("#divCimBulkdCount").html(
              '<h1><span style="color: #a7c7e7;">' +
                itemCount +
                " entities selected currently</span></h1>"
            );

            // open modal
            closeModals();
            $("#modal_entry_bulk_splk_cim").modal();
          });

        // save inline edit
        $("#splk-cim-table-save")
          .unbind()
          .click(function () {
            // disable the button
            $(this).prop("disabled", true);

            var selectedData = table.getData("active");
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              // create the JSON object
              record_object = {
                keyid: selectedData[i].keyid,
                object: selectedData[i].object,
                alias: selectedData[i].alias,
                priority: selectedData[i].priority,
                monitored_state: selectedData[i].monitored_state,
              };
              // push to the array
              itemList.push(record_object);
            }
            // run the rest call
            var tk_tenant_id = getToken("tenant_id");

            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/write/cim_bulk_edit";

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: tk_tenant_id,
              json_data: itemList,
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Run the search again to update the table
                searchSplkCimMain.startSearch();
                // refresh tabulator
                $("#splk-cim-table-refresh-hidden").click();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Entities bulk edit was performed successfully.",
                  "5"
                );
                // disable the cancel button
                $("#splk-cim-table-cancel").prop("disabled", true);
                return;
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });

        // cancel inline edit
        $("#splk-cim-table-cancel")
          .unbind()
          .click(function () {
            document.getElementById("splkCimLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            // disable the button
            $(this).prop("disabled", true);
            // notify
            notify(
              "info",
              "bottom",
              "Inline changes canceled, refreshing the table.",
              "5"
            );
            // disable the save button
            $("#splk-cim-table-save").prop("disabled", true);
            // refresh the table
            $("#splk-cim-table-refresh-hidden").click();
          });

        // priority: create a function to limit code repetition
        function splkCimBulkPriority(priority) {
          var tk_tenant_id = getToken("tenant_id");
          var splkCimBulkIds = getToken("splkCimBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_cim_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/write/cim_tracker_update_priority";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-cim",
            keys_list: splkCimBulkIds,
            priority: priority,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkCimMain.startSearch();
              // refresh tabulator
              $("#splk-cim-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk priority high
        $("#btn_splk_cim_bulk_priority_high")
          .unbind()
          .click(function () {
            splkCimBulkPriority("high");
          });

        // bulk priority medium
        $("#btn_splk_cim_bulk_priority_medium")
          .unbind()
          .click(function () {
            splkCimBulkPriority("medium");
          });

        // bulk priority low
        $("#btn_splk_cim_bulk_priority_low")
          .unbind()
          .click(function () {
            splkCimBulkPriority("low");
          });

        // priority: create a function to limit code repetition
        function splkCimBulkAck(action) {
          var tk_tenant_id = getToken("tenant_id");
          var splkCimBulkObjs = getToken("splkCimBulkObjs");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_cim_bulk_comment");

          // Create the endpoint URL and record
          var myendpoint_URl;
          var record;

          if (action == "enable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "enable",
              object_category: "splk-cim",
              object_list: splkCimBulkObjs,
              ack_period: "86400",
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          } else if (action == "disable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "disable",
              object_category: "splk-cim",
              object_list: splkCimBulkObjs,
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          }

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkCimMain.startSearch();
              // refresh tabulator
              $("#splk-cim-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk ack enable
        $("#btn_splk_cim_bulk_priority_enable_ack")
          .unbind()
          .click(function () {
            splkCimBulkAck("enable");
          });

        // bulk ack disable
        $("#btn_splk_cim_bulk_priority_disable_ack")
          .unbind()
          .click(function () {
            splkCimBulkAck("disable");
          });

        // monitoring: create a function to limit code repetition
        function splkCimBulkMonitoring(actionTarget) {
          var tk_tenant_id = getToken("tenant_id");
          var splkCimBulkIds = getToken("splkCimBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_cim_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker_enablement";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: splkCimBulkIds,
            action: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkCimMain.startSearch();
              // refresh tabulator
              $("#splk-cim-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk enable
        $("#btn_splk_cim_bulk_enable")
          .unbind()
          .click(function () {
            splkCimBulkMonitoring("enable");
          });

        // bulk disable
        $("#btn_splk_cim_bulk_disable")
          .unbind()
          .click(function () {
            splkCimBulkMonitoring("disable");
          });

        // delete: create a function to limit code repetition
        function splkCimBulkDelete() {
          object_manage(
            "delete",
            getToken("splkCimBulkObjs"),
            "none",
            "input_splk_cim_bulk_comment",
            "none"
          );
        }

        // bulk delete
        $("#btn_splk_cim_bulk_deletion")
          .unbind()
          .click(function () {
            splkCimBulkDelete();
          });

        //
        // end
        //
      });
    }

    // splk-cim get table
    function getSplkCimTable() {
      var tk_tenant_id = getToken("tenant_id");
      // avoid causing double interval
      clearInterval(splkCimIntervalId);
      splkCimHandlerTable(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/get_cim_table",
        "POST",
        { tenant_id: tk_tenant_id, key_id: "*", object: "*" }
      );
    }

    // splk-cim refresh timer
    var splkCimIntervalId;

    function splkCimRefreshInfo() {
      var myDate = new Date();
      var splkCimLastRefresh = document.getElementById("splkCimLastRefresh");
      function updateTime() {
        splkCimLastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
      }

      splkCimIntervalId = setInterval(updateTime, 2000);
    }

    function splkCimResetRefreshInfo() {
      clearInterval(splkCimIntervalId);
      // release our intervalID from the variable
      splkCimIntervalId = null;
      splkCimRefreshInfo();
    }

    function splkCimPauseRefreshInfo() {
      clearInterval(splkCimIntervalId);
      clearInterval(tableRefreshIntervalId);
      // release our intervalID from the variable
      splkCimIntervalId = null;
      tableRefreshIntervalId = null;
      splkCimLastRefresh.innerText =
        "auto-refresh table is paused until inline changes are saved or cancelled";
    }

    function splkCimResumeTableRefresh() {
      if (!tableRefreshIntervalId) {
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-cim-table-refresh-hidden").click();
        }, 300000);
      }
    }

    // splk-cim modal entity view

    function showSplkSplkCimModal(jsonData, actionTarget, actionType) {
      // mainTokens
      var tk_keyid = jsonData["keyid"];

      // mainTokens
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);

      // Get tenant and manage replica
      var tk_tenant_id = jsonData["tenant_id"];
      var tk_parent_tenant_id = jsonData["tenant_parent"];

      // handle replica
      var target_tenant_id = tk_parent_tenant_id || tk_tenant_id;
      if (tk_parent_tenant_id) {
        setToken("tenant_id", target_tenant_id);
      }

      var tk_object = jsonData["object"];
      var tk_alias = jsonData["alias"];
      // token is required
      setToken("tk_object", tk_object);
      setToken("tk_object_category", jsonData["object_category"]);

      var tk_tracker_name = jsonData["tracker_name"];
      // token is required
      setToken("tk_tracker_name", tk_tracker_name);

      var tk_account = jsonData["account"];
      // token is required
      setToken("tk_account", tk_account);

      // get the tracking rules as an object
      var cim_tracking_rules = JSON.parse(jsonData["cim_tracking_rules"]);

      // from it, retrieve the breakby and set it as a token
      var cim_breakby = cim_tracking_rules["cim_breakby"];

      // if unused, will be set to none, override this to be cim_entity_zone
      if (cim_breakby == "none") {
        cim_breakby = "cim_entity_zone";
      }

      // Set as a token
      setToken("tk_cim_breakby", cim_breakby);

      // define an information span
      var tk_location;
      if (tk_account === "local") {
        tk_location = "local";
      } else {
        tk_location = "remote (account=" + tk_account + ")";
      }

      var tk_object_state = jsonData["object_state"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_cim_monitored_state = jsonData["monitored_state"];
      var tk_cim_datamodel_name = jsonData["cim_datamodel_name"];
      var tk_cim_datamodel_nodename = jsonData["cim_datamodel_nodename"];
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      var tk_priority = jsonData["priority"];
      // token required for priority audit change
      setToken("tk_priority", tk_priority);
      setToken("form.tk_input_splk_cim_priority", tk_priority);

      var tk_tracker_runtime = jsonData["tracker_runtime"];
      var tk_tracker_last_duration = jsonData["tracker_last_duration"];

      // pre-fill current wdays input
      setToken("form.tk_input_wdays_cim", jsonData["monitoring_wdays"]);

      // pre-fill current hours ranges
      setToken(
        "form.tk_input_splk_cim_hours_ranges",
        jsonData["monitoring_hours_ranges"]
      );

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divCimOutliersInfo").css("display", "none");
        $("#divCimOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divCimOutliersSimulationInfo").css("display", "none");
        $("#divCimOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_cim_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_cim_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divCimOutliersInfo").css("display", "inherit");
        $("#divCimOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-cim-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divCimOutliersSimulationInfo").css("display", "inherit");
        $("#divCimOutliersSimulationRender").css("display", "none");
        $("#child-cim-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_cim_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_cim_save").prop("disabled", true);
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_cim").disabled = false;
        $("#btn_ack_splk_cim").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_cim").disabled = false;
        $("#btn_ack_splk_cim").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_cim").disabled = false;
        $("#btn_ack_splk_cim").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_cim").disabled = true;
        $("#btn_ack_splk_cim").html("Acknowledge alert");
      }

      // Define the history search
      var search_cim_tracking =
        '| from datamodel:"' +
        tk_cim_datamodel_name +
        "." +
        tk_cim_datamodel_nodename +
        '"';
      // handle local vs remote searches
      if (tk_account != "local") {
        search_cim_tracking =
          '| splunkremotesearch account="' +
          tk_account +
          '" search="' +
          search_cim_tracking.replace(/\"/g, '\\"') +
          ' | head 10000 | fields *" earliest="-60m" latest="now"';
      }
      // update the href
      search_cim_tracking =
        "search" +
        "?q=" +
        encodeURI(search_cim_tracking) +
        "&earliest=-15m&latest=now";

      // Define the URL target
      document.getElementById("btn_search_cim").href = search_cim_tracking;

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_cim_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_cim_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_cim_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_cim_status_message_class = "status_message_json_red";
      }

      // Dynamically manage buttons states
      var tk_cim_monitored_state_class;
      if (tk_cim_monitored_state == "enabled") {
        document.getElementById("btn_enable_cim").disabled = true;
        document.getElementById("btn_disable_cim").disabled = false;
        tk_cim_monitored_state_class = "title_green";
      } else {
        document.getElementById("btn_enable_cim").disabled = false;
        document.getElementById("btn_disable_cim").disabled = true;
        tk_cim_monitored_state_class = "title_grey";
      }

      // replace info panels
      $("#parent-cim-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for CIM entity: ' +
          tk_object +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-cim-top-info1").html(
        '<h3>monitored state:</b> <span class="' +
          tk_cim_monitored_state_class +
          '">' +
          tk_cim_monitored_state +
          "</span></h3>" +
          '<h3>entity state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-cim-top-info2").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-cim-top-info3").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span>" +
          '<h3>location: <span style="color: dodgerblue;">' +
          tk_location +
          "</span></h3>"
      );

      $("#child-cim-top-info4").html(
        '<h3>tracker last runtime: <span style="color: dodgerblue;">' +
          tk_tracker_runtime +
          '<span style="color: dodgerblue;">' +
          '<h3>tracker last duration: <span style="color: dodgerblue;">' +
          tk_tracker_last_duration +
          '<span style="color: dodgerblue;">'
      );

      $("#child-cim-status-message").html(
        '<div class="' +
          tk_cim_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );

      // Start searches
      searchHostTableMSplkCim.startSearch();

      // Run
      if (
        getToken("userLevel") === "user" &&
        actionTarget.startsWith("modal_modify_")
      ) {
        $("#modal_user_restricted").modal();
      } else {
        if (actionType === "modal") {
          if (actionTarget === "modal_cmdb_splk_cim") {
            searchCmdbSplkCim.startSearch();
          }
          $("#" + actionTarget).modal();
        } else if (actionType === "click") {
          $("#" + actionTarget).click();
        }
      }
    }

    //
    // splk-dhm
    //

    // disable the bulk edit button
    $("#splk-dhm-table-bulk").prop("disabled", true);

    // disable the inline save button
    $("#splk-dhm-table-save").prop("disabled", true);

    // disable the inline cancel button
    $("#splk-dhm-table-cancel").prop("disabled", true);

    // splk-dhm tabulator
    function splkDhmHandlerTable(ajaxUrl, ajaxType, ajaxData, modeView) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // set the table div
        var tabulatorElement = "#" + "splk-dhm-table";

        function jsonFormatter(cell, formatterParams, onRendered) {
          // get mode
          var modeView = document.getElementById("splk-dhm-table-mode").value;

          if (modeView === "minimal") {
            return JSON.stringify(JSON.parse(cell.getValue()), null, 4);
          } else {
            cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
            return JSON.stringify(JSON.parse(cell.getValue()), null, 4);
          }
        }

        //Generate open icon
        var openIcon = function (cell, formatterParams) {
          return "<i class='bi bi-box-arrow-up-right'></i>";
        };

        //Generate tool icon
        var toolIcon = function (cell, formatterParams) {
          return "<i class='bi bi-tools'></i>";
        };

        //Generate cmdb icon
        var cmdbIcon = function (cell, formatterParams) {
          return "<i class='bi bi-database-fill-gear'></i>";
        };

        // filters
        //Define variables for input elements

        var fieldEl = document.getElementById("splk-dhm-table-filter-field");
        var typeEl = document.getElementById("splk-dhm-table-filter-type");
        var valueEl = document.getElementById("splk-dhm-table-filter-value");
        var enabledEl = document.getElementById(
          "splk-dhm-table-filter-enabled"
        );

        // listen for a change
        $("#splk-dhm-table-mode").change(function () {
          var newmodeView = document.getElementById(
            "splk-dhm-table-mode"
          ).value;
          // loop through each object in the resultCall array
          resultCall.forEach(function (obj) {
            if (newmodeView === "compact") {
              // if the mode is compact, set the 'summary' field to the value of 'summary_compact'
              obj["sourcetype_summary"] = obj["splk_dhm_st_summary_compact"];
            } else if (newmodeView === "full") {
              // if the mode is full, set the 'summary' field to the value of 'summary_full'
              obj["sourcetype_summary"] = obj["splk_dhm_st_summary_full"];
            } else if (newmodeView === "minimal") {
              // if the mode is hidden, set the 'summary' field to empty
              obj["sourcetype_summary"] = obj["splk_dhm_st_summary_minimal"];
            }
          });
          table.replaceData(resultCall);
        });

        // custom functions

        function customFilterRedState(data, filterEnabled) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red";
          } else {
            return (
              data.object_state == "red" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOrangeState(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "orange";
          } else {
            return (
              data.object_state == "orange" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterGreenState(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "green";
          } else {
            return (
              data.object_state == "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterBlueState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "blue";
          } else {
            return (
              data.object_state == "blue" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterAlertState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state != "green";
          } else {
            return (
              data.object_state != "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "high";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "high" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "medium";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "medium" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "low";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "low" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "high";
          } else {
            return data.priority == "high" && data.monitored_state == "enabled";
          }
        }

        function customFilterMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "medium";
          } else {
            return (
              data.priority == "medium" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterEnabled(data) {
          return data.monitored_state == "enabled";
        }

        function customFilterDisabled(data) {
          return data.monitored_state == "disabled";
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterLatencyTresholdAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "lag_threshold_breached";
          } else {
            return (
              data.anomaly_reason == "lag_threshold_breached" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterDelayTresholdAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "delay_threshold_breached";
          } else {
            return (
              data.anomaly_reason == "delay_threshold_breached" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOutliersAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "ml_outliers_detection";
          } else {
            return (
              data.anomaly_reason == "ml_outliers_detection" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterFuture(data) {
          var filterEnabled = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "future_over_tolerance";
          } else {
            return (
              data.anomaly_reason == "future_over_tolerance" &&
              data.monitored_state == "enabled"
            );
          }
        }

        //Trigger setFilter function with correct parameters
        function updateFilter() {
          var filterVal = fieldEl.options[fieldEl.selectedIndex].value;
          var typeVal = typeEl.options[typeEl.selectedIndex].value;

          // handle filter functions and normal filter
          var filter;
          if (filterVal == "function_high_priority") {
            filter = customFilterHighPriority;
          } else if (filterVal == "function_medium_priority") {
            filter = customFilterMediumPriority;
          } else if (filterVal == "function_low_priority") {
            filter = customFilterLowPriority;
          } else if (filterVal == "function_red_state_high_priority") {
            filter = customFilterRedStateHighPriority;
          } else if (filterVal == "function_red_state_medium_priority") {
            filter = customFilterRedStateMediumPriority;
          } else if (filterVal == "function_red_state_low_priority") {
            filter = customFilterRedStateLowPriority;
          } else if (filterVal == "function_enabled") {
            filter = customFilterEnabled;
          } else if (filterVal == "function_disabled") {
            filter = customFilterDisabled;
          } else if (filterVal == "function_lagthreshold_anomaly") {
            filter = customFilterLatencyTresholdAnomaly;
          } else if (filterVal == "function_delaythreshold_anomaly") {
            filter = customFilterDelayTresholdAnomaly;
          } else if (filterVal == "function_outliers_anomaly") {
            filter = customFilterOutliersAnomaly;
          } else if (filterVal == "function_future") {
            filter = customFilterFuture;
          } else if (filterVal == "function_red_state") {
            filter = customFilterRedState;
          } else if (filterVal == "function_orange_state") {
            filter = customFilterOrangeState;
          } else if (filterVal == "function_green_state") {
            filter = customFilterGreenState;
          } else if (filterVal == "function_blue_state") {
            filter = customFilterBlueState;
          } else if (filterVal == "function_alert_state") {
            filter = customFilterAlertState;
          } else {
            filter = filterVal;
          }

          // disable filters conditionally
          if (
            filterVal == "function_red_state" ||
            filterVal == "function_orange_state" ||
            filterVal == "function_green_state" ||
            filterVal == "function_blue_state" ||
            filterVal == "function_alert_state" ||
            filterVal == "function_red_state_high_priority" ||
            filterVal == "function_red_state_medium_priority" ||
            filterVal == "function_red_state_low_priority" ||
            filterVal == "function_high_priority" ||
            filterVal == "function_medium_priority" ||
            filterVal == "function_low_priority" ||
            filterVal == "function_enabled" ||
            filterVal == "function_disabled" ||
            filterVal == "function_lagthreshold_anomaly" ||
            filterVal == "function_delaythreshold_anomaly" ||
            filterVal == "function_hostdcount_anomaly" ||
            filterVal == "function_outliers_anomaly" ||
            filterVal == "function_future"
          ) {
            typeEl.disabled = true;
            valueEl.disabled = true;
          } else {
            typeEl.disabled = false;
            valueEl.disabled = false;
          }

          if (filterVal) {
            var filterEnabled = document.getElementById(
              "splk-dhm-table-filter-enabled"
            ).value;
            if (filterEnabled == "true") {
              table.setFilter(filter, typeVal, valueEl.value);
            } else {
              table.setFilter("monitored_state", "=", "enabled");
              table.addFilter(filter, typeVal, valueEl.value);
            }
          }
        }

        // Drilldown click from single all entities
        singleFormTotalSplkDhm.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dhm-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "like", value: "" },
            ]);
            // notify
            notify("success", "bottom", "Filtering on all entities.", "5");
          }
        });

        singleFormTotalSplkDhmAlerts.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dhm-table-filter-field").val("function_red_state");
            // set filters
            table.setFilter([
              {
                field: "object_state",
                type: "in",
                value: ["red", "orange", "blue"],
              },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on enabled entities in alert (red, orange, blue).",
              "5"
            );
          }
        });

        // Drilldown click from single high priority red
        singleFormTotalSplkDhmAlertsHighPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dhm-table-filter-field").val(
              "function_red_state_high_priority"
            );
            // set filters
            table.setFilter([
              { field: "object_state", type: "=", value: "red" },
              { field: "priority", type: "=", value: "high" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on high priority red entities.",
              "5"
            );
          }
        });

        singleFormTotalSplkDhmDisabled.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dhm-table-filter-field").val("function_disabled");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "disabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on all disabled entities.",
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkDhmCountByPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-dhm-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              {
                field: "priority",
                type: "like",
                value: e.data["row.priority"],
              },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on any state monitored entities with priority: " +
                e.data["row.priority"],
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkDhmCountByStateAndPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();

            // set clicked_state
            clicked_state = e.data["row.state"];

            if (
              clicked_state === "green" ||
              clicked_state === "blue" ||
              clicked_state === "orange" ||
              clicked_state === "red"
            ) {
              // update dropdown
              $("#splk-dhm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: clicked_state },
                {
                  field: "priority",
                  type: "like",
                  value: "",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on any priority monitored entities with state: " +
                  clicked_state,
                "5"
              );
            } else if (clicked_state === "red - other priority") {
              // update dropdown
              $("#splk-dhm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "in",
                  value: ["low", "medium"],
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on low or medium priority monitored entities with state: red",
                "5"
              );
            } else if (clicked_state === "red - high priority") {
              // update dropdown
              $("#splk-dhm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "=",
                  value: "high",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on high priority monitored entities with state: red",
                "5"
              );
            }
          }
        });

        //Update filters on value change
        document
          .getElementById("splk-dhm-table-filter-field")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-dhm-table-filter-type")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-dhm-table-filter-value")
          .addEventListener("keyup", updateFilter);

        //Clear filters on "Clear Filters" button click
        document
          .getElementById("splk-dhm-table-filter-clear")
          .addEventListener("click", function () {
            fieldEl.value = "object";
            typeEl.value = "like";
            valueEl.value = "";
            enabledEl = "false";
            table.clearFilter(true);
            table.setFilter("monitored_state", "=", "enabled");
            typeEl.disabled = false;
            valueEl.disabled = false;
            // notify
            notify(
              "success",
              "bottom",
              "Tabulator filters were reset successfully.",
              "5"
            );
          });

        // popup formatter
        var rowPopupFormatter = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Entity Details</strong><br/>";
          contents +=
            "<div style='max-height: 600px; width: 800px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
          contents +=
            "<li><strong>Entity name:</strong> " + data.object + "</li>";
          contents +=
            "<li><strong>Entity alias:</strong> " + data.alias + "</li>";
          contents +=
            "<li><strong>Index(es):</strong> " + data.data_index + "</li>";
          contents +=
            "<li><strong>Sourcetype(s):</strong> " +
            data.data_sourcetype +
            "</li>";
          contents +=
            "<li><strong>Entity keyid:</strong> " + data.keyid + "</li>";
          contents +=
            "<li><strong>State:</strong> " + data.object_state + "</li>";
          contents +=
            "<li><strong>AnomalyReason:</strong> " +
            data.anomaly_reason +
            "</li>";
          contents +=
            "<li><strong>Outliers anomaly detection state:</strong> " +
            data.OutliersStatus +
            "</li>";
          contents +=
            "<li><strong>Acknowledgement state:</strong> " +
            data.ack_state +
            "</li>";
          contents +=
            "<li><strong>Status message:</strong> " +
            data.status_message +
            "</li>";
          contents +=
            "<li><strong>Priority:</strong> " + data.priority + "</li>";
          contents +=
            "<li><strong>Lagging summary:</strong> " +
            data.lag_summary +
            "</li>";
          contents +=
            "<li><strong>Last ingest:</strong> " + data.last_ingest + "</li>";
          contents +=
            "<li><strong>Last event:</strong> " + data.last_time + "</li>";
          contents +=
            "<li><strong>Max latency allowed:</strong> " +
            data.data_max_lag_allowed +
            " seconds</li>";
          contents +=
            "<li><strong>Max delay allowed:</strong> " +
            data.data_max_delay_allowed +
            " seconds</li>";
          contents +=
            "<li><strong>Currently under monitoring days:</strong> " +
            data.isUnderMonitoringDays +
            "</li>";
          contents +=
            "<li><strong>Currently under monitoring hours:</strong> " +
            data.isUnderMonitoringHours +
            "</li>";
          contents +=
            "<li><strong>Date and time of last inspection:</strong> " +
            epochToHumanReadable(data.tracker_runtime) +
            "</li>";

          contents += "</ul></div>";

          container.innerHTML = contents;

          return container;
        };

        // popup formatter
        var rowPopupFormatterSourcetypesDetails = function (
          e,
          row,
          onRendered
        ) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Sourcetypes Details (use the scrollerbar to scroll down through details)</strong><br/>";
          contents +=
            "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>" +
            JSON.stringify(JSON.parse(data.splk_dhm_st_summary_full), null, 4);
          ("</code></pre></div>");
          container.innerHTML = contents;
          return container;
        };

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "keyid",
          layout: "fitDataFill", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 50, //allow 50 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          height: "100%", // fixed height
          //groupBy: "object",
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            {
              //create column group
              title: "Actions",
              columns: [
                // open
                {
                  formatter: openIcon,
                  width: 40,
                  hozAlign: "center",
                  cellClick: function (e, cell) {
                    // Open the entity modal
                    showSplkDhmEntityModal(
                      cell.getRow().getData(),
                      "modal_manage_splk_dhm",
                      "modal"
                    );
                  },
                },
                // tool
                {
                  formatter: toolIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("update_icon_visible"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkDhmEntityModal(
                      cell.getRow().getData(),
                      "modal_modify_splk_dhm_unified",
                      "modal"
                    );
                  },
                },
                // cmdb
                {
                  formatter: cmdbIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("cmdb_lookup"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkDhmEntityModal(
                      cell.getRow().getData(),
                      "modal_cmdb_splk_dhm",
                      "modal"
                    );
                  },
                },
              ],
            },
            {
              //create column group
              title: "Identifier/state (click: rename/right click: info)",
              columns: [
                //define the table columns
                {
                  title: "object",
                  field: "object",
                  visible: false,
                },
                {
                  title: "Entity",
                  field: "alias",
                  minWidth: getToken("ui_min_object_width"),
                  contextPopup: rowPopupFormatter, //add click popup to row
                  editor: true,
                  headerFilter: true,
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_bootstrap"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setBootstrapStatusIcons(status);
                  },
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_emoji"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setEmojiStatusIcons(status);
                  },
                },
              ],
            },
            {
              //create column group
              title: "Priority and monitoring state",
              columns: [
                {
                  title: "Priority",
                  field: "priority",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["low", "medium", "high"] },
                  headerFilter: "input",
                },
                {
                  title: "Monitoring",
                  field: "monitored_state",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["disabled", "enabled"] },
                  headerFilter: "input",
                },
              ],
            },
            {
              //create column group
              title: "Indexes and sourcetypes",
              columns: [
                {
                  title: "Summary (right click to show full details popup)",
                  field: "sourcetype_summary",
                  width: 450,
                  formatter: jsonFormatter,
                  contextPopup: rowPopupFormatterSourcetypesDetails,
                  variableHeight: true,
                  editor: false,
                  headerFilter: false,
                },
              ],
            },
            {
              //create column group
              title: "Current statistics and main indexing information",
              columns: [
                {
                  title: "lag (delay / latency)",
                  field: "lag_summary",
                  width: 160,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Latest event",
                  field: "last_time",
                  width: 140,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Latest ingest",
                  field: "last_ingest",
                  width: 140,
                  editor: false,
                  headerFilter: false,
                },
              ],
            },
            {
              //create column group
              title: "Thresholds and features status",
              columns: [
                {
                  title: "Delay",
                  field: "data_max_delay_allowed",
                  editor: "number",
                  editorParams: {
                    min: 0,
                    step: 300,
                    verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
                  },
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Duration",
                  field: "data_max_delay_allowed_duration",
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Latency",
                  field: "data_max_lag_allowed",
                  editor: "number",
                  editorParams: {
                    min: 0,
                    step: 300,
                    verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
                  },
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Duration",
                  field: "data_max_lag_allowed_duration",
                  headerFilter: false,
                  width: 110,
                },
                {
                  title: "Alerting policy",
                  field: "splk_dhm_alerting_policy",
                  editor: "list",
                  editorParams: {
                    values: [
                      "global_policy",
                      "track_per_sourcetype",
                      "track_per_host",
                    ],
                  },
                  headerFilter: "input",
                  width: 130,
                },
                {
                  title: "Outliers",
                  field: "OutliersIsOk",
                  contextPopup: rowPopupFormatterOutliers, //add click popup to row
                  hozAlign: "center",
                  formatter: "tickCross",
                  width: 100,
                },
              ],
            },
          ],
        });

        // Set initial filters
        function setInitialFilters() {
          var filterEnabledEl = document.getElementById(
            "splk-dhm-table-filter-enabled"
          ).value;
          if (filterEnabledEl == "true") {
            table.setFilter("monitored_state", "in", ["enabled", "disabled"]);
          } else if (filterEnabledEl == "false") {
            table.setFilter("monitored_state", "in", ["enabled"]);
          }
        }

        // reset and set filters (for listener)
        function resetAndSetInitialFilters() {
          var fieldEl = document.getElementById("splk-dhm-table-filter-field");
          var typeEl = document.getElementById("splk-dhm-table-filter-type");
          var valueEl = document.getElementById("splk-dhm-table-filter-value");
          fieldEl.value = "object";
          typeEl.value = "like";
          valueEl.value = "";
          table.clearFilter(true);
          setInitialFilters();
        }

        // Call it only once the table is built
        table.on("tableBuilt", function () {
          setInitialFilters();

          // create the change listener
          document
            .getElementById("splk-dhm-table-filter-enabled")
            .addEventListener("change", resetAndSetInitialFilters);
        });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $("#splk-dhm-table-bulk").prop("disabled", false);
            splkDhmPauseRefreshInfo();
          } else {
            $("#splk-dhm-table-bulk").prop("disabled", true);
            document.getElementById("splkDhmLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            splkDhmResumeTableRefresh();
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $("#splk-dhm-table-save").prop("disabled", false);
          $("#splk-dhm-table-cancel").prop("disabled", false);
          splkDhmPauseRefreshInfo();
        });

        // set the timer
        splkDhmRefreshInfo();

        // auto-refresh
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-dhm-table-refresh-hidden").click();
        }, 300000);

        // manual refresh
        $("#splk-dhm-table-refresh")
          .unbind()
          .click(function () {
            // notify
            notify("info", "bottom", "Please wait while refreshing...", "5");
            var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
              resultCall
            ) {
              // get current filters
              var currentFilters = table.getFilters(true);
              // clear filters
              table.clearFilter(true);
              // refresh data
              table.replaceData(resultCall);
              // re-apply filters
              table.setFilter(currentFilters);
              // notify
              notify(
                "success",
                "bottom",
                "Tabulator was refreshed successfully.",
                "5"
              );
              // refresh the timer
              splkDhmResetRefreshInfo();
            });
          });

        // auto hidden refresh
        $("#splk-dhm-table-refresh-hidden")
          .unbind()
          .click(function () {
            var doAsync = asyncAjaxNoLoader(ajaxUrl, ajaxType, ajaxData).then(
              function (resultCall) {
                // get current filters
                var currentFilters = table.getFilters(true);
                // clear filters
                table.clearFilter(true);
                // refresh data
                table.replaceData(resultCall);
                // re-apply filters
                table.setFilter(currentFilters);
                // refresh the timer
                splkDhmResetRefreshInfo();
              }
            );
          });

        // bulk edit
        $("#splk-dhm-table-bulk")
          .unbind()
          .click(function () {
            // get filters
            var allFilters = table.getFilters(true);

            // get selected rows
            var selectedData = table.getSelectedData(allFilters);

            // get data according to all filters and store in its array
            var searchData = table.searchData(allFilters);
            var searchList = [];
            for (var i = 0; i < searchData.length; i++) {
              searchList.push(searchData[i].keyid);
            }

            // loop and create a list of keys ensuring these are parts of the searched entities
            var itemList = [];
            var itemKeys = [];
            for (var i = 0; i < selectedData.length; i++) {
              if (searchList.includes(selectedData[i].keyid)) {
                itemList.push(selectedData[i].object);
                itemKeys.push(selectedData[i].keyid);
              }
            }

            // set a token for later usage
            setToken("splkDhmBulkObjs", itemList.toString());
            setToken("splkDhmBulkIds", itemKeys.toString());

            // count the number of selected entities and add to the bulk edit modal
            itemCount = itemList.length;
            $("#divDhmBulkdCount").html(
              '<h1><span style="color: #a7c7e7;">' +
                itemCount +
                " entities selected currently</span></h1>"
            );

            // open modal
            closeModals();
            $("#modal_entry_bulk_splk_dhm").modal();
          });

        // save inline edit
        $("#splk-dhm-table-save")
          .unbind()
          .click(function () {
            // disable the button
            $(this).prop("disabled", true);

            var selectedData = table.getData("active");
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              // create the JSON object
              record_object = {
                keyid: selectedData[i].keyid,
                object: selectedData[i].object,
                alias: selectedData[i].alias,
                priority: selectedData[i].priority,
                monitored_state: selectedData[i].monitored_state,
                data_override_lagging_class:
                  selectedData[i].data_override_lagging_class,
                data_lag_alert_kpis: selectedData[i].data_lag_alert_kpis,
                data_max_lag_allowed: selectedData[i].data_max_lag_allowed,
                data_max_delay_allowed: selectedData[i].data_max_delay_allowed,
                splk_dhm_alerting_policy:
                  selectedData[i].splk_dhm_alerting_policy,
              };
              // push to the array
              itemList.push(record_object);
            }
            // run the rest call
            var tk_tenant_id = getToken("tenant_id");

            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_bulk_edit";

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: tk_tenant_id,
              json_data: itemList,
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Run the search again to update the table
                searchSplkDhmMain.startSearch();
                // refresh tabulator
                $("#splk-dhm-table-refresh-hidden").click();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Entities bulk edit was performed successfully.",
                  "5"
                );
                // disable the cancel button
                $("#splk-dhm-table-cancel").prop("disabled", true);
                return;
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });

        // cancel inline edit
        $("#splk-dhm-table-cancel")
          .unbind()
          .click(function () {
            document.getElementById("splkDhmLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            // disable the button
            $(this).prop("disabled", true);
            // notify
            notify(
              "info",
              "bottom",
              "Inline changes canceled, refreshing the table.",
              "5"
            );
            // disable the save button
            $("#splk-dhm-table-save").prop("disabled", true);
            // refresh the table
            $("#splk-dhm-table-refresh-hidden").click();
          });

        // priority: create a function to limit code repetition
        function splkDhmBulkPriority(priority) {
          var tk_tenant_id = getToken("tenant_id");
          var splkDhmBulkIds = getToken("splkDhmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_priority";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-dhm",
            keys_list: splkDhmBulkIds,
            priority: priority,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();
              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk priority high
        $("#btn_splk_dhm_bulk_priority_high")
          .unbind()
          .click(function () {
            splkDhmBulkPriority("high");
          });

        // bulk priority medium
        $("#btn_splk_dhm_bulk_priority_medium")
          .unbind()
          .click(function () {
            splkDhmBulkPriority("medium");
          });

        // bulk priority low
        $("#btn_splk_dhm_bulk_priority_low")
          .unbind()
          .click(function () {
            splkDhmBulkPriority("low");
          });

        // reset: create a function to limit code repetition
        function splkDhmBulkreset() {
          var tk_tenant_id = getToken("tenant_id");
          var splkDhmBulkIds = getToken("splkDhmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_reset";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-dhm",
            keys_list: splkDhmBulkIds,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();
              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk reset
        $("#btn_splk_dhm_bulk_reset")
          .unbind()
          .click(function () {
            splkDhmBulkreset();
          });

        // priority: create a function to limit code repetition
        function splkDhmBulkAck(action) {
          var tk_tenant_id = getToken("tenant_id");
          var splkDhmBulkObjs = getToken("splkDhmBulkObjs");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // Create the endpoint URL and record
          var myendpoint_URl;
          var record;

          if (action == "enable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "enable",
              object_category: "splk-dhm",
              object_list: splkDhmBulkObjs,
              ack_period: "86400",
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          } else if (action == "disable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "disable",
              object_category: "splk-dhm",
              object_list: splkDhmBulkObjs,
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          }

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();
              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk ack enable
        $("#btn_splk_dhm_bulk_priority_enable_ack")
          .unbind()
          .click(function () {
            splkDhmBulkAck("enable");
          });

        // bulk ack disable
        $("#btn_splk_dhm_bulk_priority_disable_ack")
          .unbind()
          .click(function () {
            splkDhmBulkAck("disable");
          });

        // monitoring: create a function to limit code repetition
        function splkDhmBulkMonitoring(actionTarget) {
          var tk_tenant_id = getToken("tenant_id");
          var splkDhmBulkIds = getToken("splkDhmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_monitoring";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-dhm",
            keys_list: splkDhmBulkIds,
            action: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();
              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk enable
        $("#btn_splk_dhm_bulk_enable")
          .unbind()
          .click(function () {
            splkDhmBulkMonitoring("enable");
          });

        // bulk disable
        $("#btn_splk_dhm_bulk_disable")
          .unbind()
          .click(function () {
            splkDhmBulkMonitoring("disable");
          });

        // delete: create a function to limit code repetition
        function splkDhmBulkDelete(actionTarget) {
          var splkDhmBulkIds = getToken("splkDhmBulkIds");
          var tk_tenant_id = getToken("tenant_id");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_delete";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: splkDhmBulkIds,
            deletion_type: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Update
              $("#splk-dhm-table-refresh-hidden").click();
              var msg = "Entities bulk edit was performed successfully.";
              notify("success", "bottom", msg, "5");
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk delete temporary
        $("#btn_splk_dhm_bulk_deletion_temporary")
          .unbind()
          .click(function () {
            splkDhmBulkDelete("temporary");
          });

        // bulk delete permanent
        $("#btn_splk_dhm_bulk_deletion_permanent")
          .unbind()
          .click(function () {
            splkDhmBulkDelete("permanent");
          });

        // associate new logical group: create a function to limit code repetition
        function splkDhmBulkAssociateNewLogicalGroup() {
          var splkDhmBulkObjs = getToken("splkDhmBulkObjs");

          // this token is expected by the target
          setToken("tk_logical_group_target", splkDhmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-dhm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // Set required tokens
          setToken("tk_start_logical_member_get", "True");

          // hide this action
          $("#btn_associate_logical_group_add_group_back").hide();
          $("#btn_associate_logical_group_back").hide();

          // Open modal
          $("#logical_group_add_group").modal();
        }

        // bulk
        $("#btn_splk_dhm_bulk_associate_new_logical_group")
          .unbind()
          .click(function () {
            splkDhmBulkAssociateNewLogicalGroup();
          });

        // associate existing logical group: create a function to limit code repetition
        function splkDhmBulkAssociateExistingLogicalGroup() {
          var splkDhmBulkObjs = getToken("splkDhmBulkObjs");

          // this token is expected by the target
          setToken("tk_logical_group_target", splkDhmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-dhm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // Set required tokens
          setToken("tk_start_logical_member_add", "True");

          // Start search
          searchLogicalGroupTableAddMember.startSearch();

          // hide this action
          $("#btn_associate_logical_group_add_member_back").hide();

          // Open modal
          $("#logical_group_add_member").modal();
        }

        // bulk
        $("#btn_splk_dhm_bulk_associate_existing_logical_group")
          .unbind()
          .click(function () {
            splkDhmBulkAssociateExistingLogicalGroup();
          });

        // unassociate logical group: create a function to limit code repetition
        function splkDhmBulkUnassociateLogicalGroup() {
          var splkDhmBulkObjs = getToken("splkDhmBulkObjs");

          // Free the search
          setToken("tk_start_logical_member_get", "true");

          // Start the search
          searchLogicalGroupTable.startSearch();

          // this token is expected by the target
          setToken("tk_logical_group_target", splkDhmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-dhm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_dhm_bulk_comment");

          // hide this action
          $("#btn_associate_logical_group_back").hide();

          // Open modal
          $("#logical_group").modal();
        }

        // bulk
        $("#btn_splk_dhm_bulk_unassociate_logical_group")
          .unbind()
          .click(function () {
            splkDhmBulkUnassociateLogicalGroup();
          });

        //
        // end
        //
      });
    }

    // splk-dhm get table
    function getSplkDhmTable() {
      var tk_tenant_id = getToken("tenant_id");
      // avoid causing double interval
      clearInterval(splkDhmIntervalId);
      // get viz mode
      var modeView = document.getElementById("splk-dhm-table-mode").value;

      // get data
      splkDhmHandlerTable(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/dh_get_table",
        "POST",
        { tenant_id: tk_tenant_id, mode: modeView, key_id: "*" },
        modeView
      );
    }

    // splk-dhm refresh timer
    var splkDhmIntervalId;

    function splkDhmRefreshInfo() {
      var myDate = new Date();
      var splkDhmLastRefresh = document.getElementById("splkDhmLastRefresh");
      function updateTime() {
        splkDhmLastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
      }

      splkDhmIntervalId = setInterval(updateTime, 2000);
    }

    function splkDhmResetRefreshInfo() {
      clearInterval(splkDhmIntervalId);
      // release our intervalID from the variable
      splkDhmIntervalId = null;
      splkDhmRefreshInfo();
    }

    function splkDhmPauseRefreshInfo() {
      clearInterval(splkDhmIntervalId);
      clearInterval(tableRefreshIntervalId);
      // release our intervalID from the variable
      splkDhmIntervalId = null;
      tableRefreshIntervalId = null;
      splkDhmLastRefresh.innerText =
        "auto-refresh table is paused until inline changes are saved or cancelled";
    }

    function splkDhmResumeTableRefresh() {
      if (!tableRefreshIntervalId) {
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-dhm-table-refresh-hidden").click();
        }, 300000);
      }
    }

    // splk-dhm modal entity view

    function showSplkDhmEntityModal(jsonData, actionTarget, actionType) {
      // mainTokens
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);

      // Get tenant and manage replica
      var tk_tenant_id = jsonData["tenant_id"];
      var tk_parent_tenant_id = jsonData["tenant_parent"];

      // handle replica
      var target_tenant_id = tk_parent_tenant_id || tk_tenant_id;
      if (tk_parent_tenant_id) {
        setToken("tenant_id", target_tenant_id);
      }

      // get entity details
      var tk_splk_dhm = jsonData["object"];
      var tk_alias = jsonData["alias"];
      var tk_object = tk_splk_dhm;
      var tk_object_category = jsonData["object_category"];
      // token is required
      setToken("tk_object_category", tk_object_category);
      var tk_priority = jsonData["priority"];
      // token required for priority audit change
      setToken("tk_priority", tk_priority);
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);
      var tk_object_state = jsonData["object_state"];
      var tk_data_monitored_state = jsonData["monitored_state"];
      var tk_data_lag_summary = jsonData["lag_summary"];
      var tk_data_last_ingest_human = jsonData["last_ingest"];
      var tk_data_last_time_seen_human = jsonData["last_time"];
      var tk_data_max_lag_allowed = jsonData["data_max_lag_allowed"];
      var tk_data_max_lag_allowed_duration =
        jsonData["data_max_lag_allowed_duration"];
      var tk_data_max_delay_allowed = jsonData["data_max_delay_allowed"];
      var tk_data_max_delay_allowed_duration =
        jsonData["data_max_delay_allowed_duration"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      // token required for auto lagging
      setToken("tk_data_max_lag_allowed", tk_data_max_lag_allowed);
      setToken("tk_data_max_delay_allowed", tk_data_max_delay_allowed);
      var tk_data_override_lagging_class =
        jsonData["data_override_lagging_class"];
      // required for auto lagging
      setToken(
        "tk_data_override_lagging_class",
        tk_data_override_lagging_class
      );

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divDhmOutliersInfo").css("display", "none");
        $("#divDhmOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divDhmOutliersSimulationInfo").css("display", "none");
        $("#divDhmOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_dhm_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_dhm_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divDhmOutliersInfo").css("display", "inherit");
        $("#divDhmOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-dhm-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divDhmOutliersSimulationInfo").css("display", "inherit");
        $("#divDhmOutliersSimulationRender").css("display", "none");
        $("#child-dhm-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_dhm_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_dhm_save").prop("disabled", true);
      }

      // required for various purposes
      setToken("tk_keyid", tk_keyid);
      setToken("tk_splk_dhm", tk_splk_dhm);
      setToken("tk_object", tk_object);
      setToken("tk_object_category", tk_object_category);

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      if (tk_data_monitored_state == "enabled") {
        document.getElementById("btn_enable_monitoring_host").disabled = true;
        document.getElementById("btn_disable_monitoring_host").disabled = false;
        tk_data_monitored_state_class = "title_green";
      } else {
        document.getElementById("btn_enable_monitoring_host").disabled = false;
        document.getElementById("btn_disable_monitoring_host").disabled = true;
        tk_data_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_dhm_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_dhm_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_dhm_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_dhm_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_dhm").disabled = false;
        $("#btn_ack_splk_dhm").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_dhm").disabled = false;
        $("#btn_ack_splk_dhm").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_dhm").disabled = false;
        $("#btn_ack_splk_dhm").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_dhm").disabled = true;
        $("#btn_ack_splk_dhm").html("Acknowledge alert");
      }

      // replace info panels
      $("#parent-data-host-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_splk_dhm +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-data-host-top-info1").html(
        '<h3>Delay event / latency ingestion: ([D+]HH:MM:SS) <span style="color: dodgerblue;">' +
          tk_data_lag_summary +
          '<span style="color: dodgerblue;">' +
          '<h3>Last time seen: <span style="color: dodgerblue;">' +
          tk_data_last_time_seen_human +
          '<span style="color: dodgerblue;">' +
          '<h3>Last ingest: <span style="color: dodgerblue;">' +
          tk_data_last_ingest_human +
          '<span style="color: dodgerblue;">'
      );

      $("#child-data-host-top-info2").html(
        '<h3>Threshold lag ingestion / delay: <span style="color: dodgerblue;">' +
          tk_data_max_lag_allowed +
          " sec (" +
          tk_data_max_lag_allowed_duration +
          ") / " +
          tk_data_max_delay_allowed +
          " sec (" +
          tk_data_max_delay_allowed_duration +
          ")" +
          '<span style="color: dodgerblue;">' +
          '<h3>Monitored state:</b> <span class="' +
          tk_data_monitored_state_class +
          '">' +
          tk_data_monitored_state +
          "</span></h3>" +
          '<h3>State:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></p>"
      );

      $("#child-data-host-top-info3").html(
        '<h3>Latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>Latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">' +
          '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></p>"
      );

      $("#child-data-host-status-message").html(
        '<div class="' +
          tk_splk_dhm_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );

      // pre-fill current lagging input
      setToken("form.tk_input_lag_host", jsonData["data_max_lag_allowed"]);

      // pre-fill current delay input
      setToken("form.tk_input_delay_host", jsonData["data_max_delay_allowed"]);

      // pre-fill future tolerance
      setToken(
        "form.tk_input_future_tolerance_host",
        jsonData["future_tolerance"]
      );

      // pre-fill current wdays input
      setToken("form.tk_input_wdays_host", jsonData["data_monitoring_wdays"]);

      // pre-fill current hours ranges
      setToken(
        "form.tk_input_splk_dhm_hours_ranges",
        jsonData["data_monitoring_hours_ranges"]
      );

      // pre-fill current priority
      setToken("form.tk_input_host_priority", jsonData["priority"]);

      // pre-fill lagging class override
      setToken(
        "form.modal_input_lag_override_class_host",
        jsonData["data_override_lagging_class"]
      );

      // pre-fill allow_adaptive_delay
      setToken(
        "form.modal_input_allow_adaptive_delay_host",
        jsonData["allow_adaptive_delay"]
      );

      // pre-fill alert over kpis
      setToken(
        "form.tk_input_data_lag_alert_kpis_host",
        jsonData["data_lag_alert_kpis"]
      );

      // pre-fill alerting policy
      setToken(
        "form.tk_input_host_alerting_policy",
        jsonData["splk_dhm_alerting_policy"]
      );

      // spinner
      cssloader("Requested action is in progress, please wait...");

      // Retrieve entity info from REST and set actions
      $.ajax({
        url: "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/dh_entity_info",
        type: "POST",
        async: true,
        contentType: "application/json",
        data: JSON.stringify({
          tenant_id: target_tenant_id,
          object: jsonData["object"],
        }),
        success: function (returneddata) {
          // spinner
          cssloaderremove();

          // get from the json response

          // Set some tokens first
          var splk_dhm_raw_search = returneddata["splk_dhm_raw_search"];

          // get the selected data provider
          var splk_dhm_data_provider = getToken(
            "tk_input_splk_dhm_overview_data_provider"
          );

          // get
          var splk_dhm_overview_trackme_single_stats =
            returneddata["splk_dhm_overview_trackme_single_stats"];
          setToken(
            "tk_splk_dhm_overview_trackme_single_stats",
            splk_dhm_overview_trackme_single_stats
          );

          var splk_dhm_overview_trackme_pie_root_search =
            returneddata["splk_dhm_overview_trackme_pie_root_search"];
          setToken(
            "tk_splk_dhm_overview_trackme_pie_root_search",
            splk_dhm_overview_trackme_pie_root_search
          );

          var splk_dhm_overview_trackme_timechart =
            returneddata["splk_dhm_overview_trackme_timechart"];
          setToken(
            "tk_splk_dhm_overview_trackme_timechart",
            splk_dhm_overview_trackme_timechart
          );

          var splk_dhm_overview_splunk_pie_root_search =
            returneddata["splk_dhm_overview_splunk_pie_root_search"];
          setToken(
            "tk_splk_dhm_overview_splunk_pie_root_search",
            splk_dhm_overview_splunk_pie_root_search
          );

          var splk_dhm_overview_splunk_timechart =
            returneddata["splk_dhm_overview_splunk_timechart"];
          setToken(
            "tk_splk_dhm_overview_splunk_timechart",
            splk_dhm_overview_splunk_timechart
          );

          var splk_dhm_overview_splunk_single_stats =
            returneddata["splk_dhm_overview_splunk_single_stats"];
          setToken(
            "tk_splk_dhm_overview_splunk_single_stats",
            splk_dhm_overview_splunk_single_stats
          );

          // set searches dynamically
          if (splk_dhm_data_provider === "trackme") {
            setToken(
              "tk_splk_dhm_overview_single_stats",
              splk_dhm_overview_trackme_single_stats
            );
            setToken(
              "tk_splk_dhm_overview_pie_root_search",
              splk_dhm_overview_trackme_pie_root_search
            );
            setToken(
              "tk_splk_dhm_overview_timechart",
              splk_dhm_overview_trackme_timechart
            );
          } else if (splk_dhm_data_provider === "splunk") {
            setToken(
              "tk_splk_dhm_overview_single_stats",
              splk_dhm_overview_splunk_single_stats
            );
            setToken(
              "tk_splk_dhm_overview_pie_root_search",
              splk_dhm_overview_splunk_pie_root_search
            );
            setToken(
              "tk_splk_dhm_overview_timechart",
              splk_dhm_overview_splunk_timechart
            );
          } else {
            setToken(
              "tk_splk_dhm_overview_single_stats",
              splk_dhm_overview_trackme_single_stats
            );
            setToken(
              "tk_splk_dhm_overview_pie_root_search",
              splk_dhm_overview_trackme_pie_root_search
            );
            setToken(
              "tk_splk_dhm_overview_timechart",
              splk_dhm_overview_trackme_timechart
            );
          }

          // Define the URL target
          document.getElementById("btn_search_splk_dhm").href =
            splk_dhm_raw_search;
          // token is required for dynamic override
          setToken("tk_splk_dhm_raw_search", splk_dhm_raw_search);
          // Run
          if (
            getToken("userLevel") === "user" &&
            actionTarget.startsWith("modal_modify_")
          ) {
            $("#modal_user_restricted").modal();
          } else {
            if (actionType === "modal") {
              if (actionTarget === "modal_cmdb_splk_dhm") {
                searchCmdbSplkDhm.startSearch();
              }
              $("#" + actionTarget).modal();
            } else if (actionType === "click") {
              $("#" + actionTarget).click();
            }
          }
          //
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          // avoid running anything unexpected
          unsetToken("tk_splk_dhm_overview_trackme_single_stats");
          unsetToken("tk_splk_dhm_overview_trackme_pie_root_search");
          unsetToken("tk_splk_dhm_overview_trackme_timechart");
          unsetToken("tk_splk_dhm_overview_splunk_pie_root_search");
          unsetToken("tk_splk_dhm_overview_splunk_timechart");
          unsetToken("tk_splk_dhm_overview_splunk_single_stats");
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });
    }

    //
    // splk-mhm
    //

    // disable the bulk edit button
    $("#splk-mhm-table-bulk").prop("disabled", true);

    // disable the inline save button
    $("#splk-mhm-table-save").prop("disabled", true);

    // disable the inline cancel button
    $("#splk-mhm-table-cancel").prop("disabled", true);

    // splk-mhm tabulator
    function splkMhmHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // set the table div
        var tabulatorElement = "#" + "splk-mhm-table";

        function jsonFormatter(cell, formatterParams, onRendered) {
          // get mode
          var modeView = document.getElementById("splk-mhm-table-mode").value;

          if (modeView === "minimal") {
            return JSON.stringify(JSON.parse(cell.getValue()), null, 4);
          } else {
            cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
            return JSON.stringify(JSON.parse(cell.getValue()), null, 4);
          }
        }

        function csvFormatter(cell, formatterParams, onRendered) {
          cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
          obj = cell.getValue().toString().split(",");
          return JSON.stringify(obj, null, 1); //return JSON formatted cell
        }

        //Generate open icon
        var openIcon = function (cell, formatterParams) {
          return "<i class='bi bi-box-arrow-up-right'></i>";
        };

        //Generate tool icon
        var toolIcon = function (cell, formatterParams) {
          return "<i class='bi bi-tools'></i>";
        };

        //Generate cmdb icon
        var cmdbIcon = function (cell, formatterParams) {
          return "<i class='bi bi-database-fill-gear'></i>";
        };

        // filters
        //Define variables for input elements

        var fieldEl = document.getElementById("splk-mhm-table-filter-field");
        var typeEl = document.getElementById("splk-mhm-table-filter-type");
        var valueEl = document.getElementById("splk-mhm-table-filter-value");
        var enabledEl = document.getElementById(
          "splk-mhm-table-filter-enabled"
        );

        // listen for a change
        $("#splk-mhm-table-mode").change(function () {
          var newmodeView = document.getElementById(
            "splk-mhm-table-mode"
          ).value;
          // loop through each object in the resultCall array
          resultCall.forEach(function (obj) {
            if (newmodeView === "compact") {
              // if the mode is compact, set the 'summary' field to the value of 'summary_compact'
              obj["metric_details"] = obj["metric_details_compact"];
            } else if (newmodeView === "full") {
              // if the mode is full, set the 'summary' field to the value of 'summary_full'
              obj["metric_details"] = obj["metric_details_full"];
            } else if (newmodeView === "minimal") {
              // if the mode is minimal
              obj["metric_details"] = obj["metric_details_minimal"];
            }
          });
          table.replaceData(resultCall);
        });

        // custom functions

        function customFilterRedState(data, filterEnabled) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red";
          } else {
            return (
              data.object_state == "red" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOrangeState(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "orange";
          } else {
            return (
              data.object_state == "orange" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterGreenState(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "green";
          } else {
            return (
              data.object_state == "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterBlueState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "blue";
          } else {
            return (
              data.object_state == "blue" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterAlertState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state != "green";
          } else {
            return (
              data.object_state != "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "high";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "high" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "medium";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "medium" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "low";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "low" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "high";
          } else {
            return data.priority == "high" && data.monitored_state == "enabled";
          }
        }

        function customFilterMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "medium";
          } else {
            return (
              data.priority == "medium" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterEnabled(data) {
          return data.monitored_state == "enabled";
        }

        function customFilterDisabled(data) {
          return data.monitored_state == "disabled";
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterLatencyTresholdAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "lag_threshold_breached";
          } else {
            return (
              data.anomaly_reason == "lag_threshold_breached" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterFuture(data) {
          var filterEnabled = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "future_over_tolerance";
          } else {
            return (
              data.anomaly_reason == "future_over_tolerance" &&
              data.monitored_state == "enabled"
            );
          }
        }

        //Trigger setFilter function with correct parameters
        function updateFilter() {
          var filterVal = fieldEl.options[fieldEl.selectedIndex].value;
          var typeVal = typeEl.options[typeEl.selectedIndex].value;

          // handle filter functions and normal filter
          var filter;
          if (filterVal == "function_high_priority") {
            filter = customFilterHighPriority;
          } else if (filterVal == "function_medium_priority") {
            filter = customFilterMediumPriority;
          } else if (filterVal == "function_low_priority") {
            filter = customFilterLowPriority;
          } else if (filterVal == "function_red_state_high_priority") {
            filter = customFilterRedStateHighPriority;
          } else if (filterVal == "function_red_state_medium_priority") {
            filter = customFilterRedStateMediumPriority;
          } else if (filterVal == "function_red_state_low_priority") {
            filter = customFilterRedStateLowPriority;
          } else if (filterVal == "function_enabled") {
            filter = customFilterEnabled;
          } else if (filterVal == "function_disabled") {
            filter = customFilterDisabled;
          } else if (filterVal == "function_lagthreshold_anomaly") {
            filter = customFilterLatencyTresholdAnomaly;
          } else if (filterVal == "function_future") {
            filter = customFilterFuture;
          } else if (filterVal == "function_red_state") {
            filter = customFilterRedState;
          } else if (filterVal == "function_orange_state") {
            filter = customFilterOrangeState;
          } else if (filterVal == "function_green_state") {
            filter = customFilterGreenState;
          } else if (filterVal == "function_blue_state") {
            filter = customFilterBlueState;
          } else if (filterVal == "function_alert_state") {
            filter = customFilterAlertState;
          } else {
            filter = filterVal;
          }

          // disable filters conditionally
          if (
            filterVal == "function_red_state" ||
            filterVal == "function_orange_state" ||
            filterVal == "function_green_state" ||
            filterVal == "function_blue_state" ||
            filterVal == "function_alert_state" ||
            filterVal == "function_red_state_high_priority" ||
            filterVal == "function_red_state_medium_priority" ||
            filterVal == "function_red_state_low_priority" ||
            filterVal == "function_high_priority" ||
            filterVal == "function_medium_priority" ||
            filterVal == "function_low_priority" ||
            filterVal == "function_enabled" ||
            filterVal == "function_disabled" ||
            filterVal == "function_lagthreshold_anomaly" ||
            filterVal == "function_hostdcount_anomaly" ||
            filterVal == "function_outliers_anomaly" ||
            filterVal == "function_future"
          ) {
            typeEl.disabled = true;
            valueEl.disabled = true;
          } else {
            typeEl.disabled = false;
            valueEl.disabled = false;
          }

          if (filterVal) {
            var filterEnabled = document.getElementById(
              "splk-mhm-table-filter-enabled"
            ).value;
            if (filterEnabled == "true") {
              table.setFilter(filter, typeVal, valueEl.value);
            } else {
              table.setFilter("monitored_state", "=", "enabled");
              table.addFilter(filter, typeVal, valueEl.value);
            }
          }
        }

        // Drilldown click from single all entities
        singleFormTotalSplkMhm.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-mhm-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "like", value: "" },
            ]);
            // notify
            notify("success", "bottom", "Filtering on all entities.", "5");
          }
        });

        singleFormTotalSplkMhmAlerts.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-mhm-table-filter-field").val("function_red_state");
            // set filters
            table.setFilter([
              {
                field: "object_state",
                type: "in",
                value: ["red", "orange", "blue"],
              },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on enabled entities in alert (red, orange, blue).",
              "5"
            );
          }
        });

        // Drilldown click from single high priority red
        singleFormTotalSplkMhmAlertsHighPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-mhm-table-filter-field").val(
              "function_red_state_high_priority"
            );
            // set filters
            table.setFilter([
              { field: "object_state", type: "=", value: "red" },
              { field: "priority", type: "=", value: "high" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on high priority red entities.",
              "5"
            );
          }
        });

        singleFormTotalSplkMhmDisabled.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-mhm-table-filter-field").val("function_disabled");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "disabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on all disabled entities.",
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkMhmCountByPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-mhm-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              {
                field: "priority",
                type: "like",
                value: e.data["row.priority"],
              },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on any state monitored entities with priority: " +
                e.data["row.priority"],
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkMhmCountByStateAndPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();

            // set clicked_state
            clicked_state = e.data["row.state"];

            if (
              clicked_state === "green" ||
              clicked_state === "blue" ||
              clicked_state === "orange" ||
              clicked_state === "red"
            ) {
              // update dropdown
              $("#splk-mhm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: clicked_state },
                {
                  field: "priority",
                  type: "like",
                  value: "",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on any priority monitored entities with state: " +
                  clicked_state,
                "5"
              );
            } else if (clicked_state === "red - other priority") {
              // update dropdown
              $("#splk-mhm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "in",
                  value: ["low", "medium"],
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on low or medium priority monitored entities with state: red",
                "5"
              );
            } else if (clicked_state === "red - high priority") {
              // update dropdown
              $("#splk-mhm-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "=",
                  value: "high",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on high priority monitored entities with state: red",
                "5"
              );
            }
          }
        });

        //Update filters on value change
        document
          .getElementById("splk-mhm-table-filter-field")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-mhm-table-filter-type")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-mhm-table-filter-value")
          .addEventListener("keyup", updateFilter);

        //Clear filters on "Clear Filters" button click
        document
          .getElementById("splk-mhm-table-filter-clear")
          .addEventListener("click", function () {
            fieldEl.value = "object";
            typeEl.value = "like";
            valueEl.value = "";
            enabledEl = "false";
            table.clearFilter(true);
            table.setFilter("monitored_state", "=", "enabled");
            typeEl.disabled = false;
            valueEl.disabled = false;
            // notify
            notify(
              "success",
              "bottom",
              "Tabulator filters were reset successfully.",
              "5"
            );
          });

        // popup formatter
        var rowPopupFormatter = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Entity Details</strong><br/>";
          contents +=
            "<div style='max-height: 600px; width: 800px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
          contents +=
            "<li><strong>Entity name:</strong> " + data.object + "</li>";
          contents +=
            "<li><strong>Entity alias:</strong> " + data.alias + "</li>";
          contents +=
            "<li><strong>Index(es):</strong> " +
            JSON.stringify(data.metric_index.toString().split(","), null, 1) +
            "</li>";
          contents +=
            "<li><strong>Metric categorie(s):</strong> " +
            JSON.stringify(
              data.metric_category.toString().split(","),
              null,
              1
            ) +
            "</li>";
          contents +=
            "<li><strong>Entity keyid:</strong> " + data.keyid + "</li>";
          contents +=
            "<li><strong>State:</strong> " + data.object_state + "</li>";
          contents +=
            "<li><strong>Acknowledgement state:</strong> " +
            data.ack_state +
            "</li>";
          contents +=
            "<li><strong>Status message:</strong> " +
            data.status_message +
            "</li>";
          contents +=
            "<li><strong>Priority:</strong> " + data.priority + "</li>";
          contents +=
            "<li><strong>Lagging summary:</strong> " +
            data.lag_summary +
            "</li>";
          contents +=
            "<li><strong>Last metric:</strong> " + data.last_time + "</li>";
          contents +=
            "<li><strong>Currently under monitoring days:</strong> " +
            data.isUnderMonitoringDays +
            "</li>";
          contents +=
            "<li><strong>Currently under monitoring hours:</strong> " +
            data.isUnderMonitoringHours +
            "</li>";
          contents +=
            "<li><strong>Date and time of last inspection:</strong> " +
            epochToHumanReadable(data.tracker_runtime) +
            "</li>";

          contents += "</ul></div>";

          container.innerHTML = contents;

          return container;
        };

        // popup formatter
        var rowPopupFormatterMetricsDetails = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Metrics Details (use the scrollerbar to scroll down through details)</strong><br/>";
          contents +=
            "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>" +
            JSON.stringify(JSON.parse(data.metric_details_full), null, 4);
          ("</code></pre></div>");
          container.innerHTML = contents;
          return container;
        };

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "keyid",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 50, //allow 50 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          height: "100%", // fixed height
          //groupBy: "object",
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            {
              //create column group
              title: "Actions",
              columns: [
                // open
                {
                  formatter: openIcon,
                  width: 40,
                  hozAlign: "center",
                  cellClick: function (e, cell) {
                    // Open the entity modal
                    showSplkMhmEntityModal(
                      cell.getRow().getData(),
                      "modal_manage_splk_mhm",
                      "modal"
                    );
                  },
                },
                // tool
                {
                  formatter: toolIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("update_icon_visible"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkMhmEntityModal(
                      cell.getRow().getData(),
                      "modal_modify_splk_mhm_unified",
                      "modal"
                    );
                  },
                },
                // cmdb
                {
                  formatter: cmdbIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("cmdb_lookup"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkMhmEntityModal(
                      cell.getRow().getData(),
                      "modal_cmdb_splk_mhm",
                      "modal"
                    );
                  },
                },
              ],
            },
            {
              //create column group
              title: "Identifier/state (click: rename/right click: info)",
              columns: [
                //define the table columns
                {
                  title: "object",
                  field: "object",
                  visible: false,
                },
                {
                  title: "Entity",
                  field: "alias",
                  contextPopup: rowPopupFormatter, //add click popup to row
                  minWidth: getToken("ui_min_object_width"),
                  editor: true,
                  headerFilter: true,
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_bootstrap"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setBootstrapStatusIcons(status);
                  },
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_emoji"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setEmojiStatusIcons(status);
                  },
                },
              ],
            },
            {
              //create column group
              title: "Priority and monitoring state",
              columns: [
                {
                  title: "Priority",
                  field: "priority",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["low", "medium", "high"] },
                  headerFilter: "input",
                },
                {
                  title: "Monitoring",
                  field: "monitored_state",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["disabled", "enabled"] },
                  headerFilter: "input",
                },
              ],
            },
            {
              //create column group
              title: "Indexes and metric details",
              columns: [
                {
                  title: "Index(es)",
                  field: "metric_index",
                  width: 160,
                  formatter: csvFormatter,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Summary (right click to show full details popup)",
                  field: "metric_details",
                  width: 650,
                  formatter: jsonFormatter,
                  contextPopup: rowPopupFormatterMetricsDetails,
                  variableHeight: true,
                  editor: false,
                  headerFilter: false,
                },
              ],
            },
            {
              //create column group
              title: "Current stats and main indexing info",
              columns: [
                {
                  title: "Metric lag",
                  field: "lag_summary",
                  width: 160,
                  editor: false,
                  headerFilter: false,
                },
                {
                  title: "Metric latest",
                  field: "last_time",
                  width: 160,
                  editor: false,
                  headerFilter: false,
                },
              ],
            },
          ],
        });

        // Set initial filters
        function setInitialFilters() {
          var filterEnabledEl = document.getElementById(
            "splk-mhm-table-filter-enabled"
          ).value;
          if (filterEnabledEl == "true") {
            table.setFilter("monitored_state", "in", ["enabled", "disabled"]);
          } else if (filterEnabledEl == "false") {
            table.setFilter("monitored_state", "in", ["enabled"]);
          }
        }

        // reset and set filters (for listener)
        function resetAndSetInitialFilters() {
          var fieldEl = document.getElementById("splk-mhm-table-filter-field");
          var typeEl = document.getElementById("splk-mhm-table-filter-type");
          var valueEl = document.getElementById("splk-mhm-table-filter-value");
          fieldEl.value = "object";
          typeEl.value = "like";
          valueEl.value = "";
          table.clearFilter(true);
          setInitialFilters();
        }

        // Call it only once the table is built
        table.on("tableBuilt", function () {
          setInitialFilters();

          // create the change listener
          document
            .getElementById("splk-mhm-table-filter-enabled")
            .addEventListener("change", resetAndSetInitialFilters);
        });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $("#splk-mhm-table-bulk").prop("disabled", false);
            splkMhmPauseRefreshInfo();
          } else {
            $("#splk-mhm-table-bulk").prop("disabled", true);
            document.getElementById("splkMhmLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            splkMhmResumeTableRefresh();
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $("#splk-mhm-table-save").prop("disabled", false);
          $("#splk-mhm-table-cancel").prop("disabled", false);
          splkMhmPauseRefreshInfo();
        });

        // set the timer
        splkMhmRefreshInfo();

        // auto-refresh
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-mhm-table-refresh-hidden").click();
        }, 300000);

        // manual refresh
        $("#splk-mhm-table-refresh")
          .unbind()
          .click(function () {
            // notify
            notify("info", "bottom", "Please wait while refreshing...", "5");
            var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
              resultCall
            ) {
              // get current filters
              var currentFilters = table.getFilters(true);
              // clear filters
              table.clearFilter(true);
              // refresh data
              table.replaceData(resultCall);
              // re-apply filters
              table.setFilter(currentFilters);
              // notify
              notify(
                "success",
                "bottom",
                "Tabulator was refreshed successfully.",
                "5"
              );
              // refresh the timer
              splkMhmResetRefreshInfo();
            });
          });

        // auto hidden refresh
        $("#splk-mhm-table-refresh-hidden")
          .unbind()
          .click(function () {
            var doAsync = asyncAjaxNoLoader(ajaxUrl, ajaxType, ajaxData).then(
              function (resultCall) {
                // get current filters
                var currentFilters = table.getFilters(true);
                // clear filters
                table.clearFilter(true);
                // refresh data
                table.replaceData(resultCall);
                // re-apply filters
                table.setFilter(currentFilters);
                // refresh the timer
                splkMhmResetRefreshInfo();
              }
            );
          });

        // bulk edit
        $("#splk-mhm-table-bulk")
          .unbind()
          .click(function () {
            // get filters
            var allFilters = table.getFilters(true);

            // get selected rows
            var selectedData = table.getSelectedData(allFilters);

            // get data according to all filters and store in its array
            var searchData = table.searchData(allFilters);
            var searchList = [];
            for (var i = 0; i < searchData.length; i++) {
              searchList.push(searchData[i].keyid);
            }

            // loop and create a list of keys ensuring these are parts of the searched entities
            var itemList = [];
            var itemKeys = [];
            for (var i = 0; i < selectedData.length; i++) {
              if (searchList.includes(selectedData[i].keyid)) {
                itemList.push(selectedData[i].object);
                itemKeys.push(selectedData[i].keyid);
              }
            }

            // set a token for later usage
            setToken("splkMhmBulkObjs", itemList.toString());
            setToken("splkMhmBulkIds", itemKeys.toString());

            // count the number of selected entities and add to the bulk edit modal
            itemCount = itemList.length;
            $("#divMhmBulkdCount").html(
              '<h1><span style="color: #a7c7e7;">' +
                itemCount +
                " entities selected currently</span></h1>"
            );

            // open modal
            closeModals();
            $("#modal_entry_bulk_splk_mhm").modal();
          });

        // save inline edit
        $("#splk-mhm-table-save")
          .unbind()
          .click(function () {
            // disable the button
            $(this).prop("disabled", true);

            var selectedData = table.getData("active");
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              // create the JSON object
              record_object = {
                keyid: selectedData[i].keyid,
                object: selectedData[i].object,
                alias: selectedData[i].alias,
                priority: selectedData[i].priority,
                monitored_state: selectedData[i].monitored_state,
              };
              // push to the array
              itemList.push(record_object);
            }
            // run the rest call
            var tk_tenant_id = getToken("tenant_id");

            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_bulk_edit";

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: tk_tenant_id,
              json_data: itemList,
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Run the search again to update the table
                searchSplkMhmMain.startSearch();
                // refresh tabulator
                $("#splk-mhm-table-refresh-hidden").click();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Entities bulk edit was performed successfully.",
                  "5"
                );
                // disable the cancel button
                $("#splk-mhm-table-cancel").prop("disabled", true);
                return;
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });

        // cancel inline edit
        $("#splk-mhm-table-cancel")
          .unbind()
          .click(function () {
            document.getElementById("splkMhmLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            // disable the button
            $(this).prop("disabled", true);
            // notify
            notify(
              "info",
              "bottom",
              "Inline changes canceled, refreshing the table.",
              "5"
            );
            // disable the save button
            $("#splk-mhm-table-save").prop("disabled", true);
            // refresh the table
            $("#splk-mhm-table-refresh-hidden").click();
          });

        // priority: create a function to limit code repetition
        function splkMhmBulkPriority(priority) {
          var tk_tenant_id = getToken("tenant_id");
          var splkMhmBulkIds = getToken("splkMhmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_update_priority";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-mhm",
            keys_list: splkMhmBulkIds,
            priority: priority,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkMhmMain.startSearch();
              // refresh tabulator
              $("#splk-mhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk priority high
        $("#btn_splk_mhm_bulk_priority_high")
          .unbind()
          .click(function () {
            splkMhmBulkPriority("high");
          });

        // bulk priority medium
        $("#btn_splk_mhm_bulk_priority_medium")
          .unbind()
          .click(function () {
            splkMhmBulkPriority("medium");
          });

        // bulk priority low
        $("#btn_splk_mhm_bulk_priority_low")
          .unbind()
          .click(function () {
            splkMhmBulkPriority("low");
          });

        // reset: create a function to limit code repetition
        function splkMhmBulkreset() {
          var tk_tenant_id = getToken("tenant_id");
          var splkMhmBulkIds = getToken("splkMhmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_reset";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-mhm",
            keys_list: splkMhmBulkIds,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkMhmMain.startSearch();
              // refresh tabulator
              $("#splk-mhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk reset
        $("#btn_splk_mhm_bulk_reset")
          .unbind()
          .click(function () {
            splkMhmBulkreset();
          });

        // priority: create a function to limit code repetition
        function splkMhmBulkAck(action) {
          var tk_tenant_id = getToken("tenant_id");
          var splkMhmBulkObjs = getToken("splkMhmBulkObjs");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // Create the endpoint URL and record
          var myendpoint_URl;
          var record;

          if (action == "enable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "enable",
              object_category: "splk-mhm",
              object_list: splkMhmBulkObjs,
              ack_period: "86400",
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          } else if (action == "disable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "disable",
              object_category: "splk-mhm",
              object_list: splkMhmBulkObjs,
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          }

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkMhmMain.startSearch();
              // refresh tabulator
              $("#splk-mhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk ack enable
        $("#btn_splk_mhm_bulk_priority_enable_ack")
          .unbind()
          .click(function () {
            splkMhmBulkAck("enable");
          });

        // bulk ack disable
        $("#btn_splk_mhm_bulk_priority_disable_ack")
          .unbind()
          .click(function () {
            splkMhmBulkAck("disable");
          });

        // monitoring: create a function to limit code repetition
        function splkMhmBulkMonitoring(actionTarget) {
          var tk_tenant_id = getToken("tenant_id");
          var splkMhmBulkIds = getToken("splkMhmBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_monitoring";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-mhm",
            keys_list: splkMhmBulkIds,
            action: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkMhmMain.startSearch();
              // refresh tabulator
              $("#splk-mhm-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk enable
        $("#btn_splk_mhm_bulk_enable")
          .unbind()
          .click(function () {
            splkMhmBulkMonitoring("enable");
          });

        // bulk disable
        $("#btn_splk_mhm_bulk_disable")
          .unbind()
          .click(function () {
            splkMhmBulkMonitoring("disable");
          });

        // delete: create a function to limit code repetition
        function splkMhmBulkDelete(actionTarget) {
          var splkMhmBulkIds = getToken("splkMhmBulkIds");
          var tk_tenant_id = getToken("tenant_id");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_delete";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: splkMhmBulkIds,
            deletion_type: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Update
              $("#splk-mhm-table-refresh-hidden").click();
              var msg = "Entities bulk edit was performed successfully.";
              notify("success", "bottom", msg, "5");
              // Run the search again to update the table
              searchSplkMhmMain.startSearch();
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk delete temporary
        $("#btn_splk_mhm_bulk_deletion_temporary")
          .unbind()
          .click(function () {
            splkMhmBulkDelete("temporary");
          });

        // bulk delete permanent
        $("#btn_splk_mhm_bulk_deletion_permanent")
          .unbind()
          .click(function () {
            splkMhmBulkDelete("permanent");
          });

        // associate new logical group: create a function to limit code repetition
        function splkMhmBulkAssociateNewLogicalGroup() {
          var splkMhmBulkObjs = getToken("splkMhmBulkObjs");

          // this token is expected by the target
          setToken("tk_logical_group_target", splkMhmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-mhm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // Set required tokens
          setToken("tk_start_logical_member_get", "True");

          // hide this action
          $("#btn_associate_logical_group_add_group_back").hide();
          $("#btn_associate_logical_group_back").hide();

          // Open modal
          $("#logical_group_add_group").modal();
        }

        // bulk
        $("#btn_splk_mhm_bulk_associate_new_logical_group")
          .unbind()
          .click(function () {
            splkMhmBulkAssociateNewLogicalGroup();
          });

        // associate existing logical group: create a function to limit code repetition
        function splkMhmBulkAssociateExistingLogicalGroup() {
          var splkMhmBulkObjs = getToken("splkMhmBulkObjs");

          // this token is expected by the target
          setToken("tk_logical_group_target", splkMhmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-mhm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // Set required tokens
          setToken("tk_start_logical_member_add", "True");

          // Start search
          searchLogicalGroupTableAddMember.startSearch();

          // hide this action
          $("#btn_associate_logical_group_add_member_back").hide();

          // Open modal
          $("#logical_group_add_member").modal();
        }

        // bulk
        $("#btn_splk_mhm_bulk_associate_existing_logical_group")
          .unbind()
          .click(function () {
            splkMhmBulkAssociateExistingLogicalGroup();
          });

        // unassociate logical group: create a function to limit code repetition
        function splkMhmBulkUnassociateLogicalGroup() {
          var splkMhmBulkObjs = getToken("splkMhmBulkObjs");

          // Free the search
          setToken("tk_start_logical_member_get", "true");

          // Start the search
          searchLogicalGroupTable.startSearch();

          // this token is expected by the target
          setToken("tk_logical_group_target", splkMhmBulkObjs);

          // logical group dynamically handle searches
          setToken("tk_object_category", "splk-mhm");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_mhm_bulk_comment");

          // hide this action
          $("#btn_associate_logical_group_back").hide();

          // Open modal
          $("#logical_group").modal();
        }

        // bulk
        $("#btn_splk_mhm_bulk_unassociate_logical_group")
          .unbind()
          .click(function () {
            splkMhmBulkUnassociateLogicalGroup();
          });

        //
        // end
        //
      });
    }

    // splk-mhm get table
    function getSplkMhmTable() {
      var tk_tenant_id = getToken("tenant_id");
      // avoid causing double interval
      clearInterval(splkMhmIntervalId);
      // get viz mode
      var modeView = document.getElementById("splk-mhm-table-mode").value;
      // get data
      splkMhmHandlerTable(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/mh_get_table",
        "POST",
        { tenant_id: tk_tenant_id, mode: modeView, key_id: "*" }
      );
    }

    // splk-mhm refresh timer
    var splkMhmIntervalId;

    function splkMhmRefreshInfo() {
      var myDate = new Date();
      var splkMhmLastRefresh = document.getElementById("splkMhmLastRefresh");
      function updateTime() {
        splkMhmLastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
      }

      splkMhmIntervalId = setInterval(updateTime, 2000);
    }

    function splkMhmResetRefreshInfo() {
      clearInterval(splkMhmIntervalId);
      // release our intervalID from the variable
      splkMhmIntervalId = null;
      splkMhmRefreshInfo();
    }

    function splkMhmPauseRefreshInfo() {
      clearInterval(splkMhmIntervalId);
      clearInterval(tableRefreshIntervalId);
      // release our intervalID from the variable
      splkMhmIntervalId = null;
      tableRefreshIntervalId = null;
      splkMhmLastRefresh.innerText =
        "auto-refresh table is paused until inline changes are saved or cancelled";
    }

    function splkMhmResumeTableRefresh() {
      if (!tableRefreshIntervalId) {
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-mhm-table-refresh-hidden").click();
        }, 300000);
      }
    }

    // splk-mhm modal entity view

    function showSplkMhmEntityModal(jsonData, actionTarget, actionType) {
      // mainTokens
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);
      // get tenant_id
      var tk_tenant_id = jsonData["tenant_id"];
      var tk_parent_tenant_id = jsonData["tenant_parent"];
      // get entity details
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);
      var tk_splk_mhm = jsonData["object"];
      setToken("tk_splk_mhm", tk_splk_mhm);
      var tk_object = tk_splk_mhm;
      var tk_alias = jsonData["alias"];
      // token is required
      setToken("tk_object", tk_object);
      var tk_object_category = jsonData["object_category"];
      // token is required
      setToken("tk_object_category", tk_object_category);
      var tk_priority = jsonData["priority"];
      // token required for priority audit change
      setToken("tk_priority", tk_priority);
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);
      var tk_object_state = jsonData["object_state"];
      var tk_metric_monitored_state = jsonData["monitored_state"];
      var tk_metric_last_time_seen_human = jsonData["last_time"];
      var tk_metric_last_lag_seen = jsonData["last_lag_seen"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];

      // pre-fill current priority
      setToken("form.tk_input_splk_mhm_priority", tk_priority);

      // spinner
      cssloader("Requested action is in progress, please wait...");

      // handle replica
      var target_tenant_id = tk_parent_tenant_id || tk_tenant_id;
      if (tk_parent_tenant_id) {
        setToken("tenant_id", target_tenant_id);
      }

      // get entity info
      // Retrieve entity info from REST and set actions
      $.ajax({
        url: "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/mh_entity_info",
        type: "POST",
        async: true,
        contentType: "application/json",
        data: JSON.stringify({
          tenant_id: target_tenant_id,
          object: tk_object,
        }),
        success: function (returneddata) {
          // spinner
          cssloaderremove();
          // get from the json response
          document.getElementById("btn_search_splk_mhm").href =
            returneddata["splk_mhm_mctalog_search"];
          //
          document.getElementById("btn_mpreview_splk_mhm").href =
            returneddata["splk_mhn_mpreview"];
          //
          document.getElementById("btn_search_splk_mhm_live_report").href =
            returneddata["splk_mhn_metrics_report"];
          //
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      var tk_metric_monitored_state_class;
      if (tk_metric_monitored_state == "enabled") {
        document.getElementById(
          "btn_enable_monitoring_splk_mhm"
        ).disabled = true;
        document.getElementById(
          "btn_disable_monitoring_splk_mhm"
        ).disabled = false;
        tk_metric_monitored_state_class = "title_green";
      } else {
        document.getElementById(
          "btn_enable_monitoring_splk_mhm"
        ).disabled = false;
        document.getElementById(
          "btn_disable_monitoring_splk_mhm"
        ).disabled = true;
        tk_metric_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_mhm_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_mhm_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_mhm_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_mhm_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_mhm").disabled = false;
        $("#btn_ack_splk_mhm").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_mhm").disabled = false;
        $("#btn_ack_splk_mhm").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_mhm").disabled = false;
        $("#btn_ack_splk_mhm").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_mhm").disabled = true;
        $("#btn_ack_splk_mhm").html("Acknowledge alert");
      }

      // Explicitly refresh the get tags search
      searchGetSplkMhmTags.startSearch();

      // replace info panels
      $("#parent-metric-host-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_splk_mhm +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-metric-host-top-info1").html(
        '<h3>last lag seen: <span style="color: dodgerblue;">' +
          tk_metric_last_lag_seen +
          '<span style="color: dodgerblue;">' +
          '<h3>last time seen: <span style="color: dodgerblue;">' +
          tk_metric_last_time_seen_human +
          '<span style="color: dodgerblue;">'
      );

      $("#child-metric-host-top-info2").html(
        '<h3>monitored state:</b> <span class="' +
          tk_metric_monitored_state_class +
          '">' +
          tk_metric_monitored_state +
          "</span></h3>" +
          '<h3>host state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-metric-host-top-info3").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-metric-host-top-info4").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></p>"
      );

      $("#child-metric-host-status-message").html(
        '<div class="' +
          tk_splk_mhm_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );

      // Run
      if (
        getToken("userLevel") === "user" &&
        actionTarget.startsWith("modal_modify_")
      ) {
        $("#modal_user_restricted").modal();
      } else {
        if (actionType === "modal") {
          if (actionTarget === "modal_cmdb_splk_mhm") {
            searchCmdbSplkMhm.startSearch();
          }
          $("#" + actionTarget).modal();
        } else if (actionType === "click") {
          $("#" + actionTarget).click();
        }
      }
    }

    //
    // splk-flx
    //

    // disable the bulk edit button
    $("#splk-flx-table-bulk").prop("disabled", true);

    // disable the inline save button
    $("#splk-flx-table-save").prop("disabled", true);

    // disable the inline cancel button
    $("#splk-flx-table-cancel").prop("disabled", true);

    // splk-flx tabulator
    function splkFlxHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // set the table div
        var tabulatorElement = "#" + "splk-flx-table";

        // get tenant level preference
        var ui_expand_metrics = getToken("ui_expand_metrics");
        if (ui_expand_metrics == 1) {
          var fieldEl = document.getElementById("splk-flx-table-mode");
          fieldEl.value = "full";
        }

        function jsonFormatter(cell, formatterParams, onRendered) {
          // get mode
          var modeView = document.getElementById("splk-flx-table-mode").value;
          if (modeView === "minimal") {
            return "right click for popup";
          } else {
            cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
            return JSON.stringify(JSON.parse(cell.getValue()), null, 1).replace(
              /\\/g,
              ""
            ); //return JSON formatted cell
          }
        }

        // popup formatter
        var rowPopupFormatterMetricsDetails = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Metrics Details (use the scrollerbar to scroll down through details)</strong><br/>";
          contents +=
            "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>" +
            JSON.stringify(JSON.parse(data.metrics), null, 4);
          ("</code></pre></div>");
          container.innerHTML = contents;
          return container;
        };

        function csvFormatter(cell, formatterParams, onRendered) {
          cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
          obj = cell.getValue().toString().split(",");
          return JSON.stringify(obj, null, 1); //return JSON formatted cell
        }

        //Generate open icon
        var openIcon = function (cell, formatterParams) {
          return "<i class='bi bi-box-arrow-up-right'></i>";
        };

        //Generate tool icon
        var toolIcon = function (cell, formatterParams) {
          return "<i class='bi bi-tools'></i>";
        };

        //Generate cmdb icon
        var cmdbIcon = function (cell, formatterParams) {
          return "<i class='bi bi-database-fill-gear'></i>";
        };

        // filters
        //Define variables for input elements

        var fieldEl = document.getElementById("splk-flx-table-filter-field");
        var typeEl = document.getElementById("splk-flx-table-filter-type");
        var valueEl = document.getElementById("splk-flx-table-filter-value");
        var enabledEl = document.getElementById(
          "splk-flx-table-filter-enabled"
        );

        // listen for a change
        $("#splk-flx-table-mode").change(function () {
          var newmodeView = document.getElementById(
            "splk-flx-table-mode"
          ).value;
          table.replaceData(resultCall);
        });

        // custom functions

        function customFilterRedState(data, filterEnabled) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red";
          } else {
            return (
              data.object_state == "red" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOrangeState(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "orange";
          } else {
            return (
              data.object_state == "orange" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterGreenState(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "green";
          } else {
            return (
              data.object_state == "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterAlertState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state != "green";
          } else {
            return (
              data.object_state != "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "high";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "high" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "medium";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "medium" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "low";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "low" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "high";
          } else {
            return data.priority == "high" && data.monitored_state == "enabled";
          }
        }

        function customFilterMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "medium";
          } else {
            return (
              data.priority == "medium" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterEnabled(data) {
          return data.monitored_state == "enabled";
        }

        function customFilterDisabled(data) {
          return data.monitored_state == "disabled";
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterLatencyTresholdAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "lag_threshold_breached";
          } else {
            return (
              data.anomaly_reason == "lag_threshold_breached" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterFuture(data) {
          var filterEnabled = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "future_over_tolerance";
          } else {
            return (
              data.anomaly_reason == "future_over_tolerance" &&
              data.monitored_state == "enabled"
            );
          }
        }

        //Trigger setFilter function with correct parameters
        function updateFilter() {
          var filterVal = fieldEl.options[fieldEl.selectedIndex].value;
          var typeVal = typeEl.options[typeEl.selectedIndex].value;

          // handle filter functions and normal filter
          var filter;
          if (filterVal == "function_high_priority") {
            filter = customFilterHighPriority;
          } else if (filterVal == "function_medium_priority") {
            filter = customFilterMediumPriority;
          } else if (filterVal == "function_low_priority") {
            filter = customFilterLowPriority;
          } else if (filterVal == "function_red_state_high_priority") {
            filter = customFilterRedStateHighPriority;
          } else if (filterVal == "function_red_state_medium_priority") {
            filter = customFilterRedStateMediumPriority;
          } else if (filterVal == "function_red_state_low_priority") {
            filter = customFilterRedStateLowPriority;
          } else if (filterVal == "function_enabled") {
            filter = customFilterEnabled;
          } else if (filterVal == "function_disabled") {
            filter = customFilterDisabled;
          } else if (filterVal == "function_lagthreshold_anomaly") {
            filter = customFilterLatencyTresholdAnomaly;
          } else if (filterVal == "function_future") {
            filter = customFilterFuture;
          } else if (filterVal == "function_red_state") {
            filter = customFilterRedState;
          } else if (filterVal == "function_orange_state") {
            filter = customFilterOrangeState;
          } else if (filterVal == "function_green_state") {
            filter = customFilterGreenState;
          } else if (filterVal == "function_alert_state") {
            filter = customFilterAlertState;
          } else {
            filter = filterVal;
          }

          // disable filters conditionally
          if (
            filterVal == "function_red_state" ||
            filterVal == "function_orange_state" ||
            filterVal == "function_green_state" ||
            filterVal == "function_alert_state" ||
            filterVal == "function_red_state_high_priority" ||
            filterVal == "function_red_state_medium_priority" ||
            filterVal == "function_red_state_low_priority" ||
            filterVal == "function_high_priority" ||
            filterVal == "function_medium_priority" ||
            filterVal == "function_low_priority" ||
            filterVal == "function_enabled" ||
            filterVal == "function_disabled" ||
            filterVal == "function_lagthreshold_anomaly" ||
            filterVal == "function_hostdcount_anomaly" ||
            filterVal == "function_outliers_anomaly" ||
            filterVal == "function_future"
          ) {
            typeEl.disabled = true;
            valueEl.disabled = true;
          } else {
            typeEl.disabled = false;
            valueEl.disabled = false;
          }

          if (filterVal) {
            var filterEnabled = document.getElementById(
              "splk-flx-table-filter-enabled"
            ).value;
            if (filterEnabled == "true") {
              table.setFilter(filter, typeVal, valueEl.value);
            } else {
              table.setFilter("monitored_state", "=", "enabled");
              table.addFilter(filter, typeVal, valueEl.value);
            }
          }
        }

        // Drilldown click from single all entities
        singleFormTotalSplkFlx.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-flx-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "like", value: "" },
            ]);
            // notify
            notify("success", "bottom", "Filtering on all entities.", "5");
          }
        });

        singleFormTotalSplkFlxAlerts.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-flx-table-filter-field").val("function_red_state");
            // set filters
            table.setFilter([
              {
                field: "object_state",
                type: "in",
                value: ["red", "orange", "blue"],
              },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on enabled entities in alert (red, orange, blue).",
              "5"
            );
          }
        });

        // Drilldown click from single high priority red
        singleFormTotalSplkFlxAlertsHighPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-flx-table-filter-field").val(
              "function_red_state_high_priority"
            );
            // set filters
            table.setFilter([
              { field: "object_state", type: "=", value: "red" },
              { field: "priority", type: "=", value: "high" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on high priority red entities.",
              "5"
            );
          }
        });

        singleFormTotalSplkFlxDisabled.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-flx-table-filter-field").val("function_disabled");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "disabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on all disabled entities.",
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkFlxCountByPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-flx-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              {
                field: "priority",
                type: "like",
                value: e.data["row.priority"],
              },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on any state monitored entities with priority: " +
                e.data["row.priority"],
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkFlxCountByStateAndPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();

            // set clicked_state
            clicked_state = e.data["row.state"];

            if (
              clicked_state === "green" ||
              clicked_state === "blue" ||
              clicked_state === "orange" ||
              clicked_state === "red"
            ) {
              // update dropdown
              $("#splk-flx-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: clicked_state },
                {
                  field: "priority",
                  type: "like",
                  value: "",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on any priority monitored entities with state: " +
                  clicked_state,
                "5"
              );
            } else if (clicked_state === "red - other priority") {
              // update dropdown
              $("#splk-flx-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "in",
                  value: ["low", "medium"],
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on low or medium priority monitored entities with state: red",
                "5"
              );
            } else if (clicked_state === "red - high priority") {
              // update dropdown
              $("#splk-flx-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "=",
                  value: "high",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on high priority monitored entities with state: red",
                "5"
              );
            }
          }
        });

        //Update filters on value change
        document
          .getElementById("splk-flx-table-filter-field")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-flx-table-filter-type")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-flx-table-filter-value")
          .addEventListener("keyup", updateFilter);

        //Clear filters on "Clear Filters" button click
        document
          .getElementById("splk-flx-table-filter-clear")
          .addEventListener("click", function () {
            fieldEl.value = "object";
            typeEl.value = "like";
            valueEl.value = "";
            enabledEl = "false";
            table.clearFilter(true);
            table.setFilter("monitored_state", "=", "enabled");
            typeEl.disabled = false;
            valueEl.disabled = false;
            // notify
            notify(
              "success",
              "bottom",
              "Tabulator filters were reset successfully.",
              "5"
            );
          });

        // popup formatter
        var rowPopupFormatter = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Entity Details</strong><br/>";
          contents +=
            "<div style='max-height: 600px; width: 800px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
          contents +=
            "<li><strong>Entity name:</strong> " + data.object + "</li>";
          contents +=
            "<li><strong>Entity alias:</strong> " + data.alias + "</li>";
          contents +=
            "<li><strong>Entity keyid:</strong> " + data.keyid + "</li>";
          contents +=
            "<li><strong>State:</strong> " + data.object_state + "</li>";
          contents +=
            "<li><strong>Acknowledgement state:</strong> " +
            data.ack_state +
            "</li>";
          contents +=
            "<li><strong>Object description:</strong> " +
            data.object_description +
            "</li>";
          contents += "<li><strong>Status:</strong> " + data.status + "</li>";
          contents +=
            "<li><strong>Status description:</strong> " +
            data.status_description +
            "</li>";
          contents +=
            "<li><strong>Priority:</strong> " + data.priority + "</li>";
          contents +=
            "<li><strong>AnomalyReason:</strong> " +
            data.anomaly_reason +
            "</li>";
          contents +=
            "<li><strong>Outliers anomaly detection state:</strong> " +
            data.OutliersStatus +
            "</li>";
          contents +=
            "<li><strong>Status message:</strong> " +
            data.status_message +
            "</li>";
          contents +=
            "<li><strong>Currently under monitoring days:</strong> " +
            data.isUnderMonitoringDays +
            "</li>";
          contents +=
            "<li><strong>Currently under monitoring hours:</strong> " +
            data.isUnderMonitoringHours +
            "</li>";
          contents +=
            "<li><strong>Date and time of last inspection:</strong> " +
            epochToHumanReadable(data.tracker_runtime) +
            "</li>";
          contents += "</ul></div>";

          container.innerHTML = contents;

          return container;
        };

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "keyid",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 50, //allow 50 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          height: "100%", // fixed height
          groupBy: "group",
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            {
              //create column group
              title: "Actions",
              columns: [
                // open
                {
                  formatter: openIcon,
                  width: 40,
                  hozAlign: "center",
                  cellClick: function (e, cell) {
                    // Open the entity modal
                    showSplkFlxEntityModal(
                      cell.getRow().getData(),
                      "modal_manage_splk_flx",
                      "modal"
                    );
                  },
                },
                // tool
                {
                  formatter: toolIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("update_icon_visible"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkFlxEntityModal(
                      cell.getRow().getData(),
                      "modal_modify_splk_flx_unified",
                      "modal"
                    );
                  },
                },
                // cmdb
                {
                  formatter: cmdbIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("cmdb_lookup"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkFlxEntityModal(
                      cell.getRow().getData(),
                      "modal_cmdb_splk_flx",
                      "modal"
                    );
                  },
                },
              ],
            },
            {
              //create column group
              title: "Identifier/state (click: rename/right click: info)",
              columns: [
                //define the table columns
                {
                  title: "group",
                  field: "group",
                  visible: false,
                },
                {
                  title: "object",
                  field: "object",
                  visible: false,
                },
                {
                  title: "Entity",
                  field: "alias",
                  contextPopup: rowPopupFormatter, //add click popup to row
                  minWidth: getToken("ui_min_object_width"),
                  editor: true,
                  headerFilter: true,
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_bootstrap"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setBootstrapStatusIcons(status);
                  },
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_emoji"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setEmojiStatusIcons(status);
                  },
                },
              ],
            },
            {
              //create column group
              title: "Priority and monitoring state",
              columns: [
                {
                  title: "Priority",
                  field: "priority",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["low", "medium", "high"] },
                  headerFilter: "input",
                },
                {
                  title: "Monitoring",
                  field: "monitored_state",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["disabled", "enabled"] },
                  headerFilter: "input",
                },
              ],
            },
            {
              //create column group
              title: "Status and description",
              columns: [
                {
                  title: "Status",
                  field: "status",
                  width: 80,
                  editor: false,
                  headerFilter: true,
                },
                {
                  title: "Status description",
                  field: "status_description",
                  editor: false,
                  headerFilter: true,
                },
              ],
            },
            {
              //create column group
              title: "Metrics",
              columns: [
                {
                  title: "Last metrics",
                  field: "metrics",
                  width: 200,
                  formatter: jsonFormatter,
                  contextPopup: rowPopupFormatterMetricsDetails,
                  editor: false,
                  headerFilter: true,
                },
              ],
            },
            {
              //create column group
              title: "Tracking information",
              columns: [
                {
                  title: "Tracker runtime",
                  field: "tracker_runtime (translated)",
                  width: 150,
                  editor: false,
                  headerFilter: true,
                },
              ],
            },
            {
              title: "Outliers",
              field: "OutliersIsOk",
              contextPopup: rowPopupFormatterOutliers, //add click popup to row
              hozAlign: "center",
              formatter: "tickCross",
              width: 100,
            },
          ],
        });

        // Set initial filters
        function setInitialFilters() {
          var filterEnabledEl = document.getElementById(
            "splk-flx-table-filter-enabled"
          ).value;
          if (filterEnabledEl == "true") {
            table.setFilter("monitored_state", "in", ["enabled", "disabled"]);
          } else if (filterEnabledEl == "false") {
            table.setFilter("monitored_state", "in", ["enabled"]);
          }
        }

        // reset and set filters (for listener)
        function resetAndSetInitialFilters() {
          var fieldEl = document.getElementById("splk-flx-table-filter-field");
          var typeEl = document.getElementById("splk-flx-table-filter-type");
          var valueEl = document.getElementById("splk-flx-table-filter-value");
          fieldEl.value = "object";
          typeEl.value = "like";
          valueEl.value = "";
          table.clearFilter(true);
          setInitialFilters();
        }

        // Call it only once the table is built
        table.on("tableBuilt", function () {
          setInitialFilters();

          // create the change listener
          document
            .getElementById("splk-flx-table-filter-enabled")
            .addEventListener("change", resetAndSetInitialFilters);
        });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $("#splk-flx-table-bulk").prop("disabled", false);
            splkFlxPauseRefreshInfo();
          } else {
            $("#splk-flx-table-bulk").prop("disabled", true);
            document.getElementById("splkFlxLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            splkFlxResumeTableRefresh();
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $("#splk-flx-table-save").prop("disabled", false);
          $("#splk-flx-table-cancel").prop("disabled", false);
          splkFlxPauseRefreshInfo();
        });

        // set the timer
        splkFlxRefreshInfo();

        // auto-refresh
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-flx-table-refresh-hidden").click();
        }, 300000);

        // manual refresh
        $("#splk-flx-table-refresh")
          .unbind()
          .click(function () {
            // notify
            notify("info", "bottom", "Please wait while refreshing...", "5");
            var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
              resultCall
            ) {
              // get current filters
              var currentFilters = table.getFilters(true);
              // clear filters
              table.clearFilter(true);
              // refresh data
              table.replaceData(resultCall);
              // re-apply filters
              table.setFilter(currentFilters);
              // notify
              notify(
                "success",
                "bottom",
                "Tabulator was refreshed successfully.",
                "5"
              );
              // refresh the timer
              splkFlxResetRefreshInfo();
            });
          });

        // auto hidden refresh
        $("#splk-flx-table-refresh-hidden")
          .unbind()
          .click(function () {
            var doAsync = asyncAjaxNoLoader(ajaxUrl, ajaxType, ajaxData).then(
              function (resultCall) {
                // get current filters
                var currentFilters = table.getFilters(true);
                // clear filters
                table.clearFilter(true);
                // refresh data
                table.replaceData(resultCall);
                // re-apply filters
                table.setFilter(currentFilters);
                // refresh the timer
                splkFlxResetRefreshInfo();
              }
            );
          });

        // bulk edit
        $("#splk-flx-table-bulk")
          .unbind()
          .click(function () {
            // get filters
            var allFilters = table.getFilters(true);

            // get selected rows
            var selectedData = table.getSelectedData(allFilters);

            // get data according to all filters and store in its array
            var searchData = table.searchData(allFilters);
            var searchList = [];
            for (var i = 0; i < searchData.length; i++) {
              searchList.push(searchData[i].keyid);
            }

            // loop and create a list of keys ensuring these are parts of the searched entities
            var itemList = [];
            var itemKeys = [];
            for (var i = 0; i < selectedData.length; i++) {
              if (searchList.includes(selectedData[i].keyid)) {
                itemList.push(selectedData[i].object);
                itemKeys.push(selectedData[i].keyid);
              }
            }

            // set a token for later usage
            setToken("splkFlxBulkObjs", itemList.toString());
            setToken("splkFlxBulkIds", itemKeys.toString());

            // count the number of selected entities and add to the bulk edit modal
            itemCount = itemList.length;
            $("#divFlxBulkdCount").html(
              '<h1><span style="color: #a7c7e7;">' +
                itemCount +
                " entities selected currently</span></h1>"
            );

            // open modal
            closeModals();
            $("#modal_entry_bulk_splk_flx").modal();
          });

        // save inline edit
        $("#splk-flx-table-save")
          .unbind()
          .click(function () {
            // disable the button
            $(this).prop("disabled", true);

            var selectedData = table.getData("active");
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              // create the JSON object
              record_object = {
                keyid: selectedData[i].keyid,
                object: selectedData[i].object,
                alias: selectedData[i].alias,
                priority: selectedData[i].priority,
                monitored_state: selectedData[i].monitored_state,
              };
              // push to the array
              itemList.push(record_object);
            }
            // run the rest call
            var tk_tenant_id = getToken("tenant_id");

            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_bulk_edit";

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: tk_tenant_id,
              json_data: itemList,
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Run the search again to update the table
                searchSplkFlxMain.startSearch();
                // refresh tabulator
                $("#splk-flx-table-refresh-hidden").click();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Entities bulk edit was performed successfully.",
                  "5"
                );
                // disable the cancel button
                $("#splk-flx-table-cancel").prop("disabled", true);
                return;
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });

        // cancel inline edit
        $("#splk-flx-table-cancel")
          .unbind()
          .click(function () {
            document.getElementById("splkFlxLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            // disable the button
            $(this).prop("disabled", true);
            // notify
            notify(
              "info",
              "bottom",
              "Inline changes canceled, refreshing the table.",
              "5"
            );
            // disable the save button
            $("#splk-flx-table-save").prop("disabled", true);
            // refresh the table
            $("#splk-flx-table-refresh-hidden").click();
          });

        // priority: create a function to limit code repetition
        function splkFlxBulkPriority(priority) {
          var tk_tenant_id = getToken("tenant_id");
          var splkFlxBulkIds = getToken("splkFlxBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_flx_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_update_priority";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-flx",
            keys_list: splkFlxBulkIds,
            priority: priority,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();
              // refresh tabulator
              $("#splk-flx-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk priority high
        $("#btn_splk_flx_bulk_priority_high")
          .unbind()
          .click(function () {
            splkFlxBulkPriority("high");
          });

        // bulk priority medium
        $("#btn_splk_flx_bulk_priority_medium")
          .unbind()
          .click(function () {
            splkFlxBulkPriority("medium");
          });

        // bulk priority low
        $("#btn_splk_flx_bulk_priority_low")
          .unbind()
          .click(function () {
            splkFlxBulkPriority("low");
          });

        // priority: create a function to limit code repetition
        function splkFlxBulkAck(action) {
          var tk_tenant_id = getToken("tenant_id");
          var splkFlxBulkObjs = getToken("splkFlxBulkObjs");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_flx_bulk_comment");

          // Create the endpoint URL and record
          var myendpoint_URl;
          var record;

          if (action == "enable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "enable",
              object_category: "splk-flx",
              object_list: splkFlxBulkObjs,
              ack_period: "86400",
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          } else if (action == "disable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "disable",
              object_category: "splk-flx",
              object_list: splkFlxBulkObjs,
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          }

          // spinner
          cssloaderremove();

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();
              // refresh tabulator
              $("#splk-flx-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk ack enable
        $("#btn_splk_flx_bulk_priority_enable_ack")
          .unbind()
          .click(function () {
            splkFlxBulkAck("enable");
          });

        // bulk ack disable
        $("#btn_splk_flx_bulk_priority_disable_ack")
          .unbind()
          .click(function () {
            splkFlxBulkAck("disable");
          });

        // monitoring: create a function to limit code repetition
        function splkFlxBulkMonitoring(actionTarget) {
          var tk_tenant_id = getToken("tenant_id");
          var splkFlxBulkIds = getToken("splkFlxBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_flx_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_monitoring";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-flx",
            keys_list: splkFlxBulkIds,
            action: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();
              // refresh tabulator
              $("#splk-flx-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk enable
        $("#btn_splk_flx_bulk_enable")
          .unbind()
          .click(function () {
            splkFlxBulkMonitoring("enable");
          });

        // bulk disable
        $("#btn_splk_flx_bulk_disable")
          .unbind()
          .click(function () {
            splkFlxBulkMonitoring("disable");
          });

        // delete: create a function to limit code repetition
        function splkFlxBulkDelete(actionTarget) {
          var splkFlxBulkIds = getToken("splkFlxBulkIds");
          var tk_tenant_id = getToken("tenant_id");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_flx_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_delete";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: splkFlxBulkIds,
            deletion_type: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Update
              $("#splk-flx-table-refresh-hidden").click();
              var msg = "Entities bulk edit was performed successfully.";
              notify("success", "bottom", msg, "5");
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk delete temporary
        $("#btn_splk_flx_bulk_deletion_temporary")
          .unbind()
          .click(function () {
            splkFlxBulkDelete("temporary");
          });

        // bulk delete permanent
        $("#btn_splk_flx_bulk_deletion_permanent")
          .unbind()
          .click(function () {
            splkFlxBulkDelete("permanent");
          });

        //
        // end
        //
      });
    }

    // splk-flx get table
    function getSplkFlxTable() {
      var tk_tenant_id = getToken("tenant_id");
      // avoid causing double interval
      clearInterval(splkFlxIntervalId);
      // get data
      splkFlxHandlerTable(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/flx_get_table",
        "POST",
        { tenant_id: tk_tenant_id, key_id: "*", object: "*" }
      );
    }

    // splk-flx refresh timer
    var splkFlxIntervalId;

    function splkFlxRefreshInfo() {
      var myDate = new Date();
      var splkFlxLastRefresh = document.getElementById("splkFlxLastRefresh");
      function updateTime() {
        splkFlxLastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
      }

      splkFlxIntervalId = setInterval(updateTime, 2000);
    }

    function splkFlxResetRefreshInfo() {
      clearInterval(splkFlxIntervalId);
      // release our intervalID from the variable
      splkFlxIntervalId = null;
      splkFlxRefreshInfo();
    }

    function splkFlxPauseRefreshInfo() {
      clearInterval(splkFlxIntervalId);
      clearInterval(tableRefreshIntervalId);
      // release our intervalID from the variable
      splkFlxIntervalId = null;
      tableRefreshIntervalId = null;
      splkFlxLastRefresh.innerText =
        "auto-refresh table is paused until inline changes are saved or cancelled";
    }

    function splkFlxResumeTableRefresh() {
      if (!tableRefreshIntervalId) {
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-flx-table-refresh-hidden").click();
        }, 300000);
      }
    }

    // splk-flx modal entity view

    function showSplkFlxEntityModal(jsonData, actionTarget, actionType) {
      // mainTokens
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);
      // get tenant_id
      var tk_tenant_id = jsonData["tenant_id"];
      var tk_parent_tenant_id = jsonData["tenant_parent"];
      // get entity details
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);
      var tk_splk_flx = jsonData["object"];
      setToken("tk_splk_flx", tk_splk_flx);
      var tk_object = tk_splk_flx;
      var tk_alias = jsonData["alias"];
      // token is required
      setToken("tk_object", tk_object);
      var tk_object_category = jsonData["object_category"];
      // token is required
      setToken("tk_object_category", tk_object_category);
      var tk_priority = jsonData["priority"];
      // token required for priority audit change
      setToken("tk_priority", tk_priority);
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);
      var tk_object_state = jsonData["object_state"];
      var tk_monitored_state = jsonData["monitored_state"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];

      // specific to splk-flx
      var tk_status = jsonData["status"];
      var tk_status_description = jsonData["status_description"];
      var tk_description = jsonData["object_description"];

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divFlxOutliersInfo").css("display", "none");
        $("#divFlxOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divFlxOutliersSimulationInfo").css("display", "none");
        $("#divFlxOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_flx_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_flx_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divFlxOutliersInfo").css("display", "inherit");
        $("#divFlxOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-flx-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divFlxOutliersSimulationInfo").css("display", "inherit");
        $("#divFlxOutliersSimulationRender").css("display", "none");
        $("#child-flx-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_flx_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_flx_save").prop("disabled", true);
      }

      // pre-fill current priority
      setToken("form.tk_input_splk_flx_priority", tk_priority);

      // spinner
      cssloader("Requested action is in progress, please wait...");

      // handle replica
      var target_tenant_id = tk_parent_tenant_id || tk_tenant_id;
      if (tk_parent_tenant_id) {
        setToken("tenant_id", target_tenant_id);
      }

      // get entity info
      // Retrieve entity info from REST and set actions
      $.ajax({
        url: "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/flx_entity_info",
        type: "POST",
        async: true,
        contentType: "application/json",
        data: JSON.stringify({
          tenant_id: target_tenant_id,
          object: tk_object,
        }),
        success: function (returneddata) {
          // spinner
          cssloaderremove();
          // get from the json response
          document.getElementById("btn_search_splk_flx").href =
            returneddata["splk_flx_mctalog_search"];
          //
          document.getElementById("btn_mpreview_splk_flx").href =
            returneddata["splk_flx_mpreview"];
          //
          document.getElementById("btn_search_splk_flx_live_report").href =
            returneddata["splk_flx_metrics_report"];
          // Set and start the populating search for metrics
          setToken(
            "splk_flx_metrics_populate_search",
            returneddata["splk_flx_metrics_populate_search"]
          );
          searchPopulateSplkFlxMetrics.startSearch();
          //
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      var tk_monitored_state_class;
      if (tk_monitored_state == "enabled") {
        document.getElementById(
          "btn_enable_monitoring_splk_flx"
        ).disabled = true;
        document.getElementById(
          "btn_disable_monitoring_splk_flx"
        ).disabled = false;
        tk_monitored_state_class = "title_green";
      } else {
        document.getElementById(
          "btn_enable_monitoring_splk_flx"
        ).disabled = false;
        document.getElementById(
          "btn_disable_monitoring_splk_flx"
        ).disabled = true;
        tk_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_flx_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_flx_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_flx_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_flx_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_flx").disabled = false;
        $("#btn_ack_splk_flx").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_flx").disabled = false;
        $("#btn_ack_splk_flx").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_flx").disabled = false;
        $("#btn_ack_splk_flx").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_flx").disabled = true;
        $("#btn_ack_splk_flx").html("Acknowledge alert");
      }

      // replace info panels
      $("#parent-splk-flx-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_splk_flx +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-splk-flx-top-info1").html(
        '<h3>Status: <span style="color: dodgerblue;">' +
          tk_status +
          '<span style="color: dodgerblue;">' +
          '<h3>Status description: <span style="color: dodgerblue;">' +
          truncate(tk_status_description, 200) +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-flx-top-info2").html(
        '<h3>monitored state:</b> <span class="' +
          tk_monitored_state_class +
          '">' +
          tk_monitored_state +
          "</span></h3>" +
          '<h3>host state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-splk-flx-top-info3").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-flx-top-info4").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></h3>" +
          '<h3>Description: <span style="color: dodgerblue;">' +
          truncate(tk_description, 200) +
          "</span></h3>"
      );

      $("#child-splk-flx-status-message").html(
        '<div class="' +
          tk_splk_flx_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );

      // Run
      if (
        getToken("userLevel") === "user" &&
        actionTarget.startsWith("modal_modify_")
      ) {
        $("#modal_user_restricted").modal();
      } else {
        if (actionType === "modal") {
          if (actionTarget === "modal_cmdb_splk_flx") {
            searchCmdbSplkFlx.startSearch();
          }
          $("#" + actionTarget).modal();
        } else if (actionType === "click") {
          $("#" + actionTarget).click();
        }
      }
    }

    //
    // splk-wlk
    //

    // disable the bulk edit button
    $("#splk-wlk-table-bulk").prop("disabled", true);

    // disable the inline save button
    $("#splk-wlk-table-save").prop("disabled", true);

    // disable the inline cancel button
    $("#splk-wlk-table-cancel").prop("disabled", true);

    // splk-wlk tabulator
    function splkWlkHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // set the table div
        var tabulatorElement = "#" + "splk-wlk-table";

        // get tenant level preference
        var ui_expand_metrics = getToken("ui_expand_metrics");
        if (ui_expand_metrics == 1) {
          var fieldEl = document.getElementById("splk-wlk-table-mode");
          fieldEl.value = "full";
        }

        function jsonFormatter(cell, formatterParams, onRendered) {
          // get mode
          var modeView = document.getElementById("splk-wlk-table-mode").value;
          if (modeView === "minimal") {
            return "right click for popup";
          } else {
            cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
            return JSON.stringify(JSON.parse(cell.getValue()), null, 1).replace(
              /\\/g,
              ""
            ); //return JSON formatted cell
          }
        }

        function csvFormatter(cell, formatterParams, onRendered) {
          cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
          obj = cell.getValue().toString().split(",");
          return JSON.stringify(obj, null, 1); //return JSON formatted cell
        }

        //Generate open icon
        var openIcon = function (cell, formatterParams) {
          return "<i class='bi bi-box-arrow-up-right'></i>";
        };

        //Generate tool icon
        var toolIcon = function (cell, formatterParams) {
          return "<i class='bi bi-tools'></i>";
        };

        //Generate cmdb icon
        var cmdbIcon = function (cell, formatterParams) {
          return "<i class='bi bi-database-fill-gear'></i>";
        };

        // filters
        //Define variables for input elements

        var fieldEl = document.getElementById("splk-wlk-table-filter-field");
        var typeEl = document.getElementById("splk-wlk-table-filter-type");
        var valueEl = document.getElementById("splk-wlk-table-filter-value");
        var enabledEl = document.getElementById(
          "splk-wlk-table-filter-enabled"
        );

        // listen for a change
        $("#splk-wlk-table-mode").change(function () {
          var newmodeView = document.getElementById(
            "splk-wlk-table-mode"
          ).value;
          table.replaceData(resultCall);
        });

        // custom functions

        function customFilterRedState(data, filterEnabled) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red";
          } else {
            return (
              data.object_state == "red" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOrangeState(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "orange";
          } else {
            return (
              data.object_state == "orange" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterGreenState(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "green";
          } else {
            return (
              data.object_state == "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterAlertState(data) {
          var filterEnabled = document.getElementById(
            "splk-dsm-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state != "green";
          } else {
            return (
              data.object_state != "green" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "high";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "high" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "medium";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "medium" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterRedStateLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.object_state == "red" && data.priority == "low";
          } else {
            return (
              data.object_state == "red" &&
              data.priority == "low" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterHighPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "high";
          } else {
            return data.priority == "high" && data.monitored_state == "enabled";
          }
        }

        function customFilterMediumPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "medium";
          } else {
            return (
              data.priority == "medium" && data.monitored_state == "enabled"
            );
          }
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterEnabled(data) {
          return data.monitored_state == "enabled";
        }

        function customFilterDisabled(data) {
          return data.monitored_state == "disabled";
        }

        function customFilterLowPriority(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.priority == "low";
          } else {
            return data.priority == "low" && data.monitored_state == "enabled";
          }
        }

        function customFilterSkippingSearches(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "skipping_searches_detected";
          } else {
            return (
              data.anomaly_reason == "skipping_searches_detected" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOrphan(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "orphan_search_detected";
          } else {
            return (
              data.anomaly_reason == "orphan_search_detected" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterExecutionErrors(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "execution_errors_detected";
          } else {
            return (
              data.anomaly_reason == "execution_errors_detected" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterExecutionDelayed(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "execution_delayed";
          } else {
            return (
              data.anomaly_reason == "execution_delayed" &&
              data.monitored_state == "enabled"
            );
          }
        }

        function customFilterOutliersAnomaly(data) {
          var filterEnabled = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabled == "true") {
            return data.anomaly_reason == "anomaly_outliers_detected";
          } else {
            return (
              data.anomaly_reason == "anomaly_outliers_detected" &&
              data.monitored_state == "enabled"
            );
          }
        }

        //Trigger setFilter function with correct parameters
        function updateFilter() {
          var filterVal = fieldEl.options[fieldEl.selectedIndex].value;
          var typeVal = typeEl.options[typeEl.selectedIndex].value;

          // handle filter functions and normal filter
          var filter;
          if (filterVal == "function_high_priority") {
            filter = customFilterHighPriority;
          } else if (filterVal == "function_medium_priority") {
            filter = customFilterMediumPriority;
          } else if (filterVal == "function_low_priority") {
            filter = customFilterLowPriority;
          } else if (filterVal == "function_red_state_high_priority") {
            filter = customFilterRedStateHighPriority;
          } else if (filterVal == "function_red_state_medium_priority") {
            filter = customFilterRedStateMediumPriority;
          } else if (filterVal == "function_red_state_low_priority") {
            filter = customFilterRedStateLowPriority;
          } else if (filterVal == "function_enabled") {
            filter = customFilterEnabled;
          } else if (filterVal == "function_disabled") {
            filter = customFilterDisabled;
          } else if (filterVal == "function_red_state") {
            filter = customFilterRedState;
          } else if (filterVal == "function_orange_state") {
            filter = customFilterOrangeState;
          } else if (filterVal == "function_green_state") {
            filter = customFilterGreenState;
          } else if (filterVal == "function_alert_state") {
            filter = customFilterAlertState;
          } else if (filterVal == "function_skipping_searches_detected") {
            filter = customFilterSkippingSearches;
          } else if (filterVal == "function_orphan_search_detected") {
            filter = customFilterOrphan;
          } else if (filterVal == "function_execution_errors_detected") {
            filter = customFilterExecutionErrors;
          } else if (filterVal == "function_execution_delayed") {
            filter = customFilterExecutionDelayed;
          } else if (filterVal == "function_outliers_anomaly") {
            filter = customFilterOutliersAnomaly;
          } else {
            filter = filterVal;
          }

          // disable filters conditionally
          if (
            filterVal == "function_red_state" ||
            filterVal == "function_orange_state" ||
            filterVal == "function_green_state" ||
            filterVal == "function_alert_state" ||
            filterVal == "function_red_state_high_priority" ||
            filterVal == "function_red_state_medium_priority" ||
            filterVal == "function_red_state_low_priority" ||
            filterVal == "function_high_priority" ||
            filterVal == "function_medium_priority" ||
            filterVal == "function_low_priority" ||
            filterVal == "function_enabled" ||
            filterVal == "function_disabled" ||
            filterVal == "function_outliers_anomaly" ||
            filterVal == "function_skipping_searches_detected" ||
            filterVal == "function_orphan_search_detected" ||
            filterVal == "function_execution_errors_detected" ||
            filterVal == "function_execution_delayed"
          ) {
            typeEl.disabled = true;
            valueEl.disabled = true;
          } else {
            typeEl.disabled = false;
            valueEl.disabled = false;
          }

          if (filterVal) {
            var filterEnabled = document.getElementById(
              "splk-wlk-table-filter-enabled"
            ).value;
            if (filterEnabled == "true") {
              table.setFilter(filter, typeVal, valueEl.value);
            } else {
              table.setFilter("monitored_state", "=", "enabled");
              table.addFilter(filter, typeVal, valueEl.value);
            }
          }
        }

        // Drilldown click from single all entities
        singleFormTotalSplkWlk.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-wlk-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "like", value: "" },
            ]);
            // notify
            notify("success", "bottom", "Filtering on all entities.", "5");
          }
        });

        singleFormTotalSplkWlkAlerts.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-wlk-table-filter-field").val("function_red_state");
            // set filters
            table.setFilter([
              {
                field: "object_state",
                type: "in",
                value: ["red", "orange", "blue"],
              },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on enabled entities in alert (red, orange, blue).",
              "5"
            );
          }
        });

        // Drilldown click from single high priority red
        singleFormTotalSplkWlkAlertsHighPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-wlk-table-filter-field").val(
              "function_red_state_high_priority"
            );
            // set filters
            table.setFilter([
              { field: "object_state", type: "=", value: "red" },
              { field: "priority", type: "=", value: "high" },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on high priority red entities.",
              "5"
            );
          }
        });

        singleFormTotalSplkWlkDisabled.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-wlk-table-filter-field").val("function_disabled");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              { field: "priority", type: "like", value: "" },
              { field: "monitored_state", type: "=", value: "disabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on all disabled entities.",
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkWlkCountByPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();
            // update dropdown
            $("#splk-wlk-table-filter-field").val("object");
            // set filters
            table.setFilter([
              { field: "object_state", type: "like", value: "" },
              {
                field: "priority",
                type: "like",
                value: e.data["row.priority"],
              },
              { field: "monitored_state", type: "=", value: "enabled" },
            ]);
            // notify
            notify(
              "success",
              "bottom",
              "Filtering on any state monitored entities with priority: " +
                e.data["row.priority"],
              "5"
            );
          }
        });

        // donut drilldown
        DonutSplkWlkCountByStateAndPriority.on("click", function (e) {
          if (e.field !== undefined) {
            e.preventDefault();

            // set clicked_state
            clicked_state = e.data["row.state"];

            if (
              clicked_state === "green" ||
              clicked_state === "blue" ||
              clicked_state === "orange" ||
              clicked_state === "red"
            ) {
              // update dropdown
              $("#splk-wlk-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: clicked_state },
                {
                  field: "priority",
                  type: "like",
                  value: "",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on any priority monitored entities with state: " +
                  clicked_state,
                "5"
              );
            } else if (clicked_state === "red - other priority") {
              // update dropdown
              $("#splk-wlk-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "in",
                  value: ["low", "medium"],
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on low or medium priority monitored entities with state: red",
                "5"
              );
            } else if (clicked_state === "red - high priority") {
              // update dropdown
              $("#splk-wlk-table-filter-field").val("object");
              // set filters
              table.setFilter([
                { field: "object_state", type: "=", value: "red" },
                {
                  field: "priority",
                  type: "=",
                  value: "high",
                },
                { field: "monitored_state", type: "=", value: "enabled" },
              ]);
              // notify
              notify(
                "success",
                "bottom",
                "Filtering on high priority monitored entities with state: red",
                "5"
              );
            }
          }
        });

        //Update filters on value change
        document
          .getElementById("splk-wlk-table-filter-field")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-wlk-table-filter-type")
          .addEventListener("change", updateFilter);
        document
          .getElementById("splk-wlk-table-filter-value")
          .addEventListener("keyup", updateFilter);

        //Clear filters on "Clear Filters" button click
        document
          .getElementById("splk-wlk-table-filter-clear")
          .addEventListener("click", function () {
            fieldEl.value = "object";
            typeEl.value = "like";
            valueEl.value = "";
            enabledEl = "false";
            table.clearFilter(true);
            table.setFilter("monitored_state", "=", "enabled");
            typeEl.disabled = false;
            valueEl.disabled = false;
            // notify
            notify(
              "success",
              "bottom",
              "Tabulator filters were reset successfully.",
              "5"
            );
          });

        // popup formatter
        var rowPopupFormatter = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Entity Details</strong><br/>";
          contents +=
            "<div style='max-height: 600px; width: 800px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>";
          contents +=
            "<li><strong>Entity name:</strong> " + data.object + "</li>";
          contents +=
            "<li><strong>Entity alias:</strong> " + data.alias + "</li>";
          contents +=
            "<li><strong>Application namespace:</strong> " + data.app + "</li>";
          contents += "<li><strong>Owner user:</strong> " + data.user + "</li>";
          contents += "<li><strong>Account:</strong> " + data.account + "</li>";
          contents +=
            "<li><strong>Entity keyid:</strong> " + data.keyid + "</li>";
          contents +=
            "<li><strong>State:</strong> " + data.object_state + "</li>";
          contents +=
            "<li><strong>Acknowledgement state:</strong> " +
            data.ack_state +
            "</li>";
          contents +=
            "<li><strong>Object description:</strong> " +
            data.object_description +
            "</li>";
          contents += "<li><strong>Status:</strong> " + data.status + "</li>";
          contents +=
            "<li><strong>Anomaly reason:</strong> " +
            data.anomaly_reason +
            "</li>";
          contents +=
            "<li><strong>Status description:</strong> " +
            data.status_description +
            "</li>";
          contents +=
            "<li><strong>Priority:</strong> " + data.priority + "</li>";
          contents +=
            "<li><strong>Last execution seen:</strong> " +
            epochToHumanReadable(data.last_seen) +
            "</li>";
          contents +=
            "<li><strong>Date and time of last inspection:</strong> " +
            epochToHumanReadable(data.tracker_runtime) +
            "</li>";

          contents += "</ul></div>";

          container.innerHTML = contents;

          return container;
        };

        // popup formatter
        var rowPopupFormatterMetricsDetails = function (e, row, onRendered) {
          var data = row.getData(),
            container = document.createElement("div"),
            metricsData =
              data.metrics_extended && data.metrics_extended.trim() !== ""
                ? data.metrics_extended
                : data.metrics,
            contents =
              "<strong style='font-size:1.2em; color: #a7c7e7;'>Metrics Details (use the scrollerbar to scroll down through details)</strong><br/>";
          contents +=
            "<div style='max-height: 600px; min-width: 600px; overflow: auto;'><pre style='background-color: transparent; color: white;'><code style='background-color: transparent; color: white; font-size:1.2em;'>" +
            JSON.stringify(JSON.parse(metricsData), null, 4);
          ("</code></pre></div>");
          container.innerHTML = contents;
          return container;
        };

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "keyid",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 50, //allow 50 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          height: "100%", // fixed height
          groupBy: "overgroup",
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            {
              //create column group
              title: "Actions",
              columns: [
                // open
                {
                  formatter: openIcon,
                  width: 40,
                  hozAlign: "center",
                  cellClick: function (e, cell) {
                    // Open the entity modal
                    showSplkWlkEntityModal(
                      cell.getRow().getData(),
                      "modal_manage_splk_wlk",
                      "modal"
                    );
                  },
                },
                // tool
                {
                  formatter: toolIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("update_icon_visible"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkWlkEntityModal(
                      cell.getRow().getData(),
                      "modal_modify_splk_wlk_unified",
                      "modal"
                    );
                  },
                },
                // cmdb
                {
                  formatter: cmdbIcon,
                  width: 40,
                  hozAlign: "center",
                  visible: getToken("cmdb_lookup"),
                  cellClick: function (e, cell) {
                    // Open the entity modal modify
                    showSplkWlkEntityModal(
                      cell.getRow().getData(),
                      "modal_cmdb_splk_wlk",
                      "modal"
                    );
                  },
                },
              ],
            },
            {
              //create column group
              title: "Identifier/state (click: rename/right click: info)",
              columns: [
                //define the table columns
                {
                  title: "object",
                  field: "object",
                  visible: false,
                },
                {
                  title: "Entity",
                  field: "alias",
                  contextPopup: rowPopupFormatter, //add click popup to row
                  minWidth: getToken("ui_min_object_width"),
                  editor: true,
                  headerFilter: true,
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_bootstrap"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setBootstrapStatusIcons(status);
                  },
                },
                {
                  title: "",
                  field: "state_icon_code",
                  contextPopup: rowPopupFormatterAck, //add click popup to row
                  visible: getToken("show_state_icons_emoji"),
                  hozAlign: "center",
                  width: 60,
                  formatter: function (cell, formatterParams) {
                    var status = cell.getValue();
                    return setEmojiStatusIcons(status);
                  },
                },
                ,
              ],
            },
            {
              //create column group
              title: "Priority and monitoring state",
              columns: [
                {
                  title: "Priority",
                  field: "priority",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["low", "medium", "high"] },
                  headerFilter: "input",
                },
                {
                  title: "Monitoring",
                  field: "monitored_state",
                  width: 110,
                  editor: "list",
                  editorParams: { values: ["disabled", "enabled"] },
                  headerFilter: "input",
                },
              ],
            },
            {
              //create column group
              title: "Status",
              columns: [
                {
                  title: "Status",
                  field: "status",
                  width: 80,
                  editor: false,
                  headerFilter: true,
                },
                {
                  title: "Anomaly reason",
                  field: "anomaly_reason",
                  width: 200,
                  editor: false,
                  headerFilter: true,
                },
              ],
            },
            {
              //create column group
              title: "Metrics",
              columns: [
                {
                  title: "Metrics summary (24h)",
                  field: "metrics",
                  width: 200,
                  formatter: jsonFormatter,
                  contextPopup: rowPopupFormatterMetricsDetails,
                  editor: false,
                  headerFilter: true,
                },
              ],
            },
            {
              //create column group
              title: "Time information",
              columns: [
                {
                  title: "Last time seen",
                  field: "last_seen (translated)",
                  width: 150,
                  editor: false,
                  headerFilter: true,
                },
              ],
            },
            {
              title: "Outliers",
              field: "OutliersIsOk",
              contextPopup: rowPopupFormatterOutliers, //add click popup to row
              hozAlign: "center",
              formatter: "tickCross",
              width: 100,
            },
          ],
        });

        // Set initial filters
        function setInitialFilters() {
          var filterEnabledEl = document.getElementById(
            "splk-wlk-table-filter-enabled"
          ).value;
          if (filterEnabledEl == "true") {
            table.setFilter("monitored_state", "in", ["enabled", "disabled"]);
          } else if (filterEnabledEl == "false") {
            table.setFilter("monitored_state", "in", ["enabled"]);
          }
        }

        // reset and set filters (for listener)
        function resetAndSetInitialFilters() {
          var fieldEl = document.getElementById("splk-wlk-table-filter-field");
          var typeEl = document.getElementById("splk-wlk-table-filter-type");
          var valueEl = document.getElementById("splk-wlk-table-filter-value");
          fieldEl.value = "object";
          typeEl.value = "like";
          valueEl.value = "";
          table.clearFilter(true);
          setInitialFilters();
        }

        // Call it only once the table is built
        table.on("tableBuilt", function () {
          setInitialFilters();

          // create the change listener
          document
            .getElementById("splk-wlk-table-filter-enabled")
            .addEventListener("change", resetAndSetInitialFilters);
        });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $("#splk-wlk-table-bulk").prop("disabled", false);
            splkWlkPauseRefreshInfo();
          } else {
            $("#splk-wlk-table-bulk").prop("disabled", true);
            document.getElementById("splkWlkLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            splkWlkResumeTableRefresh();
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $("#splk-wlk-table-save").prop("disabled", false);
          $("#splk-wlk-table-cancel").prop("disabled", false);
          splkWlkPauseRefreshInfo();
        });

        // set the timer
        splkWlkRefreshInfo();

        // auto-refresh
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-wlk-table-refresh-hidden").click();
        }, 300000);

        // manual refresh
        $("#splk-wlk-table-refresh")
          .unbind()
          .click(function () {
            // notify
            notify("info", "bottom", "Please wait while refreshing...", "5");
            var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
              resultCall
            ) {
              // get current filters
              var currentFilters = table.getFilters(true);
              // clear filters
              table.clearFilter(true);
              // refresh data
              table.replaceData(resultCall);
              // re-apply filters
              table.setFilter(currentFilters);
              // notify
              notify(
                "success",
                "bottom",
                "Tabulator was refreshed successfully.",
                "5"
              );
              // refresh the timer
              splkWlkResetRefreshInfo();
            });
          });

        // auto hidden refresh
        $("#splk-wlk-table-refresh-hidden")
          .unbind()
          .click(function () {
            var doAsync = asyncAjaxNoLoader(ajaxUrl, ajaxType, ajaxData).then(
              function (resultCall) {
                // get current filters
                var currentFilters = table.getFilters(true);
                // clear filters
                table.clearFilter(true);
                // refresh data
                table.replaceData(resultCall);
                // re-apply filters
                table.setFilter(currentFilters);
                // refresh the timer
                splkWlkResetRefreshInfo();
              }
            );
          });

        // bulk edit
        $("#splk-wlk-table-bulk")
          .unbind()
          .click(function () {
            // get filters
            var allFilters = table.getFilters(true);

            // get selected rows
            var selectedData = table.getSelectedData(allFilters);

            // get data according to all filters and store in its array
            var searchData = table.searchData(allFilters);
            var searchList = [];
            for (var i = 0; i < searchData.length; i++) {
              searchList.push(searchData[i].keyid);
            }

            // loop and create a list of keys ensuring these are parts of the searched entities
            var itemList = [];
            var itemKeys = [];
            for (var i = 0; i < selectedData.length; i++) {
              if (searchList.includes(selectedData[i].keyid)) {
                itemList.push(selectedData[i].object);
                itemKeys.push(selectedData[i].keyid);
              }
            }

            // set a token for later usage
            setToken("splkWlkBulkObjs", itemList.toString());
            setToken("splkWlkBulkIds", itemKeys.toString());

            // count the number of selected entities and add to the bulk edit modal
            itemCount = itemList.length;
            $("#divWlkBulkdCount").html(
              '<h1><span style="color: #a7c7e7;">' +
                itemCount +
                " entities selected currently</span></h1>"
            );

            // open modal
            closeModals();
            $("#modal_entry_bulk_splk_wlk").modal();
          });

        // save inline edit
        $("#splk-wlk-table-save")
          .unbind()
          .click(function () {
            // disable the button
            $(this).prop("disabled", true);

            var selectedData = table.getData("active");
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              // create the JSON object
              record_object = {
                keyid: selectedData[i].keyid,
                object: selectedData[i].object,
                alias: selectedData[i].alias,
                priority: selectedData[i].priority,
                monitored_state: selectedData[i].monitored_state,
              };
              // push to the array
              itemList.push(record_object);
            }
            // run the rest call
            var tk_tenant_id = getToken("tenant_id");

            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_bulk_edit";

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: tk_tenant_id,
              json_data: itemList,
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Run the search again to update the table
                searchSplkWlkMain.startSearch();
                // refresh tabulator
                $("#splk-wlk-table-refresh-hidden").click();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Entities bulk edit was performed successfully.",
                  "5"
                );
                // disable the cancel button
                $("#splk-wlk-table-cancel").prop("disabled", true);
                return;
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });

        // cancel inline edit
        $("#splk-wlk-table-cancel")
          .unbind()
          .click(function () {
            document.getElementById("splkWlkLastRefresh").innerHTML =
              "auto-refresh will restart shortly";
            // disable the button
            $(this).prop("disabled", true);
            // notify
            notify(
              "info",
              "bottom",
              "Inline changes canceled, refreshing the table.",
              "5"
            );
            // disable the save button
            $("#splk-wlk-table-save").prop("disabled", true);
            // refresh the table
            $("#splk-wlk-table-refresh-hidden").click();
          });

        // priority: create a function to limit code repetition
        function splkWlkBulkPriority(priority) {
          var tk_tenant_id = getToken("tenant_id");
          var splkWlkBulkIds = getToken("splkWlkBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_wlk_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_update_priority";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-wlk",
            keys_list: splkWlkBulkIds,
            priority: priority,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();
              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk priority high
        $("#btn_splk_wlk_bulk_priority_high")
          .unbind()
          .click(function () {
            splkWlkBulkPriority("high");
          });

        // bulk priority medium
        $("#btn_splk_wlk_bulk_priority_medium")
          .unbind()
          .click(function () {
            splkWlkBulkPriority("medium");
          });

        // bulk priority low
        $("#btn_splk_wlk_bulk_priority_low")
          .unbind()
          .click(function () {
            splkWlkBulkPriority("low");
          });

        // priority: create a function to limit code repetition
        function splkWlkBulkAck(action) {
          var tk_tenant_id = getToken("tenant_id");
          var splkWlkBulkObjs = getToken("splkWlkBulkObjs");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_wlk_bulk_comment");

          // Create the endpoint URL and record
          var myendpoint_URl;
          var record;

          if (action == "enable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "enable",
              object_category: "splk-wlk",
              object_list: splkWlkBulkObjs,
              ack_period: "86400",
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          } else if (action == "disable") {
            myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";
            record = {
              tenant_id: tk_tenant_id,
              action: "disable",
              object_category: "splk-wlk",
              object_list: splkWlkBulkObjs,
              ack_comment: tk_comment,
              update_comment: tk_comment,
            };
          }

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();
              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk ack enable
        $("#btn_splk_wlk_bulk_priority_enable_ack")
          .unbind()
          .click(function () {
            splkWlkBulkAck("enable");
          });

        // bulk ack disable
        $("#btn_splk_wlk_bulk_priority_disable_ack")
          .unbind()
          .click(function () {
            splkWlkBulkAck("disable");
          });

        // monitoring: create a function to limit code repetition
        function splkWlkBulkMonitoring(actionTarget) {
          var tk_tenant_id = getToken("tenant_id");
          var splkWlkBulkIds = getToken("splkWlkBulkIds");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_wlk_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_monitoring";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-wlk",
            keys_list: splkWlkBulkIds,
            action: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();
              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();
              // notify
              notify(
                "success",
                "bottom",
                "Entities bulk edit was performed successfully.",
                "5"
              );
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk enable
        $("#btn_splk_wlk_bulk_enable")
          .unbind()
          .click(function () {
            splkWlkBulkMonitoring("enable");
          });

        // bulk disable
        $("#btn_splk_wlk_bulk_disable")
          .unbind()
          .click(function () {
            splkWlkBulkMonitoring("disable");
          });

        // delete: create a function to limit code repetition
        function splkWlkBulkDelete(actionTarget) {
          var splkWlkBulkIds = getToken("splkWlkBulkIds");
          var tk_tenant_id = getToken("tenant_id");

          // Retrieve update comment if any
          var tk_comment = getComment("input_splk_wlk_bulk_comment");

          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_delete";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: splkWlkBulkIds,
            deletion_type: actionTarget,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Update
              $("#splk-wlk-table-refresh-hidden").click();
              var msg = "Entities bulk edit was performed successfully.";
              notify("success", "bottom", msg, "5");
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }

        // bulk delete temporary
        $("#btn_splk_wlk_bulk_deletion_temporary")
          .unbind()
          .click(function () {
            splkWlkBulkDelete("temporary");
          });

        // bulk delete permanent
        $("#btn_splk_wlk_bulk_deletion_permanent")
          .unbind()
          .click(function () {
            splkWlkBulkDelete("permanent");
          });

        //
        // end
        //
      });
    }

    // splk-wlk get table
    function getSplkWlkTable() {
      var tk_tenant_id = getToken("tenant_id");
      // avoid causing double interval
      clearInterval(splkWlkIntervalId);
      // get data
      splkWlkHandlerTable(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_get_table",
        "POST",
        { tenant_id: tk_tenant_id, key_id: "*", object: "*" }
      );
    }

    // splk-wlk refresh timer
    var splkWlkIntervalId;

    function splkWlkRefreshInfo() {
      var myDate = new Date();
      var splkWlkLastRefresh = document.getElementById("splkWlkLastRefresh");
      function updateTime() {
        splkWlkLastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
      }

      splkWlkIntervalId = setInterval(updateTime, 2000);
    }

    function splkWlkResetRefreshInfo() {
      clearInterval(splkWlkIntervalId);
      // release our intervalID from the variable
      splkWlkIntervalId = null;
      splkWlkRefreshInfo();
    }

    function splkWlkPauseRefreshInfo() {
      clearInterval(splkWlkIntervalId);
      clearInterval(tableRefreshIntervalId);
      // release our intervalID from the variable
      splkWlkIntervalId = null;
      tableRefreshIntervalId = null;
      splkWlkLastRefresh.innerText =
        "auto-refresh table is paused until inline changes are saved or cancelled";
    }

    function splkWlkResumeTableRefresh() {
      if (!tableRefreshIntervalId) {
        tableRefreshIntervalId = setInterval(function () {
          $("#splk-wlk-table-refresh-hidden").click();
        }, 300000);
      }
    }

    // splk-wlk modal entity view

    function showSplkWlkEntityModal(jsonData, actionTarget, actionType) {
      // mainTokens
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);
      // get tenant_id
      var tk_tenant_id = jsonData["tenant_id"];
      var tk_parent_tenant_id = jsonData["tenant_parent"];
      // get entity details
      var tk_keyid = jsonData["keyid"];
      // token is required
      setToken("tk_keyid", tk_keyid);
      var tk_splk_wlk = jsonData["object"];
      setToken("tk_splk_wlk", tk_splk_wlk);
      var tk_object = tk_splk_wlk;
      var tk_alias = jsonData["alias"];
      // token is required
      setToken("tk_object", tk_object);
      var tk_object_category = jsonData["object_category"];
      // token is required
      setToken("tk_object_category", tk_object_category);
      var tk_priority = jsonData["priority"];
      // token required for priority audit change
      setToken("tk_priority", tk_priority);
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);
      var tk_object_state = jsonData["object_state"];
      var tk_monitored_state = jsonData["monitored_state"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];

      // specific to splk-wlk
      var tk_status = jsonData["status"];
      var tk_status_description = jsonData["status_description"];
      var tk_description = jsonData["object_description"];

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divWlkOutliersInfo").css("display", "none");
        $("#divWlkOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divWlkOutliersSimulationInfo").css("display", "none");
        $("#divWlkOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_wlk_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_wlk_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divWlkOutliersInfo").css("display", "inherit");
        $("#divWlkOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-wlk-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divWlkOutliersSimulationInfo").css("display", "inherit");
        $("#divWlkOutliersSimulationRender").css("display", "none");
        $("#child-wlk-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_wlk_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_wlk_save").prop("disabled", true);
      }

      // pre-fill current priority
      setToken("form.tk_input_splk_wlk_priority", tk_priority);

      // spinner
      cssloader("Requested action is in progress, please wait...");

      // handle replica
      var target_tenant_id = tk_parent_tenant_id || tk_tenant_id;
      if (tk_parent_tenant_id) {
        setToken("tenant_id", target_tenant_id);
      }

      // get entity info
      // Retrieve entity info from REST and set actions
      $.ajax({
        url: "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_entity_info",
        type: "POST",
        async: true,
        contentType: "application/json",
        data: JSON.stringify({
          tenant_id: target_tenant_id,
          object: tk_object,
        }),
        success: function (returneddata) {
          // spinner
          cssloaderremove();
          // get from the json response
          document.getElementById("btn_search_splk_wlk").href =
            returneddata["splk_wlk_mctalog_search"];
          //
          document.getElementById("btn_mpreview_splk_wlk").href =
            returneddata["splk_wlk_mpreview"];
          //
          document.getElementById("btn_search_splk_wlk_live_report").href =
            returneddata["splk_wlk_metrics_report"];

          // set search links
          document.getElementById("btn_search_splk_wlk_skipping_events").href =
            returneddata["splk_wlk_scheduler_skipping_search"];

          // set search links
          document.getElementById("btn_search_splk_wlk_scheduler_errors").href =
            returneddata["splk_wlk_scheduler_errors_search"];

          // Set and start the populating search for metrics
          setToken(
            "splk_wlk_metrics_populate_search",
            returneddata["splk_wlk_metrics_populate_search"]
          );
          searchPopulateSplkWlkMetrics.startSearch();
          //
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      var tk_monitored_state_class;
      if (tk_monitored_state == "enabled") {
        document.getElementById(
          "btn_enable_monitoring_splk_wlk"
        ).disabled = true;
        document.getElementById(
          "btn_disable_monitoring_splk_wlk"
        ).disabled = false;
        tk_monitored_state_class = "title_green";
      } else {
        document.getElementById(
          "btn_enable_monitoring_splk_wlk"
        ).disabled = false;
        document.getElementById(
          "btn_disable_monitoring_splk_wlk"
        ).disabled = true;
        tk_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_wlk_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_wlk_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_wlk_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_wlk_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_wlk").disabled = false;
        $("#btn_ack_splk_wlk").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_wlk").disabled = false;
        $("#btn_ack_splk_wlk").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_wlk").disabled = false;
        $("#btn_ack_splk_wlk").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_wlk").disabled = true;
        $("#btn_ack_splk_wlk").html("Acknowledge alert");
      }

      // replace info panels
      $("#parent-splk-wlk-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_splk_wlk +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-splk-wlk-top-info1").html(
        '<h3>Status: <span style="color: dodgerblue;">' +
          tk_status +
          '<span style="color: dodgerblue;">' +
          '<h3>Status description: <span style="color: dodgerblue;">' +
          truncate(tk_status_description, 200) +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-wlk-top-info2").html(
        '<h3>monitored state:</b> <span class="' +
          tk_monitored_state_class +
          '">' +
          tk_monitored_state +
          "</span></h3>" +
          '<h3>host state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-splk-wlk-top-info3").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-wlk-top-info4").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></h3>" +
          '<h3>Description: <span style="color: dodgerblue;">' +
          truncate(tk_description, 200) +
          "</span></h3>"
      );

      $("#child-splk-wlk-status-message").html(
        '<div class="' +
          tk_splk_wlk_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );

      // Run
      if (
        getToken("userLevel") === "user" &&
        actionTarget.startsWith("modal_modify_")
      ) {
        $("#modal_user_restricted").modal();
      } else {
        if (actionType === "modal") {
          if (actionTarget === "modal_cmdb_splk_wlk") {
            searchCmdbSplkWlk.startSearch();
          }
          $("#" + actionTarget).modal();
        } else if (actionType === "click") {
          $("#" + actionTarget).click();
        }
      }
    }

    // splk-dsm modal entity view

    function showSplkDsmEntityModal(jsonData, actionTarget, actionType) {
      // mainTokens
      var tk_tenant_id = jsonData["tenant_id"];
      var tk_parent_tenant_id = jsonData["tenant_parent"];
      var tk_keyid = jsonData["keyid"];
      var tk_object = jsonData["object"];
      var tk_object_category = jsonData["object_category"];
      // token is required
      setToken("tk_object_category", tk_object_category);
      var tk_alias = jsonData["alias"];
      var tk_data_index = jsonData["data_index"];
      // token required for operations
      setToken("tk_data_index", tk_data_index);
      var tk_splk_dsmtype = jsonData["data_sourcetype"];
      // token required for operations
      setToken("tk_splk_dsmtype", tk_splk_dsmtype);
      var tk_data_lag_summary = jsonData["lag_summary"];
      var tk_data_last_time_seen_human = jsonData["last_time"];
      var tk_data_last_ingest_human = jsonData["last_ingest"];
      var tk_data_max_lag_allowed = jsonData["data_max_lag_allowed"];
      var tk_data_max_lag_allowed_duration =
        jsonData["data_max_lag_allowed_duration"];
      var tk_data_max_delay_allowed = jsonData["data_max_delay_allowed"];
      var tk_data_max_delay_allowed_duration =
        jsonData["data_max_delay_allowed_duration"];
      // token required for auto lagging
      setToken("tk_data_max_lag_allowed", tk_data_max_lag_allowed);
      setToken("tk_data_max_delay_allowed", tk_data_max_delay_allowed);
      var tk_data_monitored_state = jsonData["monitored_state"];
      var tk_data_override_lagging_class =
        jsonData["data_override_lagging_class"];
      // required for auto lagging
      setToken(
        "tk_data_override_lagging_class",
        tk_data_override_lagging_class
      );
      var tk_object_state = jsonData["object_state"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_priority = jsonData["priority"];

      // doc href
      var tk_doc_link = jsonData["doc_link"];
      var tk_doc_note = jsonData["doc_note"];
      var tk_doc_identity_card_is_global =
        jsonData["doc_identity_card_is_global"];
      var tk_doc_key_match = jsonData["doc_key_match"];

      // tags
      var tk_tags = jsonData["tags"];
      // token required for tags operations
      setToken("tk_tags", tk_tags);

      // status
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      // required for various purposes
      setToken("tk_keyid", tk_keyid);
      setToken("tk_object", tk_object);
      var tk_object_category = jsonData["object_category"];
      setToken("tk_object_category", tk_object_category);

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      var tk_splk_dsm_status_message_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_dsm_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_dsm_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_dsm_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_dsm_status_message_class = "status_message_json_red";
      }

      // Dynamically manage buttons states
      var tk_data_monitored_state_class;
      if (tk_data_monitored_state == "enabled") {
        document.getElementById("btn_enable_monitoring").disabled = true;
        document.getElementById("btn_disable_monitoring").disabled = false;
        tk_data_monitored_state_class = "title_green";
      } else {
        document.getElementById("btn_enable_monitoring").disabled = false;
        document.getElementById("btn_disable_monitoring").disabled = true;
        tk_data_monitored_state_class = "title_grey";
      }

      // href docs
      var tk_doc_link_main;
      var tk_doc_modal_target;

      // If the documentation reference has not been set, define the href format
      if (tk_doc_link == "null") {
        tk_doc_link_main = "Click here to define a documentation reference";
        tk_doc_modal_target = "define_identity_card";
        // replace the textinput for modification requests
        document.getElementById("input_doc_link").value =
          "link to documentation";
      } else {
        tk_doc_link_main = "Show data source identity card";
        tk_doc_modal_target = "manage_identity_card";
        // replace the textinput for modification requests
        document.getElementById("input_doc_link").value = tk_doc_link;
      }

      if (tk_doc_note == "null") {
        tk_doc_link = "No documentation defined.";
        // replace the textarea for modification requests
        document.getElementById("input_doc_note").value = "documentation note";
      } else {
        // replace the textarea for modification requests
        document.getElementById("input_doc_note").value = tk_doc_note;
      }

      // If the identity card info is global, disable the delete card
      var tk_msg_doc_identity_card_is_global;
      if (tk_doc_identity_card_is_global == "true") {
        document.getElementById(
          "btn_delete_manage_identity_card"
        ).disabled = true;
        document.getElementById(
          "btn_modify_manage_identity_card"
        ).disabled = false;
        tk_msg_doc_identity_card_is_global =
          "TrackMe info: this is a default identity card configured at the system level, you cannot delete this card but you can create a new card linked to this specific data source, consult: ";
      } else if (tk_doc_key_match == "wildcard") {
        document.getElementById(
          "btn_delete_manage_identity_card"
        ).disabled = true;
        document.getElementById(
          "btn_modify_manage_identity_card"
        ).disabled = true;
        tk_msg_doc_identity_card_is_global =
          "TrackMe info: this is a wildcard matching identity card, this card has to be managed via the API endpoints, consult: ";
      } else {
        document.getElementById(
          "btn_delete_manage_identity_card"
        ).disabled = false;
        document.getElementById(
          "btn_modify_manage_identity_card"
        ).disabled = false;
        tk_msg_doc_identity_card_is_global =
          "TrackMe info: this identity card was associated to this data source, you can update or delete this card, consult: ";
      }

      // Update the div
      $("#child-data-source-identity-card1").html(
        '<h2 style="font-weight: bold; color: darkslategray;">' +
          tk_doc_note +
          "</h2>"
      );

      $("#child-data-source-identity-card2").html(
        '<a target="_blank" href=' + tk_doc_link + ">" + tk_doc_link + "</a>"
      );

      $("#child-data-source-identity-card3").html(
        "<i>" + tk_msg_doc_identity_card_is_global + "</i>"
      );

      // tags
      var tk_tags_link_main;
      // define the href depending on the tags
      if (tk_tags == "null") {
        tk_tags_link_main = "Click here to define tags";
        tk_tags_modal_target = "manage_tags";
        $("#child-data-source-tag-header").html(
          '<h1 style="font-size: 18px;">Tags for data source: ' +
            tk_object +
            "</h1>"
        );
        $("#child-data-source-tag-content").html(
          '<h2 style="font-weight: bold; color: darkslategray;">' +
            "No tags defined, click on Update tags to define one or more tags to be associated with this data source." +
            "</h2>"
        );
      } else {
        tk_tags_link_main = "Show tags";
        tk_tags_modal_target = "manage_tags";
        $("#child-data-source-tag-header").html(
          '<h1 style="font-size: 18px;">Tags for data source: ' +
            tk_object +
            "</h1>"
        );
        $("#child-data-source-tag-content").html(
          '<h2 style="font-weight: bold; color: darkslategray;">' +
            tk_tags +
            "</h2>"
        );
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_dsm").disabled = false;
        $("#btn_ack_splk_dsm").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_dsm").disabled = false;
        $("#btn_ack_splk_dsm").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_dsm").disabled = false;
        $("#btn_ack_splk_dsm").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_dsm").disabled = true;
        $("#btn_ack_splk_dsm").html("Acknowledge alert");
      }

      // replace info panels
      $("#parent-data-source-main").html(
        "<h1>Actions for entity: " +
          tk_object +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-data-source-top-info1").html(
        '<h3>Index: <span style="color: dodgerblue;">' +
          tk_data_index +
          "</span></h3>" +
          '<h3>Sourcetype: <span style="color: dodgerblue;">' +
          tk_splk_dsmtype +
          '<span style="color: dodgerblue;">' +
          '<h3>Delay event / latency ingestion: ([D+]HH:MM:SS) <span style="color: dodgerblue;">' +
          tk_data_lag_summary +
          '<span style="color: dodgerblue;">' +
          '<h3>Last time seen: <span style="color: dodgerblue;">' +
          tk_data_last_time_seen_human +
          '<span style="color: dodgerblue;">'
      );

      $("#child-data-source-top-info2").html(
        '<h3>Last ingest: <span style="color: dodgerblue;">' +
          tk_data_last_ingest_human +
          '<span style="color: dodgerblue;">' +
          "</span></h3>" +
          '<h3>Threshold latency ingestion: <span style="color: dodgerblue;">' +
          tk_data_max_lag_allowed +
          " sec (duration: " +
          tk_data_max_lag_allowed_duration +
          ")" +
          "</span></h3>" +
          '<h3>Threshold events delay: <span style="color: dodgerblue;">' +
          tk_data_max_delay_allowed +
          " sec (duration: " +
          tk_data_max_delay_allowed_duration +
          ")" +
          "</span></h3>" +
          '<h3>Monitored state:</b> <span class="' +
          tk_data_monitored_state_class +
          '">' +
          tk_data_monitored_state +
          "</span></h3>"
      );

      $("#child-data-source-top-info3").html(
        '<h3>Latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>Latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">' +
          '<h3>State:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></p>" +
          '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></p>"
      );

      $("#child-data-source-top-docs-tags").html(
        '<h3><span><a id="doc_link_splk_dsm" data-toggle="modal" data-dismiss="modal" data-target="#' +
          tk_doc_modal_target +
          '">' +
          tk_doc_link_main +
          "</a>" +
          " / " +
          '<a id="tags_splk_dsm" data-toggle="modal" data-dismiss="modal" data-target="#' +
          tk_tags_modal_target +
          '">' +
          tk_tags_link_main +
          "</a>" +
          "</span>" +
          "</h3>"
      );

      $("#child-data-source-status-message").html(
        '<div class="' +
          tk_splk_dsm_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );

      // data sampling
      var tk_data_sampling_status_message =
        jsonData["data_sample_status_message"];
      var tk_data_sampling_status_colour =
        jsonData["data_sample_status_colour"];
      var tk_data_sampling_status_message_class;
      if (tk_data_sampling_status_colour == "green") {
        var tk_data_sampling_status_message_class = "status_message_green";
      } else if (tk_data_sampling_status_colour == "orange") {
        var tk_data_sampling_status_message_class = "status_message_orange";
      } else if (tk_data_sampling_status_colour == "blue") {
        var tk_data_sampling_status_message_class = "status_message_blue";
      } else if (tk_data_sampling_status_colour == "red") {
        var tk_data_sampling_status_message_class = "status_message_red";
      } else {
        var tk_data_sampling_status_message_class = "status_message_blue";
      }

      // replace the panel
      $("#child-data-source-data-sampling").html(
        '<div class="' +
          tk_data_sampling_status_message_class +
          '">' +
          '<h2 style="font-weight: bold; color: darkslategray;">' +
          tk_data_sampling_status_message +
          "</h2>" +
          "</div>"
      );

      // status message
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      // dcount hosts
      setToken(
        "form.tk_input_splk_dsm_dcount_host",
        jsonData["min_dcount_host"]
      );

      setToken(
        "form.tk_input_splk_dsm_dcount_field",
        jsonData["min_dcount_field"]
      );

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divDsmOutliersInfo").css("display", "none");
        $("#divDsmOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divDsmOutliersSimulationInfo").css("display", "none");
        $("#divDsmOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_dsm_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_dsm_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divDsmOutliersInfo").css("display", "inherit");
        $("#divDsmOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-dsm-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divDsmOutliersSimulationInfo").css("display", "inherit");
        $("#divDsmOutliersSimulationRender").css("display", "none");
        $("#child-dsm-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_dsm_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_dsm_save").prop("disabled", true);
      }

      // doc href
      var tk_doc_link = jsonData["doc_link"];
      var tk_doc_note = jsonData["doc_note"];
      var tk_doc_identity_card_is_global =
        jsonData["doc_identity_card_is_global"];
      var tk_doc_key_match = jsonData["doc_key_match"];

      // tags
      var tk_tags = jsonData["tags"];

      // pre-fill current lagging input
      setToken("form.tk_input_lag", jsonData["data_max_lag_allowed"]);
      setToken(
        "form.tk_input_splk_dsm_simulate_latency",
        jsonData["data_max_lag_allowed"]
      );

      // pre-fill current delay input
      setToken("form.tk_input_delay", jsonData["data_max_delay_allowed"]);
      setToken(
        "form.tk_input_splk_dsm_simulate_delay",
        jsonData["data_max_delay_allowed"]
      );

      // pre-fill future tolerance
      setToken("form.tk_input_future_tolerance", jsonData["future_tolerance"]);

      // pre-fill current wdays input
      setToken("form.tk_input_wdays", jsonData["data_monitoring_wdays"]);

      // pre-fill current hours ranges
      setToken(
        "form.tk_input_hours_ranges",
        jsonData["data_monitoring_hours_ranges"]
      );

      // pre-fill current priority
      setToken("form.tk_input_priority", jsonData["priority"]);

      // pre-fill lagging class override
      setToken(
        "form.modal_input_lag_override_class",
        jsonData["data_override_lagging_class"]
      );

      // pre-fill allow_adaptive_delay
      setToken(
        "form.modal_input_allow_adaptive_delay",
        jsonData["allow_adaptive_delay"]
      );

      // pre-fill alert over kpis
      setToken(
        "form.tk_input_data_lag_alert_kpis",
        jsonData["data_lag_alert_kpis"]
      );

      // get data provider

      // spinner
      cssloader("Requested action is in progress, please wait...");

      // Retrieve entity info from REST and set actions

      // handle replica
      var target_tenant_id = tk_parent_tenant_id || tk_tenant_id;
      if (tk_parent_tenant_id) {
        setToken("tenant_id", target_tenant_id);
      }

      $.ajax({
        url: "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_entity_info",
        type: "POST",
        async: true,
        contentType: "application/json",
        data: JSON.stringify({
          tenant_id: target_tenant_id,
          object: tk_object,
        }),
        success: function (returneddata) {
          // spinner
          cssloaderremove();

          //
          // get from the json response
          //

          setToken(
            "tk_splk_dsm_overview_root_search",
            returneddata["splk_dsm_overview_root_search"]
          );

          // get the selected data provider
          var splk_dsm_data_provider = getToken(
            "tk_input_splk_dsm_overview_data_provider"
          );

          // get
          var splk_dsm_overview_trackme_single_stats =
            returneddata["splk_dsm_overview_trackme_single_stats"];
          setToken(
            "tk_splk_dsm_overview_trackme_single_stats",
            splk_dsm_overview_trackme_single_stats
          );

          var splk_dsm_overview_trackme_timechart =
            returneddata["splk_dsm_overview_trackme_timechart"];
          setToken(
            "tk_splk_dsm_overview_trackme_timechart",
            splk_dsm_overview_trackme_timechart
          );

          var splk_dsm_overview_splunk_single_stats =
            returneddata["splk_dsm_overview_splunk_single_stats"];
          setToken(
            "tk_splk_dsm_overview_splunk_single_stats",
            splk_dsm_overview_splunk_single_stats
          );

          var splk_dsm_overview_splunk_timechart =
            returneddata["splk_dsm_overview_splunk_timechart"];
          setToken(
            "tk_splk_dsm_overview_splunk_timechart",
            splk_dsm_overview_splunk_timechart
          );

          // set searches dynamically
          if (splk_dsm_data_provider === "trackme") {
            setToken(
              "tk_splk_dsm_overview_single_stats",
              splk_dsm_overview_trackme_single_stats
            );
            setToken(
              "tk_splk_dsm_overview_timechart",
              splk_dsm_overview_trackme_timechart
            );
          } else if (splk_dsm_data_provider === "splunk") {
            setToken(
              "tk_splk_dsm_overview_single_stats",
              splk_dsm_overview_splunk_single_stats
            );
            setToken(
              "tk_splk_dsm_overview_timechart",
              splk_dsm_overview_splunk_timechart
            );
          } else {
            setToken(
              "tk_splk_dsm_overview_single_stats",
              splk_dsm_overview_trackme_single_stats
            );
            setToken(
              "tk_splk_dsm_overview_timechart",
              splk_dsm_overview_trackme_timechart
            );
          }

          var splk_dsm_raw_search = returneddata["splk_dsm_raw_search"];

          // Define the URL target
          document.getElementById("btn_search_splk_dsm").href =
            splk_dsm_raw_search;
          // token is required for dynamic override
          setToken("tk_splk_dsm_raw_search", splk_dsm_raw_search);
          // Run
          if (
            getToken("userLevel") === "user" &&
            actionTarget.startsWith("modal_modify_")
          ) {
            $("#modal_user_restricted").modal();
          } else {
            if (actionType === "modal") {
              // start the CMDB search if requested
              if (actionTarget === "modal_cmdb_splk_dsm") {
                searchCmdbSplkDsm.startSearch();
              }
              $("#" + actionTarget).modal();
            } else if (actionType === "click") {
              $("#" + actionTarget).click();
            }
          }
          //
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          // unset tokens to avoid running anything unexpected
          unsetToken("tk_splk_dsm_overview_root_search");
          unsetToken("tk_splk_dsm_overview_trackme_single_stats");
          unsetToken("tk_splk_dsm_overview_trackme_timechart");
          unsetToken("tk_splk_dsm_overview_splunk_single_stats");
          unsetToken("tk_splk_dsm_overview_splunk_timechart");
          unsetToken("tk_splk_dsm_overview_single_stats");
          unsetToken("tk_splk_dsm_overview_timechart");
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });

      //
      //
      //
    }

    // Lagging Classes handler
    function laggingClassesHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleLaggingClasses" + component + "Manage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Lagging Classes currently</span></h1>"
        );

        var tabulatorElement;
        if (component === "dsmdhm") {
          tabulatorElement = "#" + "dsmdhm-laggingclasses-table";
        } else if (component === "mhm") {
          tabulatorElement = "#" + "mhm-laggingclasses-table";
        }

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 5, //allow 5 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          groupBy: "object_category",
          initialSort: [
            //set the initial sort order of the data
            { column: "name", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Name",
              field: "name",
              editor: true,
              headerFilter: true,
            },
            {
              title: "Level (applies to)",
              field: "level",
              editor: "list",
              editorParams: { values: ["sourcetype", "index", "priority"] },
              headerFilter: "input",
            },
            {
              title: "Object (component)",
              field: "object",
              editor: "list",
              editorParams: { values: ["splk-dsm", "splk-dhm", "all"] },
              headerFilter: "input",
            },
            {
              title: "Threshold delay value (seconds)",
              field: "value_delay",
              editor: true,
              headerFilter: true,
            },
            {
              title: "Threshold latency value (seconds)",
              field: "value_lag",
              editor: true,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var saveBtn = "#" + "btn_modal_laggingclasses_" + component + "_save";
        var deleteBtn =
          "#" + "btn_modal_laggingclasses_" + component + "_delete";
        var saveToken = "tk_laggingclasses_" + component + "_update";
        var deleteToken = "tk_laggingclasses_" + component + "_delete";
        var saveConfirmModal =
          "#modal_laggingclasses_" + component + "_confirm_save";
        var deleteConfirmModal =
          "#modal_laggingclasses_" + component + "_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");
            setToken(saveToken, JSON.stringify(selectedData));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i]._key);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#modify_custom_lagging").modal();
        });
      });
    }

    // Lagging Classes handler
    function laggingClassesMetricsHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleLaggingClasses" + component + "Manage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Lagging Classes currently</span></h1>"
        );

        var tabulatorElement;
        if (component === "mhm") {
          tabulatorElement = "#" + "mhm-laggingclasses-table";
        }

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 5, //allow 5 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "metric_category", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "metric_category",
              field: "metric_category",
              editor: true,
              headerFilter: true,
            },
            {
              title: "Threshold value (seconds)",
              field: "metric_max_lag_allowed",
              editor: true,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var saveBtn = "#" + "btn_modal_laggingclasses_" + component + "_save";
        var deleteBtn =
          "#" + "btn_modal_laggingclasses_" + component + "_delete";
        var saveToken = "tk_laggingclasses_" + component + "_update";
        var deleteToken = "tk_laggingclasses_" + component + "_delete";
        var saveConfirmModal =
          "#modal_laggingclasses_" + component + "_confirm_save";
        var deleteConfirmModal =
          "#modal_laggingclasses_" + component + "_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");
            setToken(saveToken, JSON.stringify(selectedData));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i]._key);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });
      });
    }

    // Tags Policies handler
    function tagsPoliciesHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // static component
        var component = "dsm";

        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleTagsPolicies" + component + "Manage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Tags policies currently</span></h1>"
        );

        var tabulatorElement;
        if (component === "dsm") {
          tabulatorElement = "#" + "dsm-tagspolicies-table";
        }

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 5 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "tags_policy_id", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "tags_policy_id",
              field: "tags_policy_id",
              editor: true,
              headerFilter: true,
            },
            {
              title: "tags_policy_regex",
              field: "tags_policy_regex",
              editor: true,
              headerFilter: true,
            },
            {
              title: "tags_policy_value",
              field: "tags_policy_value",
              editor: true,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var saveBtn = "#" + "btn_modal_tagspolicies_" + component + "_save";
        var deleteBtn = "#" + "btn_modal_tagspolicies_" + component + "_delete";
        var saveToken = "tk_tagspolicies_" + component + "_update";
        var deleteToken = "tk_tagspolicies_" + component + "_delete";
        var saveConfirmModal =
          "#modal_tagspolicies_" + component + "_confirm_save";
        var deleteConfirmModal =
          "#modal_tagspolicies_" + component + "_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");
            setToken(saveToken, JSON.stringify(selectedData));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].tags_policy_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#manage_tags_policies").modal();
        });
      });
    }

    // Manage Permanently Deleted entities handler
    function permDeletedEntitiesHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitlePermDeletedEntitiesCount").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " entities currently</span></h1>"
        );

        var tabulatorElement = "#perm-deleted-entities-table";

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 5 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "_key",
              field: "_key",
              editor: false,
              headerFilter: false,
            },
            {
              title: "object_category",
              field: "object_category",
              editor: false,
              headerFilter: false,
            },
            {
              title: "object",
              field: "object",
              editor: false,
              headerFilter: true,
            },
            {
              title: "ctime",
              field: "ctime_human",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_modal_perm_deleted_entities_delete";
        var deleteToken = "tk_perm_deleted";
        var deleteConfirmModal = "#modal_perm_deleted_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i]._key);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#manage_perm_deleted").modal();
        });
      });
    }

    // Manage Ack handler
    function ackHandlerTable(ajaxUrl, ajaxType, ajaxData, openModal) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        var tabulatorElement = "#ack-entities-table";
        // copy resultCall to originalData
        var originalData = JSON.parse(JSON.stringify(resultCall));

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 5 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "_key",
              field: "_key",
              editor: false,
              headerFilter: false,
              visible: false,
            },
            {
              title: "object",
              field: "object",
              editor: false,
              headerFilter: false,
            },
            {
              title: "ack_mtime",
              field: "ack_mtime_datetime",
              editor: false,
              headerFilter: false,
            },
            {
              title: "ack_expiration",
              field: "ack_expiration_datetime",
              editor: false,
              headerFilter: false,
            },
            {
              title: "ack_type",
              field: "ack_type",
              headerFilter: false,
              editor: "list",
              editorParams: { values: ["sticky", "unsticky"] },
            },
            {
              title: "ack_comment",
              field: "ack_comment",
              editor: true,
              headerFilter: false,
            },
            {
              title: "enabled",
              field: "ack_is_enabled",
              headerFilter: false,
              hozAlign: "center",
              formatter: "tickCross",
              width: 100,
              editor: "list",
              editorParams: { values: ["True", "False"] },
            },
          ],
        });

        // Add Ack
        var addBtn = "#btn_modal_ack_add";

        // delete Ack
        var deleteBtn = "#btn_modal_ack_disable";

        // save Ack changes
        var saveBtn = "#btn_modal_ack_save";

        // cancel Ack changes
        var cancelBtn = "#btn_modal_ack_cancel";

        // back button
        var backBtn = "#btn_modal_ack_back";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // disable the inline save button
        $(cancelBtn).prop("disabled", true);

        // return to main
        $(backBtn)
          .unbind()
          .click(function () {
            // retrieve token
            var tk_object_category = getToken("tk_object_category");
            // conditional modal target
            if (tk_object_category === "splk-dsm") {
              $("#modal_manage_splk_dsm").modal();
            } else if (tk_object_category === "splk-dhm") {
              $("#modal_manage_splk_dhm").modal();
            } else if (tk_object_category === "splk-mhm") {
              $("#modal_manage_splk_mhm").modal();
            } else if (tk_object_category === "splk-cim") {
              $("#modal_manage_splk_cim").modal();
            } else if (tk_object_category === "splk-flx") {
              $("#modal_manage_splk_flx").modal();
            } else if (tk_object_category === "splk-wlk") {
              $("#modal_manage_splk_wlk").modal();
            }
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: getToken("tenant_id"),
              action: "disable",
              object_category: getToken("tk_object_category"),
              object_list: getToken("tk_object"),
              update_comment: getComment("input_ack_comment"),
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Refresh the main search
                tk_object_category = getToken("tk_object_category");
                if (tk_object_category == "splk-dsm") {
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-cim") {
                  searchSplkCimMain.startSearch();
                  // refresh tabulator
                  $("#splk-cim-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-dhm") {
                  searchSplkDhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dhm-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-mhm") {
                  searchSplkMhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-mhm-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-flx") {
                  searchSplkFlxMain.startSearch();
                  // refresh tabulator
                  $("#splk-flx-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-wlk") {
                  searchSplkWlkMain.startSearch();
                  // refresh tabulator
                  $("#splk-wlk-table-refresh-hidden").click();
                }

                // refresh the ack table
                ackHandlerTable(
                  "/en-US/splunkd/__raw/services/trackme/v2/ack/get_ack_for_object",
                  "POST",
                  {
                    tenant_id: getToken("tenant_id"),
                    object_category: getToken("tk_object_category"),
                    object_list: getToken("tk_object"),
                  },
                  "false"
                );

                // notify
                notify("success", "bottom", "Ack disabled successfully", "5");
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;

                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
          $(cancelBtn).prop("disabled", false);
        });

        // Open modal
        if (openModal == "true") {
          table.on("tableBuilt", function () {
            $("#confirm_ack").modal();
          });
        }

        // Save inline changes
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // lopp through the records in selectedData, get the value for ack_is_enabled and log
            for (var i = 0; i < selectedData.length; i++) {
              var record_ack_is_enabled = selectedData[i].ack_is_enabled;
              var record_ack_comment = selectedData[i].ack_comment;
              var record_ack_type = selectedData[i].ack_type;
              if (record_ack_type == "N/A") {
                record_ack_type = "unsticky";
              }
              //var record_ack_expiration = selectedData[i].ack_expiration;
              //var record_ack_mtime = selectedData[i].ack_mtime;
              var record_object = selectedData[i].object;
              var record_object_category = selectedData[i].object_category;
              //var record_tenant_id = selectedData[i].tenant_id;
              //var _key = selectedData[i]._key;

              var record_ack_action;
              if (record_ack_is_enabled == "True" || record_ack_is_enabled == 1) {
                record_ack_action = "enable";
              } else {
                record_ack_action = "disable";
              }

              // get ack_period, if null set to 86400
              var record_ack_period = getToken("input_ack_duration");
              if (record_ack_period == null) {
                record_ack_period = 86400;
              }

              var record = {
                tenant_id: getToken("tenant_id"),
                action: record_ack_action,
                ack_is_enabled: record_ack_is_enabled,
                object_category: record_object_category,
                object_list: record_object,
                ack_period: record_ack_period,
                ack_type: record_ack_type,
                ack_comment: record_ack_comment,
                update_comment: record_ack_comment,
              };

              // Create the endpoint URL
              var myendpoint_URl =
                "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // Refresh the main search
                  tk_object_category = getToken("tk_object_category");
                  if (tk_object_category == "splk-dsm") {
                    searchSplkDsmMain.startSearch();
                    // refresh tabulator
                    $("#splk-dsm-table-refresh-hidden").click();
                  } else if (tk_object_category == "splk-cim") {
                    searchSplkCimMain.startSearch();
                    // refresh tabulator
                    $("#splk-cim-table-refresh-hidden").click();
                  } else if (tk_object_category == "splk-dhm") {
                    searchSplkDhmMain.startSearch();
                    // refresh tabulator
                    $("#splk-dhm-table-refresh-hidden").click();
                  } else if (tk_object_category == "splk-mhm") {
                    searchSplkMhmMain.startSearch();
                    // refresh tabulator
                    $("#splk-mhm-table-refresh-hidden").click();
                  } else if (tk_object_category == "splk-flx") {
                    searchSplkFlxMain.startSearch();
                    // refresh tabulator
                    $("#splk-flx-table-refresh-hidden").click();
                  } else if (tk_object_category == "splk-wlk") {
                    searchSplkWlkMain.startSearch();
                    // refresh tabulator
                    $("#splk-wlk-table-refresh-hidden").click();
                  }

                  // refresh the ack table
                  ackHandlerTable(
                    "/en-US/splunkd/__raw/services/trackme/v2/ack/get_ack_for_object",
                    "POST",
                    {
                      tenant_id: getToken("tenant_id"),
                      object_category: getToken("tk_object_category"),
                      object_list: getToken("tk_object"),
                    },
                    "false"
                  );
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            }

            // notify
            notify("success", "bottom", "Ack saved successfully", "5");
            $(saveBtn).prop("disabled", true);
            $(cancelBtn).prop("disabled", true);
          });

        // Cancel inline changes
        $(cancelBtn)
          .unbind()
          .click(function () {

            ackHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/ack/get_ack_for_object",
              "POST",
              {
                tenant_id: getToken("tenant_id"),
                object_category: getToken("tk_object_category"),
                object_list: getToken("tk_object"),
              },
              "false"
            );

            $(saveBtn).prop("disabled", true);
            $(cancelBtn).prop("disabled", true);
          });

        // Add new Ack
        $(addBtn)
          .unbind()
          .click(function () {
            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/ack/ack_manage";

            // get ack_period, if null set to 86400
            var record_ack_period = getToken("input_ack_duration");
            if (record_ack_period == null) {
              record_ack_period = 86400;
            }

            // get ack_type, if null set to unsticky
            var record_ack_type = getToken("input_ack_type");
            if (record_ack_type == null) {
              record_ack_type = "unsticky";
            }

            // Create a dictionary to store the field names and values
            var record = {
              tenant_id: getToken("tenant_id"),
              action: "enable",
              object_category: getToken("tk_object_category"),
              object_list: getToken("tk_object"),
              ack_period: record_ack_period,
              ack_type: record_ack_type,
              update_comment: getComment("input_ack_comment"),
            };

            // spinner
            cssloader("Requested action is in progress, please wait...");

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "text",
              beforeSend: function (xhr) {
                xhr.overrideMimeType("text/plain; charset=x-user-defined");
              },
              data: JSON.stringify(record),
              success: function (returneddata) {
                // spinner
                cssloaderremove();
                // Refresh the main search
                tk_object_category = getToken("tk_object_category");
                if (tk_object_category == "splk-dsm") {
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-cim") {
                  searchSplkCimMain.startSearch();
                  // refresh tabulator
                  $("#splk-cim-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-dhm") {
                  searchSplkDhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dhm-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-mhm") {
                  searchSplkMhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-mhm-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-flx") {
                  searchSplkFlxMain.startSearch();
                  // refresh tabulator
                  $("#splk-flx-table-refresh-hidden").click();
                } else if (tk_object_category == "splk-wlk") {
                  searchSplkWlkMain.startSearch();
                  // refresh tabulator
                  $("#splk-wlk-table-refresh-hidden").click();
                }

                // refresh the ack table
                ackHandlerTable(
                  "/en-US/splunkd/__raw/services/trackme/v2/ack/get_ack_for_object",
                  "POST",
                  {
                    tenant_id: getToken("tenant_id"),
                    object_category: getToken("tk_object_category"),
                    object_list: getToken("tk_object"),
                  },
                  "false"
                );

                // notify
                notify("success", "bottom", "Ack added successfully", "5");
              },
              error: function (xhr, textStatus, error) {
                // spinner
                cssloaderremove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;

                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
            });
          });
      });
    }

    // Data sampling model handler
    function dataSamplingHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // static component
        var component = "dsm";

        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleDataSamplingModels" + component + "Manage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Data sampling custom models currently</span></h1>"
        );

        var tabulatorElement;
        if (component === "dsm") {
          tabulatorElement = "#" + "dsm-datasamplingmodels-table";
        }

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 5 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "tags_policy_id", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "model_id",
              field: "model_id",
              editor: true,
              headerFilter: true,
            },
            {
              title: "model_name",
              field: "model_name",
              editor: true,
              headerFilter: true,
            },
            {
              title: "model_regex",
              field: "model_regex",
              editor: true,
              headerFilter: true,
            },
            {
              title: "model_type",
              field: "model_type",
              editor: "list",
              editorParams: { values: ["inclusive", "exclusive"] },
              headerFilter: "input",
            },
            {
              title: "sourcetype_scope",
              field: "sourcetype_scope",
              editor: true,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var saveBtn =
          "#" + "btn_modal_datasamplingmodels_" + component + "_save";
        var deleteBtn =
          "#" + "btn_modal_datasamplingmodels_" + component + "_delete";
        var saveToken = "tk_datasamplingmodels_" + component + "_update";
        var deleteToken = "tk_datasamplingmodels_" + component + "_delete";
        var saveConfirmModal =
          "#modal_datasamplingmodels_" + component + "_confirm_save";
        var deleteConfirmModal =
          "#modal_datasamplingmodels_" + component + "_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");
            setToken(saveToken, JSON.stringify(selectedData));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i]._key);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#data_sampling_show_custom_rules").modal();
        });
      });
    }

    // dataset handler
    function dataSetHandlerTable(ajaxUrl, ajaxType, ajaxData, component) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleDataSet" + component + "Manage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Object(s) in the dataset handler currently</span></h1>"
        );

        var tabulatorElement;
        if (component === "dsm") {
          tabulatorElement = "#" + "dsm-dataset-table";
        } else if (component === "dhm") {
          tabulatorElement = "#" + "dhm-dataset-table";
        } else if (component === "mhm") {
          tabulatorElement = "#" + "mhm-dataset-table";
        }

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          groupBy: "object_category",
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "_key",
              field: "_key",
              editor: false,
            },
            {
              title: "Object category",
              field: "object_category",
              editor: false,
              headerFilter: true,
            },
            {
              title: "Value",
              field: "object",
              editor: "input",
              headerFilter: true,
            },
            {
              title: "Action",
              field: "action",
              visible: false,
              editor: "list",
              editorParams: { values: ["allow", "block"] },
              headerFilter: "input",
            },
            {
              title: "Is regular expression based",
              field: "is_rex",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var saveBtn = "#" + "btn_modal_dataset_" + component + "_save";
        var deleteBtn = "#" + "btn_modal_dataset_" + component + "_delete";
        var saveToken = "tk_dataset_" + component + "_update";
        var deleteToken = "tk_dataset_" + component + "_delete";
        var saveConfirmModal = "#modal_dataset_" + component + "_confirm_save";
        var deleteConfirmModal =
          "#modal_dataset_" + component + "_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");
            setToken(saveToken, JSON.stringify(selectedData));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i]._key);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          if (component === "dsm") {
            $("#modal_dsm_dataset_handler").modal();
          } else if (component === "dhm") {
            $("#modal_dhm_dataset_handler").modal();
          } else if (component === "mhm") {
            $("#modal_mhm_dataset_handler").modal();
          }
        });
      });
    }

    // CIM tracking handler
    function cimTrackingHandlerTable(ajaxUrl, ajaxType, ajaxData, component) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleCimManage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " CIM tracker(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#cim-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "account",
              field: "account",
              editor: false,
              headerFilter: true,
            },
            {
              title: "object",
              field: "object",
              editor: false,
              headerFilter: true,
            },
            {
              title: "tracker_name",
              field: "tracker_name",
              editor: false,
              headerFilter: true,
            },
            {
              title: "priority",
              field: "priority",
              editor: "list",
              editorParams: { values: ["low", "medium", "high"] },
              headerFilter: "input",
            },
            {
              title: "monitored_state",
              field: "monitored_state",
              editor: "list",
              editorParams: { values: ["enabled", "disabled"] },
              headerFilter: "input",
            },
          ],
        });

        // actions per component
        var deleteBtn = "#" + "btn_modal_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var saveBtn = "#" + "btn_modal_" + component + "_save";
        var saveToken = "tk_" + component + "_update";
        var saveConfirmModal = "#modal_" + component + "_confirm_save";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var selectedEntity = selectedData[i].object;
              var selectedPriority = selectedData[i].priority;
              var selectedMonitoredState = selectedData[i].monitored_state;

              var subDict = {
                object: selectedEntity,
                priority: selectedPriority,
                monitored_state: selectedMonitoredState,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].object);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#modify_cim_trackers").modal();
        });
      });
    }

    //
    // splk-wlk
    //

    // Apps management handler
    function splkWlkAppsManageTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // static component
        var component = "wlk";

        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleWlkAppsManagement").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Apps policies currently</span></h1>"
        );

        var tabulatorElement;
        tabulatorElement = "#wlk-apps-management-table";

        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 5 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "app", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "app",
              field: "app",
              editor: true,
              headerFilter: true,
            },
            {
              title: "enabled",
              field: "enabled",
              hozAlign: "center",
              formatter: "tickCross",
              editor: "list",
              editorParams: { values: ["True", "False"] },
              headerFilter: false,
              headerSort: false,
            },
          ],
        });

        // actions per component
        var saveBtn = "#btn_modal_wlk_apps_management_save";
        var deleteBtn = "#btn_modal_wlk_apps_management_delete";
        var saveToken = "tk_wlk_apps_management_update";
        var deleteToken = "tk_wlk_apps_management_delete";
        var saveConfirmModal = "#modal_wlk_apps_enablement_confirm_save";
        var deleteConfirmModal = "#modal_wlk_apps_enablement_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");
            setToken(saveToken, JSON.stringify(selectedData));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].app);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#manage_wlk_apps_enablement").modal();
        });
      });
    }

    //
    // replica tracking handler
    //

    function replicaTrackingHandlerTable(ajaxUrl, ajaxType, ajaxData) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;

        $("#divTitleReplicaManage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " replica tracker(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#replica-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "tracker_name",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "tracker_name", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "tracker_name",
              field: "tracker_name",
              editor: false,
              headerFilter: true,
            },
            {
              title: "knowledge_objects",
              field: "knowledge_objects",
              editor: false,
              headerFilter: false,
              formatter: "textarea",
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_modal_replica_delete";
        var deleteToken = "tk_replica_delete";
        var deleteConfirmModal = "#modal_replica_confirm_delete";
        var saveBtn = "#btn_modal_replica_save";
        var saveToken = "tk_replica_update";
        var saveConfirmModal = "#modal_replica_confirm_save";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var selectedEntity = selectedData[i].object;
              var selectedPriority = selectedData[i].priority;
              var selectedMonitoredState = selectedData[i].monitored_state;

              var subDict = {
                object: selectedEntity,
                priority: selectedPriority,
                monitored_state: selectedMonitoredState,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].tracker_name);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#manage_replica_trackers").modal();
        });
      });
    }

    //
    // hybrid tracking handler
    //

    // dsm

    function hybridTrackingHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;

        var divTitleInfo;
        if (component === "dsm") {
          divTitleInfo = "divTitleHybridDsmManage";
        } else if (component === "dhm") {
          divTitleInfo = "divTitleHybridDhmManage";
        } else if (component === "mhm") {
          divTitleInfo = "divTitleHybridMhmManage";
        } else if (component === "flx") {
          divTitleInfo = "divTitleHybridFlxManage";
        } else if (component === "wlk") {
          divTitleInfo = "divTitleHybridWlkManage";
        }

        $("#" + divTitleInfo).html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " hybrid tracker(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#hybrid-" + component + "-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "tracker_name",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "tracker_name", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "tracker_name",
              field: "tracker_name",
              editor: false,
              headerFilter: true,
            },
            {
              title: "knowledge_objects",
              field: "knowledge_objects",
              editor: false,
              headerFilter: false,
              formatter: "textarea",
            },
          ],
        });

        // actions per component
        var deleteBtn = "#" + "btn_modal_hybrid_" + component + "_delete";
        var deleteToken = "tk_hybrid_" + component + "_delete";
        var deleteConfirmModal =
          "#modal_hybrid_" + component + "_confirm_delete";
        var saveBtn = "#" + "btn_modal_hybrid_" + component + "_save";
        var saveToken = "tk_hybrid_" + component + "_update";
        var saveConfirmModal = "#modal_hybrid_" + component + "_confirm_save";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var selectedEntity = selectedData[i].object;
              var selectedPriority = selectedData[i].priority;
              var selectedMonitoredState = selectedData[i].monitored_state;

              var subDict = {
                object: selectedEntity,
                priority: selectedPriority,
                monitored_state: selectedMonitoredState,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].tracker_name);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });

        // Open modal
        table.on("tableBuilt", function () {
          if (component === "dsm") {
            $("#manage_hybrid_trackers_dsm").modal();
          } else if (component === "dhm") {
            $("#manage_hybrid_trackers_dhm").modal();
          } else if (component === "mhm") {
            $("#manage_hybrid_trackers_mhm").modal();
          } else if (component === "flx") {
            $("#manage_hybrid_trackers_flx").modal();
          } else if (component === "wlk") {
            $("#manage_hybrid_trackers_wlk").modal();
          }
        });
      });
    }

    // Shared Elastic Source tracking handler
    function elasticSharedHandlerTable(ajaxUrl, ajaxType, ajaxData, component) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitle" + component + "Manage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Elastic Source(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#elasticshared-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "object",
              field: "object",
              editor: false,
              headerFilter: true,
            },
            {
              title: "search_mode",
              field: "search_mode",
              editor: false,
              headerFilter: true,
            },
            {
              title: "search_constraint",
              field: "search_constraint",
              editor: false,
              headerFilter: true,
            },
            {
              title: "elastic_index",
              field: "elastic_index",
              editor: false,
              headerFilter: true,
            },
            {
              title: "elastic_sourcetype",
              field: "elastic_sourcetype",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#" + "btn_modal_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].object);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#modify_elastic_sources_shared").modal();
        });
      });
    }

    // Dedicated Elastic Source tracking handler
    function elasticDedicatedHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitle" + component + "Manage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Elastic Source(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#elasticdedicated-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "_key",
          layout: "fitColumns", //fit columns to width of table
          responsiveLayout: "hide", //hide columns that dont fit on the table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          pagination: "local", //paginate the data
          paginationSize: 7, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "elastic_report",
              field: "elastic_report",
              editor: false,
              headerFilter: true,
            },
            {
              title: "object",
              field: "object",
              editor: false,
              headerFilter: true,
            },
            {
              title: "search_mode",
              field: "search_mode",
              editor: false,
              headerFilter: true,
            },
            {
              title: "search_constraint",
              field: "search_constraint",
              editor: false,
              headerFilter: true,
            },
            {
              title: "elastic_index",
              field: "elastic_index",
              editor: false,
              headerFilter: true,
            },
            {
              title: "elastic_sourcetype",
              field: "elastic_sourcetype",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#" + "btn_modal_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].object);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#modify_elastic_sources_dedicated").modal();
        });
      });
    }

    // Outliers anomaly detection splk-dsm handler
    function OutliersAnomalySplkDsmHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // from the first record in resultCall, get the value for confidence and confidence_reason
        if (resultCall.length > 0) {
          var confidence = resultCall[0].confidence;
          var confidence_reason = resultCall[0].confidence_reason;

          if (confidence == "low") {
            $("#divTitleSplkDsmOutliersModelManageMainTitle").html(
              '<h2><span style="color: #ffb347;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          } else {
            $("#divTitleSplkDsmOutliersModelManageMainTitle").html(
              '<h2><span style="color: #45d4ba;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          }
        } else {
          // Handle the case where resultCall is empty
          $("#divTitleSplkDsmOutliersModelManageMainTitle").html(
            '<h2><span style="color: #ffb347">Confidence: Unknown, reason: Pending for model(s) definition</span></h2>'
          );
        }

        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkDsmOutliersModelManage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Machine Learning Outliers Model(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-dsm-outliers-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitDataStretch", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 2, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "model_id", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: false,
            },
            {
              title: "kpi_metric",
              field: "kpi_metric",
              editor: "list",
              editorParams: {
                values: [
                  "splk.feeds.avg_eventcount_5m",
                  "splk.feeds.latest_eventcount_5m",
                  "splk.feeds.perc95_eventcount_5m",
                  "splk.feeds.stdev_eventcount_5m",
                  "splk.feeds.avg_latency_5m",
                  "splk.feeds.latest_latency_5m",
                  "splk.feeds.perc95_latency_5m",
                  "splk.feeds.stdev_latency_5m",
                  "splk.feeds.avg_dcount_host_5m",
                  "splk.feeds.latest_dcount_host_5m",
                  "splk.feeds.perc95_dcount_host_5m",
                  "splk.feeds.stdev_dcount_host_5m",
                ],
              },
              headerFilter: false,
            },
            {
              title: "kpi_span",
              field: "kpi_span",
              editor: "list",
              editorParams: {
                values: ["5m", "10m", "15m", "30m", "1h"],
              },
              headerFilter: false,
            },
            {
              title: "method_calculation",
              field: "method_calculation",
              editor: "list",
              editorParams: {
                values: ["stdev", "avg", "perc95", "latest"],
              },
              headerFilter: false,
            },
            {
              title: "period_calculation",
              field: "period_calculation",
              editor: "list",
              editorParams: {
                values: ["-7d", "-30d", "-60d", "-90d"],
              },
              headerFilter: false,
            },
            {
              title: "time_factor",
              field: "time_factor",
              editor: "list",
              editorParams: {
                values: ["%H", "%H%M", "%w%H", "%w%H%M", "none"],
              },
              headerFilter: false,
            },
            {
              title: "density_lowerthreshold",
              field: "density_lowerthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "density_upperthreshold",
              field: "density_upperthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "alert_lower_breached",
              field: "alert_lower_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "alert_upper_breached",
              field: "alert_upper_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "auto_correct",
              field: "auto_correct",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "perc_min_lowerbound_deviation",
              field: "perc_min_lowerbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "perc_min_upperbound_deviation",
              field: "perc_min_upperbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "is_disabled",
              field: "is_disabled",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var saveBtn = "#btn_" + component + "_save";
        var saveToken = "tk_" + component + "_update";
        var simulateBtn = "#btn_" + component + "_simulate";
        var resetBtn = "#btn_" + component + "_reset";
        var saveConfirmModal = "#modal_" + component + "_confirm_save";
        var resetConfirmModal = "#modal_" + component + "_confirm_reset";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // simulate
        $(simulateBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // get the selected model_id
            var selectedModelId = getToken(
              "tk_input_splk_dsm_outliers_model_id_settings_dropdown"
            );

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: time_factor,
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              // push the model definition if equals to the selectedModelId
              if (model_id === selectedModelId) {
                itemList.push(subDict);
              }
            }

            setToken(saveToken, JSON.stringify(itemList[0]));

            // set the simulation JSON model def
            setToken(
              "tk_splk_dsm_simulation_model_def",
              JSON.stringify(itemList[0]).replace(/\"/g, '\\"')
            );

            // set the token the search depends on
            setToken("start_outliers_simulation_splk_dsm", "true");

            // explicitly start the search
            searchOutlierDetectionChartSimulationDsm.startSearch();

            //
          });

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: encodeURI(time_factor),
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // reset
        $(resetBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(resetConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].model_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });
      });
    }

    // Outliers anomaly detection splk-flx handler
    function OutliersAnomalySplkFlxHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;

        // from the first record in resultCall, get the value for confidence and confidence_reason
        if (resultCall.length > 0) {
          var confidence = resultCall[0].confidence;
          var confidence_reason = resultCall[0].confidence_reason;

          if (confidence == "low") {
            $("#divTitleSplkFlxOutliersModelManageMainTitle").html(
              '<h2><span style="color: #ffb347;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          } else {
            $("#divTitleSplkFlxOutliersModelManageMainTitle").html(
              '<h2><span style="color: #45d4ba;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          }
        } else {
          // Handle the case where resultCall is empty
          $("#divTitleSplkFlxOutliersModelManageMainTitle").html(
            '<h2><span style="color: #ffb347">Confidence: Unknown, reason: Pending for model(s) definition</span></h2>'
          );
        }

        $("#divTitleSplkFlxOutliersModelManage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Machine Learning Outliers Model(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-flx-outliers-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitDataStretch", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 2, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "model_id", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: false,
            },
            {
              title: "kpi_metric",
              field: "kpi_metric",
              editor: "list",
              editorParams: {
                values: [
                  "splk.feeds.avg_eventcount_5m",
                  "splk.feeds.latest_eventcount_5m",
                  "splk.feeds.perc95_eventcount_5m",
                  "splk.feeds.stdev_eventcount_5m",
                  "splk.feeds.avg_latency_5m",
                  "splk.feeds.latest_latency_5m",
                  "splk.feeds.perc95_latency_5m",
                  "splk.feeds.stdev_latency_5m",
                ],
              },
              headerFilter: false,
            },
            {
              title: "kpi_span",
              field: "kpi_span",
              editor: "list",
              editorParams: {
                values: ["5m", "10m", "15m", "30m", "1h"],
              },
              headerFilter: false,
            },
            {
              title: "method_calculation",
              field: "method_calculation",
              editor: "list",
              editorParams: {
                values: ["stdev", "avg", "perc95", "latest"],
              },
              headerFilter: false,
            },
            {
              title: "period_calculation",
              field: "period_calculation",
              editor: "list",
              editorParams: {
                values: ["-7d", "-30d", "-60d", "-90d"],
              },
              headerFilter: false,
            },
            {
              title: "time_factor",
              field: "time_factor",
              editor: "list",
              editorParams: {
                values: ["%H", "%H%M", "%w%H", "%w%H%M", "none"],
              },
              headerFilter: false,
            },
            {
              title: "density_lowerthreshold",
              field: "density_lowerthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "density_upperthreshold",
              field: "density_upperthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "alert_lower_breached",
              field: "alert_lower_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "alert_upper_breached",
              field: "alert_upper_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "auto_correct",
              field: "auto_correct",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "perc_min_lowerbound_deviation",
              field: "perc_min_lowerbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "perc_min_upperbound_deviation",
              field: "perc_min_upperbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "is_disabled",
              field: "is_disabled",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var saveBtn = "#btn_" + component + "_save";
        var saveToken = "tk_" + component + "_update";
        var simulateBtn = "#btn_" + component + "_simulate";
        var resetBtn = "#btn_" + component + "_reset";
        var saveConfirmModal = "#modal_" + component + "_confirm_save";
        var resetConfirmModal = "#modal_" + component + "_confirm_reset";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // simulate
        $(simulateBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // get the selected model_id
            var selectedModelId = getToken(
              "tk_input_splk_flx_outliers_model_id_settings_dropdown"
            );

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: time_factor,
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              // push the model definition if equals to the selectedModelId
              if (model_id === selectedModelId) {
                itemList.push(subDict);
              }
            }

            setToken(saveToken, JSON.stringify(itemList[0]));

            // set the simulation JSON model def
            setToken(
              "tk_splk_flx_simulation_model_def",
              JSON.stringify(itemList[0]).replace(/\"/g, '\\"')
            );

            // set the token the search depends on
            setToken("start_outliers_simulation_splk_flx", "true");

            // explicitly start the search
            searchOutlierDetectionChartSimulationFlx.startSearch();

            //
          });

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: encodeURI(time_factor),
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // reset
        $(resetBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(resetConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].model_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });
      });
    }

    // Outliers anomaly detection splk-cim periods exclusion handler
    function OutliersAnomalyPeriodsExclusionSplkCimHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkCimOutliersModelPeriodsExclusions").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Periods Exclusions configured currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-cim-outliers-periods-exclusions-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 10, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "ctime", dir: "desc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "period_exclusion_id",
              field: "period_exclusion_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "earliest",
              field: "earliest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "latest",
              field: "latest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "ctim",
              field: "ctime",
              visible: false,
            },
            {
              title: "Creation time",
              field: "ctime_human",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var addBtn = "#btn_" + component + "_add";
        var addConfirmModal = "#modal_" + component + "_confirm_add";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].period_exclusion_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // add
        $(addBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(addConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // open modal
        table.on("tableBuilt", function () {
          cssloaderremove();
          $("#splk_cim_outliers_periods_exclusions").modal();
        });
      });
    }

    // Outliers anomaly detection splk-flx periods exclusion handler
    function OutliersAnomalyPeriodsExclusionSplkFlxHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkFlxOutliersModelPeriodsExclusions").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Periods Exclusions configured currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-flx-outliers-periods-exclusions-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 10, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "ctime", dir: "desc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "period_exclusion_id",
              field: "period_exclusion_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "earliest",
              field: "earliest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "latest",
              field: "latest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "ctim",
              field: "ctime",
              visible: false,
            },
            {
              title: "Creation time",
              field: "ctime_human",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var addBtn = "#btn_" + component + "_add";
        var addConfirmModal = "#modal_" + component + "_confirm_add";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].period_exclusion_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // add
        $(addBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(addConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // open modal
        table.on("tableBuilt", function () {
          cssloaderremove();
          $("#splk_flx_outliers_periods_exclusions").modal();
        });
      });
    }

    // Outliers anomaly detection splk-dsm periods exclusion handler
    function OutliersAnomalyPeriodsExclusionSplkDsmHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkDsmOutliersModelPeriodsExclusions").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Periods Exclusions configured currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-dsm-outliers-periods-exclusions-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 10, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "ctime", dir: "desc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "period_exclusion_id",
              field: "period_exclusion_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "earliest",
              field: "earliest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "latest",
              field: "latest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "ctim",
              field: "ctime",
              visible: false,
            },
            {
              title: "Creation time",
              field: "ctime_human",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var addBtn = "#btn_" + component + "_add";
        var addConfirmModal = "#modal_" + component + "_confirm_add";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].period_exclusion_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // add
        $(addBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(addConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // open modal
        table.on("tableBuilt", function () {
          cssloaderremove();
          $("#splk_dsm_outliers_periods_exclusions").modal();
        });
      });
    }

    // Outliers anomaly detection splk-dhm periods exclusion handler
    function OutliersAnomalyPeriodsExclusionSplkDhmHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkDhmOutliersModelPeriodsExclusions").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Periods Exclusions configured currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-dhm-outliers-periods-exclusions-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 10, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "ctime", dir: "desc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "period_exclusion_id",
              field: "period_exclusion_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "earliest",
              field: "earliest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "latest",
              field: "latest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "ctim",
              field: "ctime",
              visible: false,
            },
            {
              title: "Creation time",
              field: "ctime_human",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var addBtn = "#btn_" + component + "_add";
        var addConfirmModal = "#modal_" + component + "_confirm_add";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].period_exclusion_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // add
        $(addBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(addConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // open modal
        table.on("tableBuilt", function () {
          cssloaderremove();
          $("#splk_dhm_outliers_periods_exclusions").modal();
        });
      });
    }

    // Outliers anomaly detection splk-wlk periods exclusion handler
    function OutliersAnomalyPeriodsExclusionSplkWlkHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkWlkOutliersModelPeriodsExclusions").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Periods Exclusions configured currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-wlk-outliers-periods-exclusions-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitColumns", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 10, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "ctime", dir: "desc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "period_exclusion_id",
              field: "period_exclusion_id",
              editor: false,
              headerFilter: true,
            },
            {
              title: "earliest",
              field: "earliest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "latest",
              field: "latest_human",
              editor: false,
              headerFilter: true,
            },
            {
              title: "ctim",
              field: "ctime",
              visible: false,
            },
            {
              title: "Creation time",
              field: "ctime_human",
              editor: false,
              headerFilter: true,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var addBtn = "#btn_" + component + "_add";
        var addConfirmModal = "#modal_" + component + "_confirm_add";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].period_exclusion_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // add
        $(addBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(addConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // open modal
        table.on("tableBuilt", function () {
          cssloaderremove();
          $("#splk_wlk_outliers_periods_exclusions").modal();
        });
      });
    }

    // Outliers anomaly detection splk-wlk handler
    function OutliersAnomalySplkWlkHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // from the first record in resultCall, get the value for confidence and confidence_reason
        if (resultCall.length > 0) {
          var confidence = resultCall[0].confidence;
          var confidence_reason = resultCall[0].confidence_reason;

          if (confidence == "low") {
            $("#divTitleSplkWlkOutliersModelManageMainTitle").html(
              '<h2><span style="color: #ffb347;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          } else {
            $("#divTitleSplkWlkOutliersModelManageMainTitle").html(
              '<h2><span style="color: #45d4ba;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          }
        } else {
          // Handle the case where resultCall is empty
          $("#divTitleSplkWlkOutliersModelManageMainTitle").html(
            '<h2><span style="color: #ffb347">Confidence: Unknown, reason: Pending for model(s) definition</span></h2>'
          );
        }

        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkWlkOutliersModelManage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Machine Learning Outliers Model(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-wlk-outliers-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitDataStretch", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 2, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "model_id", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: false,
            },
            {
              title: "kpi_metric",
              field: "kpi_metric",
              editor: "list",
              editorParams: {
                values: [
                  "splk.feeds.avg_eventcount_5m",
                  "splk.feeds.latest_eventcount_5m",
                  "splk.feeds.perc95_eventcount_5m",
                  "splk.feeds.stdev_eventcount_5m",
                  "splk.feeds.avg_latency_5m",
                  "splk.feeds.latest_latency_5m",
                  "splk.feeds.perc95_latency_5m",
                  "splk.feeds.stdev_latency_5m",
                ],
              },
              headerFilter: false,
            },
            {
              title: "kpi_span",
              field: "kpi_span",
              editor: "list",
              editorParams: {
                values: ["5m", "10m", "15m", "30m", "1h"],
              },
              headerFilter: false,
            },
            {
              title: "method_calculation",
              field: "method_calculation",
              editor: "list",
              editorParams: {
                values: ["stdev", "avg", "perc95", "latest"],
              },
              headerFilter: false,
            },
            {
              title: "period_calculation",
              field: "period_calculation",
              editor: "list",
              editorParams: {
                values: ["-7d", "-30d", "-60d", "-90d"],
              },
              headerFilter: false,
            },
            {
              title: "time_factor",
              field: "time_factor",
              editor: "list",
              editorParams: {
                values: ["%H", "%H%M", "%w%H", "%w%H%M", "none"],
              },
              headerFilter: false,
            },
            {
              title: "density_lowerthreshold",
              field: "density_lowerthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "density_upperthreshold",
              field: "density_upperthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "alert_lower_breached",
              field: "alert_lower_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "alert_upper_breached",
              field: "alert_upper_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "auto_correct",
              field: "auto_correct",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "perc_min_lowerbound_deviation",
              field: "perc_min_lowerbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "perc_min_upperbound_deviation",
              field: "perc_min_upperbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "is_disabled",
              field: "is_disabled",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var saveBtn = "#btn_" + component + "_save";
        var saveToken = "tk_" + component + "_update";
        var simulateBtn = "#btn_" + component + "_simulate";
        var resetBtn = "#btn_" + component + "_reset";
        var saveConfirmModal = "#modal_" + component + "_confirm_save";
        var resetConfirmModal = "#modal_" + component + "_confirm_reset";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // simulate
        $(simulateBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // get the selected model_id
            var selectedModelId = getToken(
              "tk_input_splk_wlk_outliers_model_id_settings_dropdown"
            );

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: time_factor,
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              // push the model definition if equals to the selectedModelId
              if (model_id === selectedModelId) {
                itemList.push(subDict);
              }
            }

            setToken(saveToken, JSON.stringify(itemList[0]));

            // set the simulation JSON model def
            setToken(
              "tk_splk_wlk_simulation_model_def",
              JSON.stringify(itemList[0]).replace(/\"/g, '\\"')
            );

            // set the token the search depends on
            setToken("start_outliers_simulation_splk_wlk", "true");

            // explicitly start the search
            searchOutlierDetectionChartSimulationWlk.startSearch();

            //
          });

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: encodeURI(time_factor),
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // reset
        $(resetBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(resetConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].model_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });
      });
    }

    // Outliers anomaly detection splk-cim handler
    function OutliersAnomalySplkCimHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // from the first record in resultCall, get the value for confidence and confidence_reason
        if (resultCall.length > 0) {
          var confidence = resultCall[0].confidence;
          var confidence_reason = resultCall[0].confidence_reason;

          if (confidence == "low") {
            $("#divTitleSplkCimOutliersModelManageMainTitle").html(
              '<h2><span style="color: #ffb347;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          } else {
            $("#divTitleSplkCimOutliersModelManageMainTitle").html(
              '<h2><span style="color: #45d4ba;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          }
        } else {
          // Handle the case where resultCall is empty
          $("#divTitleSplkCimOutliersModelManageMainTitle").html(
            '<h2><span style="color: #ffb347">Confidence: Unknown, reason: Pending for model(s) definition</span></h2>'
          );
        }

        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkCimOutliersModelManage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Machine Learning Outliers Model(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-cim-outliers-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitDataStretch", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 2, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "cim_field", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: false,
            },
            {
              title: "entity",
              field: "entity",
              editor: false,
              headerFilter: true,
            },
            {
              title: "cim_field",
              field: "cim_field",
              editor: false,
              headerFilter: true,
            },
            {
              title: "kpi_metric",
              field: "kpi_metric",
              editor: "list",
              editorParams: {
                values: [
                  "splk.cim.pct_coverage_compliant",
                  "splk.cim.pct_coverage_unknown",
                  "splk.cim.count_unknown",
                  "splk.cim.count_not_unknown",
                  "splk.cim.total_count",
                ],
              },
              headerFilter: false,
            },
            {
              title: "kpi_span",
              field: "kpi_span",
              editor: "list",
              editorParams: {
                values: ["5m", "10m", "15m", "30m", "1h"],
              },
              headerFilter: false,
            },
            {
              title: "method_calculation",
              field: "method_calculation",
              editor: "list",
              editorParams: {
                values: ["stdev", "avg", "perc95", "latest"],
              },
              headerFilter: false,
            },
            {
              title: "period_calculation",
              field: "period_calculation",
              editor: "list",
              editorParams: {
                values: ["-7d", "-30d", "-60d", "-90d"],
              },
              headerFilter: false,
            },
            {
              title: "time_factor",
              field: "time_factor",
              editor: "list",
              editorParams: {
                values: ["%H", "%H%M", "%w%H", "%w%H%M", "none"],
              },
              headerFilter: false,
            },
            {
              title: "density_lowerthreshold",
              field: "density_lowerthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "density_upperthreshold",
              field: "density_upperthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "alert_lower_breached",
              field: "alert_lower_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "alert_upper_breached",
              field: "alert_upper_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "auto_correct",
              field: "auto_correct",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "perc_min_lowerbound_deviation",
              field: "perc_min_lowerbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "perc_min_upperbound_deviation",
              field: "perc_min_upperbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "is_disabled",
              field: "is_disabled",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var saveBtn = "#btn_" + component + "_save";
        var saveToken = "tk_" + component + "_update";
        var simulateBtn = "#btn_" + component + "_simulate";
        var resetBtn = "#btn_" + component + "_reset";
        var saveConfirmModal = "#modal_" + component + "_confirm_save";
        var resetConfirmModal = "#modal_" + component + "_confirm_reset";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // simulate
        $(simulateBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // get the selected model_id
            var selectedModelId = getToken(
              "tk_input_splk_cim_outliers_model_id_settings_dropdown"
            );

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var entity = selectedData[i].entity;
              var cim_field = selectedData[i].cim_field;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                entity: entity,
                cim_field: cim_field,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: time_factor,
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              // push the model definition if equals to the selectedModelId
              if (model_id === selectedModelId) {
                itemList.push(subDict);
                // update the token
                setToken(
                  "tk_input_splk_cim_outliers_cim_field_settings_dropdown",
                  subDict.cim_field
                );
              }
            }

            setToken(saveToken, JSON.stringify(itemList[0]));

            // set the simulation JSON model def
            setToken(
              "tk_splk_cim_simulation_model_def",
              JSON.stringify(itemList[0]).replace(/\"/g, '\\"')
            );

            // set the token the search depends on
            setToken("start_outliers_simulation_splk_cim", "true");

            // explicitly start the search
            searchOutlierDetectionChartSimulationCim.startSearch();

            //
          });

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var entity = selectedData[i].entity;
              var cim_field = selectedData[i].cim_field;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                entity: entity,
                cim_field: cim_field,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: encodeURI(time_factor),
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // reset
        $(resetBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(resetConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];

            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var entity = selectedData[i].entity;
              var cim_field = selectedData[i].cim_field;

              var subDict = {
                model_id: model_id,
                entity: entity,
                cim_field: cim_field,
              };

              itemList.push(subDict);
            }

            setToken(deleteToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });
      });
    }

    // Outliers anomaly detection splk-dhm handler
    function OutliersAnomalySplkDhmHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // from the first record in resultCall, get the value for confidence and confidence_reason
        if (resultCall.length > 0) {
          var confidence = resultCall[0].confidence;
          var confidence_reason = resultCall[0].confidence_reason;

          if (confidence == "low") {
            $("#divTitleSplkDhmOutliersModelManageMainTitle").html(
              '<h2><span style="color: #ffb347;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          } else {
            $("#divTitleSplkDhmOutliersModelManageMainTitle").html(
              '<h2><span style="color: #45d4ba;">Confidence: ' +
                confidence +
                " , reason: " +
                confidence_reason +
                "</span></h2>"
            );
          }
        } else {
          // Handle the case where resultCall is empty
          $("#divTitleSplkDhmOutliersModelManageMainTitle").html(
            '<h2><span style="color: #ffb347">Confidence: Unknown, reason: Pending for model(s) definition</span></h2>'
          );
        }

        // count the number of item in the array and update the title
        var no_items = resultCall.length;
        $("#divTitleSplkDhmOutliersModelManage").html(
          '<h1><span style="color: #a7c7e7;">' +
            no_items +
            " Machine Learning Outliers Model(s) currently</span></h1>"
        );

        // the element
        var tabulatorElement = "#splk-dhm-outliers-table";

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "model_id",
          layout: "fitDataStretch", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "100%", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 2, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "model_id", dir: "asc" },
          ],

          columns: [
            //tickbox
            {
              formatter: "rowSelection",
              titleFormatter: "rowSelection",
              hozAlign: "center",
              headerSort: false,
              width: 20,
              cellClick: function (e, cell) {
                cell.getRow().toggleSelect();
              },
            },
            //define the table columns
            {
              title: "Model",
              field: "model_id",
              editor: false,
              headerFilter: false,
            },
            {
              title: "kpi_metric",
              field: "kpi_metric",
              editor: "list",
              editorParams: {
                values: [
                  "splk.feeds.avg_eventcount_5m",
                  "splk.feeds.latest_eventcount_5m",
                  "splk.feeds.perc95_eventcount_5m",
                  "splk.feeds.stdev_eventcount_5m",
                  "splk.feeds.avg_latency_5m",
                  "splk.feeds.latest_latency_5m",
                  "splk.feeds.perc95_latency_5m",
                  "splk.feeds.stdev_latency_5m",
                ],
              },
              headerFilter: false,
            },
            {
              title: "kpi_span",
              field: "kpi_span",
              editor: "list",
              editorParams: {
                values: ["5m", "10m", "15m", "30m", "1h"],
              },
              headerFilter: false,
            },
            {
              title: "method_calculation",
              field: "method_calculation",
              editor: "list",
              editorParams: {
                values: ["stdev", "avg", "perc95", "latest"],
              },
              headerFilter: false,
            },
            {
              title: "period_calculation",
              field: "period_calculation",
              editor: "list",
              editorParams: {
                values: ["-7d", "-30d", "-60d", "-90d"],
              },
              headerFilter: false,
            },
            {
              title: "time_factor",
              field: "time_factor",
              editor: "list",
              editorParams: {
                values: ["%H", "%H%M", "%w%H", "%w%H%M", "none"],
              },
              headerFilter: false,
            },
            {
              title: "density_lowerthreshold",
              field: "density_lowerthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "density_upperthreshold",
              field: "density_upperthreshold",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.001,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "alert_lower_breached",
              field: "alert_lower_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "alert_upper_breached",
              field: "alert_upper_breached",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "auto_correct",
              field: "auto_correct",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
            {
              title: "perc_min_lowerbound_deviation",
              field: "perc_min_lowerbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "perc_min_upperbound_deviation",
              field: "perc_min_upperbound_deviation",
              editor: "number",
              editorParams: {
                min: 0,
                step: 0.5,
                verticalNavigation: "table", //up and down arrow keys navigate away from cell without changing value
              },
              headerFilter: false,
            },
            {
              title: "is_disabled",
              field: "is_disabled",
              editor: "list",
              editorParams: {
                values: ["0", "1"],
              },
              headerFilter: false,
            },
          ],
        });

        // actions per component
        var deleteBtn = "#btn_" + component + "_delete";
        var deleteToken = "tk_" + component + "_delete";
        var deleteConfirmModal = "#modal_" + component + "_confirm_delete";
        var saveBtn = "#btn_" + component + "_save";
        var saveToken = "tk_" + component + "_update";
        var simulateBtn = "#btn_" + component + "_simulate";
        var resetBtn = "#btn_" + component + "_reset";
        var saveConfirmModal = "#modal_" + component + "_confirm_save";
        var resetConfirmModal = "#modal_" + component + "_confirm_reset";

        // disable the delete edit button
        $(deleteBtn).prop("disabled", true);

        // disable the inline save button
        $(saveBtn).prop("disabled", true);

        // simulate
        $(simulateBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // get the selected model_id
            var selectedModelId = getToken(
              "tk_input_splk_dhm_outliers_model_id_settings_dropdown"
            );

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: time_factor,
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              // push the model definition if equals to the selectedModelId
              if (model_id === selectedModelId) {
                itemList.push(subDict);
              }
            }

            setToken(saveToken, JSON.stringify(itemList[0]));

            // set the simulation JSON model def
            setToken(
              "tk_splk_dhm_simulation_model_def",
              JSON.stringify(itemList[0]).replace(/\"/g, '\\"')
            );

            // set the token the search depends on
            setToken("start_outliers_simulation_splk_dhm", "true");

            // explicitly start the search
            searchOutlierDetectionChartSimulationDhm.startSearch();

            //
          });

        // update
        $(saveBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getData("active");

            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              var model_id = selectedData[i].model_id;
              var kpi_metric = selectedData[i].kpi_metric;
              var kpi_span = selectedData[i].kpi_span;
              var method_calculation = selectedData[i].method_calculation;
              var period_calculation = selectedData[i].period_calculation;
              var time_factor = selectedData[i].time_factor;
              var density_lowerthreshold =
                selectedData[i].density_lowerthreshold;
              var density_upperthreshold =
                selectedData[i].density_upperthreshold;
              var alert_lower_breached = selectedData[i].alert_lower_breached;
              var alert_upper_breached = selectedData[i].alert_upper_breached;
              var auto_correct = selectedData[i].auto_correct;
              var perc_min_lowerbound_deviation =
                selectedData[i].perc_min_lowerbound_deviation;
              var perc_min_upperbound_deviation =
                selectedData[i].perc_min_upperbound_deviation;
              var is_disabled = selectedData[i].is_disabled;

              var subDict = {
                model_id: model_id,
                kpi_metric: kpi_metric,
                kpi_span: kpi_span,
                method_calculation: method_calculation,
                period_calculation: period_calculation,
                time_factor: encodeURI(time_factor),
                density_lowerthreshold: density_lowerthreshold,
                density_upperthreshold: density_upperthreshold,
                alert_lower_breached: alert_lower_breached,
                alert_upper_breached: alert_upper_breached,
                auto_correct: auto_correct,
                perc_min_lowerbound_deviation: perc_min_lowerbound_deviation,
                perc_min_upperbound_deviation: perc_min_upperbound_deviation,
                is_disabled: is_disabled,
              };

              itemList.push(subDict);
            }

            setToken(saveToken, JSON.stringify(itemList));
            // open modal
            closeModals();
            $(saveConfirmModal).modal();
          });

        // reset
        $(resetBtn)
          .unbind()
          .click(function () {
            // open modal
            closeModals();
            $(resetConfirmModal).modal();
          });

        // delete
        $(deleteBtn)
          .unbind()
          .click(function () {
            var selectedData = table.getSelectedData();
            // loop and create a list of keys
            var itemList = [];
            for (var i = 0; i < selectedData.length; i++) {
              itemList.push(selectedData[i].model_id);
            }
            setToken(deleteToken, itemList.toString());
            // open modal
            closeModals();
            $(deleteConfirmModal).modal();
          });

        // detect selection
        table.on("rowSelectionChanged", function (data, rows) {
          //rows - array of row components for the selected rows in order of selection
          //data - array of data objects for the selected rows in order of selection
          len = rows.length;
          if (rows.length > 0) {
            $(deleteBtn).prop("disabled", false);
          } else {
            $(deleteBtn).prop("disabled", true);
          }
        });

        // detect inline edit
        table.on("cellEdited", function (cell) {
          //e - the click event object
          //row - row component
          $(saveBtn).prop("disabled", false);
        });
      });
    }

    // Returns true if numeric
    function isNumeric(n) {
      return !isNaN(parseFloat(n)) && isFinite(n) && n > 0;
    }

    // Escape double quotes
    function escapeDoubleQuotes(str) {
      return str.replace(/\\([\s\S])|(")/g, "\\$1$2");
    }

    // get comment
    function getComment(objectName) {
      // Retrieve update comment if any
      var comment = document.getElementById(objectName).value;

      // if is not defined, give it a value and override text box content
      if (comment == "null") {
        setToken("tk_update_comment", "No comments for update.");
      } else if (comment == "update note") {
        comment = "No comment for update.";
      }

      return comment;
    }

    // refresh DSM Allow lists
    function refreshDsmAllowLists() {
      searchSplkDsmMain.startSearch();
    }

    // refresh DSM main
    function refreshDsm() {
      searchSplkDsmMain.startSearch();
    }

    // refresh DHM Allow lists
    function refreshDhmAllowLists() {
      searchSplkDhmMain.startSearch();
    }

    // refresh DHM main
    function refreshDhm() {
      searchSplkDhmMain.startSearch();
    }

    // refresh MHM Allow lists
    function refreshMhmAllowLists() {
      searchSplkMhmMain.startSearch();
    }

    // refresh MHM main
    function refreshMhm() {
      searchSplkMhmMain.startSearch();
    }

    // generic function for ajax calls
    function callApi(
      endpointUrl,
      typeCall,
      dataRecord,
      returnModal,
      notifyMsg,
      changeType,
      changeItem,
      changeCat,
      comment
    ) {
      $.ajax({
        url: endpointUrl,
        type: typeCall,
        async: true,
        dataType: "json",
        data: JSON.stringify(dataRecord),
        contentType: "application/json",
        success: function (returneddata) {
          // Return to modal
          $("#" + returnModal).modal();

          // notify
          notify("success", "bottom", notifyMsg, "5");
        },
        error: function (xhr, textStatus, error) {
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          // Audit
          action = "failure";
          change_type = changeType;
          object = changeItem;
          object_category = changeCat;
          object_attrs = "N/A";
          result = message;
          auditRecord(
            action,
            change_type,
            object,
            object_category,
            object_attrs,
            result,
            comment
          );
          closeModals();
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          $("#modal_update_collection_failure_return").modal();
        },
      });
    }

    // ajax promise for API calls
    async function asyncCallApi(
      ajaxurl,
      ajaxType,
      ajaxdata,
      changeType,
      changeItem,
      changeCat,
      comment
    ) {
      var resultCall;

      // spinner
      cssloader("Requested action is in progress, please wait...");

      try {
        resultCall = await $.ajax({
          url: ajaxurl,
          type: ajaxType,
          data: JSON.stringify(ajaxdata),
        });
        // spinner
        cssloaderremove();
        // return resultUiPrefs
        return resultCall;
        // we do not want to catch the error
      } catch (error) {
        // spinner
        cssloaderremove();
        // Audit
        action = "failure";
        change_type = changeType;
        object = changeItem;
        object_category = changeCat;
        object_attrs = "N/A";
        result = error;
        auditRecord(
          action,
          change_type,
          object,
          object_category,
          object_attrs,
          result,
          comment
        );
        closeModals();
        cssloaderremove();
        $("#modal_update_collection_failure_return")
          .find(".modal-error-message p")
          .text(JSON.stringify(error));
        $("#modal_update_collection_failure_return").modal();
      }
    }

    // ajax promise for API calls
    async function asyncAjax(ajaxurl, ajaxType, ajaxdata) {
      var resultCall;
      // spinner
      cssloader("Requested action is in progress, please wait...");
      try {
        resultCall = await $.ajax({
          url: ajaxurl,
          type: ajaxType,
          data: JSON.stringify(ajaxdata),
        });
        // spinner
        cssloaderremove();
        // return resultUiPrefs
        return resultCall;
        // we do not want to catch the error
      } catch (error) {
        // spinner
        cssloaderremove();
        closeModals();
        $("#modal_update_collection_failure_return")
          .find(".modal-error-message p")
          .text(JSON.stringify(error));
        $("#modal_update_collection_failure_return").modal();
      }
    }

    // ajax promise for API calls (with cssloader)
    async function asyncAjaxNoLoader(ajaxurl, ajaxType, ajaxdata) {
      var resultCall;
      try {
        resultCall = await $.ajax({
          url: ajaxurl,
          type: ajaxType,
          data: JSON.stringify(ajaxdata),
        });
        // return resultUiPrefs
        return resultCall;
        // we do not want to catch the error
      } catch (error) {
        closeModals();
        $("#modal_update_collection_failure_return")
          .find(".modal-error-message p")
          .text(JSON.stringify(error));
        $("#modal_update_collection_failure_return").modal();
      }
    }

    // generate a unique ID
    function uuid() {
      return "xxxxxxxx-xxxx-4xxx-yxxx-xxxxxxxxxxxx".replace(
        /[xy]/g,
        function (c) {
          var r = (Math.random() * 16) | 0,
            v = c == "x" ? r : (r & 0x3) | 0x8;
          return v.toString(16);
        }
      );
    }

    // Audit record
    function auditRecord(
      action,
      change_type,
      object,
      object_category,
      object_attrs,
      result,
      comment
    ) {
      // Audit changes
      var currentUser = Splunk.util.getConfigValue("USERNAME");
      var auditendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/audit/audit_event";
      var tk_tenant_id = getToken("tenant_id");

      var time = new Date().getTime();
      var audit_record = {
        time: time,
        tenant_id: tk_tenant_id,
        action: action,
        user: currentUser,
        change_type: change_type,
        object: object,
        object_category: object_category,
        object_attrs: object_attrs,
        result: result,
        comment: comment,
      };

      $.ajax({
        url: auditendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        data: JSON.stringify(audit_record),
        success: function (returneddata) {
          // Run the search again to update the table
        },
      });
    }

    // render custom table emoji icons
    function renderTableIcon(element) {
      var CustomIconRenderer = TableView.BaseCellRenderer.extend({
        canRender: function (cell) {
          if (typeof cell.value === "string") {
            return cell.value && cell.value.substr(0, 5) === "icon|";
          }
        },
        render: function ($td, cell) {
          var parts = cell.value.split("|");

          // green
          if (parts[1] === "ico_good ico_small") {
            $td
              .css({
                "text-align": "center",
              })
              .html("<div>🟢</div>");
          }
          // red
          else if (parts[1] === "ico_error ico_small") {
            $td
              .css({
                "text-align": "center",
              })
              .html("<div>🔴</div>");
          }
          // orange
          else if (parts[1] === "ico_warn ico_small") {
            $td
              .css({
                "text-align": "center",
              })
              .html("<div>🟠</div>");
          }
          // blue
          else if (parts[1] === "ico_unknown ico_small") {
            $td
              .css({
                "text-align": "center",
              })
              .html("<div>🔵</div>");
          }
          // Ack
          else if (parts[1] === "ico_ack ico_small") {
            $td
              .css({
                "text-align": "center",
              })
              .html("<div>👀 🔴</div>");
          }
          if (parts.length > 3) {
            $td.attr("title", parts[3]);
          }
        },
      });

      element.addCellRenderer(new CustomIconRenderer());
    }

    // render custom table checkbox
    function renderTableCheckBox(element, tokenName, tokenReinit) {
      var selected_values_array = [];

      var CustomRangeRenderer = TableView.BaseCellRenderer.extend({
        canRender: function (cell) {
          return _(["select"]).contains(cell.field);
        },
        render: function ($td, cell) {
          var a = $("<div>")
            .attr({
              id: "chk-allowlist-data-source" + cell.value,
              value: cell.value,
            })
            .addClass("checkbox")
            .click(function () {
              if ($(this).attr("class") === "checkbox") {
                selected_values_array.push($(this).attr("value"));
                $(this).removeClass();
                $(this).addClass("checkbox checked");
              } else {
                $(this).removeClass();
                $(this).addClass("checkbox");
                var i = selected_values_array.indexOf($(this).attr("value"));
                if (i != -1) {
                  selected_values_array.splice(i, 1);
                }
              }
              setToken(tokenName, selected_values_array.join());
            })
            .appendTo($td);
        },
      });

      //List of table IDs
      var tableIDs = [element];
      for (i = 0; i < tableIDs.length; i++) {
        var sh = mvc.Components.get(tableIDs[i]);
        if (typeof sh != "undefined") {
          sh.getVisualization(function (tableView) {
            // Add custom cell renderer and force re-render
            tableView.table.addCellRenderer(new CustomRangeRenderer());
            tableView.table.render();
          });
        }
      }
    }

    // tooltip like table
    function renderTableToolTip(element) {
      var CustomTooltipRenderer = TableView.BaseCellRenderer.extend({
        canRender: function (cell) {
          return cell.field === "raw_sample";
        },
        render: function ($td, cell) {
          var message = cell.value;
          var tip = cell.value;

          if (message.length > 180) {
            message = message.substring(0, 179) + "...";
          }

          $td.html(
            _.template(
              '<div class="custom_title_tag"><a href="#" data-toggle="tooltip" data-container="body" data-placement="top" title="<%- tip%>"><%- message%></a></div>',
              {
                tip: tip,
                message: message,
              }
            )
          );

          // This line wires up the Bootstrap tooltip to the cell markup
          $td.children('[data-toggle="tooltip"]').tooltip();
        },
      });

      // Register custom cell renderer
      element.addCellRenderer(new CustomTooltipRenderer());

      // Force the table to re-render
      element.render();
    }

    // handle multiselect all selection in a enhanced way
    function multiselectAll(element) {
      var values = element.val();
      // I assume the default multiselect value will be the first (hardcoded) choice
      // Like <choice value="*">All</choice>
      // If there is no hardcoded choice, then .options.choices[0] won't exist...
      var first_choice_value = element.options.choices[0].value;
      // If the user removed everything then add the first choice "All" back
      if (values.length === 0) {
        element.val([first_choice_value]);
      }
      // If the user choose something else then remove the first choice "All" (if it's there)
      else if (values.indexOf(first_choice_value) >= 0 && values.length > 1) {
        element.val(_.without(values, first_choice_value));
      }
    }

    //
    // Various
    //

    //
    // Handle search elements
    //

    $(".view-elements").hover(
      function () {
        var childdiv = "#resultsLink" + this.id;
        $(childdiv).attr("style", "display: inline-block !important");
      },
      function () {
        var childdiv = "#resultsLink" + this.id;

        $(childdiv).hover(
          function () {
            $(childdiv).attr("style", "display: inline-block !important");
          },
          function () {
            $(childdiv).attr("style", "display: none !important");
          }
        );

        $(childdiv).attr("style", "display: none !important");
      }
    );

    //
    // Handle html textarea
    //

    $(".custom-textarea").each(function () {
      var $text_group = $(this);
      $text_group.find("textarea").on("click", function () {
        var $text = $(this);
        if (this.value == this.defaultValue) this.value = "";
        $(this).blur(function () {
          if (this.value == "") this.value = this.defaultValue;
        });
      });
    });

    //
    // SERVICE OBJECT
    //

    // Create a service object using the Splunk SDK for JavaScript
    // to send REST requests
    var service = mvc.createService({
      owner: "nobody",
    });

    //
    // VIZ
    //

    // semicircle donut custom viz
    var semiCircleDonut = VisualizationRegistry.getVisualizer(
      "semicircle_donut",
      "semicircle_donut"
    );

    // ML toolkit
    var OutliersViz = VisualizationRegistry.getVisualizer(
      "Splunk_ML_Toolkit",
      "OutliersViz"
    );

    // Timeline
    var TimeLine = VisualizationRegistry.getVisualizer(
      "timeline_app",
      "timeline"
    );

    //
    // SPLUNK INPUTS
    //

    //
    // SPLUNK SEARCHES
    //

    //
    // SEARCH MANAGERS
    //

    //
    // Hours ranges
    //

    var search_gen_hours_ranges = new SearchManager(
      {
        id: "search_gen_hours_ranges",
        sample_ratio: 1,
        earliest_time: "-15m",
        cancelOnUnload: true,
        search: "| `genHoursRanges`",
        latest_time: "now",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_hours_ranges$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    //
    // ALERT SUMMARY
    //

    var search_alerts_main_table = new SearchManager(
      {
        id: "search_alerts_main_table",
        sample_ratio: 1,
        earliest_time: "-15m",
        cancelOnUnload: true,
        search:
          '| trackme mode=post url=/services/trackme/v2/alerting/get_tenant_alerts body="{\'tenant_id\': \'$tenant_id$\'}" | spath | rename "{}.*" as "*"',
        latest_time: "now",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateAlertActionsAck = new SearchManager(
      {
        id: "searchPopulateAlertActionsAck",
        sample_ratio: 1,
        earliest_time: "$showAlertsTime.earliest$",
        cancelOnUnload: true,
        search:
          '(index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_auto_ack" search_name="$tk_alert_title$" response=* | rex "\\"object\\":\\s\\"(?<object>[^\\"]*)" | stats count by object | sort limit=10000 object',
        latest_time: "$showAlertsTime.latest$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts_auto_ack$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateAlertActionsSmartStatus = new SearchManager(
      {
        id: "searchPopulateAlertActionsSmartStatus",
        sample_ratio: 1,
        earliest_time: "$showAlertsTime.earliest$",
        cancelOnUnload: true,
        search:
          '(index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_smart_status" search_name="$tk_alert_title$" object_name=* | rex "object_name=(?<object>[^\\"]*)" | stats count by object | sort limit=10000 object',
        latest_time: "$showAlertsTime.latest$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts_smart_status$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSingleEnabledAlerts = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "stats first(disabled) as disabled by id | where disabled=0 | stats count",
        managerid: "search_alerts_main_table",
        id: "searchSingleEnabledAlerts",
      },
      {
        tokens: true,
      }
    );

    var searchDonutAlertsTriggered = new SearchManager(
      {
        id: "searchDonutAlertsTriggered",
        sample_ratio: 1,
        earliest_time: "-24h",
        cancelOnUnload: true,
        search:
          'index=_audit action="alert_fired" ss_app="trackme" [ | inputlookup trackme_virtual_tenants where tenant_id="$tenant_id$" | table tenant_alert_objects | spath input=tenant_alert_objects | rename "alerts{}" as ss_name | mvexpand ss_name | fields ss_name | format | fields search ] | stats count by ss_name',
        latest_time: "now",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "searchDonutAlertsTriggered",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "set",
              token: "show_no_alerts",
              value: "True",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "unset",
              token: "show_no_alerts",
            },
          ],
        },
      ],
    });

    var searchAlertTriggeredOverTime = new SearchManager(
      {
        id: "searchAlertTriggeredOverTime",
        sample_ratio: 1,
        earliest_time: "-24h",
        cancelOnUnload: true,
        search:
          'index=_audit action="alert_fired" ss_app="trackme" [ | inputlookup trackme_virtual_tenants where tenant_id="$tenant_id$" | table tenant_alert_objects | spath input=tenant_alert_objects | rename "alerts{}" as ss_name | mvexpand ss_name | fields ss_name | format | fields search ] | timechart minspan=5m bins=1000 count by ss_name',
        latest_time: "now",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAlertTriggeredOverTimePerAlert = new SearchManager(
      {
        id: "searchAlertTriggeredOverTimePerAlert",
        sample_ratio: 1,
        earliest_time: "$showAlertsTime.earliest$",
        cancelOnUnload: true,
        search:
          'index=_audit action="alert_fired" ss_app="trackme" ss_name="$tk_alert_title$" | timechart span=$showAlertsTime.span$ count by ss_name',
        latest_time: "$showAlertsTime.latest$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
          depends: "$show_alerts_overview$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchAlertTriggeredOverTimePerAlert.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#SplkAlertsOverviewTriggered").css("display", "none");
        $("#divSplkAlertsOverviewTriggeredNotFound").css("display", "none");
        $("#SplkAlertsOverviewTriggered").css("display", "none");
        // show at start
        $("#SplkAlertsOverviewTriggeredLoader").css("display", "inherit");
      }
    );

    searchAlertTriggeredOverTimePerAlert.on(
      "search:done",
      function (properties) {
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#SplkAlertsOverviewTriggeredLoader").css("display", "none");
          // hide elements
          $("#SplkAlertsOverviewTriggered").css("display", "none");
          // show no results
          $("#divSplkAlertsOverviewTriggeredNotFound").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#SplkAlertsOverviewTriggeredLoader").css("display", "none");
          // show elements
          $("#SplkAlertsOverviewTriggered").css("display", "inherit");
          // hide no results
          $("#divSplkAlertsOverviewTriggeredNotFound").css("display", "none");
        }
      }
    );

    var searchAlertActionsTriggeredOverTimePerAlert = new SearchManager(
      {
        id: "searchAlertActionsTriggeredOverTimePerAlert",
        sample_ratio: 1,
        earliest_time: "$showAlertsTime.earliest$",
        cancelOnUnload: true,
        search:
          '( (index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_auto_ack" search_name="$tk_alert_title$" response ) OR ( (index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_free_style_rest_call" search_name="$tk_alert_title$" "TrackMe REST call was successfull" ) OR ( (index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_smart_status" search_name="$tk_alert_title$" "Smart Status result successfully" ) | timechart span=$showAlertsTime.span$ count by sourcetype',
        latest_time: "$showAlertsTime.latest$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
          depends: "$show_alerts_overview$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchAlertActionsTriggeredOverTimePerAlert.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#SplkAlertsOverviewActions").css("display", "none");
        $("#divSplkAlertsOverviewActionsNotFound").css("display", "none");
        // show at start
        $("#SplkAlertsOverviewActionsLoader").css("display", "inherit");
      }
    );

    searchAlertActionsTriggeredOverTimePerAlert.on(
      "search:done",
      function (properties) {
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#SplkAlertsOverviewActionsLoader").css("display", "none");
          // hide elements
          $("#SplkAlertsOverviewActions").css("display", "none");
          // show no results
          $("#divSplkAlertsOverviewActionsNotFound").css("display", "inherit");
        } else {
          // hide loader
          $("#SplkAlertsOverviewActionsLoader").css("display", "none");
          // show elements
          $("#SplkAlertsOverviewActions").css("display", "inherit");
          // hide no results
          $("#divSplkAlertsOverviewActionsNotFound").css("display", "none");
        }
      }
    );

    var searchAlertActionsNotablesEventsOverTimePerAlert = new SearchManager(
      {
        id: "searchAlertActionsNotablesEventsOverTimePerAlert",
        sample_ratio: 1,
        earliest_time: "$showAlertsTime.earliest$",
        cancelOnUnload: true,
        search:
          '(index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_notable" search_name="$tk_alert_title$" "response=" | rex "response=\\"(?<json>\\{[^\\}]*\\})" | rename json as _raw | spath | rename records{}.object as object',
        latest_time: "$showAlertsTime.latest$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
          depends: "$show_alerts_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchAlertActionsNotablesEventsOverTimePerAlert.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#divSplkAlertsNotablesChart").css("display", "none");
        $("#divSplkAlertsNotablesNotFound").css("display", "none");
        // show at start
        $("#SplkAlertsNotablesLoader").css("display", "inherit");
      }
    );

    searchAlertActionsNotablesEventsOverTimePerAlert.on(
      "search:done",
      function (properties) {
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#SplkAlertsNotablesLoader").css("display", "none");
          // hide elements
          $("#divSplkAlertsNotablesChart").css("display", "none");
          // show no results
          $("#divSplkAlertsNotablesNotFound").css("display", "inherit");
        } else {
          // hide loader
          $("#SplkAlertsNotablesLoader").css("display", "none");
          // show elements
          $("#divSplkAlertsNotablesChart").css("display", "inherit");
          // hide no results
          $("#divSplkAlertsNotablesNotFound").css("display", "none");
        }
      }
    );

    var searchAlertActionsAckEventsOverTimePerAlert = new SearchManager(
      {
        id: "searchAlertActionsAckEventsOverTimePerAlert",
        sample_ratio: 1,
        earliest_time: "$showAlertsTime.earliest$",
        cancelOnUnload: true,
        search:
          '(index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_auto_ack" search_name="$tk_alert_title$" response | rex "response=\\"(?<json>\\{[^\\}]*\\})" | rename json as _raw | spath | rename records{}.object as object',
        latest_time: "$showAlertsTime.latest$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
          depends: "$show_alerts_auto_ack$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchAlertActionsAckEventsOverTimePerAlert.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#divSplkAlertsAckChart").css("display", "none");
        $("#divSplkAlertsAckNotFound").css("display", "none");
        // show at start
        $("#SplkAlertsAckLoader").css("display", "inherit");
      }
    );

    searchAlertActionsAckEventsOverTimePerAlert.on(
      "search:done",
      function (properties) {
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#SplkAlertsAckLoader").css("display", "none");
          // hide elements
          $("#divSplkAlertsAckChart").css("display", "none");
          // show no results
          $("#divSplkAlertsAckNotFound").css("display", "inherit");
        } else {
          // hide loader
          $("#SplkAlertsAckLoader").css("display", "none");
          // show elements
          $("#divSplkAlertsAckChart").css("display", "inherit");
          // hide no results
          $("#divSplkAlertsAckNotFound").css("display", "none");
        }
      }
    );

    var searchAlertActionsSmartStatusdEventsOverTimePerAlert =
      new SearchManager(
        {
          id: "searchAlertActionsSmartStatusdEventsOverTimePerAlert",
          sample_ratio: 1,
          earliest_time: "$showAlertsTime.earliest$",
          cancelOnUnload: true,
          search:
            '(index="_internal" OR index="cim_modactions") sourcetype="modular_alerts:trackme_smart_status" search_name="$tk_alert_title$" "response="',
          latest_time: "$showAlertsTime.latest$",
          status_buckets: 0,
          app: utils.getCurrentApp(),
          auto_cancel: 90,
          preview: true,
          tokenDependencies: {
            depends: "$show_alerts$",
            depends: "$show_alerts_smartstatus$",
          },
          runWhenTimeIsUndefined: false,
        },
        {
          tokens: true,
        }
      );

    searchAlertActionsSmartStatusdEventsOverTimePerAlert.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#divSplkAlertsSmartStatusChart").css("display", "none");
        $("#divSplkAlertsSmartStatusNotFound").css("display", "none");
        // show at start
        $("#SplkAlertsSmartStatusLoader").css("display", "inherit");
      }
    );

    searchAlertActionsSmartStatusdEventsOverTimePerAlert.on(
      "search:done",
      function (properties) {
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#SplkAlertsSmartStatusLoader").css("display", "none");
          // hide elements
          $("#divSplkAlertsSmartStatusChart").css("display", "none");
          // show no results
          $("#divSplkAlertsSmartStatusNotFound").css("display", "inherit");
        } else {
          // hide loader
          $("#SplkAlertsSmartStatusLoader").css("display", "none");
          // show elements
          $("#divSplkAlertsSmartStatusChart").css("display", "inherit");
          // hide no results
          $("#divSplkAlertsSmartStatusNotFound").css("display", "none");
        }
      }
    );

    var search_alerts_triggered_history = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "stats sum(count) as count | append [ | makeresults | eval count=0 | fields - _time ] | head 1",
        managerid: "searchDonutAlertsTriggered",
        id: "search_alerts_triggered_history",
      },
      {
        tokens: true,
      }
    );

    var search_alerts_get_tags = new SearchManager(
      {
        id: "search_alerts_get_tags",
        sample_ratio: 1,
        earliest_time: "-15m",
        cancelOnUnload: true,
        search:
          '| inputlookup trackme_dsm_tenant_$tenant_id$ | eval tags=if(match(tags, "click on Update tags"), "", tags) | makemv delim="," tags | mvexpand tags | where tags!="" | stats values(tags) as tags | mvexpand tags | dedup tags | sort limit=1000 tags',
        latest_time: "now",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_alerts$",
          depends: "$start_get_tags_for_custom_alert$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // data sampling dropdown
    var searchPopulateDataSampling = new SearchManager(
      {
        id: "searchPopulateDataSampling",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          "| inputlookup trackme_dsm_data_sampling_tenant_$tenant_id$ | eval key=_key | fields key, object | sort 0 object",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
          depends: "$start_search_input_data_sampling_dropdown$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // populate Elastic type of searches
    var searchPopulateElasticSearchType = new SearchManager(
      {
        id: "searchPopulateElasticSearchType",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search:
          "| `trackme_elastic_gen_type` | search type=$tk_elastic_source_type_deployment$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_elastic$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // populate accounts
    var searchPopulateConfigurationAccountElastic = new SearchManager(
      {
        id: "searchPopulateConfigurationAccountElastic",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search: "| `trackme_list_accounts`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_elastic$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateConfigurationAccountDsm = new SearchManager(
      {
        id: "searchPopulateConfigurationAccountDsm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search: "| `trackme_list_accounts`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_dsm$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateConfigurationAccountFlx = new SearchManager(
      {
        id: "searchPopulateConfigurationAccountFlx",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search: "| `trackme_list_accounts`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_flx$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateConfigurationAccountWlk = new SearchManager(
      {
        id: "searchPopulateConfigurationAccountWlk",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search: "| `trackme_list_accounts`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_wlk$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateConfigurationAccountDhm = new SearchManager(
      {
        id: "searchPopulateConfigurationAccountDhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search: "| `trackme_list_accounts`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_dhm$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateConfigurationAccountMhm = new SearchManager(
      {
        id: "searchPopulateConfigurationAccountMhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search: "| `trackme_list_accounts`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_mhm$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // populate accounts
    var searchPopulateConfigurationAccountSplkCim = new SearchManager(
      {
        id: "searchPopulateConfigurationAccountSplkCim",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        default: "local",
        initialValue: "local",
        search: "| `trackme_list_accounts`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_cim_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // CIM tracking

    var searchSplkCimMain = new SearchManager(
      {
        id: "searchSplkCimMain",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        latest_time: "+5m",
        search:
          '| inputlookup trackme_cim_tenant_$tenant_id$ | eval keyid=_key | eval status=if(isnotnull(object_state) AND object_state!="", object_state, "red"), monitored_state=if(isnotnull(monitored_state) AND monitored_state!="", monitored_state, "enabled")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkCimPopulateClone = new SearchManager(
      {
        id: "searchSplkCimPopulateClone",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        latest_time: "+5m",
        search:
          "| inputlookup trackme_cim_tenant_$tenant_id$ | eval keyid=_key | stats count by object | sort 0 object",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_configuration_account_cim_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "searchSplkCimMain",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "set",
              token: "show_cim_tracker",
              value: "False",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "show_cim_tracker",
              value: "True",
            },
          ],
        },
      ],
    });

    // set the panel visibility
    searchSplkCimMain.on("change", function (newValue) {
      var show_cim_tracker = getToken("show_cim_tracker");
      // handle replica
      var tenant_replica = getToken("tenant_replica");
      if (show_cim_tracker === "True") {
        if (!tenant_replica) {
          $("#divCimTrackingEmpty").css("display", "none");
        }
        $("#divCimTrackingMainTable").css("display", "inherit");
      } else if (show_cim_tracker === "False") {
        if (!tenant_replica) {
          $("#divCimTrackingEmpty").css("display", "inherit");
        }
        $("#divCimTrackingMainTable").css("display", "none");
      }
    });

    // data sources monitoring

    var searchSplkDsmMain = new SearchManager(
      {
        id: "searchSplkDsmMain",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        refresh: "5m",
        latest_time: "+5m",
        search: "| `get_splk_dsm_table($tenant_id$, *)`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        cache: false,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkDsmMain.on("search:done", function () {
      // stop the cssloader
      $("#cssloader").remove();
    });

    var searchSplkDsmsMainStats = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count as total, count(eval(monitored_state="disabled")) as total_disabled, count(eval(object_state!="green" AND object_state!="info" AND monitored_state="enabled")) as total_in_alert, count(eval(object_state="red" AND priority="high" AND monitored_state="enabled")) as total_high_priority_red, count(eval(monitored_state="enabled" AND priority="low")) as low_enabled, count(eval(monitored_state="enabled" AND priority="medium")) as medium_enabled, count(eval(monitored_state="enabled" AND priority="high")) as high_enabled, count(eval(object_state="blue" AND monitored_state="enabled")) as "blue", count(eval(object_state="orange" AND monitored_state="enabled")) as "orange", count(eval(object_state="green" AND monitored_state="enabled")) as "green", count(eval(object_state="red" AND monitored_state="enabled" AND priority="high")) as "red - high priority", count(eval(object_state="red" AND monitored_state="enabled" AND priority!="high")) as "red - other priority"',
        managerid: "searchSplkDsmMain",
        id: "searchSplkDsmsMainStats",
      },
      {
        tokens: true,
      }
    );

    // tags
    var searchShowTags = new SearchManager(
      {
        id: "searchShowTags",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| inputlookup trackme_dsm_tenant_$tenant_id$ where object="$tk_object$" | fields tags_manual | makemv delim="," tags_manual | mvexpand tags_manual | dedup tags_manual | sort tags_manual',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "searchShowTags",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "unset",
              token: "show_tags_multiselect",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "show_tags_multiselect",
              value: "True",
            },
          ],
        },
      ],
    });

    // set the panel visibility
    searchShowTags.on("change", function (newValue) {
      var show_tags_multiselect = getToken("show_tags_multiselect");
      if (show_tags_multiselect === "True") {
        $("#divTagsUpdate").css("display", "inherit");
        $("#divTagsClear").css("display", "inherit");
      } else {
        $("#divTagsUpdate").css("display", "none");
        $("#divTagsClear").css("display", "none");
      }
    });

    // CMDB

    var searchCmdbSplkDsm = new SearchManager(
      {
        id: "searchCmdbSplkDsm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| trackmesplkcmdb component="dsm" tenant_id="$tenant_id$" object_id="$tk_keyid$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchCmdbSplkDhm = new SearchManager(
      {
        id: "searchCmdbSplkDhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| trackmesplkcmdb component="dhm" tenant_id="$tenant_id$" object_id="$tk_keyid$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchCmdbSplkMhm = new SearchManager(
      {
        id: "searchCmdbSplkMhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| trackmesplkcmdb component="mhm" tenant_id="$tenant_id$" object_id="$tk_keyid$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchCmdbSplkFlx = new SearchManager(
      {
        id: "searchCmdbSplkFlx",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| trackmesplkcmdb component="flx" tenant_id="$tenant_id$" object_id="$tk_keyid$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchCmdbSplkCim = new SearchManager(
      {
        id: "searchCmdbSplkCim",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| trackmesplkcmdb component="cim" tenant_id="$tenant_id$" object_id="$tk_keyid$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchCmdbSplkWlk = new SearchManager(
      {
        id: "searchCmdbSplkWlk",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| trackmesplkcmdb component="wlk" tenant_id="$tenant_id$" object_id="$tk_keyid$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Smart Status

    var searchSmartStatusSplkDsm = new SearchManager(
      {
        id: "searchSmartStatusSplkDsm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search: "$tk_splk_dsm_smart_status_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle
    searchSmartStatusSplkDsm.on("search:start", function (properties) {
      cssloader(
        "Starting SmartStatus, running some Splunky searches, please wait..."
      );
    });

    searchSmartStatusSplkDsm.on("search:failed", function (properties) {
      notify("error", "bottom", "SmartStatus search failed!", "60");
    });

    searchSmartStatusSplkDsm.on("search:error", function (properties) {
      notify("error", "bottom", "SmartStatus search error!", "60");
    });

    searchSmartStatusSplkDsm.on("search:done", function (properties) {
      cssloaderremove();
    });

    var searchSmartStatusSplkDhm = new SearchManager(
      {
        id: "searchSmartStatusSplkDhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search: "$tk_splk_dhm_smart_status_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle
    searchSmartStatusSplkDhm.on("search:start", function (properties) {
      cssloader(
        "Starting SmartStatus, running some Splunky searches, please wait..."
      );
    });

    searchSmartStatusSplkDhm.on("search:failed", function (properties) {
      notify("error", "bottom", "SmartStatus search failed!", "60");
    });

    searchSmartStatusSplkDhm.on("search:error", function (properties) {
      notify("error", "bottom", "SmartStatus search error!", "60");
    });

    searchSmartStatusSplkDhm.on("search:done", function (properties) {
      cssloaderremove();
    });

    var searchSmartStatusSplkMhm = new SearchManager(
      {
        id: "searchSmartStatusSplkMhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search: "$tk_splk_dhm_smart_status_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle
    searchSmartStatusSplkMhm.on("search:start", function (properties) {
      cssloader(
        "Starting SmartStatus, running some Splunky searches, please wait..."
      );
    });

    searchSmartStatusSplkMhm.on("search:failed", function (properties) {
      notify("error", "bottom", "SmartStatus search failed!", "60");
    });

    searchSmartStatusSplkMhm.on("search:error", function (properties) {
      notify("error", "bottom", "SmartStatus search error!", "60");
    });

    searchSmartStatusSplkMhm.on("search:done", function (properties) {
      cssloaderremove();
    });

    var searchSmartStatusSplkWlk = new SearchManager(
      {
        id: "searchSmartStatusSplkWlk",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search: "$tk_splk_wlk_smart_status_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle
    searchSmartStatusSplkWlk.on("search:start", function (properties) {
      cssloader(
        "Starting SmartStatus, running some Splunky searches, please wait..."
      );
    });

    searchSmartStatusSplkWlk.on("search:failed", function (properties) {
      notify("error", "bottom", "SmartStatus search failed!", "60");
    });

    searchSmartStatusSplkWlk.on("search:error", function (properties) {
      notify("error", "bottom", "SmartStatus search error!", "60");
    });

    searchSmartStatusSplkWlk.on("search:done", function (properties) {
      cssloaderremove();
    });

    var searchTagsPoliciesSimulate = new SearchManager(
      {
        id: "searchTagsPoliciesSimulate",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| `trackme_tags_policies_run_simulation("$tenant_id$", "$tk_tags_policies_policy_id$", "$tk_tags_policies_tags$", "$tk_tags_policies_regex$")`',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_tags_policies$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Audit Flip
    var searchMainAuditFlip = new SearchManager(
      {
        id: "searchMainAuditFlip",
        earliest_time: "$timerange_audit_flip.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_audit_flip.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ $audit_flip_object_category$ $audit_flip_object$ $inputAuditFlipObjectFilter$ | eval separator = "-->" | dedup _time object object_category object_previous_state object_state | table _time object object_category object_previous_state separator object_state result | rename separator as " " | `trackme_eval_icons_flip`',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_audit_flip$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchMainAuditFlip.on("search:done", function () {
      // stop the css loader
      $("#cssloader").remove();
    });

    var searchMainAuditFlipTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort limit=10000 - _time",
        managerid: "searchMainAuditFlip",
        id: "searchMainAuditFlipTable",
      },
      {
        tokens: true,
      }
    );

    var searchMainAuditFlipPopulate = new SearchManager(
      {
        id: "searchMainAuditFlipPopulate",
        earliest_time: "$timerange_audit_flip.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_audit_flip.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ | stats count by object_category, object',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_audit_flip$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAuditFlipObjectCategory = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats count by object_category | sort limit=0 object_category",
        managerid: "searchMainAuditFlipPopulate",
        id: "searchAuditFlipObjectCategory",
      },
      {
        tokens: true,
      }
    );

    var searchAuditFlipObject = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "search $audit_flip_object_category$ $inputAuditFlipObjectFilter$ | stats count by object | sort limit=1000 object",
        managerid: "searchMainAuditFlipPopulate",
        id: "searchAuditFlipObject",
      },
      {
        tokens: true,
      }
    );

    var searchAuditFlipTopObject = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "top object",
        managerid: "searchMainAuditFlip",
        id: "searchAuditFlipTopObject",
      },
      {
        tokens: true,
      }
    );

    var searchAuditFlipOverTime = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "timechart limit=40 useother=t minspan=1h bins=1000 count by object",
        managerid: "searchMainAuditFlip",
        id: "searchAuditFlipOverTime",
      },
      {
        tokens: true,
      }
    );

    // Audit Changes Data Source
    var searchSplkDsmMainAuditChanges = new SearchManager(
      {
        id: "searchSplkDsmMainAuditChanges",
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTime.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-dsm")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkDsmMainAuditChanges.on("search:start", function (properties) {
      $("#SplkDsmChangesLoader").css("display", "inherit");
      $("#divSplkDsmChangesNotFound").css("display", "none");
      $("#divSplkDsmChangesChart").css("display", "none");
      $("#divSplkDsmChangesTable").css("display", "none");
    });

    searchSplkDsmMainAuditChanges.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkDsmChangesLoader").css("display", "none");
        $("#divSplkDsmChangesNotFound").css("display", "inherit");
        $("#divSplkDsmChangesChart").css("display", "none");
        $("#divSplkDsmChangesTable").css("display", "none");
        // reduce the size
        $("#splk_dsm_changes")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkDsmChangesLoader").css("display", "none");
        $("#divSplkDsmChangesNotFound").css("display", "none");
        $("#divSplkDsmChangesChart").css("display", "inherit");
        $("#divSplkDsmChangesTable").css("display", "inherit");
        // increase the size
        $("#splk_dsm_changes")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkDsmAuditChangesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkDsmMainAuditChanges",
        id: "searchMainSplkDsmAuditChangesTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkDsmAuditChangesOverTime = new SearchManager(
      {
        id: "searchAuditSplkDsmAuditChangesOverTime",
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTime.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-dsm") | timechart limit=40 useother=t minspan=5m bins=1000 count by change_type',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Lagging performance metrics
    var searchLaggingMetricSplkDsm = new SearchManager(
      {
        id: "searchLaggingMetricSplkDsm",
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTime.latest$",
        search:
          '| mstats $splk_dsm_metrics_mstats_search$ where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-dsm" object="$tk_object$" by object span=5m | timechart span=$modalTime.span$ $splk_dsm_metrics_timechart_search$',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_lagging_metrics$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchLaggingMetricSplkDhm = new SearchManager(
      {
        id: "searchLaggingMetricSplkDhm",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeHost.latest$",
        search:
          '| mstats $splk_dhm_metrics_mstats_search$ where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-dhm" object="$tk_object$" by object span=5m | timechart span=$modalTimeHost.span$ $splk_dhm_metrics_timechart_search$',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_lagging_metrics$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Audit Changes Data Host
    var searchSplkDhmMainAuditChanges = new SearchManager(
      {
        id: "searchSplkDhmMainAuditChanges",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeHost.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_splk_dhm$" AND object_category="splk-dhm")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkDhmMainAuditChanges.on("search:start", function (properties) {
      $("#SplkDhmChangesLoader").css("display", "inherit");
      $("#divSplkDhmChangesNotFound").css("display", "none");
      $("#divSplkDhmChangesChart").css("display", "none");
      $("#divSplkDhmChangesTable").css("display", "none");
    });

    searchSplkDhmMainAuditChanges.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkDhmChangesLoader").css("display", "none");
        $("#divSplkDhmChangesNotFound").css("display", "inherit");
        $("#divSplkDhmChangesChart").css("display", "none");
        $("#divSplkDhmChangesTable").css("display", "none");
        // reduce the size
        $("#splk_dhm_changes")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkDhmChangesLoader").css("display", "none");
        $("#divSplkDhmChangesNotFound").css("display", "none");
        $("#divSplkDhmChangesChart").css("display", "inherit");
        $("#divSplkDhmChangesTable").css("display", "inherit");
        // increase the size
        $("#splk_dhm_changes")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkDhmAuditChangesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkDhmMainAuditChanges",
        id: "searchMainSplkDhmAuditChangesTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkDhmAuditChangesOverTime = new SearchManager(
      {
        id: "searchAuditSplkDhmAuditChangesOverTime",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeHost.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-dhm") | timechart limit=40 useother=t minspan=5m bins=1000 count by change_type',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Audit Changes Metric Host
    var searchSplkMhmMainAuditChanges = new SearchManager(
      {
        id: "searchSplkMhmMainAuditChanges",
        earliest_time: "$modalTimeSplkMhm.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkMhm.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_splk_mhm$" AND object_category="splk-mhm")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkMhmMainAuditChanges.on("search:start", function (properties) {
      $("#SplkMhmChangesLoader").css("display", "inherit");
      $("#divSplkMhmChangesNotFound").css("display", "none");
      $("#divSplkMhmChangesChart").css("display", "none");
      $("#divSplkMhmChangesTable").css("display", "none");
    });

    searchSplkMhmMainAuditChanges.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkMhmChangesLoader").css("display", "none");
        $("#divSplkMhmChangesNotFound").css("display", "inherit");
        $("#divSplkMhmChangesChart").css("display", "none");
        $("#divSplkMhmChangesTable").css("display", "none");
        // reduce the size
        $("#splk_mhm_changes")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkMhmChangesLoader").css("display", "none");
        $("#divSplkMhmChangesNotFound").css("display", "none");
        $("#divSplkMhmChangesChart").css("display", "inherit");
        $("#divSplkMhmChangesTable").css("display", "inherit");
        // increase the size
        $("#splk_mhm_changes")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkMhmAuditChangesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkMhmMainAuditChanges",
        id: "searchMainSplkMhmAuditChangesTable",
      },
      {
        tokens: true,
      }
    );

    // splk-wlk
    var searchSplkWlkMainAuditChanges = new SearchManager(
      {
        id: "searchSplkWlkMainAuditChanges",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_splk_wlk$" AND object_category="splk-wlk")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkWlkMainAuditChanges.on("search:start", function (properties) {
      $("#SplkWlkChangesLoader").css("display", "inherit");
      $("#divSplkWlkChangesNotFound").css("display", "none");
      $("#divSplkWlkChangesChart").css("display", "none");
      $("#divSplkWlkChangesTable").css("display", "none");
    });

    searchSplkWlkMainAuditChanges.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkWlkChangesLoader").css("display", "none");
        $("#divSplkWlkChangesNotFound").css("display", "inherit");
        $("#divSplkWlkChangesChart").css("display", "none");
        $("#divSplkWlkChangesTable").css("display", "none");
        // reduce the size
        $("#splk_wlk_changes")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkWlkChangesLoader").css("display", "none");
        $("#divSplkWlkChangesNotFound").css("display", "none");
        $("#divSplkWlkChangesChart").css("display", "inherit");
        $("#divSplkWlkChangesTable").css("display", "inherit");
        // increase the size
        $("#splk_wlk_changes")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkWlkAuditChangesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkWlkMainAuditChanges",
        id: "searchMainSplkWlkAuditChangesTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkWlkMainMetadata = new SearchManager(
      {
        id: "searchSplkWlkMainMetadata",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        search:
          '| trackmesplkwlkgetreportsdefgen tenant_id="$tenant_id$" object_name="$tk_splk_wlk$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_metadata$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkWlkMainMetadata.on("search:start", function (properties) {
      $("#SplkWlkMetadataLoader").css("display", "inherit");
      $("#divSplkWlkMetadataNotFound").css("display", "none");
      $("#divSplkWlkMetadataChart").css("display", "none");
      $("#divSplkWlkMetadataTable").css("display", "none");
    });

    searchSplkWlkMainMetadata.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkWlkMetadataLoader").css("display", "none");
        $("#divSplkWlkMetadataNotFound").css("display", "inherit");
        $("#divSplkWlkMetadataChart").css("display", "none");
        $("#divSplkWlkMetadataTable").css("display", "none");
        // reduce the size
        $("#splk_wlk_changes")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkWlkMetadataLoader").css("display", "none");
        $("#divSplkWlkMetadataNotFound").css("display", "none");
        $("#divSplkWlkMetadataChart").css("display", "inherit");
        $("#divSplkWlkMetadataTable").css("display", "inherit");
        // increase the size
        $("#splk_wlk_changes")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkWlkMetadataTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkWlkMainMetadata",
        id: "searchMainSplkWlkMetadataTable",
      },
      {
        tokens: true,
      }
    );

    // Audit Changes Metric Host
    var searchSplkFlxMainAuditChanges = new SearchManager(
      {
        id: "searchSplkFlxMainAuditChanges",
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkFlx.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_splk_flx$" AND object_category="splk-flx")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkFlxMainAuditChanges.on("search:start", function (properties) {
      $("#SplkFlxChangesLoader").css("display", "inherit");
      $("#divSplkFlxChangesNotFound").css("display", "none");
      $("#divSplkFlxChangesChart").css("display", "none");
      $("#divSplkFlxChangesTable").css("display", "none");
    });

    searchSplkFlxMainAuditChanges.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkFlxChangesLoader").css("display", "none");
        $("#divSplkFlxChangesNotFound").css("display", "inherit");
        $("#divSplkFlxChangesChart").css("display", "none");
        $("#divSplkFlxChangesTable").css("display", "none");
        // reduce the size
        $("#splk_flx_changes")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkFlxChangesLoader").css("display", "none");
        $("#divSplkFlxChangesNotFound").css("display", "none");
        $("#divSplkFlxChangesChart").css("display", "inherit");
        $("#divSplkFlxChangesTable").css("display", "inherit");
        // increase the size
        $("#splk_flx_changes")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkFlxAuditChangesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkFlxMainAuditChanges",
        id: "searchMainSplkFlxAuditChangesTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkMhmAuditChangesOverTime = new SearchManager(
      {
        id: "searchAuditSplkMhmAuditChangesOverTime",
        earliest_time: "$modalTimeSplkMhm.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkMhm.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-mhm") | timechart limit=40 useother=t minspan=5m bins=1000 count by change_type',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkFlxAuditChangesOverTime = new SearchManager(
      {
        id: "searchAuditSplkFlxAuditChangesOverTime",
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkFlx.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-flx") | timechart limit=40 useother=t minspan=5m bins=1000 count by change_type',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkWlkAuditChangesOverTime = new SearchManager(
      {
        id: "searchAuditSplkWlkAuditChangesOverTime",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-wlk") | timechart limit=40 useother=t minspan=5m bins=1000 count by change_type',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // CIM metrics
    var searchSplkCimMetricsOverTime = new SearchManager(
      {
        id: "searchSplkCimMetricsOverTime",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        search:
          '| mstats $splk_cim_metrics_mstats_search$ where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-cim" object="$tk_object$" $tk_cim_breakby$="$tk_input_splk_cim_metrics_entities$" cim_field="$tk_input_splk_cim_metrics_field$" by $tk_cim_breakby$, cim_field span=1m | eval key=$tk_cim_breakby$ . ":" . cim_field | rex field=key mode=sed "s/^global://g" | timechart useother=t limit=40 span=$modalTimeCim.span$ $splk_cim_metrics_timechart_search$ by key',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_metrics$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Audit Changes CIM tracker
    var searchSplkCimMainAuditChanges = new SearchManager(
      {
        id: "searchSplkCimMainAuditChanges",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-cim")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkCimMainAuditChanges.on("search:start", function (properties) {
      $("#SplkCimChangesLoader").css("display", "inherit");
      $("#divCimChangesNotFound").css("display", "none");
      $("#divCimChangesChart").css("display", "none");
      $("#divCimChangesTable").css("display", "none");
    });

    searchSplkCimMainAuditChanges.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkCimChangesLoader").css("display", "none");
        $("#divCimChangesNotFound").css("display", "inherit");
        $("#divCimChangesChart").css("display", "none");
        $("#divCimChangesTable").css("display", "none");
        // reduce the size
        $("#splk_cim_changes")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkCimChangesLoader").css("display", "none");
        $("#divCimChangesNotFound").css("display", "none");
        $("#divCimChangesChart").css("display", "inherit");
        $("#divCimChangesTable").css("display", "inherit");
        // increase the size
        $("#splk_cim_changes")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainCimAuditChangesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkCimMainAuditChanges",
        id: "searchMainCimAuditChangesTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditCimAuditChangesOverTime = new SearchManager(
      {
        id: "searchAuditCimAuditChangesOverTime",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-cim") | timechart limit=40 useother=t minspan=5m bins=1000 count by change_type',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Audit Flip
    var searchSplkDsmMainAuditFlip = new SearchManager(
      {
        id: "searchSplkDsmMainAuditFlip",
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTime.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ object_category="splk-dsm" object="$tk_object$" | eval separator = "-->" | dedup _time object object_category object_previous_state object_state | table _time object object_category object_previous_state separator object_state result',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_flipping_status$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkDsmMainAuditFlip.on("search:start", function (properties) {
      $("#SplkDsmFlippingLoader").css("display", "inherit");
      $("#divSplkDsmFlippingNotFound").css("display", "none");
      $("#divSplkDsmFlippingChart").css("display", "none");
      $("#divSplkDsmFlippingTable").css("display", "none");
    });

    searchSplkDsmMainAuditFlip.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkDsmFlippingLoader").css("display", "none");
        $("#divSplkDsmFlippingNotFound").css("display", "inherit");
        $("#divSplkDsmFlippingChart").css("display", "none");
        $("#divSplkDsmFlippingTable").css("display", "none");
        // reduce the size
        $("#splk_dsm_flipping")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkDsmFlippingLoader").css("display", "none");
        $("#divSplkDsmFlippingNotFound").css("display", "none");
        $("#divSplkDsmFlippingChart").css("display", "inherit");
        $("#divSplkDsmFlippingTable").css("display", "inherit");
        // increase the size
        $("#splk_dsm_flipping")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkDsmAuditFlipTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'rename separator as " " | `trackme_eval_icons_flip` | fields _time	object object_category object_previous_state " " object_state result | sort - limit=10000 _time',
        managerid: "searchSplkDsmMainAuditFlip",
        id: "searchMainSplkDsmAuditFlipTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkDsmFlipOverTime = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "timechart limit=40 useother=t minspan=1h bins=1000 count by object_state",
        managerid: "searchSplkDsmMainAuditFlip",
        id: "searchAuditSplkDsmFlipOverTime",
      },
      {
        tokens: true,
      }
    );

    var searchSplkDsmTimeline = new SearchManager(
      {
        id: "searchSplkDsmTimeline",
        earliest_time: "-7d@d",
        latest_time: "now",
        sample_ratio: null,
        search:
          '| mstats latest(trackme.sla.object_state) as object_state where `trackme_metrics_idx("$tenant_id$")` object_category="splk-dsm" tenant_id="$tenant_id$" object_id="$tk_keyid$" by object_category, object span=1m | `trackme_sla_eval_current_state` | sort limit=0 _time | table _time, object, current_state | streamstats first(_time) as previous_time current=f by object | eventstats count as total | streamstats count as record_count | eval duration=_time-previous_time | eval previous_time=strftime(previous_time, "%c") | search current_state=* | fields _time, object, current_state, duration',
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_status_message$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkDhmTimeline = new SearchManager(
      {
        id: "searchSplkDhmTimeline",
        earliest_time: "-7d@d",
        latest_time: "now",
        sample_ratio: null,
        search:
          '| mstats latest(trackme.sla.object_state) as object_state where `trackme_metrics_idx("$tenant_id$")` object_category="splk-dhm" tenant_id="$tenant_id$" object_id="$tk_keyid$" by object_category, object span=1m | `trackme_sla_eval_current_state` | sort limit=0 _time | table _time, object, current_state | streamstats first(_time) as previous_time current=f by object | eventstats count as total | streamstats count as record_count | eval duration=_time-previous_time | eval previous_time=strftime(previous_time, "%c") | search current_state=* | fields _time, object, current_state, duration',
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_status_message$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkMhmTimeline = new SearchManager(
      {
        id: "searchSplkMhmTimeline",
        earliest_time: "-7d@d",
        latest_time: "now",
        sample_ratio: null,
        search:
          '| mstats latest(trackme.sla.object_state) as object_state where `trackme_metrics_idx("$tenant_id$")` object_category="splk-mhm" tenant_id="$tenant_id$" object_id="$tk_keyid$" by object_category, object span=1m | `trackme_sla_eval_current_state` | sort limit=0 _time | table _time, object, current_state | streamstats first(_time) as previous_time current=f by object | eventstats count as total | streamstats count as record_count | eval duration=_time-previous_time | eval previous_time=strftime(previous_time, "%c") | search current_state=* | fields _time, object, current_state, duration',
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_status_message$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkFlxTimeline = new SearchManager(
      {
        id: "searchSplkFlxTimeline",
        earliest_time: "-7d@d",
        latest_time: "now",
        sample_ratio: null,
        search:
          '| mstats latest(trackme.sla.object_state) as object_state where `trackme_metrics_idx("$tenant_id$")` object_category="splk-flx" tenant_id="$tenant_id$" object_id="$tk_keyid$" by object_category, object span=1m | `trackme_sla_eval_current_state` | sort limit=0 _time | table _time, object, current_state | streamstats first(_time) as previous_time current=f by object | eventstats count as total | streamstats count as record_count | eval duration=_time-previous_time | eval previous_time=strftime(previous_time, "%c") | search current_state=* | fields _time, object, current_state, duration',
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_status_message$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkWlkTimeline = new SearchManager(
      {
        id: "searchSplkWlkTimeline",
        earliest_time: "-7d@d",
        latest_time: "now",
        sample_ratio: null,
        search:
          '| mstats latest(trackme.sla.object_state) as object_state where `trackme_metrics_idx("$tenant_id$")` object_category="splk-wlk" tenant_id="$tenant_id$" object_id="$tk_keyid$" by object_category, object span=1m | `trackme_sla_eval_current_state` | sort limit=0 _time | table _time, object, current_state | streamstats first(_time) as previous_time current=f by object | eventstats count as total | streamstats count as record_count | eval duration=_time-previous_time | eval previous_time=strftime(previous_time, "%c") | search current_state=* | fields _time, object, current_state, duration',
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_status_message$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkCimTimeline = new SearchManager(
      {
        id: "searchSplkCimTimeline",
        earliest_time: "-7d@d",
        latest_time: "now",
        sample_ratio: null,
        search:
          '| mstats latest(trackme.sla.object_state) as object_state where `trackme_metrics_idx("$tenant_id$")` object_category="splk-cim" tenant_id="$tenant_id$" object_id="$tk_keyid$" by object_category, object span=1m | `trackme_sla_eval_current_state` | sort limit=0 _time | table _time, object, current_state | streamstats first(_time) as previous_time current=f by object | eventstats count as total | streamstats count as record_count | eval duration=_time-previous_time | eval previous_time=strftime(previous_time, "%c") | search current_state=* | fields _time, object, current_state, duration',
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_status_message$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkDhmMainAuditFlip = new SearchManager(
      {
        id: "searchSplkDhmMainAuditFlip",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeHost.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ object_category="splk-dhm" object="$tk_splk_dhm$" | eval separator = "-->" | dedup _time object object_category object_previous_state object_state | table _time object object_category object_previous_state separator object_state result',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_flipping_status$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkDhmMainAuditFlip.on("search:start", function (properties) {
      $("#SplkDhmFlippingLoader").css("display", "inherit");
      $("#divSplkDhmFlippingNotFound").css("display", "none");
      $("#divSplkDhmFlippingChart").css("display", "none");
      $("#divSplkDhmFlippingTable").css("display", "none");
    });

    searchSplkDhmMainAuditFlip.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkDhmFlippingLoader").css("display", "none");
        $("#divSplkDhmFlippingNotFound").css("display", "inherit");
        $("#divSplkDhmFlippingChart").css("display", "none");
        $("#divSplkDhmFlippingTable").css("display", "none");
        // reduce the size
        $("#splk_dhm_flipping")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkDhmFlippingLoader").css("display", "none");
        $("#divSplkDhmFlippingNotFound").css("display", "none");
        $("#divSplkDhmFlippingChart").css("display", "inherit");
        $("#divSplkDhmFlippingTable").css("display", "inherit");
        // increase the size
        $("#splk_dhm_flipping")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkDhmAuditFlipTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'rename separator as " " | `trackme_eval_icons_flip` | fields _time	object object_category object_previous_state " " object_state result | sort - limit=10000 _time',
        managerid: "searchSplkDhmMainAuditFlip",
        id: "searchMainSplkDhmAuditFlipTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkDhmFlipOverTime = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "timechart limit=40 useother=t minspan=1h bins=1000 count by object_state",
        managerid: "searchSplkDhmMainAuditFlip",
        id: "searchAuditSplkDhmFlipOverTime",
      },
      {
        tokens: true,
      }
    );

    var searchSplkMhmMainAuditFlip = new SearchManager(
      {
        id: "searchSplkMhmMainAuditFlip",
        earliest_time: "$modalTimeSplkMhm.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkMhm.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ object_category="splk-mhm" object="$tk_splk_mhm$" | eval separator = "-->" | dedup _time object object_category object_previous_state object_state | table _time object object_category object_previous_state separator object_state result',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_flipping_status$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkMhmMainAuditFlip.on("search:start", function (properties) {
      $("#SplkMhmFlippingLoader").css("display", "inherit");
      $("#divSplkMhmFlippingNotFound").css("display", "none");
      $("#divSplkMhmFlippingChart").css("display", "none");
      $("#divSplkMhmFlippingTable").css("display", "none");
    });

    searchSplkMhmMainAuditFlip.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkMhmFlippingLoader").css("display", "none");
        $("#divSplkMhmFlippingNotFound").css("display", "inherit");
        $("#divSplkMhmFlippingChart").css("display", "none");
        $("#divSplkMhmFlippingTable").css("display", "none");
        // reduce the size
        $("#splk_mhm_flipping")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkMhmFlippingLoader").css("display", "none");
        $("#divSplkMhmFlippingNotFound").css("display", "none");
        $("#divSplkMhmFlippingChart").css("display", "inherit");
        $("#divSplkMhmFlippingTable").css("display", "inherit");
        // increase the size
        $("#splk_mhm_flipping")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkMhmAuditFlipTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'rename separator as " " | `trackme_eval_icons_flip` | fields _time	object object_category object_previous_state " " object_state result | sort - limit=10000 _time',
        managerid: "searchSplkMhmMainAuditFlip",
        id: "searchMainSplkMhmAuditFlipTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkFlxMainAuditFlip = new SearchManager(
      {
        id: "searchSplkFlxMainAuditFlip",
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkFlx.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ object_category="splk-flx" object="$tk_splk_flx$" | eval separator = "-->" | dedup _time object object_category object_previous_state object_state | table _time object object_category object_previous_state separator object_state result',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_flipping_status$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkFlxMainAuditFlip.on("search:start", function (properties) {
      $("#SplkFlxFlippingLoader").css("display", "inherit");
      $("#divSplkFlxFlippingNotFound").css("display", "none");
      $("#divSplkFlxFlippingChart").css("display", "none");
      $("#divSplkFlxFlippingTable").css("display", "none");
    });

    searchSplkFlxMainAuditFlip.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkFlxFlippingLoader").css("display", "none");
        $("#divSplkFlxFlippingNotFound").css("display", "inherit");
        $("#divSplkFlxFlippingChart").css("display", "none");
        $("#divSplkFlxFlippingTable").css("display", "none");
        // reduce the size
        $("#splk_flx_flipping")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkFlxFlippingLoader").css("display", "none");
        $("#divSplkFlxFlippingNotFound").css("display", "none");
        $("#divSplkFlxFlippingChart").css("display", "inherit");
        $("#divSplkFlxFlippingTable").css("display", "inherit");
        // increase the size
        $("#splk_flx_flipping")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkFlxAuditFlipTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'rename separator as " " | `trackme_eval_icons_flip` | fields _time	object object_category object_previous_state " " object_state result | sort - limit=10000 _time',
        managerid: "searchSplkFlxMainAuditFlip",
        id: "searchMainSplkFlxAuditFlipTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkWlkMainAuditFlip = new SearchManager(
      {
        id: "searchSplkWlkMainAuditFlip",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ object_category="splk-wlk" object="$tk_splk_wlk$" | eval separator = "-->" | dedup _time object object_category object_previous_state object_state | table _time object object_category object_previous_state separator object_state result',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_flipping_status$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkWlkMainAuditFlip.on("search:start", function (properties) {
      $("#SplkWlkFlippingLoader").css("display", "inherit");
      $("#divSplkWlkFlippingNotFound").css("display", "none");
      $("#divSplkWlkFlippingChart").css("display", "none");
      $("#divSplkWlkFlippingTable").css("display", "none");
    });

    searchSplkWlkMainAuditFlip.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkWlkFlippingLoader").css("display", "none");
        $("#divSplkWlkFlippingNotFound").css("display", "inherit");
        $("#divSplkWlkFlippingChart").css("display", "none");
        $("#divSplkWlkFlippingTable").css("display", "none");
        // reduce the size
        $("#splk_wlk_flipping")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkWlkFlippingLoader").css("display", "none");
        $("#divSplkWlkFlippingNotFound").css("display", "none");
        $("#divSplkWlkFlippingChart").css("display", "inherit");
        $("#divSplkWlkFlippingTable").css("display", "inherit");
        // increase the size
        $("#splk_wlk_flipping")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainSplkWlkAuditFlipTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'rename separator as " " | `trackme_eval_icons_flip` | fields _time	object object_category object_previous_state " " object_state result | sort - limit=10000 _time',
        managerid: "searchSplkWlkMainAuditFlip",
        id: "searchMainSplkWlkAuditFlipTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditmetricHostFlipOverTime = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "timechart limit=40 useother=t minspan=1h bins=1000 count by object_state",
        managerid: "searchSplkMhmMainAuditFlip",
        id: "searchAuditmetricHostFlipOverTime",
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkFlxFlipOverTime = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "timechart limit=40 useother=t minspan=1h bins=1000 count by object_state",
        managerid: "searchSplkFlxMainAuditFlip",
        id: "searchAuditSplkFlxFlipOverTime",
      },
      {
        tokens: true,
      }
    );

    var searchAuditSplkWlkFlipOverTime = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "timechart limit=40 useother=t minspan=1h bins=1000 count by object_state",
        managerid: "searchSplkWlkMainAuditFlip",
        id: "searchAuditSplkWlkFlipOverTime",
      },
      {
        tokens: true,
      }
    );

    // cim tracker flip status

    var searchSplkCimMainAuditFlip = new SearchManager(
      {
        id: "searchSplkCimMainAuditFlip",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        search:
          '`trackme_idx($tenant_id$)` source="flip_state_change_tracking" tenant_id=$tenant_id$ object_category="splk-cim" object="$tk_object$" | eval separator = "-->" | dedup _time object object_category object_previous_state object_state | table _time object object_category object_previous_state separator object_state result',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_flipping_status$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkCimMainAuditFlip.on("search:start", function (properties) {
      $("#SplkCimFlippingLoader").css("display", "inherit");
      $("#divCimFlippingNotFound").css("display", "none");
      $("#divCimFlippingChart").css("display", "none");
      $("#divCimFlippingTable").css("display", "none");
    });

    searchSplkCimMainAuditFlip.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkCimFlippingLoader").css("display", "none");
        $("#divCimFlippingNotFound").css("display", "inherit");
        $("#divCimFlippingChart").css("display", "none");
        $("#divCimFlippingTable").css("display", "none");
        // reduce the size
        $("#cim_flipping")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkCimFlippingLoader").css("display", "none");
        $("#divCimFlippingNotFound").css("display", "none");
        $("#divCimFlippingChart").css("display", "inherit");
        $("#divCimFlippingTable").css("display", "inherit");
        // increase the size
        $("#cim_flipping")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchMainCimAuditFlipTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'rename separator as " " | `trackme_eval_icons_flip` | fields _time	object object_category object_previous_state " " object_state result | sort - limit=10000 _time',
        managerid: "searchSplkCimMainAuditFlip",
        id: "searchMainCimAuditFlipTable",
      },
      {
        tokens: true,
      }
    );

    var searchAuditCimFlipOverTime = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "timechart limit=40 useother=t minspan=1h bins=1000 count by object_state",
        managerid: "searchSplkCimMainAuditFlip",
        id: "searchAuditCimFlipOverTime",
      },
      {
        tokens: true,
      }
    );

    // Audit Changes
    var searchMainAuditChanges = new SearchManager(
      {
        id: "searchMainAuditChanges",
        earliest_time: "$timerange_audit_changes.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_audit_changes.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` tenant_id="$tenant_id$" $audit_changes_action$ $audit_changes_object_category$ $audit_changes_change_type$ $audit_changes_user$ $audit_changes_object$ | `trackme_eval_icons_audit_changes` | rename action_icon as " " | fields _time user action " " change_type object_category object object_attrs comment',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchMainAuditChanges.on("search:done", function () {
      // stop the css loader
      $("#cssloader").remove();
    });

    var searchMainAuditChangesPopulate = new SearchManager(
      {
        id: "searchMainAuditChangesPopulate",
        earliest_time: "$timerange_audit_changes.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_audit_changes.latest$",
        search:
          '`trackme_audit_idx($tenant_id$)` tenant_id="$tenant_id$" | stats count by action, user, object_category, object, change_type',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_audit_changes$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesAction = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats count by action | sort limit=0 action",
        managerid: "searchMainAuditChangesPopulate",
        id: "searchAuditChangesAction",
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesUser = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "search $audit_changes_action$ | stats count by user | sort limit=0 user",
        managerid: "searchMainAuditChangesPopulate",
        id: "searchAuditChangesUser",
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesObjectCategory = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "search $audit_changes_action$ $audit_changes_user$ | stats count by object_category | sort limit=0 object_category",
        managerid: "searchMainAuditChangesPopulate",
        id: "searchAuditChangesObjectCategory",
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesChangeType = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "search $audit_changes_action$ $audit_changes_user$ $audit_changes_object_category$ | stats count by change_type | sort limit=0 change_type",
        managerid: "searchMainAuditChangesPopulate",
        id: "searchAuditChangesChangeType",
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesObject = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "search $audit_changes_action$ $audit_changes_user$ $audit_changes_object_category$ $audit_changes_change_type$ | stats count by object | sort limit=0 object",
        managerid: "searchMainAuditChangesPopulate",
        id: "searchAuditChangesObject",
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesTopAction = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "top action",
        managerid: "searchMainAuditChanges",
        id: "searchAuditChangesTopAction",
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesTopUser = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "top user",
        managerid: "searchMainAuditChanges",
        id: "searchAuditChangesTopUser",
      },
      {
        tokens: true,
      }
    );

    var searchAuditChangesTopChangeType = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "top change_type",
        managerid: "searchMainAuditChanges",
        id: "searchAuditChangesTopChangeType",
      },
      {
        tokens: true,
      }
    );

    // metric hosts monitoring
    var searchSplkMhmMain = new SearchManager(
      {
        id: "searchSplkMhmMain",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        refresh: "5m",
        latest_time: "now",
        search: "| `get_splk_mhm_table($tenant_id$, compact, *, *)`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkMhmMain.on("search:done", function () {
      // stop the css loader
      $("#cssloader").remove();
    });

    var searchSplkMhmsMainStats = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count as total, count(eval(monitored_state="disabled")) as total_disabled, count(eval(object_state!="green" AND object_state!="blue" AND monitored_state="enabled")) as total_in_alert, count(eval(object_state="red" AND priority="high" AND monitored_state="enabled")) as total_high_priority_red, count(eval(monitored_state="enabled" AND priority="low")) as low_enabled, count(eval(monitored_state="enabled" AND priority="medium")) as medium_enabled, count(eval(monitored_state="enabled" AND priority="high")) as high_enabled, count(eval(object_state="blue" AND monitored_state="enabled")) as "blue", count(eval(object_state="orange" AND monitored_state="enabled")) as "orange", count(eval(object_state="green" AND monitored_state="enabled")) as "green", count(eval(object_state="red" AND monitored_state="enabled" AND priority="high")) as "red - high priority", count(eval(object_state="red" AND monitored_state="enabled" AND priority!="high")) as "red - other priority"',
        managerid: "searchSplkMhmMain",
        id: "searchSplkMhmsMainStats",
      },
      {
        tokens: true,
      }
    );

    // splk-flx monitoring
    var searchSplkFlxMain = new SearchManager(
      {
        id: "searchSplkFlxMain",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        refresh: "5m",
        latest_time: "now",
        search: "| `get_splk_flx_table($tenant_id$, *, *)`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkFlxMain.on("search:done", function () {
      // stop the css loader
      $("#cssloader").remove();
    });

    var searchSplkFlxsMainStats = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count as total, count(eval(monitored_state="disabled")) as total_disabled, count(eval(object_state!="green" AND object_state!="blue" AND monitored_state="enabled")) as total_in_alert, count(eval(object_state="red" AND priority="high" AND monitored_state="enabled")) as total_high_priority_red, count(eval(monitored_state="enabled" AND priority="low")) as low_enabled, count(eval(monitored_state="enabled" AND priority="medium")) as medium_enabled, count(eval(monitored_state="enabled" AND priority="high")) as high_enabled, count(eval(object_state="blue" AND monitored_state="enabled")) as "blue", count(eval(object_state="orange" AND monitored_state="enabled")) as "orange", count(eval(object_state="green" AND monitored_state="enabled")) as "green", count(eval(object_state="red" AND monitored_state="enabled" AND priority="high")) as "red - high priority", count(eval(object_state="red" AND monitored_state="enabled" AND priority!="high")) as "red - other priority"',
        managerid: "searchSplkFlxMain",
        id: "searchSplkFlxsMainStats",
      },
      {
        tokens: true,
      }
    );

    // splk-wlk monitoring
    var searchSplkWlkMain = new SearchManager(
      {
        id: "searchSplkWlkMain",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        refresh: "5m",
        latest_time: "now",
        search: "| `get_splk_wlk_table($tenant_id$, *, *)`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkWlkMain.on("search:done", function () {
      // stop the css loader
      $("#cssloader").remove();
    });

    var searchSplkWlksMainStats = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count as total, count(eval(monitored_state="disabled")) as total_disabled, count(eval(object_state!="green" AND object_state!="blue" AND monitored_state="enabled")) as total_in_alert, count(eval(object_state="red" AND priority="high" AND monitored_state="enabled")) as total_high_priority_red, count(eval(monitored_state="enabled" AND priority="low")) as low_enabled, count(eval(monitored_state="enabled" AND priority="medium")) as medium_enabled, count(eval(monitored_state="enabled" AND priority="high")) as high_enabled, count(eval(object_state="blue" AND monitored_state="enabled")) as "blue", count(eval(object_state="orange" AND monitored_state="enabled")) as "orange", count(eval(object_state="green" AND monitored_state="enabled")) as "green", count(eval(object_state="red" AND monitored_state="enabled" AND priority="high")) as "red - high priority", count(eval(object_state="red" AND monitored_state="enabled" AND priority!="high")) as "red - other priority"',
        managerid: "searchSplkWlkMain",
        id: "searchSplkWlksMainStats",
      },
      {
        tokens: true,
      }
    );

    var searchPopulateCim = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "search $inputCimFilter$ | stats count by object | sort limit=1000 object",
        managerid: "searchSplkCimMain",
        id: "searchPopulateCim",
      },
      {
        tokens: true,
      }
    );

    var searchPopulateSplkMhmsCategories = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "stats values(metric_category) as metric_category | makemv metric_category | mvexpand metric_category | dedup metric_category | search NOT [ | inputlookup trackme_mhm_lagging_classes_tenant_$tenant_id$ | table metric_category ] | sort limit=1000 metric_category",
        managerid: "searchSplkMhmMain",
        id: "searchPopulateSplkMhmsCategories",
      },
      {
        tokens: true,
      }
    );

    var searchHostTableSplkMhm = new SearchManager(
      {
        id: "searchHostTableSplkMhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        refresh: "5m",
        latest_time: "now",
        search: "| `get_splk_mhm_table_expanded($tenant_id$, $tk_keyid$, *)`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_tracker$",
          depends: "$tk_splk_mhm$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchHostTableMSplkCim = new SearchManager(
      {
        id: "searchHostTableMSplkCim",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        refresh: "5m",
        latest_time: "now",
        search:
          '| `get_splk_cim_table("$tenant_id$", "*", "$tk_object$")` | eval raw_cim_tracking_results=cim_tracking_results | rex field=cim_tracking_results mode=sed "s/\\"cim_fields_red\\"/\\"cim_fields_red 🔴\\"/g" | rex field=cim_tracking_results mode=sed "s/\\"cim_fields_green\\"/\\"cim_fields_green 🟢\\"/g"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_tracker$",
          depends: "$tk_object$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchHostChartSplkMhm = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "top state",
        managerid: "searchHostTableSplkMhm",
        id: "searchHostChartSplkMhm",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSLASplkMhmpct = new SearchManager(
      {
        tokenDependencies: {
          depends: "$show_splk_mhm_tracker$",
        },
        search:
          "| `trackme_get_sla_pct_metrics_per_entity_key($tenant_id$,splk-mhm,$tk_keyid$)`",
        id: "searchSingleSLASplkMhmpct",
        sample_ratio: 1,
        status_buckets: 0,
        earliest_time: "-90d@d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
      },
      {
        tokens: true,
      }
    );

    var searchSingleSLASplkFlxpct = new SearchManager(
      {
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
        },
        search:
          "| `trackme_get_sla_pct_metrics_per_entity_key($tenant_id$,splk-flx,$tk_keyid$)`",
        id: "searchSingleSLASplkFlxpct",
        sample_ratio: 1,
        status_buckets: 0,
        earliest_time: "-90d@d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
      },
      {
        tokens: true,
      }
    );

    // CIM tracker SLA
    var searchSingleSLASplkCimpct = new SearchManager(
      {
        tokenDependencies: {
          depends: "$show_cim_tracker$",
        },
        search:
          "| `trackme_get_sla_pct_metrics_per_entity_key($tenant_id$,splk-cim,$tk_keyid$)`",
        id: "searchSingleSLASplkCimpct",
        sample_ratio: 1,
        status_buckets: 0,
        earliest_time: "-90d@d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
      },
      {
        tokens: true,
      }
    );

    // CIM tracker number of fields monitored
    var searchSingleSplkCimFieldsGreen = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "fields raw_cim_tracking_results | spath input=raw_cim_tracking_results | fields cim_fields_green_count",
        managerid: "searchHostTableMSplkCim",
        id: "searchSingleSplkCimFieldsGreen",
      },
      {
        tokens: true,
      }
    );

    // CIM tracker number of fields monitored
    var searchSingleSplkCimFieldsRed = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "fields raw_cim_tracking_results | spath input=raw_cim_tracking_results | fields cim_fields_red_count",
        managerid: "searchHostTableMSplkCim",
        id: "searchSingleSplkCimFieldsRed",
      },
      {
        tokens: true,
      }
    );

    // hosts monitoring

    var searchSplkDhmMain = new SearchManager(
      {
        id: "searchSplkDhmMain",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        refresh: "5m",
        latest_time: "+5m",
        search: "| `get_splk_dhm_table($tenant_id$, compact, *, *)`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkDhmMain.on("search:done", function () {
      // stop the css loader
      $("#cssloader").remove();
    });

    var searchSplkDhmsMainStats = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count as total, count(eval(monitored_state="disabled")) as total_disabled, count(eval(object_state!="green" AND object_state!="blue" AND monitored_state="enabled")) as total_in_alert, count(eval(object_state="red" AND priority="high" AND monitored_state="enabled")) as total_high_priority_red, count(eval(monitored_state="enabled" AND priority="low")) as low_enabled, count(eval(monitored_state="enabled" AND priority="medium")) as medium_enabled, count(eval(monitored_state="enabled" AND priority="high")) as high_enabled, count(eval(object_state="blue" AND monitored_state="enabled")) as "blue", count(eval(object_state="orange" AND monitored_state="enabled")) as "orange", count(eval(object_state="green" AND monitored_state="enabled")) as "green", count(eval(object_state="red" AND monitored_state="enabled" AND priority="high")) as "red - high priority", count(eval(object_state="red" AND monitored_state="enabled" AND priority!="high")) as "red - other priority"',
        managerid: "searchSplkDhmMain",
        id: "searchSplkDhmsMainStats",
      },
      {
        tokens: true,
      }
    );

    var searchSingleNoSplkDsms = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats count by object | sort limit=0 object",
        managerid: "searchSplkDsmMain",
        id: "searchSingleNoSplkDsms",
      },
      {
        tokens: true,
      }
    );

    var searchSingleNoDataIndexes = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats count by data_index | sort limit=0 data_index",
        managerid: "searchSplkDsmMain",
        id: "searchSingleNoDataIndexes",
      },
      {
        tokens: true,
      }
    );

    var searchSingleNoSplkDsmtypes = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats count by data_sourcetype | sort limit=0 data_sourcetype",
        managerid: "searchSplkDsmMain",
        id: "searchSingleNoSplkDsmtypes",
      },
      {
        tokens: true,
      }
    );

    var searchSingleNoSplkDhms = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats count by object | sort limit=0 object",
        managerid: "searchSplkDhmMain",
        id: "searchSingleNoSplkDhms",
      },
      {
        tokens: true,
      }
    );

    var searchSingleCimDonutAlerts = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count(eval(status="green")) as green, count(eval(priority!="high" AND status="red")) as "red - other priority", count(eval(priority="high" AND status="red")) as "red - high priority" | fields green, "red - high priority", "red - other priority"\n| transpose | rename column as state, "row 1" as count | `trackme_donut_alert_by_type(state)`',
        managerid: "searchSplkCimMain",
        id: "searchSingleCimDonutAlerts",
      },
      {
        tokens: true,
      }
    );

    var searchSingleCimDonutPriorities = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count(eval(priority="low")) as low, count(eval(priority="medium")) as medium, count(eval(priority="high")) as high | transpose | rename column as priority, "row 1" as count | `trackme_donut_alert_by_priority`',
        managerid: "searchSplkCimMain",
        id: "searchSingleCimDonutPriorities",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDsmDonutAlerts = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields blue, orange, green, "red - high priority", "red - other priority"\n| transpose | rename column as state, "row 1" as count | `trackme_donut_alert_by_type(state)`',
        managerid: "searchSplkDsmsMainStats",
        id: "searchSingleSplkDsmDonutAlerts",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDsmDonutPriorities = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields low_enabled, medium_enabled, high_enabled | rename low_enabled as low, medium_enabled as medium, high_enabled as high | transpose | rename column as priority, "row 1" as count | `trackme_donut_alert_by_priority`',
        managerid: "searchSplkDsmsMainStats",
        id: "searchSingleSplkDsmDonutPriorities",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDsm1 = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total",
        managerid: "searchSplkDsmsMainStats",
        id: "searchSingleSplkDsm1",
      },
      {
        tokens: true,
      }
    );

    var searchSingleCim1 = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats count",
        managerid: "searchSplkCimMain",
        id: "searchSingleCim1",
      },
      {
        tokens: true,
      }
    );

    var searchSingleCim2 = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count(eval(status!="green" AND monitored_state="enabled")) as count',
        managerid: "searchSplkCimMain",
        id: "searchSingleCim2",
      },
      {
        tokens: true,
      }
    );

    var searchSingleCim3 = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'stats count(eval(status!="green" AND monitored_state="enabled" AND priority="high")) as count',
        managerid: "searchSplkCimMain",
        id: "searchSingleCim3",
      },
      {
        tokens: true,
      }
    );

    var searchSingleCim4 = new PostProcessManager(
      {
        tokenDependencies: {},
        search: 'stats count(eval(monitored_state="disabled")) as count',
        managerid: "searchSplkCimMain",
        id: "searchSingleCim4",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDsmInAlert = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_in_alert",
        managerid: "searchSplkDsmsMainStats",
        id: "searchSingleSplkDsmInAlert",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDsmHighPriority = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_high_priority_red",
        managerid: "searchSplkDsmsMainStats",
        id: "searchSingleSplkDsmHighPriority",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDsmNotMonitored = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_disabled",
        managerid: "searchSplkDsmsMainStats",
        id: "searchSingleSplkDsmNotMonitored",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDhmDonutAlerts = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields blue, orange, green, "red - high priority", "red - other priority"\n| transpose | rename column as state, "row 1" as count | `trackme_donut_alert_by_type(state)`',
        managerid: "searchSplkDhmsMainStats",
        id: "searchSingleSplkDhmDonutAlerts",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDhmDonutPriorities = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields low_enabled, medium_enabled, high_enabled | rename low_enabled as low, medium_enabled as medium, high_enabled as high | transpose | rename column as priority, "row 1" as count | `trackme_donut_alert_by_priority`',
        managerid: "searchSplkDhmsMainStats",
        id: "searchSingleSplkDhmDonutPriorities",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDhm1 = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total",
        managerid: "searchSplkDhmsMainStats",
        id: "searchSingleSplkDhm1",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDhmInAlert = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_in_alert",
        managerid: "searchSplkDhmsMainStats",
        id: "searchSingleSplkDhmInAlert",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDhmNotMonitored = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_disabled",
        managerid: "searchSplkDhmsMainStats",
        id: "searchSingleSplkDhmNotMonitored",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkDhmHighPriority = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_high_priority_red",
        managerid: "searchSplkDhmsMainStats",
        id: "searchSingleSplkDhmHighPriority",
      },
      {
        tokens: true,
      }
    );

    var searchGetSplkDhmTags = new SearchManager(
      {
        id: "searchGetSplkDhmTags",
        earliest_time: "-15m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| inputlookup trackme_dhm_tenant_$tenant_id$ where object="$tk_splk_dhm$" | fields tenant_id, object, alias, data_index, data_sourcetype, priority | foreach * [ eval <<FIELD>> = mvjoin(\'<<FIELD>>\', "|") ] | `trackme_get_splk_dhm_tags`',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // splk-flx

    var searchSingleSplkFlxDonutAlerts = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields blue, orange, green, "red - high priority", "red - other priority"\n| transpose | rename column as state, "row 1" as count | `trackme_donut_alert_by_type(state)`',
        managerid: "searchSplkFlxsMainStats",
        id: "searchSingleSplkFlxDonutAlerts",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkFlxDonutPriorities = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields low_enabled, medium_enabled, high_enabled | rename low_enabled as low, medium_enabled as medium, high_enabled as high | transpose | rename column as priority, "row 1" as count | `trackme_donut_alert_by_priority`',
        managerid: "searchSplkFlxsMainStats",
        id: "searchSingleSplkFlxDonutPriorities",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkFlx1 = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total",
        managerid: "searchSplkFlxsMainStats",
        id: "searchSingleSplkFlx1",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkFlxInAlert = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_in_alert",
        managerid: "searchSplkFlxsMainStats",
        id: "searchSingleSplkFlxInAlert",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkFlxHighPriority = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_high_priority_red",
        managerid: "searchSplkFlxsMainStats",
        id: "searchSingleSplkFlxHighPriority",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkFlxNotMonitored = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_disabled",
        managerid: "searchSplkFlxsMainStats",
        id: "searchSingleSplkFlxNotMonitored",
      },
      {
        tokens: true,
      }
    );

    // splk-wlk

    var searchSingleSplkWlkDonutAlerts = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields blue, orange, green, "red - high priority", "red - other priority"\n| transpose | rename column as state, "row 1" as count | `trackme_donut_alert_by_type(state)`',
        managerid: "searchSplkWlksMainStats",
        id: "searchSingleSplkWlkDonutAlerts",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkWlkDonutPriorities = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields low_enabled, medium_enabled, high_enabled | rename low_enabled as low, medium_enabled as medium, high_enabled as high | transpose | rename column as priority, "row 1" as count | `trackme_donut_alert_by_priority`',
        managerid: "searchSplkWlksMainStats",
        id: "searchSingleSplkWlkDonutPriorities",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkWlk1 = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total",
        managerid: "searchSplkWlksMainStats",
        id: "searchSingleSplkWlk1",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkWlkInAlert = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_in_alert",
        managerid: "searchSplkWlksMainStats",
        id: "searchSingleSplkWlkInAlert",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkWlkHighPriority = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_high_priority_red",
        managerid: "searchSplkWlksMainStats",
        id: "searchSingleSplkWlkHighPriority",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkWlkNotMonitored = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_disabled",
        managerid: "searchSplkWlksMainStats",
        id: "searchSingleSplkWlkNotMonitored",
      },
      {
        tokens: true,
      }
    );

    // object

    var searchSingleSplkMhmDonutAlerts = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields blue, orange, green, "red - high priority", "red - other priority"\n| transpose | rename column as state, "row 1" as count | `trackme_donut_alert_by_type(state)`',
        managerid: "searchSplkMhmsMainStats",
        id: "searchSingleSplkMhmDonutAlerts",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkMhmDonutPriorities = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'fields low_enabled, medium_enabled, high_enabled | rename low_enabled as low, medium_enabled as medium, high_enabled as high | transpose | rename column as priority, "row 1" as count | `trackme_donut_alert_by_priority`',
        managerid: "searchSplkMhmsMainStats",
        id: "searchSingleSplkMhmDonutPriorities",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkMhm1 = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total",
        managerid: "searchSplkMhmsMainStats",
        id: "searchSingleSplkMhm1",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkMhmInAlert = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_in_alert",
        managerid: "searchSplkMhmsMainStats",
        id: "searchSingleSplkMhmInAlert",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkMhmHighPriority = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_high_priority_red",
        managerid: "searchSplkMhmsMainStats",
        id: "searchSingleSplkMhmHighPriority",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkMhmNotMonitored = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields total_disabled",
        managerid: "searchSplkMhmsMainStats",
        id: "searchSingleSplkMhmNotMonitored",
      },
      {
        tokens: true,
      }
    );

    var searchGetSplkMhmTags = new SearchManager(
      {
        id: "searchGetSplkMhmTags",
        earliest_time: "-15m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| inputlookup trackme_mhm_tenant_$tenant_id$ where object="$tk_splk_mhm$" | fields tenant_id, object, alias, metric_index, priority | foreach * [ eval <<FIELD>> = mvjoin(\'<<FIELD>>\', "|") ] | `trackme_get_splk_mhm_tags`',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "searchGetSplkMhmTags",
      event: "progress",
      conditions: [
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "tk_splk_mhm_tags",
              value: "$result.splk_mhm_tags$",
            },
          ],
        },
      ],
    });

    var searchChartLag = new SearchManager(
      {
        id: "searchChartLag",
        sample_ratio: 1,
        search:
          "$tk_splk_dsm_overview_timechart$ | fields _time, $tk_input_splk_dsm_overview_chart_series$",
        status_buckets: 0,
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // data source monitoring

    // Data parsing quality
    var SearchSplkDsmParsingQualityMain = new SearchManager(
      {
        id: "SearchSplkDsmParsingQualityMain",
        tokenDependencies: {
          depends: "$show_data_quality$",
        },
        sample_ratio: 1,
        earliest_time: "$modalTime.earliest$",
        search:
          'index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` (component=LineBreakingProcessor OR component=AggregatorMiningProcessor OR component=DateParserVerbose) | `trackme_data_quality_parse` | search [ | inputlookup trackme_dsm_tenant_$tenant_id$ where _key="$tk_keyid$" | fields data_sourcetype ]',
        latest_time: "$modalTime.latest$",
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "SearchSplkDsmParsingQualityMain",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "unset",
              token: "show_data_quality_no_results",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "show_data_quality_no_results",
              value: "True",
            },
          ],
        },
      ],
    });

    // set the panel visibility
    SearchSplkDsmParsingQualityMain.on("change", function (newValue) {
      var show_data_quality_no_results = getToken(
        "show_data_quality_no_results"
      );
      if (show_data_quality_no_results === "True") {
        $("#divSplkDsmParsingErrorsNotFound").css("display", "none");
        $("#divSplkDsmParsingErrorsFound").css("display", "inherit");
        // increase the size
        $("#splk_dsm_data_parsing")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      } else {
        $("#divSplkDsmParsingErrorsNotFound").css("display", "inherit");
        $("#divSplkDsmParsingErrorsFound").css("display", "none");
        // reduce the size
        $("#splk_dsm_data_parsing")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      }
    });

    var SearchSplkDsmParsingQualityChart = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "timechart span=$modalTime.span$ count by component",
        managerid: "SearchSplkDsmParsingQualityMain",
        id: "SearchSplkDsmParsingQualityChart",
      },
      {
        tokens: true,
      }
    );

    var SearchSplkDsmParsingQualitySingle = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'top limit=0 component | eval percent=round(percent, 2) | eval summary=component . ": " . percent . " %" | fields summary | stats values(summary) as summary | append [ | makeresults | eval summary="No parsing issues detected (bravo!?), review the trackme_idx_filter macro to target indexing instances." | fields - _time ] | head 1',
        managerid: "SearchSplkDsmParsingQualityMain",
        id: "SearchSplkDsmParsingQualitySingle",
      },
      {
        tokens: true,
      }
    );

    //
    // splk-flx
    //

    // populating dropdown for metrics
    var modal_input_splk_flx_metrics_multiselect = new MultiSelectInput(
      {
        id: "modal_input_splk_flx_metrics_multiselect",
        default: "status",
        initialValue: "status",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "label",
        selectFirstChoice: true,
        valueField: "label",
        value: "$form.tk_input_splk_flx_metrics_dropdown$",
        managerid: "searchPopulateSplkFlxMetrics",
        el: $("#modal_input_splk_flx_metrics_multiselect"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_metrics_multiselect.on(
      "change",
      function (newValueArray) {
        const prefix = "metric_name=trackme.splk.flx.";
        const separator = " OR ";
        const metricNames = newValueArray.map((name) => {
          return name;
        });
        const searchFilter = metricNames
          .map((name) => prefix + name)
          .join(separator);
        setToken("tk_input_splk_flx_metrics_searchfilter", searchFilter);
      }
    );

    var modal_input_splk_flx_statsmode_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_flx_statsmode_dropdown",
        choices: [
          {
            label: "latest",
            value: "latest",
          },
          {
            label: "avg",
            value: "avg",
          },
          {
            label: "max",
            value: "max",
          },
          {
            label: "min",
            value: "min",
          },
          {
            label: "perc95",
            value: "perc95",
          },
          {
            label: "stdev",
            value: "stdev",
          },
        ],
        searchWhenChanged: false,
        default: "max",
        showClearButton: true,
        initialValue: "max",
        selectFirstChoice: false,
        width: 200,
        value: "$form.tk_input_splk_flx_statsmode_dropdown$",
        el: $("#modal_input_splk_flx_statsmode_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_statsmode_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_flx_statsmode_dropdown);
    });

    var modal_input_splk_flx_chartmode_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_flx_chartmode_dropdown",
        choices: [
          {
            label: "column",
            value: "column",
          },
          {
            label: "line",
            value: "line",
          },
        ],
        searchWhenChanged: false,
        default: "column",
        showClearButton: true,
        initialValue: "column",
        selectFirstChoice: false,
        width: 200,
        value: "$form.tk_input_splk_flx_chartmode_dropdown$",
        el: $("#modal_input_splk_flx_chartmode_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_chartmode_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_flx_chartmode_dropdown);
    });

    // Populating search
    var searchPopulateSplkFlxMetrics = new SearchManager(
      {
        id: "searchPopulateSplkFlxMetrics",
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkFlx.latest$",
        autostart: true,
        search: "$splk_flx_metrics_populate_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: true,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Metric chart search
    var searchChartSplkFlx = new SearchManager(
      {
        id: "searchChartSplkFlx",
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkFlx.latest$",
        search:
          '| mstats $tk_input_splk_flx_statsmode_dropdown$(_value) as value where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-flx" object="$tk_object$" $tk_input_splk_flx_metrics_searchfilter$ by metric_name span=5m | rex field=metric_name "^trackme.splk.flx.(?<metric_name>.*)" | timechart span=$modalTimeSplkFlx.span$ $tk_input_splk_flx_statsmode_dropdown$(value) as $tk_input_splk_flx_statsmode_dropdown$ by metric_name',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_overview$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // chart
    var elementChartSplkFlxMetrics = new ChartView(
      {
        id: "elementChartSplkFlxMetrics",
        "charting.chart.nullValueMode": "gaps",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.drilldown": "none",
        "charting.chart.showDataLabels": "none",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisY2.enabled": "1",
        "charting.axisY2.scale": "inherit",
        "trellis.scales.shared": "1",
        resizable: true,
        "charting.legend.placement": "right",
        "charting.chart": "$tk_input_splk_flx_chartmode_dropdown$",
        managerid: "searchChartSplkFlx",
        el: $("#elementChartSplkFlxMetrics"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartSplkFlxMetrics = new ResultsLinkView({
      id: "resultsLinkelementChartSplkFlxMetrics",
      managerid: "searchChartSplkFlx",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartSplkFlxMetrics"),
    });

    resultsLinkelementChartSplkFlxMetrics
      .render()
      .$el.appendTo($("resultsLinkelementChartSplkFlxMetrics"));

    //
    // splk-wlk
    //

    // populating dropdown for metrics
    var modal_input_splk_wlk_metrics_multiselect = new MultiSelectInput(
      {
        id: "modal_input_splk_wlk_metrics_multiselect",
        default: "count_execution",
        initialValue: "count_execution",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "label",
        selectFirstChoice: true,
        valueField: "label",
        value: "$form.tk_input_splk_wlk_metrics_dropdown$",
        managerid: "searchPopulateSplkWlkMetrics",
        el: $("#modal_input_splk_wlk_metrics_multiselect"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_metrics_multiselect.on(
      "change",
      function (newValueArray) {
        const prefix = "metric_name=trackme.splk.wlk.";
        const separator = " OR ";
        const metricNames = newValueArray.map((name) => {
          const parts = name.split(".");
          if (parts.length >= 2) {
            return parts[parts.length - 2] + "." + parts[parts.length - 1];
          }
          return name;
        });
        const searchFilter = metricNames
          .map((name) => prefix + name)
          .join(separator);
        setToken("tk_input_splk_wlk_metrics_searchfilter", searchFilter);
      }
    );

    var modal_input_splk_wlk_statsmode_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_wlk_statsmode_dropdown",
        choices: [
          {
            label: "latest",
            value: "latest",
          },
          {
            label: "avg",
            value: "avg",
          },
          {
            label: "max",
            value: "max",
          },
          {
            label: "min",
            value: "min",
          },
          {
            label: "perc95",
            value: "perc95",
          },
          {
            label: "stdev",
            value: "stdev",
          },
        ],
        searchWhenChanged: false,
        default: "max",
        showClearButton: true,
        initialValue: "max",
        selectFirstChoice: false,
        width: 200,
        value: "$form.tk_input_splk_wlk_statsmode_dropdown$",
        el: $("#modal_input_splk_wlk_statsmode_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_statsmode_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_wlk_statsmode_dropdown);
    });

    var modal_input_splk_wlk_chartmode_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_wlk_chartmode_dropdown",
        choices: [
          {
            label: "column",
            value: "column",
          },
          {
            label: "line",
            value: "line",
          },
        ],
        searchWhenChanged: false,
        default: "line",
        showClearButton: true,
        initialValue: "line",
        selectFirstChoice: false,
        width: 200,
        value: "$form.tk_input_splk_wlk_chartmode_dropdown$",
        el: $("#modal_input_splk_wlk_chartmode_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_chartmode_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_wlk_chartmode_dropdown);
    });

    var modal_input_splk_wlk_chartbreakby_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_wlk_chartbreakby_dropdown",
        choices: [
          {
            label: "True",
            value: "True",
          },
          {
            label: "False",
            value: "False",
          },
        ],
        searchWhenChanged: false,
        default: "False",
        showClearButton: true,
        initialValue: "False",
        selectFirstChoice: false,
        width: 200,
        value: "$form.tk_input_splk_wlk_chartbreakby_dropdown$",
        el: $("#modal_input_splk_wlk_chartbreakby_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_chartbreakby_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_splk_wlk_chartbreakby_dropdown);
        if (newValue === "True") {
          setToken("tk_input_splk_wlk_main_breakby", "version_id, metric_name");
          setToken(
            "tk_input_splk_wlk_main_evalobj",
            'eval breakbyobj = metric_name . ":" . version_id'
          );
        } else if (newValue === "False") {
          setToken("tk_input_splk_wlk_main_breakby", "metric_name");
          setToken(
            "tk_input_splk_wlk_main_evalobj",
            "eval breakbyobj = metric_name"
          );
        }
      }
    );

    // Populating search
    var searchPopulateSplkWlkMetrics = new SearchManager(
      {
        id: "searchPopulateSplkWlkMetrics",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        autostart: true,
        search: "$splk_wlk_metrics_populate_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: true,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Metric chart search
    var searchChartSplkWlk = new SearchManager(
      {
        id: "searchChartSplkWlk",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        search:
          '| mstats $tk_input_splk_wlk_statsmode_dropdown$(_value) as value where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-wlk" object_id="$tk_keyid$" $tk_input_splk_wlk_metrics_searchfilter$ by $tk_input_splk_wlk_main_breakby$ span=5m | rex field=metric_name "^trackme.splk.wlk.(?<metric_name>.*)" | $tk_input_splk_wlk_main_evalobj$ | timechart span=$modalTimeSplkWlk.span$ $tk_input_splk_wlk_statsmode_dropdown$(value) as $tk_input_splk_wlk_statsmode_dropdown$ by breakbyobj',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_overview$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSingleSplkWlk = new SearchManager(
      {
        id: "searchSingleSplkWlk",
        sample_ratio: 1,
        search: "| `trackme_wlk_single_summary($tenant_id$, $tk_keyid$)`",
        status_buckets: 0,
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeSplkWlk.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_overview$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSingleCountExecution = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields count_execution",
        managerid: "searchSingleSplkWlk",
        id: "searchSingleCountExecution",
      },
      {
        tokens: true,
      }
    );

    var searchSingleCountErrors = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields count_errors",
        managerid: "searchSingleSplkWlk",
        id: "searchSingleCountErrors",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSkipPct = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields pct_skipped",
        managerid: "searchSingleSplkWlk",
        id: "searchSingleSkipPct",
      },
      {
        tokens: true,
      }
    );

    var searchSingleElapsed = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "fields elapsed",
        managerid: "searchSingleSplkWlk",
        id: "searchSingleElapsed",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSLApctWlk = new SearchManager(
      {
        tokenDependencies: {
          depends: "$show_splk_wlk_overview$",
        },
        search:
          "| `trackme_get_sla_pct_metrics_per_entity_key($tenant_id$,splk-wlk,$tk_keyid$)`",
        id: "searchSingleSLApctWlk",
        sample_ratio: 1,
        status_buckets: 0,
        earliest_time: "-90d@d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
      },
      {
        tokens: true,
      }
    );

    // Single forms

    var elementSingleCountExecWlk = new SingleView(
      {
        id: "elementSingleCountExecWlk",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        "trellis.enabled": "0",
        colorMode: "none",
        underLabel: "# Execution",
        managerid: "searchSingleCountExecution",
        el: $("#elementSingleCountExecWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleCountExecWlk = new ResultsLinkView({
      id: "resultsLinkelementSingleCountExecWlk",
      managerid: "searchSingleCountExecution",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleCountExecWlk"),
    });

    resultsLinkelementSingleCountExecWlk
      .render()
      .$el.appendTo($("resultsLinkelementSingleCountExecWlk"));

    var elementSingleCountErrorsWlk = new SingleView(
      {
        id: "elementSingleCountErrorsWlk",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        "trellis.enabled": "0",
        colorMode: "none",
        underLabel: "# Errors",
        managerid: "searchSingleCountErrors",
        el: $("#elementSingleCountErrorsWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleCountErrorsWlk = new ResultsLinkView({
      id: "resultsLinkelementSingleCountErrorsWlk",
      managerid: "searchSingleCountErrors",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleCountErrorsWlk"),
    });

    resultsLinkelementSingleCountErrorsWlk
      .render()
      .$el.appendTo($("resultsLinkelementSingleCountErrorsWlk"));

    var elementSingleSkipPctWlk = new SingleView(
      {
        id: "elementSingleSkipPctWlk",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        "trellis.enabled": "0",
        colorMode: "none",
        unit: "%",
        unitPosition: "after",
        underLabel: "Skipping search",
        managerid: "searchSingleSkipPct",
        el: $("#elementSingleSkipPctWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleSkipPctWlk = new ResultsLinkView({
      id: "resultsLinkelementSingleSkipPctWlk",
      managerid: "searchSingleSkipPct",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSkipPctWlk"),
    });

    resultsLinkelementSingleSkipPctWlk
      .render()
      .$el.appendTo($("resultsLinkelementSingleSkipPctWlk"));

    var elementSingleElapsedWlk = new SingleView(
      {
        id: "elementSingleElapsedWlk",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        "trellis.enabled": "0",
        colorMode: "none",
        underLabel: "Average elapsed duration",
        managerid: "searchSingleElapsed",
        el: $("#elementSingleElapsedWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleElapsedWlk = new ResultsLinkView({
      id: "resultsLinkelementSingleElapsedWlk",
      managerid: "searchSingleElapsed",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleElapsedWlk"),
    });

    resultsLinkelementSingleElapsedWlk
      .render()
      .$el.appendTo($("resultsLinkelementSingleElapsedWlk"));

    var elementSingleSLApctWlk = new SingleView(
      {
        id: "elementSingleSLApctWlk",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "all",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "%",
        rangeColors: '["0xdc4e41","0xf1813f","0x45D4BA"]',
        colorMode: "none",
        rangeValues: "[50,90]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useColors: "1",
        useThousandSeparators: "1",
        underLabel: "SLA PCT (% time spent in green/blue over 90d)",
        managerid: "searchSingleSLApctWlk",
        el: $("#elementSingleSLApctWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleSLApctWlk = new ResultsLinkView({
      id: "resultsLinkelementSingleSLApctWlk",
      managerid: "searchSingleSLApctWlk",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSLApctWlk"),
    });

    resultsLinkelementSingleSLApctWlk
      .render()
      .$el.appendTo($("resultsLinkelementSingleSLApctWlk"));

    elementSingleSLApctWlk.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        var url =
          "/app/trackme/trackMe_sla?form.tk_tenant_id=" +
          encodeURI(getToken("tenant_id")) +
          "&form.tk_object_category=splk-wlk&form.tk_object=" +
          encodeURI(getToken("tk_object"));
        utils.redirect(url, false, "_blank");
      }
    });

    // chart
    var elementChartSplkWlkMetrics = new ChartView(
      {
        id: "elementChartSplkWlkMetrics",
        "charting.chart.nullValueMode": "gaps",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.drilldown": "none",
        "charting.chart.showDataLabels": "none",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisY2.enabled": "1",
        "charting.axisY2.scale": "inherit",
        "trellis.scales.shared": "1",
        resizable: true,
        "charting.legend.placement": "right",
        "charting.chart": "$tk_input_splk_wlk_chartmode_dropdown$",
        managerid: "searchChartSplkWlk",
        el: $("#elementChartSplkWlkMetrics"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartSplkWlkMetrics = new ResultsLinkView({
      id: "resultsLinkelementChartSplkWlkMetrics",
      managerid: "searchChartSplkWlk",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartSplkWlkMetrics"),
    });

    resultsLinkelementChartSplkWlkMetrics
      .render()
      .$el.appendTo($("resultsLinkelementChartSplkWlkMetrics"));

    //
    // Machine Learning Outliers detection
    //

    //
    // splk-dsm
    //

    //
    // model_id dropdown
    //

    // Populating search
    var searchPopulateSplkDsmOutliersModels = new SearchManager(
      {
        id: "searchPopulateSplkDsmOutliersModels",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="dsm" object="$tk_object$" | where is_disabled=0 | stats count by model_id, kpi_metric | eval model_desc = kpi_metric . ":" . model_id | sort 0 model_desc | fields model_desc, model_id',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
          depends: "$show_splk_dsm_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_dsm_outliers_model_id_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_dsm_outliers_model_id_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "model_desc",
        selectFirstChoice: true,
        width: 500,
        valueField: "model_id",
        value: "$form.tk_input_splk_dsm_outliers_model_id_dropdown$",
        managerid: "searchPopulateSplkDsmOutliersModels",
        el: $("#modal_input_splk_dsm_outliers_model_id_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dsm_outliers_model_id_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_model_id_dropdown
        );
      }
    );

    var searchOutlierDetectionChartDsm = new SearchManager(
      {
        id: "searchOutlierDetectionChartDsm",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="dsm" object="$tk_object$" model_id="$tk_input_splk_dsm_outliers_model_id_dropdown$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: true,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
          depends: "$show_splk_dsm_outlier$",
          depends: "$tk_outliers_readiness$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartDsm.on("search:start", function (properties) {
      // hide at start
      $("#elementOutliersNoResultsDsm").css("display", "none");
      // show at start
      $("#elementOutlierLoaderDsm").css("display", "inherit");
    });

    searchOutlierDetectionChartDsm.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        // show no result message if we have no events returned
        // hide loader
        $("#elementOutlierLoaderDsm").css("display", "none");
        // try to show chart and results link
        $("#elementOutlierDsm").css("display", "inherit");
        $("#resultsLinkelementOutlierDsm").css("display", "inherit");
        // show no results
        $("#elementOutliersNoResultsDsm").css("display", "inherit");
      } else {
        // hide loader
        $("#elementOutlierLoaderDsm").css("display", "none");
        // show chart and results link
        $("#elementOutlierDsm").css("display", "inherit");
        $("#resultsLinkelementOutlierDsm").css("display", "inherit");
        // hide no results
        $("#elementOutliersNoResultsDsm").css("display", "none");
      }
    });

    //
    // Setting screen
    //

    // Populating search
    var searchPopulateSplkDsmOutliersModelsSettings = new SearchManager(
      {
        id: "searchPopulateSplkDsmOutliersModelsSettings",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="dsm" object="$tk_object$" | where is_disabled=0 | stats count by kpi_metric, model_id | eval label=kpi_metric . ":" . model_id, value=model_id | sort 0 label | fields label, value',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
          depends: "$show_splk_dsm_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_dsm_outliers_model_id_settings_dropdown =
      new DropdownInput(
        {
          id: "modal_input_splk_dsm_outliers_model_id_settings_dropdown",
          searchWhenChanged: true,
          showClearButton: true,
          labelField: "label",
          selectFirstChoice: true,
          width: 350,
          valueField: "value",
          value: "$form.tk_input_splk_dsm_outliers_model_id_settings_dropdown$",
          managerid: "searchPopulateSplkDsmOutliersModelsSettings",
          el: $("#modal_input_splk_dsm_outliers_model_id_settings_dropdown"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_model_id_settings_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_model_id_settings_dropdown
        );
      }
    );

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkDsmTime = new LinkListInput(
      {
        id: "inputOutliersSplkDsmTime",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkDsmTime$",
        el: $("#inputOutliersSplkDsmTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkDsmTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkDsmTime);
    });

    inputOutliersSplkDsmTime.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkDsmTime.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDsmTime.latest", "now", {}, e.data);
      }
    });

    //
    // ML Outliers detection
    //

    // splk-dsm

    var searchOutlierDetectionChartSimulationDsm = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationDsm",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="dsm" object="$tk_object$" model_id="$tk_input_splk_dsm_outliers_model_id_settings_dropdown$" mode="simulation" model_json_def="$tk_splk_dsm_simulation_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkDsmTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkDsmTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
          depends: "$show_splk_dsm_outlier$",
          depends: "$start_outliers_simulation_splk_dsm$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationDsm.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkDsmNoResultsSimulate").css("display", "none");
        // show at start
        $("#elementOutlierLoaderSimulateDsm").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationDsm.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateDsm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDsmNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationDsm.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateDsm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDsmNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationDsm.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderSimulateDsm").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierSimulationDsm").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationDsm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDsmTime").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkDsmNoResultsSimulate").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderSimulateDsm").css("display", "none");
          // show chart and results link
          $("#elementOutlierSimulationDsm").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationDsm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDsmTime").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkDsmNoResultsSimulate").css("display", "none");
        }
      }
    );

    //
    // splk-flx
    //

    //
    // model_id dropdown
    //

    // Populating search
    var searchPopulateSplkFlxOutliersModels = new SearchManager(
      {
        id: "searchPopulateSplkFlxOutliersModels",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="flx" object="$tk_object$" | where is_disabled=0 | stats count by model_id, kpi_metric | eval model_desc = kpi_metric . ":" . model_id | sort 0 model_desc | fields model_desc, model_id',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
          depends: "$show_splk_flx_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_flx_outliers_model_id_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_flx_outliers_model_id_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "model_desc",
        selectFirstChoice: true,
        width: 500,
        valueField: "model_id",
        value: "$form.tk_input_splk_flx_outliers_model_id_dropdown$",
        managerid: "searchPopulateSplkFlxOutliersModels",
        el: $("#modal_input_splk_flx_outliers_model_id_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_outliers_model_id_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_model_id_dropdown
        );
      }
    );

    var searchOutlierDetectionChartFlx = new SearchManager(
      {
        id: "searchOutlierDetectionChartFlx",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="flx" object="$tk_object$" model_id="$tk_input_splk_flx_outliers_model_id_dropdown$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeSplkFlx.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: true,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
          depends: "$show_splk_flx_outlier$",
          depends: "$tk_outliers_readiness$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartFlx.on("search:start", function (properties) {
      // hide at start
      $("#elementOutliersNoResultsFlx").css("display", "none");
      // show at start
      $("#elementOutlierLoaderFlx").css("display", "inherit");
    });

    searchOutlierDetectionChartFlx.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        // show no result message if we have no events returned
        // hide loader
        $("#elementOutlierLoaderFlx").css("display", "none");
        // try to show chart and results link
        $("#elementOutlierFlx").css("display", "inherit");
        $("#resultsLinkelementOutlierFlx").css("display", "inherit");
        // show no results
        $("#elementOutliersNoResultsFlx").css("display", "inherit");
      } else {
        // hide loader
        $("#elementOutlierLoaderFlx").css("display", "none");
        // show chart and results link
        $("#elementOutlierFlx").css("display", "inherit");
        $("#resultsLinkelementOutlierFlx").css("display", "inherit");
        // hide no results
        $("#elementOutliersNoResultsFlx").css("display", "none");
      }
    });

    //
    // Setting screen
    //

    // Populating search
    var searchPopulateSplkFlxOutliersModelsSettings = new SearchManager(
      {
        id: "searchPopulateSplkFlxOutliersModelsSettings",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="flx" object="$tk_object$" | where is_disabled=0 | stats count by kpi_metric, model_id | eval label=kpi_metric . ":" . model_id, value=model_id | sort 0 label | fields label, value',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
          depends: "$show_splk_flx_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_flx_outliers_model_id_settings_dropdown =
      new DropdownInput(
        {
          id: "modal_input_splk_flx_outliers_model_id_settings_dropdown",
          searchWhenChanged: true,
          showClearButton: true,
          labelField: "label",
          selectFirstChoice: true,
          width: 350,
          valueField: "value",
          value: "$form.tk_input_splk_flx_outliers_model_id_settings_dropdown$",
          managerid: "searchPopulateSplkFlxOutliersModelsSettings",
          el: $("#modal_input_splk_flx_outliers_model_id_settings_dropdown"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_model_id_settings_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_model_id_settings_dropdown
        );
      }
    );

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkFlxTime = new LinkListInput(
      {
        id: "inputOutliersSplkFlxTime",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkFlxTime$",
        el: $("#inputOutliersSplkFlxTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkFlxTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkFlxTime);
    });

    inputOutliersSplkFlxTime.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkFlxTime.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkFlxTime.latest", "now", {}, e.data);
      }
    });

    //
    // ML Outliers detection
    //

    // splk-flx

    var searchOutlierDetectionChartSimulationFlx = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationFlx",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="flx" object="$tk_object$" model_id="$tk_input_splk_flx_outliers_model_id_settings_dropdown$" mode="simulation" model_json_def="$tk_splk_flx_simulation_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkFlxTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkFlxTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
          depends: "$show_splk_flx_outlier$",
          depends: "$start_outliers_simulation_splk_flx$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationFlx.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkFlxNoResultsSimulate").css("display", "none");
        // show at start
        $("#elementOutlierLoaderSimulateFlx").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationFlx.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateFlx").css("display", "none");
        // show no results
        $("#elementOutliersSplkFlxNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationFlx.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateFlx").css("display", "none");
        // show no results
        $("#elementOutliersSplkFlxNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationFlx.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderSimulateFlx").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierSimulationFlx").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationFlx").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkFlxTime").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkFlxNoResultsSimulate").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderSimulateFlx").css("display", "none");
          // show chart and results link
          $("#elementOutlierSimulationFlx").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationFlx").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkFlxTime").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkFlxNoResultsSimulate").css("display", "none");
        }
      }
    );

    //
    // splk-wlk
    //

    //
    // model_id dropdown
    //

    // Populating search
    var searchPopulateSplkWlkOutliersModels = new SearchManager(
      {
        id: "searchPopulateSplkWlkOutliersModels",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="wlk" object="$tk_object$" | where is_disabled=0 | stats count by model_id, kpi_metric | eval model_desc = kpi_metric . ":" . model_id | sort 0 model_desc | fields model_desc, model_id',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
          depends: "$show_splk_wlk_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_wlk_outliers_model_id_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_wlk_outliers_model_id_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "model_desc",
        selectFirstChoice: true,
        width: 500,
        valueField: "model_id",
        value: "$form.tk_input_splk_wlk_outliers_model_id_dropdown$",
        managerid: "searchPopulateSplkWlkOutliersModels",
        el: $("#modal_input_splk_wlk_outliers_model_id_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_outliers_model_id_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_model_id_dropdown
        );
      }
    );

    var searchOutlierDetectionChartWlk = new SearchManager(
      {
        id: "searchOutlierDetectionChartWlk",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="wlk" object="$tk_object$" model_id="$tk_input_splk_wlk_outliers_model_id_dropdown$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeSplkWlk.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: true,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
          depends: "$show_splk_wlk_outlier$",
          depends: "$tk_outliers_readiness$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartWlk.on("search:start", function (properties) {
      // hide at start
      $("#elementOutliersNoResultsWlk").css("display", "none");
      // show at start
      $("#elementOutlierLoaderWlk").css("display", "inherit");
    });

    searchOutlierDetectionChartWlk.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        // show no result message if we have no events returned
        // hide loader
        $("#elementOutlierLoaderWlk").css("display", "none");
        // try to show chart and results link
        $("#elementOutlierWlk").css("display", "inherit");
        $("#resultsLinkelementOutlierWlk").css("display", "inherit");
        // show no results
        $("#elementOutliersNoResultsWlk").css("display", "inherit");
      } else {
        // hide loader
        $("#elementOutlierLoaderWlk").css("display", "none");
        // show chart and results link
        $("#elementOutlierWlk").css("display", "inherit");
        $("#resultsLinkelementOutlierWlk").css("display", "inherit");
        // hide no results
        $("#elementOutliersNoResultsWlk").css("display", "none");
      }
    });

    //
    // Setting screen
    //

    // Populating search
    var searchPopulateSplkWlkOutliersModelsSettings = new SearchManager(
      {
        id: "searchPopulateSplkWlkOutliersModelsSettings",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="wlk" object="$tk_object$" | where is_disabled=0 | stats count by kpi_metric, model_id | eval label=kpi_metric . ":" . model_id, value=model_id | sort 0 label | fields label, value',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
          depends: "$show_splk_wlk_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_wlk_outliers_model_id_settings_dropdown =
      new DropdownInput(
        {
          id: "modal_input_splk_wlk_outliers_model_id_settings_dropdown",
          searchWhenChanged: true,
          showClearButton: true,
          labelField: "label",
          selectFirstChoice: true,
          width: 350,
          valueField: "value",
          value: "$form.tk_input_splk_wlk_outliers_model_id_settings_dropdown$",
          managerid: "searchPopulateSplkWlkOutliersModelsSettings",
          el: $("#modal_input_splk_wlk_outliers_model_id_settings_dropdown"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_model_id_settings_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_model_id_settings_dropdown
        );
      }
    );

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkWlkTime = new LinkListInput(
      {
        id: "inputOutliersSplkWlkTime",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkWlkTime$",
        el: $("#inputOutliersSplkWlkTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkWlkTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkWlkTime);
    });

    inputOutliersSplkWlkTime.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkWlkTime.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkWlkTime.latest", "now", {}, e.data);
      }
    });

    //
    // ML Outliers detection
    //

    // splk-wlk

    var searchOutlierDetectionChartSimulationWlk = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationWlk",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="wlk" object="$tk_object$" model_id="$tk_input_splk_wlk_outliers_model_id_settings_dropdown$" mode="simulation" model_json_def="$tk_splk_wlk_simulation_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkWlkTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkWlkTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
          depends: "$show_splk_wlk_outlier$",
          depends: "$start_outliers_simulation_splk_wlk$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationWlk.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkWlkNoResultsSimulate").css("display", "none");
        // show at start
        $("#elementOutlierLoaderSimulateWlk").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationWlk.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateWlk").css("display", "none");
        // show no results
        $("#elementOutliersSplkWlkNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationWlk.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateWlk").css("display", "none");
        // show no results
        $("#elementOutliersSplkWlkNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationWlk.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderSimulateWlk").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierSimulationWlk").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationWlk").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkWlkTime").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkWlkNoResultsSimulate").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderSimulateWlk").css("display", "none");
          // show chart and results link
          $("#elementOutlierSimulationWlk").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationWlk").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkWlkTime").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkWlkNoResultsSimulate").css("display", "none");
        }
      }
    );

    //
    // splk-cim
    //

    //
    // entity dropdown
    //

    // Populating search (list existing models)
    var searchPopulateSplkCimOutliersCimEntities = new SearchManager(
      {
        id: "searchPopulateSplkCimOutliersCimEntities",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutlierscimgetrules tenant_id="$tenant_id$" component="cim" object="$tk_object$" entity=* cim_field=* | stats count by object, entity, cim_field',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Populating search (add new model)
    var searchPopulateSplkCimOutliersAddCimEntities = new SearchManager(
      {
        id: "searchPopulateSplkCimOutliersAddCimEntities",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| inputlookup trackme_cim_tenant_$tenant_id$ where object="$tk_object$" | spath input=cim_tracking_rules path=cim_fields | spath input=cim_tracking_results path=cim_entities | fields object, cim_fields, cim_entities | makemv cim_fields delim="," | makemv cim_entities delim="," | mvexpand cim_fields | mvexpand cim_entities | rename cim_entities as entity, cim_fields as cim_field | stats c by object, entity, cim_field',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    //
    // cim_field dropdown
    //

    // Populating search
    var searchPopulateSplkCimOutliersCimFields = new SearchManager(
      {
        id: "searchPopulateSplkCimOutliersCimFields",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutlierscimgetrules tenant_id="$tenant_id$" component="cim" object="$tk_object$" entity=* cim_field=* | stats count by object, entity, cim_field',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Populating search (add new model)
    var searchPopulateSplkCimOutliersAddCimFields = new SearchManager(
      {
        id: "searchPopulateSplkCimOutliersAddCimFields",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| inputlookup trackme_cim_tenant_$tenant_id$ where object="$tk_object$" | spath input=cim_tracking_rules path=cim_fields | spath input=cim_tracking_results path=cim_entities | fields object, cim_fields, cim_entities | makemv cim_fields delim="," | makemv cim_entities delim="," | mvexpand cim_fields | mvexpand cim_entities | rename cim_entities as entity, cim_fields as cim_field | search entity="$input_splk_cim_outliers_add_model_entity$" | stats c by object, entity, cim_field',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    //
    // model_id dropdown
    //

    // Populating search
    var searchPopulateSplkCimOutliersModels = new SearchManager(
      {
        id: "searchPopulateSplkCimOutliersModels",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutlierscimgetrules tenant_id="$tenant_id$" component="cim" object="$tk_object$" entity="$tk_input_splk_cim_outliers_cim_entity_dropdown$" cim_field="$tk_input_splk_cim_outliers_cim_field_dropdown$" | where is_disabled=0 | stats count by model_id, kpi_metric | eval model_desc = kpi_metric . ":" . model_id | sort 0 model_desc | fields model_desc, model_id | sort - model_desc',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object

    var modal_input_splk_cim_outliers_cim_entity_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_cim_entity_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "entity",
        selectFirstChoice: true,
        width: 300,
        valueField: "entity",
        value: "$form.tk_input_splk_cim_outliers_cim_entity_dropdown$",
        managerid: "searchPopulateSplkCimOutliersCimEntities",
        el: $("#modal_input_splk_cim_outliers_cim_entity_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_cim_entity_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_cim_entity_dropdown
        );
      }
    );

    var modal_input_splk_cim_outliers_cim_field_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_cim_field_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "cim_field",
        selectFirstChoice: true,
        width: 300,
        valueField: "cim_field",
        value: "$form.tk_input_splk_cim_outliers_cim_field_dropdown$",
        managerid: "searchPopulateSplkCimOutliersCimFields",
        el: $("#modal_input_splk_cim_outliers_cim_field_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_cim_field_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_cim_field_dropdown
        );
      }
    );

    var modal_input_splk_cim_outliers_model_id_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_model_id_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "model_desc",
        selectFirstChoice: true,
        width: 550,
        valueField: "model_id",
        value: "$form.tk_input_splk_cim_outliers_model_id_dropdown$",
        managerid: "searchPopulateSplkCimOutliersModels",
        el: $("#modal_input_splk_cim_outliers_model_id_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_model_id_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_model_id_dropdown
        );
      }
    );

    var searchOutlierDetectionChartCim = new SearchManager(
      {
        id: "searchOutlierDetectionChartCim",
        sample_ratio: 1,
        search:
          '| trackmesplkoutlierscimrender tenant_id="$tenant_id$" component="cim" object="$tk_object$" earliest="$modalTimeCim.earliest$" latest="$modalTimeCim.latest$" entity="$tk_input_splk_cim_outliers_cim_entity_dropdown$" cim_field="$tk_input_splk_cim_outliers_cim_field_dropdown$" model_id="$tk_input_splk_cim_outliers_model_id_dropdown$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeCim.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: true,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
          depends: "$tk_outliers_readiness$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartCim.on("search:start", function (properties) {
      // hide at start
      $("#elementOutliersNoResultsCim").css("display", "none");
      // show at start
      $("#elementOutlierLoaderCim").css("display", "inherit");
    });

    searchOutlierDetectionChartCim.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;

      if (eventCount == 0) {
        // show no result message if we have no events returned
        // hide loader
        $("#elementOutlierLoaderCim").css("display", "none");
        // try to show chart and results link
        $("#elementOutlierCim").css("display", "inherit");
        $("#resultsLinkelementOutlierCim").css("display", "inherit");
        // show no results
        $("#elementOutliersNoResultsCim").css("display", "inherit");
      } else {
        // hide loader
        $("#elementOutlierLoaderCim").css("display", "none");
        // show chart and results link
        $("#elementOutlierCim").css("display", "inherit");
        $("#resultsLinkelementOutlierCim").css("display", "inherit");
        // hide no results
        $("#elementOutliersNoResultsCim").css("display", "none");
      }
    });

    //
    // Setting screen
    //

    // Populating search

    var searchPopulateSplkCimOutliersCimFieldsSettings = new SearchManager(
      {
        id: "searchPopulateSplkCimOutliersCimFieldsSettings",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| inputlookup trackme_cim_outliers_entity_rules_tenant_$tenant_id$ where object="$tk_object$" | stats count by cim_field | sort 0 cim_field | fields cim_field',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateSplkCimOutliersModelsSettings = new SearchManager(
      {
        id: "searchPopulateSplkCimOutliersModelsSettings",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutlierscimgetrules tenant_id="$tenant_id$" component="cim" object="$tk_object$" entity=* cim_field=* | where is_disabled=0 | stats count by entity, cim_field, kpi_metric, model_id | eval label=entity . ":" . cim_field . ":" . kpi_metric . ":" . model_id, value=model_id | sort 0 label | fields label, value',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object

    var modal_input_splk_cim_outliers_cim_field_settings_dropdown =
      new DropdownInput(
        {
          id: "modal_input_splk_cim_outliers_cim_field_settings_dropdown",
          searchWhenChanged: true,
          showClearButton: true,
          labelField: "cim_field",
          selectFirstChoice: true,
          width: 300,
          valueField: "cim_field",
          value:
            "$form.tk_input_splk_cim_outliers_cim_field_settings_dropdown$",
          managerid: "searchPopulateSplkCimOutliersCimFieldsSettings",
          el: $("#modal_input_splk_cim_outliers_cim_field_settings_dropdown"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_cim_field_settings_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_cim_field_settings_dropdown
        );
      }
    );

    var modal_input_splk_cim_outliers_model_id_settings_dropdown =
      new DropdownInput(
        {
          id: "modal_input_splk_cim_outliers_model_id_settings_dropdown",
          searchWhenChanged: true,
          showClearButton: true,
          labelField: "label",
          selectFirstChoice: true,
          width: 350,
          valueField: "value",
          value: "$form.tk_input_splk_cim_outliers_model_id_settings_dropdown$",
          managerid: "searchPopulateSplkCimOutliersModelsSettings",
          el: $("#modal_input_splk_cim_outliers_model_id_settings_dropdown"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_model_id_settings_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_model_id_settings_dropdown
        );
      }
    );

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkCimTime = new LinkListInput(
      {
        id: "inputOutliersSplkCimTime",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkCimTime$",
        el: $("#inputOutliersSplkCimTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkCimTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkCimTime);
    });

    inputOutliersSplkCimTime.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkCimTime.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkCimTime.latest", "now", {}, e.data);
      }
    });

    //
    // ML Outliers detection
    //

    // splk-cim

    var searchOutlierDetectionChartSimulationCim = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationCim",
        sample_ratio: 1,
        search:
          '| trackmesplkoutlierscimrender tenant_id="$tenant_id$" component="cim" object="$tk_object$" earliest="$OutliersSplkCimTime.earliest$" latest="$OutliersSplkCimTime.latest$" model_id="$tk_input_splk_cim_outliers_model_id_settings_dropdown$" entity="noop" cim_field="$tk_input_splk_cim_outliers_cim_field_settings_dropdown$" mode="simulation" model_json_def="$tk_splk_cim_simulation_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkCimTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkCimTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
          depends: "$start_outliers_simulation_splk_cim$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationCim.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkCimNoResultsSimulate").css("display", "none");
        // show at start
        $("#elementOutlierLoaderSimulateCim").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationCim.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateCim").css("display", "none");
        // show no results
        $("#elementOutliersSplkCimNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationCim.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateCim").css("display", "none");
        // show no results
        $("#elementOutliersSplkCimNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationCim.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderSimulateCim").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierSimulationCim").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationCim").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkCimTime").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkCimNoResultsSimulate").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderSimulateCim").css("display", "none");
          // show chart and results link
          $("#elementOutlierSimulationCim").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationCim").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkCimTime").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkCimNoResultsSimulate").css("display", "none");
        }
      }
    );

    //
    // splk-dhm
    //

    //
    // model_id dropdown
    //

    // Populating search
    var searchPopulateSplkDhmOutliersModels = new SearchManager(
      {
        id: "searchPopulateSplkDhmOutliersModels",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="dhm" object="$tk_object$" | where is_disabled=0 | stats count by model_id, kpi_metric | eval model_desc = kpi_metric . ":" . model_id | sort 0 model_desc | fields model_desc, model_id',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
          depends: "$show_splk_dhm_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_dhm_outliers_model_id_dropdown = new DropdownInput(
      {
        id: "modal_input_splk_dhm_outliers_model_id_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "model_desc",
        selectFirstChoice: true,
        width: 500,
        valueField: "model_id",
        value: "$form.tk_input_splk_dhm_outliers_model_id_dropdown$",
        managerid: "searchPopulateSplkDhmOutliersModels",
        el: $("#modal_input_splk_dhm_outliers_model_id_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dhm_outliers_model_id_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_model_id_dropdown
        );
      }
    );

    var searchOutlierDetectionChartDhm = new SearchManager(
      {
        id: "searchOutlierDetectionChartDhm",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="dhm" object="$tk_object$" model_id="$tk_input_splk_dhm_outliers_model_id_dropdown$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeHost.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: true,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
          depends: "$show_splk_dhm_outlier$",
          depends: "$tk_outliers_readiness$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartDhm.on("search:start", function (properties) {
      // hide at start
      $("#elementOutliersNoResultsDhm").css("display", "none");
      // show at start
      $("#elementOutlierLoaderDhm").css("display", "inherit");
    });

    searchOutlierDetectionChartDhm.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        // show no result message if we have no events returned
        // hide loader
        $("#elementOutlierLoaderDhm").css("display", "none");
        // try to show chart and results link
        $("#elementOutlierDhm").css("display", "inherit");
        $("#resultsLinkelementOutlierDhm").css("display", "inherit");
        // show no results
        $("#elementOutliersNoResultsDhm").css("display", "inherit");
      } else {
        // hide loader
        $("#elementOutlierLoaderDhm").css("display", "none");
        // show chart and results link
        $("#elementOutlierDhm").css("display", "inherit");
        $("#resultsLinkelementOutlierDhm").css("display", "inherit");
        // hide no results
        $("#elementOutliersNoResultsDhm").css("display", "none");
      }
    });

    //
    // Setting screen
    //

    // Populating search
    var searchPopulateSplkDhmOutliersModelsSettings = new SearchManager(
      {
        id: "searchPopulateSplkDhmOutliersModelsSettings",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: true,
        search:
          '| trackmesplkoutliersgetrules tenant_id="$tenant_id$" component="dhm" object="$tk_object$" | where is_disabled=0 | stats count by kpi_metric, model_id | eval label=kpi_metric . ":" . model_id, value=model_id | sort 0 label | fields label, value',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
          depends: "$show_splk_dhm_outlier$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Dropdown object
    var modal_input_splk_dhm_outliers_model_id_settings_dropdown =
      new DropdownInput(
        {
          id: "modal_input_splk_dhm_outliers_model_id_settings_dropdown",
          searchWhenChanged: true,
          showClearButton: true,
          labelField: "label",
          selectFirstChoice: true,
          width: 350,
          valueField: "value",
          value: "$form.tk_input_splk_dhm_outliers_model_id_settings_dropdown$",
          managerid: "searchPopulateSplkDhmOutliersModelsSettings",
          el: $("#modal_input_splk_dhm_outliers_model_id_settings_dropdown"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_model_id_settings_dropdown.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_model_id_settings_dropdown
        );
      }
    );

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkDhmTime = new LinkListInput(
      {
        id: "inputOutliersSplkDhmTime",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkDhmTime$",
        el: $("#inputOutliersSplkDhmTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkDhmTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkDhmTime);
    });

    inputOutliersSplkDhmTime.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkDhmTime.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken("OutliersSplkDhmTime.latest", "now", {}, e.data);
      }
    });

    var searchOutlierDetectionChartSimulationDhm = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationDhm",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="dhm" object="$tk_object$" model_id="$tk_input_splk_dhm_outliers_model_id_settings_dropdown$" mode="simulation" model_json_def="$tk_splk_dhm_simulation_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkDhmTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkDhmTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
          depends: "$show_splk_dhm_outlier$",
          depends: "$start_outliers_simulation_splk_dhm$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationDhm.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkDhmNoResultsSimulate").css("display", "none");
        // show at start
        $("#elementOutlierLoaderSimulateDhm").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationDhm.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateDhm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDhmNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationDhm.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderSimulateDhm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDhmNoResultsSimulate").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationDhm.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderSimulateDhm").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierSimulationDhm").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationDhm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDhmTime").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkDhmNoResultsSimulate").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderSimulateDhm").css("display", "none");
          // show chart and results link
          $("#elementOutlierSimulationDhm").css("display", "inherit");
          $("#resultsLinkelementOutlierSimulationDhm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDhmTime").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkDhmNoResultsSimulate").css("display", "none");
        }
      }
    );

    //
    // splk-dsm: auto lagging
    //

    // 7 days

    var searchSingleLagAutoLaggingSplkDsm7d = new SearchManager(
      {
        id: "searchSingleLagAutoLaggingSplkDsm7d",
        sample_ratio: 1,
        search:
          "| mstats avg(trackme.splk.feeds.lag_event_sec) as avg_delay, perc95(trackme.splk.feeds.lag_event_sec) as perc95_delay, avg(trackme.splk.feeds.avg_latency_5m) as avg_latency, avg(trackme.splk.feeds.perc95_latency_5m) as perc95_latency where `trackme_metrics_idx($tenant_id$)` tenant_id=\"$tenant_id$\" object_category=\"splk-dsm\" object=\"$tk_object$\" | foreach avg_delay, perc95_delay [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | foreach avg_latency, perc95_latency [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | fields avg_delay, perc95_delay, avg_latency, perc95_latency | trackmegenjsonmetrics fields=\"avg_delay,perc95_delay,avg_latency,perc95_latency\" | fields metrics, *",
        status_buckets: 0,
        earliest_time: "-7d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_autolagging$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSingleLagAutoLaggingSplkDsm7d
      .data("results", { count: 0, output_mode: "json_rows" })
      .on("data", function (data) {
        setToken("tk_7d_metrics", data._data["rows"][0][0]);
      });

    var searchSingleLagAutoLaggingSplkDsm7dSingleLagPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_latency | eval perc95_latency = round(perc95_latency, 0) . " sec (" . tostring(perc95_latency, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDsm7d",
          id: "searchSingleLagAutoLaggingSplkDsm7dSingleLagPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleLagAutoLaggingSplkDsm7dSingleLagAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields avg_latency | eval avg_latency = round(avg_latency, 0) . " sec (" . tostring(avg_latency, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDsm7d",
          id: "searchSingleLagAutoLaggingSplkDsm7dSingleLagAvg",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDsm7dSingleDelayPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_delay | eval perc95_delay = round(perc95_delay, 0) . " sec (" . tostring(perc95_delay, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDsm7d",
          id: "searchSingleDelayAutoLaggingSplkDsm7dSingleDelayPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDsm7dSingleDelayAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields avg_delay | eval avg_delay = round(avg_delay, 0) . " sec (" . tostring(avg_delay, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDsm7d",
          id: "searchSingleDelayAutoLaggingSplkDsm7dSingleDelayAvg",
        },
        {
          tokens: true,
        }
      );

    // 30 days

    var searchDsmSingleLag30dAutoLagging = new SearchManager(
      {
        id: "searchDsmSingleLag30dAutoLagging",
        sample_ratio: 1,
        search:
          "| mstats avg(trackme.splk.feeds.lag_event_sec) as avg_delay, perc95(trackme.splk.feeds.lag_event_sec) as perc95_delay, avg(trackme.splk.feeds.avg_latency_5m) as avg_latency, avg(trackme.splk.feeds.perc95_latency_5m) as perc95_latency where `trackme_metrics_idx($tenant_id$)` tenant_id=\"$tenant_id$\" object_category=\"splk-dsm\" object=\"$tk_object$\" | foreach avg_delay, perc95_delay [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | foreach avg_latency, perc95_latency [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | trackmegenjsonmetrics fields=\"avg_delay,perc95_delay,avg_latency,perc95_latency\" | fields metrics, *",
        status_buckets: 0,
        earliest_time: "-30d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_autolagging$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchDsmSingleLag30dAutoLagging
      .data("results", { count: 0, output_mode: "json_rows" })
      .on("data", function (data) {
        setToken("tk_30d_metrics", data._data["rows"][0][0]);
      });

    var searchSingleLagAutoLaggingSplkDsm30dSingleLagPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_latency | eval perc95_latency = round(perc95_latency, 0) . " sec (" . tostring(perc95_latency, "duration") . ")"',
          managerid: "searchDsmSingleLag30dAutoLagging",
          id: "searchSingleLagAutoLaggingSplkDsm30dSingleLagPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleLagAutoLaggingSplkDsm30dSingleLagAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_latency | eval perc95_latency = round(perc95_latency, 0) . " sec (" . tostring(perc95_latency, "duration") . ")"',
          managerid: "searchDsmSingleLag30dAutoLagging",
          id: "searchSingleLagAutoLaggingSplkDsm30dSingleLagAvg",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDsm30dSingleDelayPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_delay | eval perc95_delay = round(perc95_delay, 0) . " sec (" . tostring(perc95_delay, "duration") . ")"',
          managerid: "searchDsmSingleLag30dAutoLagging",
          id: "searchSingleDelayAutoLaggingSplkDsm30dSingleDelayPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDsm30dSingleDelayAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields avg_delay | eval avg_delay = round(avg_delay, 0) . " sec (" . tostring(avg_delay, "duration") . ")"',
          managerid: "searchDsmSingleLag30dAutoLagging",
          id: "searchSingleDelayAutoLaggingSplkDsm30dSingleDelayAvg",
        },
        {
          tokens: true,
        }
      );

    //
    // splk-dhm: auto lagging
    //

    // 7 days

    var searchSingleLagAutoLaggingSplkDhm7d = new SearchManager(
      {
        id: "searchSingleLagAutoLaggingSplkDhm7d",
        sample_ratio: 1,
        search:
          "| mstats avg(trackme.splk.feeds.lag_event_sec) as avg_delay, perc95(trackme.splk.feeds.lag_event_sec) as perc95_delay, avg(trackme.splk.feeds.avg_latency_5m) as avg_latency, avg(trackme.splk.feeds.perc95_latency_5m) as perc95_latency where `trackme_metrics_idx($tenant_id$)` tenant_id=\"$tenant_id$\" object_category=\"splk-dhm\" object=\"$tk_object$\" | foreach avg_delay, perc95_delay [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | foreach avg_latency, perc95_latency [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | fields avg_delay, perc95_delay, avg_latency, perc95_latency | trackmegenjsonmetrics fields=\"avg_delay,perc95_delay,avg_latency,perc95_latency\" | fields metrics, *",
        status_buckets: 0,
        earliest_time: "-7d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_autolagging$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSingleLagAutoLaggingSplkDhm7d
      .data("results", { count: 0, output_mode: "json_rows" })
      .on("data", function (data) {
        setToken("tk_7d_metrics", data._data["rows"][0][0]);
      });

    var searchSingleLagAutoLaggingSplkDhm7dSingleLagPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_latency | eval perc95_latency = round(perc95_latency, 0) . " sec (" . tostring(perc95_latency, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDhm7d",
          id: "searchSingleLagAutoLaggingSplkDhm7dSingleLagPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleLagAutoLaggingSplkDhm7dSingleLagAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields avg_latency | eval avg_latency = round(avg_latency, 0) . " sec (" . tostring(avg_latency, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDhm7d",
          id: "searchSingleLagAutoLaggingSplkDhm7dSingleLagAvg",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDhm7dSingleDelayPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_delay | eval perc95_delay = round(perc95_delay, 0) . " sec (" . tostring(perc95_delay, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDhm7d",
          id: "searchSingleDelayAutoLaggingSplkDhm7dSingleDelayPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDhm7dSingleDelayAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields avg_delay | eval avg_delay = round(avg_delay, 0) . " sec (" . tostring(avg_delay, "duration") . ")"',
          managerid: "searchSingleLagAutoLaggingSplkDhm7d",
          id: "searchSingleDelayAutoLaggingSplkDhm7dSingleDelayAvg",
        },
        {
          tokens: true,
        }
      );

    // 30 days

    var searchDhmSingleLag30dAutoLagging = new SearchManager(
      {
        id: "searchDhmSingleLag30dAutoLagging",
        sample_ratio: 1,
        search:
          "| mstats avg(trackme.splk.feeds.lag_event_sec) as avg_delay, perc95(trackme.splk.feeds.lag_event_sec) as perc95_delay, avg(trackme.splk.feeds.avg_latency_5m) as avg_latency, avg(trackme.splk.feeds.perc95_latency_5m) as perc95_latency where `trackme_metrics_idx($tenant_id$)` tenant_id=\"$tenant_id$\" object_category=\"splk-dhm\" object=\"$tk_object$\" | foreach avg_delay, perc95_delay [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | foreach avg_latency, perc95_latency [ eval <<FIELD>> = if('<<FIELD>>'<600, 600, round('<<FIELD>>', 0)) ] | trackmegenjsonmetrics fields=\"avg_delay,perc95_delay,avg_latency,perc95_latency\" | fields metrics, *",
        status_buckets: 0,
        earliest_time: "-30d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_autolagging$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchDhmSingleLag30dAutoLagging
      .data("results", { count: 0, output_mode: "json_rows" })
      .on("data", function (data) {
        setToken("tk_30d_metrics", data._data["rows"][0][0]);
      });

    var searchSingleLagAutoLaggingSplkDhm30dSingleLagPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_latency | eval perc95_latency = round(perc95_latency, 0) . " sec (" . tostring(perc95_latency, "duration") . ")"',
          managerid: "searchDhmSingleLag30dAutoLagging",
          id: "searchSingleLagAutoLaggingSplkDhm30dSingleLagPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleLagAutoLaggingSplkDhm30dSingleLagAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_latency | eval perc95_latency = round(perc95_latency, 0) . " sec (" . tostring(perc95_latency, "duration") . ")"',
          managerid: "searchDhmSingleLag30dAutoLagging",
          id: "searchSingleLagAutoLaggingSplkDhm30dSingleLagAvg",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDhm30dSingleDelayPerc95 =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields perc95_delay | eval perc95_delay = round(perc95_delay, 0) . " sec (" . tostring(perc95_delay, "duration") . ")"',
          managerid: "searchDhmSingleLag30dAutoLagging",
          id: "searchSingleDelayAutoLaggingSplkDhm30dSingleDelayPerc95",
        },
        {
          tokens: true,
        }
      );

    var searchSingleDelayAutoLaggingSplkDhm30dSingleDelayAvg =
      new PostProcessManager(
        {
          tokenDependencies: {},
          search:
            '| fields avg_delay | eval avg_delay = round(avg_delay, 0) . " sec (" . tostring(avg_delay, "duration") . ")"',
          managerid: "searchDhmSingleLag30dAutoLagging",
          id: "searchSingleDelayAutoLaggingSplkDhm30dSingleDelayAvg",
        },
        {
          tokens: true,
        }
      );

    //
    //
    //

    var searchSingleLag = new SearchManager(
      {
        id: "searchSingleLag",
        sample_ratio: 1,
        search: "$tk_splk_dsm_overview_single_stats$",
        status_buckets: 0,
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSingleLagPerc95 = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "| fields perc95_latency | `trackme_parse_duration(perc95_latency, 60)`",
        managerid: "searchSingleLag",
        id: "searchSingleLagPerc95",
      },
      {
        tokens: true,
      }
    );

    var searchSingleLagAvg = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "| fields avg_latency | `trackme_parse_duration(avg_latency, 60)`",
        managerid: "searchSingleLag",
        id: "searchSingleLagAvg",
      },
      {
        tokens: true,
      }
    );

    var searchSingleEventLag = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "| fields event_delay | `trackme_parse_duration(event_delay, 60)`",
        managerid: "searchSingleLag",
        id: "searchSingleEventLag",
      },
      {
        tokens: true,
      }
    );

    var searchSingleSLApct = new SearchManager(
      {
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
        },
        search:
          "| `trackme_get_sla_pct_metrics_per_entity_key($tenant_id$,splk-dsm,$tk_keyid$)`",
        id: "searchSingleSLApct",
        sample_ratio: 1,
        status_buckets: 0,
        earliest_time: "-90d@d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
      },
      {
        tokens: true,
      }
    );

    var searchSingleByMetricsLag = new SearchManager(
      {
        id: "searchSingleByMetricsLag",
        sample_ratio: 1,
        search:
          '| mstats perc95(trackme.splk.feeds.lag_ingestion_sec) as perc95_latency, avg(trackme.splk.feeds.lag_ingestion_sec) as perc95_latency, latest(trackme.splk.feeds.lag_event_sec) as event_delay where `trackme_metrics_idx($tenant_id$)` object_category="splk-dsm" object="$tk_object$"',
        status_buckets: 0,
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTime.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_lagging_metrics$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // data host monitoring

    // Data parsing quality
    var SearchSplkDhmParsingQualityMain = new SearchManager(
      {
        id: "SearchSplkDhmParsingQualityMain",
        tokenDependencies: {
          depends: "$show_splk_dhm_quality$",
        },
        sample_ratio: 1,
        earliest_time: "$modalTimeHost.earliest$",
        search:
          'index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=LineBreakingProcessor OR component=AggregatorMiningProcessor OR component=DateParserVerbose | `trackme_data_quality_parse` | search object="$tk_splk_dhm$"',
        latest_time: "$modalTimeHost.latest$",
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "SearchSplkDhmParsingQualityMain",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "unset",
              token: "show_splk_dhm_quality_no_results",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "show_splk_dhm_quality_no_results",
              value: "True",
            },
          ],
        },
      ],
    });

    // set the panel visibility
    SearchSplkDhmParsingQualityMain.on("change", function (newValue) {
      var show_splk_dhm_quality_no_results = getToken(
        "show_splk_dhm_quality_no_results"
      );
      if (show_splk_dhm_quality_no_results === "True") {
        $("#divSplkDhmParsingErrorsNotFound").css("display", "none");
        $("#divSplkDhmParsingErrorsFound").css("display", "inherit");
        // increase the size
        $("#splk_dhm_data_parsing")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      } else {
        $("#divSplkDhmParsingErrorsNotFound").css("display", "inherit");
        $("#divSplkDhmParsingErrorsFound").css("display", "none");
        // reduce the size
        $("#splk_dhm_data_parsing")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      }
    });

    var SearchSplkDhmParsingQualityChart = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "timechart span=$modalTimeHost.span$ count by component",
        managerid: "SearchSplkDhmParsingQualityMain",
        id: "SearchSplkDhmParsingQualityChart",
      },
      {
        tokens: true,
      }
    );

    var SearchSplkDhmParsingQualitySingle = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'top limit=0 component | eval percent=round(percent, 2) | eval summary=component . ": " . percent . " %" | fields summary | stats values(summary) as summary',
        managerid: "SearchSplkDhmParsingQualityMain",
        id: "SearchSplkDhmParsingQualitySingle",
      },
      {
        tokens: true,
      }
    );

    var searchSingleLagHost = new SearchManager(
      {
        id: "searchSingleLagHost",
        sample_ratio: 1,
        search: "$tk_splk_dhm_overview_single_stats$",
        status_buckets: 0,
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeHost.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSingleLagHostPerc95 = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "| fields perc95_latency | `trackme_parse_duration(perc95_latency, 60)`",
        managerid: "searchSingleLagHost",
        id: "searchSingleLagHostPerc95",
      },
      {
        tokens: true,
      }
    );

    var searchSingleLagHostAvg = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "| fields avg_latency | `trackme_parse_duration(avg_latency, 60)`",
        managerid: "searchSingleLagHost",
        id: "searchSingleLagHostAvg",
      },
      {
        tokens: true,
      }
    );

    var searchSingleLagHostEventLag = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "| fields event_delay | `trackme_parse_duration(event_delay, 60)`",
        managerid: "searchSingleLagHost",
        id: "searchSingleLagHostEventLag",
      },
      {
        tokens: true,
      }
    );

    var searchSingleLagByMetricsHost = new SearchManager(
      {
        id: "searchSingleLagByMetricsHost",
        sample_ratio: 1,
        search:
          '| mstats perc95(trackme.splk.feeds.lag_ingestion_sec) as perc95_latency, avg(trackme.splk.feeds.lag_ingestion_sec) as perc95_latency, latest(trackme.splk.feeds.lag_event_sec) as event_delay where `trackme_metrics_idx($tenant_id$)` object_category="splk-dhm" object="$tk_splk_dhm$"',
        status_buckets: 0,
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeHost.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_lagging_metrics$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSingleSLAHostpct = new SearchManager(
      {
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
        },
        search:
          "| `trackme_get_sla_pct_metrics_per_entity_key($tenant_id$,splk-dhm,$tk_keyid$)`",
        id: "searchSingleSLAHostpct",
        sample_ratio: 1,
        status_buckets: 0,
        earliest_time: "-90d@d",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
      },
      {
        tokens: true,
      }
    );

    var searchChartHostBaseSearch = new SearchManager(
      {
        id: "searchChartHostBaseSearch",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeHost.latest$",
        sample_ratio: 1,
        search: "$tk_splk_dhm_overview_pie_root_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchChartHostIndexes = new PostProcessManager(
      {
        tokenDependencies: {},
        managerid: "searchChartHostBaseSearch",
        search: "stats sum(count) as count by index | sort - count",
        id: "searchChartHostIndexes",
      },
      {
        tokens: true,
      }
    );

    var searchChartHostSourcetypes = new PostProcessManager(
      {
        tokenDependencies: {},
        managerid: "searchChartHostBaseSearch",
        search: "stats sum(count) as count by sourcetype | sort - count",
        id: "searchChartHostSourcetypes",
      },
      {
        tokens: true,
      }
    );

    var searchChartLagHostOverTime = new SearchManager(
      {
        id: "searchChartLagHostOverTime",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        latest_time: "$modalTimeHost.latest$",
        sample_ratio: 1,
        search: "$tk_splk_dhm_overview_timechart$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Metric SLA policies

    var searchMetricPolicies = new SearchManager(
      {
        id: "searchMetricPolicies",
        earliest_time: "-15m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          "| inputlookup trackme_metric_lagging_definition | eval keyid=_key, select=keyid",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_modify_metric_sla_policies$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "searchMetricPolicies",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "unset",
              token: "show_table_metric_policies",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "show_table_metric_policies",
              value: "True",
            },
          ],
        },
      ],
    });

    // set the panel visibility
    searchMetricPolicies.on("change", function (newValue) {
      show_table_metric_policies = getToken("show_table_metric_policies");
      if (show_table_metric_policies === "True") {
        $("#divTableMetricPolicies").css("display", "inherit");
      } else {
        $("#divTableMetricPolicies").css("display", "none");
      }
    });

    var searchSingleMetricPolicies = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "| stats count",
        managerid: "searchMetricPolicies",
        id: "searchSingleMetricPolicies",
      },
      {
        tokens: true,
      }
    );

    // Data sampling

    var searchDataSamplingShowBuiltinRules = new SearchManager(
      {
        id: "searchDataSamplingShowBuiltinRules",
        earliest_time: "-15m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search: "| `trackme_show_builtin_model_rules`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_data_sampling$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchDataSamplingSimulateCustomRule = new SearchManager(
      {
        id: "searchDataSamplingSimulateCustomRule",
        earliest_time: "$timerange_sampling_simulation.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_sampling_simulation.latest$",
        search:
          '| trackmesamplingexecutor tenant_id="$tenant_id$" object="$tk_input_data_sampling_dropdown$" mode="get_samples" get_samples_max_count="10000" earliest="$timerange_sampling_simulation.earliest$" latest="$timerange_sampling_simulation.latest$" | table _raw data_sourcetype | rename data_sourcetype as sourcetype | eval sourcetype_scope="$tk_data_sampling_custom_sourcetype_scope$", model_type="$tk_data_sampling_custom_rule_type$" | eval detected_format = case((sourcetype_scope=="*"), case(match(_raw, "$tk_data_sampling_custom_rule_regex$"), "$tk_data_sampling_custom_rule_name$"), in(sourcetype, `trackme_data_sampling_custom_models_simulate_genlist("$tk_data_sampling_custom_sourcetype_scope$")`), case(match(_raw, "$tk_data_sampling_custom_rule_regex$"), "$tk_data_sampling_custom_rule_name$")) | `trackme_data_sampling_simulate_custom_rule($tenant_id$)`',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_data_sampling_custom_rule$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchDataSamplingSimulateCustomRuleLatestEvent = new SearchManager(
      {
        id: "searchDataSamplingSimulateCustomRuleLatestEvent",
        earliest_time: "$timerange_sampling_simulation.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_sampling_simulation.latest$",
        search:
          '| trackmesamplingexecutor tenant_id="$tenant_id$" object="$tk_input_data_sampling_dropdown$" mode="get_samples" get_samples_max_count="10000" earliest="$timerange_sampling_simulation.earliest$" latest="$timerange_sampling_simulation.latest$"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_data_sampling_custom_rule_show_events$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Custom lagging

    var searchCustomLagging = new SearchManager(
      {
        id: "searchCustomLagging",
        earliest_time: "-15m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          '| inputlookup trackme_custom_lagging_definition | eval keyid=_key | search name=$tk_input_custom_lagging_search$ | eval select=keyid, object=if(isnull(object), "all", object) | fields keyid, level, name, object, value, select',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_modify_custom_lagging$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "searchCustomLagging",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "unset",
              token: "show_table_custom_lagging",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "show_table_custom_lagging",
              value: "True",
            },
          ],
        },
      ],
    });

    var searchSingleCustomLagging = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "| stats count",
        managerid: "searchCustomLagging",
        id: "searchSingleCustomLagging",
      },
      {
        tokens: true,
      }
    );

    var searchElasticSourcesTest = new SearchManager(
      {
        id: "searchElasticSourcesTest",
        earliest_time: "$tk_input_elastic_source_earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$tk_input_elastic_source_latest$",
        search:
          '$tk_elastic_source_simulation_search$ | `trackme_elastic_sources_simulate_get_results("$tenant_id$", "$tk_input_elastic_source_object$")`',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_elastic_sources$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchHybridTrackerTest = new SearchManager(
      {
        id: "searchHybridTrackerTest",
        autostart: false,
        earliest_time: "$tk_input_hybrid_tracker_earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$tk_input_hybrid_tracker_latest$",
        search: "$tk_hybrid_tracker_simulation_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_hybrid_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchHybridRemoteTrackerDsmTest = new SearchManager(
      {
        id: "searchHybridRemoteTrackerDsmTest",
        autostart: false,
        earliest_time: "$tk_input_hybrid_remote_tracker_dsm_earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$tk_input_hybrid_remote_tracker_dsm_latest$",
        search:
          "$tk_hybrid_remote_tracker_simulation_search$ | `trackme_hybrid_tracker_simulation`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_dsm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // enable/disable the creation button

    searchHybridRemoteTrackerDsmTest.on("search:start", function (properties) {
      document.getElementById(
        "btn_modal_input_hybrid_remote_dsm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerDsmTest.on("search:failed", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_dsm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerDsmTest.on("search:error", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_dsm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerDsmTest.on("search:done", function (properties) {
      // notify
      var eventCount = properties.content.eventCount;
      if (eventCount > 0) {
        notify(
          "success",
          "bottom",
          "Hybrid tracker simulation finished successfully, verify the results before proceeding to its creation",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_dsm_add_new"
        ).disabled = false;
      } else {
        notify(
          "warning",
          "bottom",
          "The Hybrid tracker simulation finished successfully but sadly no entities were returned, verify your search constraint!",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_dsm_add_new"
        ).disabled = true;
      }
    });

    //
    // splk-flx
    //

    var searchHybridRemoteTrackerFlxTest = new SearchManager(
      {
        id: "searchHybridRemoteTrackerFlxTest",
        autostart: false,
        earliest_time: "$tk_input_hybrid_remote_tracker_flx_earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$tk_input_hybrid_remote_tracker_flx_latest$",
        search:
          '$tk_hybrid_remote_tracker_simulation_search$ | table _raw | trackmeprettyjson fields="_raw"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_flx_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // enable/disable the creation button

    searchHybridRemoteTrackerFlxTest.on("search:failed", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_flx_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerFlxTest.on("search:error", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_flx_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerFlxTest.on("search:done", function (properties) {
      // notify
      var eventCount = properties.content.resultCount;
      if (eventCount > 0) {
        notify(
          "success",
          "bottom",
          "Hybrid tracker simulation finished successfully, verify the results before proceeding to its creation",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_flx_add_new"
        ).disabled = false;
      } else {
        notify(
          "success",
          "bottom",
          "The Hybrid tracker simulation finished successfully, there were no entities returned but this can be expected if are only looking for bad conditions",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_flx_add_new"
        ).disabled = false;
      }
    });

    //
    // splk-wlk
    //

    var searchHybridRemoteTrackerWlkTest = new SearchManager(
      {
        id: "searchHybridRemoteTrackerWlkTest",
        autostart: false,
        earliest_time: "$tk_input_hybrid_remote_tracker_wlk_earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$tk_input_hybrid_remote_tracker_wlk_latest$",
        search:
          '$tk_hybrid_remote_tracker_simulation_search$ | table _raw | trackmeprettyjson fields="_raw"',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_wlk_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // enable/disable the creation button

    searchHybridRemoteTrackerWlkTest.on("search:start", function (properties) {
      document.getElementById(
        "btn_modal_input_hybrid_remote_wlk_add_new"
      ).disabled = false;
    });

    searchHybridRemoteTrackerWlkTest.on("search:failed", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_wlk_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerWlkTest.on("search:error", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_wlk_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerWlkTest.on("search:done", function (properties) {
      // notify
      var eventCount = properties.content.resultCount;
      if (eventCount > 0) {
        notify(
          "success",
          "bottom",
          "Hybrid tracker simulation finished successfully, verify the results before proceeding to its creation",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_wlk_add_new"
        ).disabled = false;
      } else {
        notify(
          "info",
          "bottom",
          "The Hybrid tracker simulation finished successfully, no entities were returned which can be expected depending on the type of tracker and conditions, you can confirm the creation of the tracker",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_wlk_add_new"
        ).disabled = false;
      }
    });

    //

    //
    // splk-dhm
    //

    var searchHybridRemoteTrackerDhmTest = new SearchManager(
      {
        id: "searchHybridRemoteTrackerDhmTest",
        autostart: false,
        earliest_time: "$tk_input_hybrid_remote_tracker_dhm_earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$tk_input_hybrid_remote_tracker_dhm_latest$",
        search:
          "$tk_hybrid_remote_tracker_simulation_search$ | `trackme_hybrid_tracker_simulation`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_dhm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // enable/disable the creation button

    searchHybridRemoteTrackerDhmTest.on("search:failed", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_dhm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerDhmTest.on("search:error", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_dhm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerDhmTest.on("search:start", function (properties) {
      document.getElementById(
        "btn_modal_input_hybrid_remote_dhm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerDhmTest.on("search:done", function (properties) {
      // notify
      var eventCount = properties.content.eventCount;
      if (eventCount > 0) {
        notify(
          "success",
          "bottom",
          "Hybrid tracker simulation finished successfully, verify the results before proceeding to its creation",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_dhm_add_new"
        ).disabled = false;
      } else {
        notify(
          "warning",
          "bottom",
          "The Hybrid tracker simulation finished successfully but sadly no entities were returned, verify your search constraint!",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_dhm_add_new"
        ).disabled = true;
      }
    });

    var searchHybridRemoteTrackerMhmTest = new SearchManager(
      {
        id: "searchHybridRemoteTrackerMhmTest",
        autostart: false,
        earliest_time: "$tk_input_hybrid_remote_tracker_mhm_earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$tk_input_hybrid_remote_tracker_mhm_latest$",
        search:
          "$tk_hybrid_remote_tracker_simulation_search$ | `trackme_hybrid_tracker_simulation`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_mhm_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // enable/disable the creation button

    searchHybridRemoteTrackerMhmTest.on("search:failed", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_mhm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerMhmTest.on("search:error", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Hybrid tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "btn_modal_input_hybrid_remote_mhm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerMhmTest.on("search:start", function (properties) {
      document.getElementById(
        "btn_modal_input_hybrid_remote_mhm_add_new"
      ).disabled = true;
    });

    searchHybridRemoteTrackerMhmTest.on("search:done", function (properties) {
      // notify
      var eventCount = properties.content.eventCount;
      if (eventCount > 0) {
        notify(
          "success",
          "bottom",
          "Hybrid tracker simulation finished successfully, verify the results before proceeding to its creation",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_mhm_add_new"
        ).disabled = false;
      } else {
        notify(
          "warning",
          "bottom",
          "The Hybrid tracker simulation finished successfully but sadly no entities were returned, verify your search constraint!",
          "10"
        );
        document.getElementById(
          "btn_modal_input_hybrid_remote_mhm_add_new"
        ).disabled = true;
      }
    });

    var searchCreateCimJsonSimulationExec = new SearchManager(
      {
        id: "searchCreateCimJsonSimulationExec",
        autostart: false,
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        search:
          "$tk_create_cim_json_simulation_search$ | `trackme_get_cim_entities_simulation_table`",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_create_cim_json_simulation_exec$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Indexer queues

    var searchPopulateHostQueues = new SearchManager(
      {
        id: "searchPopulateHostQueues",
        earliest_time: "$inputLinkQueuesTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        latest_time: "$inputLinkQueuesTime.latest$",
        search:
          "| tstats count where (index=_internal `trackme_idx_filter` source=*metrics.log sourcetype=splunkd) by host | sort 0 host | fields host",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_indexers_queues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchQueueAll = new SearchManager(
      {
        id: "searchQueueAll",
        tokenDependencies: {
          depends: "$tk_start_indexers_queues_searches$",
        },
        sample_ratio: 1,
        earliest_time: "$inputLinkQueuesTime.earliest$",
        search:
          '(index=_internal `trackme_idx_filter` source=*metrics.log sourcetype=splunkd $inputHostQueues$ group=queue) | eval max=if(isnotnull(max_size_kb),max_size_kb,max_size) | eval curr=if(isnotnull(current_size_kb),current_size_kb,current_size) | eval fill_perc=round((curr/max)*100,2) | bucket _time span=1m | stats Median(fill_perc) AS "fill_percentage" by host, _time, name | timechart limit=0 useother=f span=2m avg(fill_percentage) as "pct_fill_indexqueue" by name',
        latest_time: "$inputLinkQueuesTime.latest$",
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchQueueTreillis = new SearchManager(
      {
        id: "searchQueueTreillis",
        earliest_time: "$inputLinkQueuesTime.earliest$",
        latest_time: "$inputLinkQueuesTime.latest$",
        sample_ratio: 1,
        search:
          '(index=_internal `trackme_idx_filter` source=*metrics.log sourcetype=splunkd $inputHostQueues$ group=queue) | eval max=if(isnotnull(max_size_kb),max_size_kb,max_size) | eval curr=if(isnotnull(current_size_kb),current_size_kb,current_size) | eval fill_perc=round((curr/max)*100,2) | bucket _time span=1m | eval ingest_pipe=if(isnull(ingest_pipe), 0, ingest_pipe) | eval key = $inputHostQueuesBreak$ | stats Median(fill_perc) AS "fill_percentage" by key, _time | timechart limit=0 useother=f span=2m avg(fill_percentage) as "pct_fill_indexqueue" by key',
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_indexers_queues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Parsing issues

    var searchPopulateHostParsing = new SearchManager(
      {
        id: "searchPopulateHostParsing",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        refreshType: "delay",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        search:
          "| tstats count where (index=_internal `trackme_idx_filter` source=*metrics.log sourcetype=splunkd) by host | sort 0 host | fields host",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchParsingIssuesChart = new SearchManager(
      {
        id: "searchParsingIssuesChart",
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        sample_ratio: 1,
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` $inputHostParsing$ component=LineBreakingProcessor OR component=AggregatorMiningProcessor OR component=DateParserVerbose | timechart span=$inputLinkParsingIssuesTime.span$ count by component",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchParsingIssuesSingle = new SearchManager(
      {
        id: "searchParsingIssuesSingle",
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        sample_ratio: 1,
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        search:
          'index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` $inputHostParsing$ component=LineBreakingProcessor OR component=AggregatorMiningProcessor OR component=DateParserVerbose | top limit=0 component | eval percent=round(percent, 2) | eval summary=component . ": " . percent . " %" | fields summary | stats values(summary) as summary | append [ | makeresults | eval summary="No parsing issues detected (bravo!?), review the trackme_idx_filter macro to target indexing instances." | fields - _time ] | head 1',
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchLineBreakingProcessorTopSource = new SearchManager(
      {
        id: "searchLineBreakingProcessorTopSource",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=LineBreakingProcessor | top limit=50 data_source | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchLineBreakingProcessorTopHost = new SearchManager(
      {
        id: "searchLineBreakingProcessorTopHost",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=LineBreakingProcessor | top limit=50 object | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchLineBreakingProcessorTopSourcetype = new SearchManager(
      {
        id: "searchLineBreakingProcessorTopSourcetype",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=LineBreakingProcessor | top limit=50 data_sourcetype | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAggregatorMiningProcessorTopSource = new SearchManager(
      {
        id: "searchAggregatorMiningProcessorTopSource",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=AggregatorMiningProcessor | top limit=50 data_source | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAggregatorMiningProcessorTopHost = new SearchManager(
      {
        id: "searchAggregatorMiningProcessorTopHost",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=AggregatorMiningProcessor | top limit=50 object | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAggregatorMiningProcessorTopSourcetype = new SearchManager(
      {
        id: "searchAggregatorMiningProcessorTopSourcetype",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=AggregatorMiningProcessor | top limit=50 data_sourcetype | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchDateParserVerboseTopSource = new SearchManager(
      {
        id: "searchDateParserVerboseTopSource",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=DateParserVerbose | `trackme_rex_dateparserverbose` | top limit=50 data_source | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchDateParserVerboseTopHost = new SearchManager(
      {
        id: "searchDateParserVerboseTopHost",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=DateParserVerbose | `trackme_rex_dateparserverbose` | top limit=50 object | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchDateParserVerboseTopSourcetype = new SearchManager(
      {
        id: "searchDateParserVerboseTopSourcetype",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: 1,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=DateParserVerbose | `trackme_rex_dateparserverbose` | top limit=50 data_sourcetype | eval percent=round(percent, 2)",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchLineBreakingProcessorEvent = new SearchManager(
      {
        id: "searchLineBreakingProcessorEvent",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: null,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=LineBreakingProcessor | head 100",
        status_buckets: 300,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchAggregatorMiningProcessorEvent = new SearchManager(
      {
        id: "searchAggregatorMiningProcessorEvent",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: null,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=aggregatorMiningProcessor | head 100",
        status_buckets: 300,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchDateParserVerboseEvent = new SearchManager(
      {
        id: "searchDateParserVerboseEvent",
        earliest_time: "$inputLinkParsingIssuesTime.earliest$",
        latest_time: "$inputLinkParsingIssuesTime.latest$",
        sample_ratio: null,
        search:
          "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=DateParserVerbose | head 100",
        status_buckets: 300,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Identity card

    var searchIdentityCardTable = new SearchManager(
      {
        id: "searchIdentityCardTable",
        tokenDependencies: {
          depends: "$tk_start_associate_identity_card$",
        },
        sample_ratio: 1,
        search:
          "| inputlookup trackme_dsm_knowledge_tenant_$tenant_id$ | eval keyid=_key | search object=*$FilterIdentityCardTable$* OR doc_link=*$FilterIdentityCardTable$ OR doc_note=*$FilterIdentityCardTable$* | table keyid, object, doc_link, doc_note",
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Logical group

    var searchLogicalGroupTable = new SearchManager(
      {
        id: "searchLogicalGroupTable",
        tokenDependencies: {
          depends: "$tk_start_logical_member_get$",
        },
        sample_ratio: 1,
        search:
          '| inputlookup trackme_common_logical_group_tenant_$tenant_id$ | eval keyid=_key | search [ | makeresults | eval list="$tk_logical_group_target$" | eval list="\\"" . mvjoin(split(list, ","), "\\",\\"") . "\\"" | eval spl = "object_group_members IN (" . list . ")" | return $spl ] | eval object_group_mtime=strftime(object_group_mtime, "%c") | table keyid, object_group_name, object_group_members, object_group_min_green_percent, object_group_mtime',
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    new SearchEventHandler({
      managerid: "searchLogicalGroupTable",
      event: "progress",
      conditions: [
        {
          attr: "match",
          value: "'job.resultCount' == 0",
          actions: [
            {
              type: "set",
              token: "show_add_logical_group",
              value: "True",
            },
            {
              type: "unset",
              token: "show_table_logical_group",
            },
          ],
        },
        {
          attr: "any",
          value: "*",
          actions: [
            {
              type: "set",
              token: "show_table_logical_group",
              value: "True",
            },
            {
              type: "unset",
              token: "show_add_logical_group",
            },
          ],
        },
      ],
    });

    // set the panel visibility
    searchLogicalGroupTable.on("change", function (newValue) {
      show_add_logical_group = getToken("show_add_logical_group");
      if (show_add_logical_group === "True") {
        $("#divShowAddLogicalGroup").css("display", "inherit");
        $("#divShowTableLogicalGroup").css("display", "none");
      } else {
        $("#divShowAddLogicalGroup").css("display", "none");
        $("#divShowTableLogicalGroup").css("display", "inherit");
      }
    });

    // Logical group add member

    var searchLogicalGroupTableAddMember = new SearchManager(
      {
        id: "searchLogicalGroupTableAddMember",
        tokenDependencies: {
          depends: "$tk_start_logical_member_add$",
        },
        sample_ratio: 1,
        search:
          '| inputlookup trackme_common_logical_group_tenant_$tenant_id$ | eval keyid=_key | search object_group_name=*$FilterLogicalGroupTable$* OR object_group_members=*$FilterLogicalGroupTable$* | eval object_group_mtime=strftime(object_group_mtime, "%c") | table keyid, object_group_name, object_group_members, object_group_min_green_percent, object_group_mtime',
        cancelOnUnload: true,
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Ack

    var searchAckDuration = new SearchManager(
      {
        id: "searchAckDuration",
        tokenDependencies: {
          depends: "$tk_start_ack_get$",
        },
        earliest_time: "-5m",
        latest_time: "now",
        sample_ratio: null,
        search: "| `trackme_ack_populate_dropdown`",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    //
    // CIM TRACKING
    //

    var DonutCimCountByPriority = new semiCircleDonut(
      {
        id: "DonutCimCountByPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleCimDonutPriorities",
        el: $("#DonutCimCountByPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var DonutCimCountByStateAndPriority = new semiCircleDonut(
      {
        id: "DonutCimCountByStateAndPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleCimDonutAlerts",
        el: $("#DonutCimCountByStateAndPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    //
    // SPLK DATA SOURCES TRACKING
    //

    var DonutSplkDsmCountByPriority = new semiCircleDonut(
      {
        id: "DonutSplkDsmCountByPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkDsmDonutPriorities",
        el: $("#DonutSplkDsmCountByPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var DonutSplkDsmCountByStateAndPriority = new semiCircleDonut(
      {
        id: "DonutSplkDsmCountByStateAndPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkDsmDonutAlerts",
        el: $("#DonutSplkDsmCountByStateAndPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    //
    // list input
    //

    // dynamicall generate the Trackme components

    function genLinkMainInputReturnChoices(
      componentSplkDsms,
      componentSplkDhms,
      componentSplkMhms,
      componentCimTracking,
      componentSplkFlx,
      componentSplkWlk
    ) {
      var choices = [];

      if (componentSplkDsms === 1) {
        choices.push({
          value: "show_splk_dsm_tracker",
          label: "SPLK-DSM - DATA SOURCES TRACKING",
        });
      }

      if (componentCimTracking === 1) {
        choices.push({
          value: "show_cim_tracker",
          label: "SPLK-CIM - CIM COMPLIANCY TRACKING",
        });
      }

      if (componentSplkFlx === 1) {
        choices.push({
          value: "show_splk_flx_tracker",
          label: "SPLK-FLX - FLEX OBJECTS TRACKING",
        });
      }

      if (componentSplkWlk === 1) {
        choices.push({
          value: "show_splk_wlk_tracker",
          label: "SPLK-WLK - SPLUNK WORKLOAD",
        });
      }

      if (componentSplkDhms === 1) {
        choices.push({
          value: "show_splk_dhm_tracker",
          label: "SPLK-DHM - EVENT ENDPOINTS TRACKING",
        });
      }

      if (componentSplkMhms === 1) {
        choices.push({
          value: "show_splk_mhm_tracker",
          label: "SPLK-MHM - METRIC ENDPOINTS TRACKING",
        });
      }

      // push mandatory components
      choices.push({
        value: "show_audit_flip",
        label: "INVESTIGATE STATUS FLIPPING",
      });

      choices.push({
        value: "show_audit_changes",
        label: "INVESTIGATE AUDIT CHANGES",
      });

      choices.push({
        value: "show_alerts",
        label: "TRACKING ALERTS",
      });

      // return the choices array
      return choices;
    }

    function genLinkMainInput() {
      // retrieve the tenant_id
      tenant_id = getToken("tenant_id");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/configuration/components";

      var data = {
        tenant_id: tenant_id,
      };

      // Get the KV entry content first
      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        dataType: "json",
        data: JSON.stringify(data),
        contentType: "application/json",
        success: function (returneddata) {
          var componentSplkDsms = returneddata.component_splk_dsm;
          var componentSplkDhms = returneddata.component_splk_dhm;
          var componentSplkMhms = returneddata.component_splk_mhm;
          var componentCimTracking = returneddata.component_cim_tracking;
          var componentSplkFlxs = returneddata.component_splk_flx;
          var componentSplkWlks = returneddata.component_splk_wlk;
          var componentOwner = returneddata.component_owner;
          var ui_min_object_width = returneddata.ui_min_object_width;
          var ui_expand_metrics = returneddata.ui_expand_metrics;
          var cmdb_lookup = returneddata.cmdb_lookup;

          // set some UI tenant level configuration
          setToken("ui_min_object_width", ui_min_object_width);
          setToken("ui_expand_metrics", ui_expand_metrics);
          setToken("cmdb_lookup", cmdb_lookup);

          // set the component owner token
          setToken("tk_tenant_owner", componentOwner);

          // get the choices array
          var choicesArray = genLinkMainInputReturnChoices(
            componentSplkDsms,
            componentSplkDhms,
            componentSplkMhms,
            componentCimTracking,
            componentSplkFlxs,
            componentSplkWlks
          );

          var linkMainInput = new LinkListInput(
            {
              id: "linkMainInput",
              choices: choicesArray,
              selectFirstChoice: true,
              searchWhenChanged: true,
              value: "$form.tk_main_link$",
              el: $("#linkMainInput"),
            },
            {
              tokens: true,
            }
          ).render();

          linkMainInput.on("change", function (newValue) {
            FormUtils.handleValueChange(linkMainInput);
          });

          linkMainInput.on("valueChange", function (e) {
            if (e.value === "show_splk_dsm_tracker") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_splk_dsm_tracker", "true");
              setToken("tk_component", "dsm");
              unsetToken("show_cim_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_splk_wlk_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_audit_changes");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_alerts");
              // get the Tabulator
              getSplkDsmTable();
              // get the sampling obfuscation mode once and once only
              splkDsmGetSamplingObfuscation();
            } else if (e.value === "show_cim_tracker") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_cim_tracker", "true");
              setToken("tk_component", "cim");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_audit_changes");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_alerts");
              // get the Tabulator
              getSplkCimTable();
            } else if (e.value === "show_splk_flx_tracker") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_splk_flx_tracker", "true");
              setToken("tk_component", "flx");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_cim_tracker");
              unsetToken("show_splk_wlk_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_audit_changes");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_alerts");
              // get the Tabulator
              getSplkFlxTable();
            } else if (e.value === "show_splk_dhm_tracker") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_splk_dhm_tracker", "true");
              setToken("tk_component", "dhm");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_cim_tracker");
              unsetToken("show_splk_wlk_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_audit_changes");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_alerts");
              // get the Tabulator
              getSplkDhmTable();
            } else if (e.value === "show_splk_mhm_tracker") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_splk_mhm_tracker", "true");
              setToken("tk_component", "mhm");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_cim_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_splk_wlk_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_audit_changes");
              unsetToken("show_alerts");
              // get the Tabulator
              getSplkMhmTable();
            } else if (e.value === "show_splk_wlk_tracker") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_splk_wlk_tracker", "true");
              setToken("tk_component", "wlk");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_cim_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_audit_changes");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_alerts");
              // get the Tabulator
              getSplkWlkTable();
            } else if (e.value === "show_audit_flip") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_audit_flip", "true");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_cim_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_splk_wlk_tracker");
              unsetToken("show_audit_changes");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_alerts");
            } else if (e.value === "show_audit_changes") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_audit_changes", "true");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_cim_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_splk_wlk_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_alerts");
            } else if (e.value === "show_alerts") {
              setToken("tenant_id", getToken("root_tenant_id"));
              setToken("show_alerts", "true");
              unsetToken("show_splk_dsm_tracker");
              unsetToken("show_cim_tracker");
              unsetToken("show_splk_dhm_tracker");
              unsetToken("show_splk_flx_tracker");
              unsetToken("show_splk_wlk_tracker");
              unsetToken("show_audit_flip");
              unsetToken("show_splk_mhm_tracker");
              unsetToken("show_audit_changes");
              getAlertTable();
            }
          });
        },
        error: function (xhr, textStatus, error) {
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          cssloaderremove();
          $("#modal_load_components_error")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_load_components_error").modal();
        },
      });
    }

    // generate now
    genLinkMainInput();

    // Remove the css spinner at this stage
    cssloaderremove();

    // main data_source link input for modal window
    var inputLinkSplkDsm = new LinkListInput(
      {
        id: "inputLinkSplkDsm",
        choices: [
          {
            value: "overview",
            label: "Overview data source",
          },
          {
            value: "notables",
            label: "Notables",
          },
          {
            value: "lagging_metrics",
            label: "Performance Metrics",
          },
          {
            value: "outlier",
            label: "Outliers anomaly detection",
          },
          {
            value: "data_sampling",
            label: "Data sampling",
          },
          {
            value: "data_quality",
            label: "Data parsing quality",
          },
          {
            value: "flipping_status",
            label: "Status flipping",
          },
          {
            value: "status_message",
            label: "Status message",
          },
          {
            value: "splk_dsm_audit_changes",
            label: "Audit changes",
          },
        ],
        default: "overview",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "overview",
        value: "$form.inputLinkSplkDsm$",
        el: $("#inputLinkSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkSplkDsm.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkSplkDsm);
    });

    inputLinkSplkDsm.on("valueChange", function (e) {
      if (e.value === "overview") {
        EventHandler.setToken("show_splk_dsm_overview", "true", {}, e.data);
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_outlier");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_data_quality");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "inherit");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "inherit");
      } else if (e.value === "notables") {
        EventHandler.setToken("show_splk_dsm_notables", "true", {}, e.data);
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_data_quality");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "inherit");
        $("#splk_dsm_outliers").css("display", "none");
        // show the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "inherit");
      } else if (e.value === "outlier") {
        EventHandler.setToken("show_splk_dsm_outlier", "true", {}, e.data);
        searchOutlierDetectionChartDsm.startSearch();
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_data_quality");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "inherit");
        // show the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "inherit");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "inherit");
      } else if (e.value === "data_sampling") {
        EventHandler.setToken("show_data_sampling", "true", {}, e.data);
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_outlier");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_quality");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "inherit");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "none");
      } else if (e.value === "data_quality") {
        EventHandler.setToken("show_data_quality", "true", {}, e.data);
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_outlier");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "inherit");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "inherit");
      } else if (e.value === "lagging_metrics") {
        EventHandler.setToken(
          "show_splk_dsm_lagging_metrics",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_outlier");
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_data_quality");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "inherit");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "inherit");
      } else if (e.value === "flipping_status") {
        EventHandler.setToken("show_flipping_status", "true", {}, e.data);
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_outlier");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_data_quality");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "inherit");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "inherit");
      } else if (e.value === "status_message") {
        EventHandler.setToken(
          "show_splk_dsm_status_message",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_outlier");
        unsetToken("show_data_quality");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_audit_changes");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "inherit");
        $("#splk_dsm_changes").css("display", "none");
        $("#splk_dsm_timepicker").css("display", "none");
      } else if (e.value === "splk_dsm_audit_changes") {
        EventHandler.setToken(
          "show_splk_dsm_audit_changes",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_dsm_overview");
        unsetToken("show_splk_dsm_notables");
        unsetToken("show_splk_dsm_outlier");
        unsetToken("show_data_quality");
        unsetToken("show_flipping_status");
        unsetToken("show_splk_dsm_status_message");
        unsetToken("show_splk_dsm_lagging_metrics");
        unsetToken("show_data_sampling");
        $("#splk_dsm_overview").css("display", "none");
        $("#splk_dsm_notables").css("display", "none");
        $("#splk_dsm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDsmManageOutliers").css("display", "none");
        $("#splk_dsm_data_sampling").css("display", "none");
        $("#splk_dsm_data_parsing").css("display", "none");
        $("#splk_dsm_metrics").css("display", "none");
        $("#splk_dsm_flipping").css("display", "none");
        $("#splk_dsm_status").css("display", "none");
        $("#splk_dsm_changes").css("display", "inherit");
        $("#splk_dsm_timepicker").css("display", "inherit");
      }
    });

    var singleFormTotalSplkDsm = new SingleView(
      {
        id: "singleFormTotalSplkDsm",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "DATA SOURCES",
        managerid: "searchSingleSplkDsm1",
        el: $("#singleFormTotalSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalCimEntities = new SingleView(
      {
        id: "singleFormTotalCimEntities",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "CIM ENTITIES",
        managerid: "searchSingleCim1",
        el: $("#singleFormTotalCimEntities"),
      },
      {
        tokens: true,
      }
    ).render();

    singleFormTotalCimEntities.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        setToken("form.object_state", "*");
        setToken("form.inputCimPriority", "*");
        setToken("form.monitored_state", "*");
      }
    });

    var singleFormTotalSplkDsmAlerts = new SingleView(
      {
        id: "singleFormTotalSplkDsmAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xffb347"]',
        underLabel: "ANY PRIORITY DATA SOURCES IN ALERT",
        managerid: "searchSingleSplkDsmInAlert",
        el: $("#singleFormTotalSplkDsmAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalCimEntitiesAlerts = new SingleView(
      {
        id: "singleFormTotalCimEntitiesAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xffb347"]',
        underLabel: "ANY PRIORITY CIM ENTITIES IN ALERT",
        managerid: "searchSingleCim2",
        el: $("#singleFormTotalCimEntitiesAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    singleFormTotalCimEntitiesAlerts.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        setToken("form.inputCimPriority", "*");
        setToken("form.monitored_state", "enabled");
        setToken("form.object_state", "red");
      }
    });

    var singleFormTotalCimEntitiesDisabled = new SingleView(
      {
        id: "ingleFormTotalCimEntitiesDisabled",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "CIM ENTITIES NOT MONITORED",
        managerid: "searchSingleCim4",
        el: $("#singleFormTotalCimEntitiesDisabled"),
      },
      {
        tokens: true,
      }
    ).render();

    singleFormTotalCimEntitiesDisabled.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        setToken("form.monitored_state", "disabled");
        setToken("form.object_state", "*");
        setToken("form.inputCimPriority", "*");
      }
    });

    var singleFormTotalSplkDsmAlertsHighPriority = new SingleView(
      {
        id: "singleFormTotalSplkDsmAlertsHighPriority",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xff6961"]',
        underLabel: "HIGH PRIORITY DATA SOURCES IN ALERT",
        managerid: "searchSingleSplkDsmHighPriority",
        el: $("#singleFormTotalSplkDsmAlertsHighPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    // drilldown in Tabulator function

    var singleFormTotalCimEntitiesAlertsHighPriority = new SingleView(
      {
        id: "singleFormTotalCimEntitiesAlertsHighPriority",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xff6961"]',
        underLabel: "HIGH PRIORITY CIM ENTITIES IN ALERT",
        managerid: "searchSingleCim3",
        el: $("#singleFormTotalCimEntitiesAlertsHighPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    singleFormTotalCimEntitiesAlertsHighPriority.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        setToken("form.object_state", "red");
        setToken("form.monitored_state", "enabled");
        setToken("form.inputCimPriority", "high");
      }
    });

    var singleFormTotalSplkDsmDisabled = new SingleView(
      {
        id: "singleFormTotalSplkDsmDisabled",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "DATA SOURCES NOT MONITORED",
        managerid: "searchSingleSplkDsmNotMonitored",
        el: $("#singleFormTotalSplkDsmDisabled"),
      },
      {
        tokens: true,
      }
    ).render();

    //
    // Data host tracking
    //

    var DonutSplkDhmCountByStateAndPriority = new semiCircleDonut(
      {
        id: "DonutSplkDhmCountByStateAndPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkDhmDonutAlerts",
        el: $("#DonutSplkDhmCountByStateAndPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var DonutSplkDhmCountByPriority = new semiCircleDonut(
      {
        id: "DonutSplkDhmCountByPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkDhmDonutPriorities",
        el: $("#DonutSplkDhmCountByPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkDhm = new SingleView(
      {
        id: "singleFormTotalSplkDhm",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "DATA HOSTS",
        managerid: "searchSingleSplkDhm1",
        el: $("#singleFormTotalSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkDhmAlerts = new SingleView(
      {
        id: "singleFormTotalSplkDhmAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xffb347"]',
        underLabel: "ANY PRIORITY DATA HOSTS IN ALERT",
        managerid: "searchSingleSplkDhmInAlert",
        el: $("#singleFormTotalSplkDhmAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkDhmAlertsHighPriority = new SingleView(
      {
        id: "singleFormTotalSplkDhmAlertsHighPriority",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xff6961"]',
        underLabel: "HIGH PRIORITY DATA HOSTS IN ALERT",
        managerid: "searchSingleSplkDhmHighPriority",
        el: $("#singleFormTotalSplkDhmAlertsHighPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkDhmDisabled = new SingleView(
      {
        id: "singleFormTotalSplkDhmDisabled",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "DATA HOSTS NOT MONITORED",
        managerid: "searchSingleSplkDhmNotMonitored",
        el: $("#singleFormTotalSplkDhmDisabled"),
      },
      {
        tokens: true,
      }
    ).render();

    //
    // Metric host tracking
    //

    var DonutSplkMhmCountByStateAndPriority = new semiCircleDonut(
      {
        id: "DonutSplkMhmCountByStateAndPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkMhmDonutAlerts",
        el: $("#DonutSplkMhmCountByStateAndPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var DonutSplkMhmCountByPriority = new semiCircleDonut(
      {
        id: "DonutSplkMhmCountByPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkMhmDonutPriorities",
        el: $("#DonutSplkMhmCountByPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkMhm = new SingleView(
      {
        id: "singleFormTotalSplkMhm",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "METRIC HOSTS",
        managerid: "searchSingleSplkMhm1",
        el: $("#singleFormTotalSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkMhmAlerts = new SingleView(
      {
        id: "singleFormTotalSplkMhmAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xffb347"]',
        underLabel: "ANY PRIORITY METRIC HOSTS IN ALERT",
        managerid: "searchSingleSplkMhmInAlert",
        el: $("#singleFormTotalSplkMhmAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkMhmAlertsHighPriority = new SingleView(
      {
        id: "singleFormTotalSplkMhmAlertsHighPriority",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xff6961"]',
        underLabel: "HIGH PRIORITY METRIC HOSTS IN ALERT",
        managerid: "searchSingleSplkMhmHighPriority",
        el: $("#singleFormTotalSplkMhmAlertsHighPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkMhmDisabled = new SingleView(
      {
        id: "singleFormTotalSplkMhmDisabled",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "METRIC HOSTS NOT MONITORED",
        managerid: "searchSingleSplkMhmNotMonitored",
        el: $("#singleFormTotalSplkMhmDisabled"),
      },
      {
        tokens: true,
      }
    ).render();

    // splk-flx

    var DonutSplkFlxCountByStateAndPriority = new semiCircleDonut(
      {
        id: "DonutSplkFlxCountByStateAndPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkFlxDonutAlerts",
        el: $("#DonutSplkFlxCountByStateAndPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var DonutSplkFlxCountByPriority = new semiCircleDonut(
      {
        id: "DonutSplkFlxCountByPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkFlxDonutPriorities",
        el: $("#DonutSplkFlxCountByPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkFlx = new SingleView(
      {
        id: "singleFormTotalSplkFlx",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "ENTITIES",
        managerid: "searchSingleSplkFlx1",
        el: $("#singleFormTotalSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkFlxAlerts = new SingleView(
      {
        id: "singleFormTotalSplkFlxAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xffb347"]',
        underLabel: "ANY PRIORITY ENTITIES IN ALERT",
        managerid: "searchSingleSplkFlxInAlert",
        el: $("#singleFormTotalSplkFlxAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkFlxAlertsHighPriority = new SingleView(
      {
        id: "singleFormTotalSplkFlxAlertsHighPriority",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xff6961"]',
        underLabel: "HIGH PRIORITY ENTITIES IN ALERT",
        managerid: "searchSingleSplkFlxHighPriority",
        el: $("#singleFormTotalSplkFlxAlertsHighPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkFlxDisabled = new SingleView(
      {
        id: "singleFormTotalSplkFlxDisabled",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "ENTITIES NOT MONITORED",
        managerid: "searchSingleSplkFlxNotMonitored",
        el: $("#singleFormTotalSplkFlxDisabled"),
      },
      {
        tokens: true,
      }
    ).render();

    // splk-wlk

    var DonutSplkWlkCountByStateAndPriority = new semiCircleDonut(
      {
        id: "DonutSplkWlkCountByStateAndPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkWlkDonutAlerts",
        el: $("#DonutSplkWlkCountByStateAndPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var DonutSplkWlkCountByPriority = new semiCircleDonut(
      {
        id: "DonutSplkWlkCountByPriority",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "all",
        height: "170",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchSingleSplkWlkDonutPriorities",
        el: $("#DonutSplkWlkCountByPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkWlk = new SingleView(
      {
        id: "singleFormTotalSplkWlk",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "ENTITIES",
        managerid: "searchSingleSplkWlk1",
        el: $("#singleFormTotalSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkWlkAlerts = new SingleView(
      {
        id: "singleFormTotalSplkWlkAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xffb347"]',
        underLabel: "ANY PRIORITY ENTITIES IN ALERT",
        managerid: "searchSingleSplkWlkInAlert",
        el: $("#singleFormTotalSplkWlkAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkWlkAlertsHighPriority = new SingleView(
      {
        id: "singleFormTotalSplkWlkAlertsHighPriority",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xff6961"]',
        underLabel: "HIGH PRIORITY ENTITIES IN ALERT",
        managerid: "searchSingleSplkWlkHighPriority",
        el: $("#singleFormTotalSplkWlkAlertsHighPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTotalSplkWlkDisabled = new SingleView(
      {
        id: "singleFormTotalSplkWlkDisabled",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "ENTITIES NOT MONITORED",
        managerid: "searchSingleSplkWlkNotMonitored",
        el: $("#singleFormTotalSplkWlkDisabled"),
      },
      {
        tokens: true,
      }
    ).render();

    //
    // Flipping statuses
    //

    var input_timerange_audit_flip = new TimeRangeInput(
      {
        id: "input_timerange_audit_flip",
        searchWhenChanged: true,
        default: {
          latest_time: "now",
          earliest_time: "-24h",
        },
        earliest_time: "$form.timerange_audit_flip.earliest$",
        latest_time: "$form.timerange_audit_flip.latest$",
        el: $("#input_timerange_audit_flip"),
      },
      {
        tokens: true,
      }
    ).render();

    input_timerange_audit_flip.on("change", function (newValue) {
      FormUtils.handleValueChange(input_timerange_audit_flip);
    });

    var inputAuditFlipObjectFilter = new TextInput(
      {
        id: "inputAuditFlipObjectFilter",
        searchWhenChanged: true,
        default: "*",
        prefix: 'object="*',
        suffix: '*"',
        initialValue: "*",
        value: "$form.inputAuditFlipObjectFilter$",
        el: $("#inputAuditFlipObjectFilter"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditFlipObjectFilter.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditFlipObjectFilter);
    });

    var inputAuditFlipObjectCategory = new DropdownInput(
      {
        id: "inputAuditFlipObjectCategory",
        tokenDependencies: {
          depends: "$show_audit_flip$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        labelField: "object_category",
        prefix: 'object_category="',
        suffix: '"',
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "object_category",
        value: "$form.audit_flip_object_category$",
        managerid: "searchAuditFlipObjectCategory",
        el: $("#inputAuditFlipObjectCategory"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditFlipObjectCategory.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditFlipObjectCategory);
    });

    var inputAuditFlipObject = new DropdownInput(
      {
        id: "inputAuditFlipObject",
        tokenDependencies: {
          depends: "$show_audit_flip$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        labelField: "object",
        prefix: 'object="',
        suffix: '"',
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "object",
        value: "$form.audit_flip_object$",
        managerid: "searchAuditFlipObject",
        el: $("#inputAuditFlipObject"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditFlipObject.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditFlipObject);
    });

    var elementMainTableAuditFlip = new TableView(
      {
        id: "elementMainTableAuditFlip",
        count: 100,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMainAuditFlipTable",
        el: $("#elementMainTableAuditFlip"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(elementMainTableAuditFlip);

    var resultsLinkelementMainTableAuditFlip = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditFlip",
      managerid: "searchMainAuditFlipTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditFlip"),
    });

    resultsLinkelementMainTableAuditFlip
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditFlip"));

    //
    // Audit changes
    //

    var input_timerange_audit_changes = new TimeRangeInput(
      {
        id: "input_timerange_audit_changes",
        searchWhenChanged: true,
        default: {
          latest_time: "now",
          earliest_time: "-24h",
        },
        earliest_time: "$form.timerange_audit_changes.earliest$",
        latest_time: "$form.timerange_audit_changes.latest$",
        el: $("#input_timerange_audit_changes"),
      },
      {
        tokens: true,
      }
    ).render();

    input_timerange_audit_changes.on("change", function (newValue) {
      FormUtils.handleValueChange(input_timerange_audit_changes);
    });

    var inputAuditChangesAction = new DropdownInput(
      {
        id: "inputAuditChangesAction",
        tokenDependencies: {
          depends: "$show_audit_changes$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        labelField: "action",
        prefix: 'action="',
        suffix: '"',
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "action",
        value: "$form.audit_changes_action$",
        managerid: "searchAuditChangesAction",
        el: $("#inputAuditChangesAction"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditChangesAction.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditChangesAction);
    });

    var inputAuditChangesUser = new DropdownInput(
      {
        id: "inputAuditChangesUser",
        tokenDependencies: {
          depends: "$show_audit_changes$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        labelField: "user",
        prefix: 'user="',
        suffix: '"',
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "user",
        value: "$form.audit_changes_user$",
        managerid: "searchAuditChangesUser",
        el: $("#inputAuditChangesUser"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditChangesUser.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditChangesUser);
    });

    var inputAuditChangesObjectCategory = new DropdownInput(
      {
        id: "inputAuditChangesObjectCategory",
        tokenDependencies: {
          depends: "$show_audit_changes$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        labelField: "object_category",
        prefix: 'object_category="',
        suffix: '"',
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "object_category",
        value: "$form.audit_changes_object_category$",
        managerid: "searchAuditChangesObjectCategory",
        el: $("#inputAuditChangesObjectCategory"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditChangesObjectCategory.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditChangesObjectCategory);
    });

    var inputAuditChangesChangeType = new DropdownInput(
      {
        id: "inputAuditChangesChangeType",
        tokenDependencies: {
          depends: "$show_audit_changes$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        labelField: "change_type",
        prefix: 'change_type="',
        suffix: '"',
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "change_type",
        value: "$form.audit_changes_change_type$",
        managerid: "searchAuditChangesChangeType",
        el: $("#inputAuditChangesChangeType"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditChangesChangeType.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditChangesChangeType);
    });

    var inputAuditChangesObject = new DropdownInput(
      {
        id: "inputAuditChangesObject",
        tokenDependencies: {
          depends: "$show_audit_changes$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        labelField: "object",
        prefix: 'object="',
        suffix: '"',
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "object",
        value: "$form.audit_changes_object$",
        managerid: "searchAuditChangesObject",
        el: $("#inputAuditChangesObject"),
      },
      {
        tokens: true,
      }
    ).render();

    inputAuditChangesObject.on("change", function (newValue) {
      FormUtils.handleValueChange(inputAuditChangesObject);
    });

    var elementMainTableAuditChanges = new TableView(
      {
        id: "elementMainTableAuditChanges",
        count: 100,
        drilldown: "none",
        "refresh.display": "none",
        fields:
          "_time, user, action, change_type, object_category, object, object_attrs, comment",
        wrap: "true",
        managerid: "searchMainAuditChanges",
        el: $("#elementMainTableAuditChanges"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(elementMainTableAuditChanges);

    var resultsLinkelementMainTableAuditChanges = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditChanges",
      managerid: "searchMainAuditChanges",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditChanges"),
    });

    resultsLinkelementMainTableAuditChanges
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditChanges"));

    //
    // Tracking UI alerts
    //

    var singleFormEnabledAlerts = new SingleView(
      {
        id: "singleFormEnabledAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0x7fbfff"]',
        underLabel: "ENABLED ALERTS",
        managerid: "searchSingleEnabledAlerts",
        el: $("#singleFormEnabledAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    var singleFormTriggeredAlerts = new SingleView(
      {
        id: "singleFormTriggeredAlerts",
        showTrendIndicator: "1",
        unitPosition: "after",
        useThousandSeparators: "1",
        numberPrecision: "0",
        colorBy: "value",
        colorMode: "block",
        drilldown: "all",
        height: "95",
        showSparkline: "1",
        "trellis.scales.shared": "1",
        useColors: "1",
        trendDisplayMode: "absolute",
        "trellis.enabled": "0",
        trendColorInterpretation: "standard",
        "trellis.size": "medium",
        rangeValues: "[0]",
        rangeColors: '["0x7fbfff","0xffb347"]',
        underLabel: "TRIGGERED ALERTS IN THE PAST 24h",
        managerid: "search_alerts_triggered_history",
        el: $("#singleFormTriggeredAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    var DonutAlertTriggered = new semiCircleDonut(
      {
        id: "DonutAlertTriggered",
        type: "semicircle_donut.semicircle_donut",
        resizable: true,
        drilldown: "none",
        height: "200",
        "refresh.display": "progressbar",
        "semicircle_donut.semicircle_donut.colorField": "color",
        "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
        "semicircle_donut.semicircle_donut.legendPosition": "top",
        "semicircle_donut.semicircle_donut.type": "half",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchDonutAlertsTriggered",
        el: $("#DonutAlertTriggered"),
      },
      {
        tokens: true,
      }
    ).render();

    // Delete an alert (button)
    $("#btn_alert_delete")
      .unbind()
      .click(function () {
        // Enable modal context
        closeModals();
        $("#modal_alert_confirm_delete").modal();
      });

    // Delete an alert (cancel)
    $("#btn_confirm_modal_alert_confirm_cancel")
      .unbind()
      .click(function () {
        // Enable modal context
        closeModals();
        $("#modal_manage_alerts").modal();
      });

    // Delete an alert (button)
    $("#btn_confirm_modal_alert_confirm_delete")
      .unbind()
      .click(function () {
        // Get alert name
        var tk_alert_title = getToken("tk_alert_title");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/alerting/admin/del_alert";

        // retrieve comment, if any
        comment = getComment("comment_modal_alert_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          alert_name: tk_alert_title,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete alert",
          tk_alert_title,
          "alerts",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            actionResult = resultCall.action;
            if (actionResult == "success") {
              // notify
              notify("success", "bottom", JSON.stringify(resultCall), "5");
              // refresh
              $("#btn_refresh_alerts").click();
              // close modals
              closeModals();
            }
          }
        });
      });

    // Elastic Sources Shared

    var modal_input_elastic_sources_search = new TextInput(
      {
        id: "modal_input_elastic_sources_search",
        default: "*",
        searchWhenChanged: true,
        value: "$form.tk_input_elastic_sources_search$",
        el: $("#modal_input_elastic_sources_search"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_sources_search.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_elastic_sources_search);
    });

    // Elastic Sources Dedicated

    var modal_input_elastic_sources_dedicated_search = new TextInput(
      {
        id: "modal_input_elastic_sources_dedicated_search",
        default: "*",
        searchWhenChanged: true,
        value: "$form.tk_input_elastic_sources_dedicated_search$",
        el: $("#modal_input_elastic_sources_dedicated_search"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_sources_dedicated_search.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_elastic_sources_dedicated_search
        );
      }
    );

    // Simulation
    var tableElasticSourcesTest = new TableView(
      {
        id: "tableElasticSourcesTest",
        tokenDependencies: {
          depends: "$start_simulation_elastic_sources$",
        },
        count: 1,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchElasticSourcesTest",
        el: $("#tableElasticSourcesTest"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(tableElasticSourcesTest);

    var resultsLinktableElasticSourcesTest = new ResultsLinkView({
      id: "resultsLinktableElasticSourcesTest",
      managerid: "searchElasticSourcesTest",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableElasticSourcesTest"),
    });

    resultsLinktableElasticSourcesTest
      .render()
      .$el.appendTo($("resultsLinktableElasticSourcesTest"));

    //
    // replica remote tracker simulation
    //

    var searchReplicaTrackerTest = new SearchManager(
      {
        id: "searchReplicaTrackerTest",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search: "$tk_hybrid_replica_tracker_simulation_search$",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_simulation_replica_tracker$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // enable/disable the creation button

    searchReplicaTrackerTest.on("search:start", function (properties) {
      document.getElementById(
        "modal_input_replica_tracker_add"
      ).disabled = true;
    });

    searchReplicaTrackerTest.on("search:failed", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Replica tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "modal_input_replica_tracker_add"
      ).disabled = true;
    });

    searchReplicaTrackerTest.on("search:error", function (properties) {
      // notify
      notify(
        "error",
        "bottom",
        "Oops, Replica tracker simulation failed, review the search output!",
        "5"
      );
      document.getElementById(
        "modal_input_replica_tracker_add"
      ).disabled = true;
    });

    searchReplicaTrackerTest.on("search:done", function (properties) {
      // notify
      var resultCount = properties.content.resultCount;
      if (resultCount > 0) {
        notify(
          "success",
          "bottom",
          "Replica tracker simulation finished successfully, verify the results before proceeding to its creation",
          "10"
        );
        document.getElementById(
          "modal_input_replica_tracker_add"
        ).disabled = false;
      } else {
        notify(
          "warning",
          "bottom",
          "The Replica tracker simulation finished successfully but sadly no entities were returned, verify your search constraint!",
          "10"
        );
        document.getElementById(
          "modal_input_replica_tracker_add"
        ).disabled = true;
      }
    });

    var tableReplicaTrackerTest = new TableView(
      {
        id: "tableReplicaTrackerTest",
        tokenDependencies: {
          depends: "$start_simulation_replica_tracker$",
        },
        count: 1,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchReplicaTrackerTest",
        el: $("#tableReplicaTrackerTest"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(tableReplicaTrackerTest);

    var resultsLinktableReplicaTrackerTest = new ResultsLinkView({
      id: "resultsLinktableReplicaTrackerTest",
      managerid: "searchReplicaTrackerTest",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableReplicaTrackerTest"),
    });

    resultsLinktableReplicaTrackerTest
      .render()
      .$el.appendTo($("resultsLinktableReplicaTrackerTest"));

    //
    // hybrid remote tracker simulation
    //

    // dsm

    var tableHybridRemoteTrackerDsmTest = new TableView(
      {
        id: "tableHybridRemoteTrackerDsmTest",
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_dsm_tracker$",
        },
        count: 1,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchHybridRemoteTrackerDsmTest",
        el: $("#tableHybridRemoteTrackerDsmTest"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(tableHybridRemoteTrackerDsmTest);

    var resultsLinktableHybridRemoteTrackerDsmTest = new ResultsLinkView({
      id: "resultsLinktableHybridRemoteTrackerDsmTest",
      managerid: "searchHybridRemoteTrackerDsmTest",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableHybridRemoteTrackerDsmTest"),
    });

    resultsLinktableHybridRemoteTrackerDsmTest
      .render()
      .$el.appendTo($("resultsLinktableHybridRemoteTrackerDsmTest"));

    // splk-flx

    var tableHybridRemoteTrackerFlxTest = new TableView(
      {
        id: "tableHybridRemoteTrackerFlxTest",
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_flx_tracker$",
        },
        count: 10,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "true",
        managerid: "searchHybridRemoteTrackerFlxTest",
        el: $("#tableHybridRemoteTrackerFlxTest"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableHybridRemoteTrackerFlxTest = new ResultsLinkView({
      id: "resultsLinktableHybridRemoteTrackerFlxTest",
      managerid: "searchHybridRemoteTrackerFlxTest",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableHybridRemoteTrackerFlxTest"),
    });

    resultsLinktableHybridRemoteTrackerFlxTest
      .render()
      .$el.appendTo($("resultsLinktableHybridRemoteTrackerFlxTest"));

    // splk-wlk

    var tableHybridRemoteTrackerWlkTest = new TableView(
      {
        id: "tableHybridRemoteTrackerWlkTest",
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_wlk_tracker$",
        },
        count: 10,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "true",
        managerid: "searchHybridRemoteTrackerWlkTest",
        el: $("#tableHybridRemoteTrackerWlkTest"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableHybridRemoteTrackerWlkTest = new ResultsLinkView({
      id: "resultsLinktableHybridRemoteTrackerWlkTest",
      managerid: "searchHybridRemoteTrackerWlkTest",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableHybridRemoteTrackerWlkTest"),
    });

    resultsLinktableHybridRemoteTrackerWlkTest
      .render()
      .$el.appendTo($("resultsLinktableHybridRemoteTrackerWlkTest"));

    // dhm

    var tableHybridRemoteTrackerDhmTest = new TableView(
      {
        id: "tableHybridRemoteTrackerDhmTest",
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_dhm_tracker$",
        },
        count: 1,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchHybridRemoteTrackerDhmTest",
        el: $("#tableHybridRemoteTrackerDhmTest"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(tableHybridRemoteTrackerDhmTest);

    var resultsLinktableHybridRemoteTrackerDhmTest = new ResultsLinkView({
      id: "resultsLinktableHybridRemoteTrackerDhmTest",
      managerid: "searchHybridRemoteTrackerDhmTest",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableHybridRemoteTrackerDhmTest"),
    });

    resultsLinktableHybridRemoteTrackerDhmTest
      .render()
      .$el.appendTo($("resultsLinktableHybridRemoteTrackerDhmTest"));

    // mhm

    var tableHybridRemoteTrackerMhmTest = new TableView(
      {
        id: "tableHybridRemoteTrackerMhmTest",
        tokenDependencies: {
          depends: "$start_simulation_hybrid_remote_mhm_tracker$",
        },
        count: 1,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchHybridRemoteTrackerMhmTest",
        el: $("#tableHybridRemoteTrackerMhmTest"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(tableHybridRemoteTrackerMhmTest);

    var resultsLinktableHybridRemoteTrackerMhmTest = new ResultsLinkView({
      id: "resultsLinktableHybridRemoteTrackerMhmTest",
      managerid: "searchHybridRemoteTrackerMhmTest",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableHybridRemoteTrackerMhmTest"),
    });

    resultsLinktableHybridRemoteTrackerMhmTest
      .render()
      .$el.appendTo($("resultsLinktableHybridRemoteTrackerMhmTest"));

    // elastic sources
    var modal_input_elastic_source_search_type = new DropdownInput(
      {
        id: "modal_input_elastic_source_search_type",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "label",
        valueField: "value",
        managerid: "searchPopulateElasticSearchType",
        value: "$form.tk_input_elastic_source_search_type$",
        el: $("#modal_input_elastic_source_search_type"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_source_search_type.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_elastic_source_search_type);
    });

    var modal_input_elastic_source_object = new TextInput(
      {
        id: "modal_input_elastic_source_object",
        searchWhenChanged: false,
        value: "$form.tk_input_elastic_source_object$",
        el: $("#modal_input_elastic_source_object"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_source_object.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_elastic_source_object);
    });

    // Splunk deployment target
    var modal_input_elastic_account = new DropdownInput(
      {
        id: "modal_input_elastic_account",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "account",
        valueField: "account",
        managerid: "searchPopulateConfigurationAccountElastic",
        value: "$form.tk_input_elastic_dsm_account$",
        el: $("#modal_input_elastic_account"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_account.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_elastic_account);
      // check the connectivity if the account is not local
      if (newValue != undefined) {
        if (newValue != "local") {
          checkSplkFeedsRemoteAccount("elastic", newValue);
          setToken("tk_elastic_source_type_deployment", "remote");
        } else {
          $("#divParentCreateElasticValidateRemoteConnectivity").css(
            "display",
            "none"
          );
          setToken("tk_elastic_source_type_deployment", "local");
        }
      }
    });

    var modal_input_elastic_source_elastic_data_index = new TextInput(
      {
        id: "modal_input_elastic_source_elastic_data_index",
        searchWhenChanged: false,
        default: "myindex",
        initialValue: "myindex",
        value: "$form.tk_input_elastic_source_elastic_data_index$",
        el: $("#modal_input_elastic_source_elastic_data_index"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_source_elastic_data_index.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_elastic_source_elastic_data_index
        );
      }
    );

    var modal_input_elastic_source_elastic_splk_dsmtype = new TextInput(
      {
        id: "modal_input_elastic_source_elastic_splk_dsmtype",
        searchWhenChanged: false,
        default: "mysourcetype",
        initialValue: "mysourcetype",
        value: "$form.tk_input_elastic_source_elastic_splk_dsmtype$",
        el: $("#modal_input_elastic_source_elastic_splk_dsmtype"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_source_elastic_splk_dsmtype.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_elastic_source_elastic_splk_dsmtype
        );
      }
    );

    var modal_input_elastic_source_earliest = new TextInput(
      {
        id: "modal_input_elastic_source_earliest",
        searchWhenChanged: false,
        default: "-4h",
        initialValue: "-4h",
        value: "$form.tk_input_elastic_source_earliest$",
        el: $("#modal_input_elastic_source_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_source_earliest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_elastic_source_earliest);
    });

    var modal_input_elastic_source_latest = new TextInput(
      {
        id: "modal_input_elastic_source_latest",
        searchWhenChanged: false,
        default: "+4h",
        initialValue: "+4h",
        value: "$form.tk_input_elastic_source_latest$",
        el: $("#modal_input_elastic_source_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_source_latest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_elastic_source_latest);
    });

    // object_category

    var input_dataset_handler_dsm_object_category = new DropdownInput(
      {
        id: "input_dataset_handler_dsm_object_category",
        choices: [
          {
            label: "Object",
            value: "object",
          },
          {
            label: "Index",
            value: "index",
          },
          {
            label: "Sourcetype",
            value: "sourcetype",
          },
        ],
        searchWhenChanged: false,
        default: "object",
        showClearButton: true,
        initialValue: "object",
        selectFirstChoice: false,
        value: "$form.input_dataset_handler_dsm_object_category$",
        el: $("#input_dataset_handler_dsm_object_category"),
      },
      {
        tokens: true,
      }
    ).render();

    input_dataset_handler_dsm_object_category.on("change", function (newValue) {
      FormUtils.handleValueChange(input_dataset_handler_dsm_object_category);
    });

    // object

    var input_dataset_handler_dsm_object = new TextInput(
      {
        id: "input_dataset_handler_dsm_object",
        searchWhenChanged: true,
        value: "$form.input_dataset_handler_dsm_object$",
        el: $("#input_dataset_handler_dsm_object"),
      },
      {
        tokens: true,
      }
    ).render();

    input_dataset_handler_dsm_object.on("change", function (newValue) {
      FormUtils.handleValueChange(input_dataset_handler_dsm_object);
    });

    // object_category

    var input_dataset_handler_dhm_object_category = new DropdownInput(
      {
        id: "input_dataset_handler_dhm_object_category",
        choices: [
          {
            label: "Object",
            value: "object",
          },
          {
            label: "Index",
            value: "index",
          },
          {
            label: "Sourcetype",
            value: "sourcetype",
          },
        ],
        searchWhenChanged: false,
        default: "object",
        showClearButton: true,
        initialValue: "object",
        selectFirstChoice: false,
        value: "$form.input_dataset_handler_dhm_object_category$",
        el: $("#input_dataset_handler_dhm_object_category"),
      },
      {
        tokens: true,
      }
    ).render();

    input_dataset_handler_dhm_object_category.on("change", function (newValue) {
      FormUtils.handleValueChange(input_dataset_handler_dhm_object_category);
    });

    // object

    var input_dataset_handler_dhm_object = new TextInput(
      {
        id: "input_dataset_handler_dhm_object",
        searchWhenChanged: true,
        value: "$form.input_dataset_handler_dhm_object$",
        el: $("#input_dataset_handler_dhm_object"),
      },
      {
        tokens: true,
      }
    ).render();

    input_dataset_handler_dhm_object.on("change", function (newValue) {
      FormUtils.handleValueChange(input_dataset_handler_dhm_object);
    });

    // object_category

    var input_dataset_handler_mhm_object_category = new DropdownInput(
      {
        id: "input_dataset_handler_mhm_object_category",
        choices: [
          {
            label: "Object",
            value: "object",
          },
          {
            label: "Index",
            value: "index",
          },
          {
            label: "metric_category",
            value: "metric_category",
          },
        ],
        searchWhenChanged: false,
        default: "object",
        showClearButton: true,
        initialValue: "object",
        selectFirstChoice: false,
        value: "$form.input_dataset_handler_mhm_object_category$",
        el: $("#input_dataset_handler_mhm_object_category"),
      },
      {
        tokens: true,
      }
    ).render();

    input_dataset_handler_mhm_object_category.on("change", function (newValue) {
      FormUtils.handleValueChange(input_dataset_handler_mhm_object_category);
    });

    // object

    var input_dataset_handler_mhm_object = new TextInput(
      {
        id: "input_dataset_handler_mhm_object",
        searchWhenChanged: true,
        value: "$form.input_dataset_handler_mhm_object$",
        el: $("#input_dataset_handler_mhm_object"),
      },
      {
        tokens: true,
      }
    ).render();

    input_dataset_handler_mhm_object.on("change", function (newValue) {
      FormUtils.handleValueChange(input_dataset_handler_mhm_object);
    });

    // Custom lagging

    var modal_input_custom_lagging_type = new DropdownInput(
      {
        id: "modal_input_custom_lagging_type",
        choices: [
          {
            label: "sourcetype",
            value: "sourcetype",
          },
          {
            label: "index",
            value: "index",
          },
          {
            label: "priority",
            value: "priority",
          },
        ],
        searchWhenChanged: true,
        default: "sourcetype",
        showClearButton: true,
        initialValue: "sourcetype",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_lagging_type$",
        el: $("#modal_input_custom_lagging_type"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_lagging_type.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_lagging_type);
    });

    var modal_input_custom_lagging_name = new TextInput(
      {
        id: "modal_input_custom_lagging_name",
        searchWhenChanged: true,
        value: "$form.tk_input_custom_lagging_name$",
        el: $("#modal_input_custom_lagging_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_lagging_name.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_lagging_name);
    });

    var modal_input_custom_lagging_value = new TextInput(
      {
        id: "modal_input_custom_lagging_value",
        searchWhenChanged: true,
        value: "$form.tk_input_custom_lagging_value$",
        el: $("#modal_input_custom_lagging_value"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_lagging_value.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_lagging_value);
    });

    var modal_input_custom_delay_value = new TextInput(
      {
        id: "modal_input_custom_delay_value",
        searchWhenChanged: true,
        value: "$form.tk_input_custom_delay_value$",
        el: $("#modal_input_custom_delay_value"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_delay_value.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_delay_value);
    });

    var modal_input_custom_lagging_object = new DropdownInput(
      {
        id: "modal_input_custom_lagging_object",
        choices: [
          {
            label: "splk-dsm",
            value: "splk-dsm",
          },
          {
            label: "splk-dhm",
            value: "splk-dhm",
          },
          {
            label: "all",
            value: "all",
          },
        ],
        searchWhenChanged: true,
        default: "all",
        showClearButton: true,
        initialValue: "all",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_lagging_object$",
        el: $("#modal_input_custom_lagging_object"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_lagging_object.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_lagging_object);
    });

    // Custom lagging
    var SingleCustomLagging = new SingleView(
      {
        id: "SingleCustomLagging",
        trendDisplayMode: "absolute",
        drilldown: "none",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        numberPrecision: "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        "trellis.size": "medium",
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "current lagging class(es)",
        managerid: "searchSingleCustomLagging",
        el: $("#SingleCustomLagging"),
      },
      {
        tokens: true,
      }
    ).render();

    // Custom lagging

    var modal_input_custom_lagging_search = new TextInput(
      {
        id: "modal_input_custom_lagging_search",
        tokenDependencies: {
          depends: "$show_table_custom_lagging$",
        },
        default: "*",
        searchWhenChanged: true,
        value: "$form.tk_input_custom_lagging_search$",
        el: $("#modal_input_custom_lagging_search"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_lagging_search.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_lagging_search);
    });

    // Custom lagging

    var tableCustomLagging = new TableElement(
      {
        id: "tableCustomLagging",
        tokenDependencies: {
          depends: "$show_table_custom_lagging$",
        },
        count: 5,
        drilldown: "none",
        fields: "level, name, object, value, select",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchCustomLagging",
        el: $("#tableCustomLagging"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableCheckBox("tableCustomLagging", "removeSplkDsmLaggingPolicy");

    var modal_input_tags_policies_policy_id = new TextInput(
      {
        id: "modal_input_tags_policies_id",
        searchWhenChanged: false,
        value: "$form.tk_tags_policies_policy_id$",
        el: $("#modal_input_tags_policies_policy_id"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_tags_policies_policy_id.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_tags_policies_policy_id);
    });

    // Simulation
    var tableTagsPoliciesSimulate = new TableElement(
      {
        id: "tableTagsPoliciesSimulate",
        tokenDependencies: {
          depends: "$start_simulation_tags_policies$",
        },
        count: 1,
        drilldown: "row",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchTagsPoliciesSimulate",
        el: $("#tableTagsPoliciesSimulate"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableTagsPoliciesSimulate = new ResultsLinkView({
      id: "resultsLinktableTagsPoliciesSimulate",
      managerid: "searchTagsPoliciesSimulate",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableTagsPoliciesSimulate"),
    });

    resultsLinktableTagsPoliciesSimulate
      .render()
      .$el.appendTo($("resultsLinktableTagsPoliciesSimulate"));

    // Data Sampling

    var tableDataSamplingShowBuiltinRules = new TableView(
      {
        id: "tableDataSamplingShowBuiltinRules",
        tokenDependencies: {
          depends: "$show_data_sampling$",
        },
        count: 8,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchDataSamplingShowBuiltinRules",
        el: $("#tableDataSamplingShowBuiltinRules"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableDataSamplingShowBuiltinRules = new ResultsLinkView({
      id: "resultsLinktableDataSamplingShowBuiltinRules",
      managerid: "searchDataSamplingShowBuiltinRules",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableDataSamplingShowBuiltinRules"),
    });

    resultsLinktableDataSamplingShowBuiltinRules
      .render()
      .$el.appendTo($("resultsLinktableDataSamplingShowBuiltinRules"));

    // Data sampling
    var modal_input_data_sampling_custom_rule_name = new TextInput(
      {
        id: "modal_input_data_sampling_custom_rule_name",
        searchWhenChanged: false,
        value: "$form.tk_data_sampling_custom_rule_name$",
        el: $("#modal_input_data_sampling_custom_rule_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_data_sampling_custom_rule_name.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_data_sampling_custom_rule_name);
      }
    );

    var modal_input_data_sampling_custom_rule_type = new DropdownInput(
      {
        id: "modal_input_data_sampling_custom_rule_type",
        choices: [
          {
            label: "rule must match",
            value: "inclusive",
          },
          {
            label: "rule must not match",
            value: "exclusive",
          },
        ],
        searchWhenChanged: true,
        default: "inclusive",
        showClearButton: true,
        initialValue: "inclusive",
        selectFirstChoice: false,
        value: "$form.tk_data_sampling_custom_rule_type$",
        el: $("#modal_input_data_sampling_custom_rule_type"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_data_sampling_custom_rule_type.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_data_sampling_custom_rule_type);
      }
    );

    // Data sampling sourcetype value
    var modal_input_data_sampling_custom_st_value = new TextInput(
      {
        id: "modal_input_data_sampling_custom_st_value",
        searchWhenChanged: false,
        default: "simulation:test_sourcetype",
        initialValue: "simulation:test_sourcetype",
        value: "$form.tk_data_sampling_custom_st_value$",
        width: 300,
        el: $("#modal_input_data_sampling_custom_st_value"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_data_sampling_custom_st_value.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_data_sampling_custom_st_value);
    });

    var modal_input_data_sampling_custom_timerange = new TimeRangeInput(
      {
        id: "modal_input_data_sampling_custom_timerange",
        searchWhenChanged: true,
        default: {
          latest_time: "now",
          earliest_time: "-24h",
        },
        earliest_time: "$form.timerange_sampling_simulation.earliest$",
        latest_time: "$form.timerange_sampling_simulation.latest$",
        el: $("#modal_input_data_sampling_custom_timerange"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_data_sampling_custom_timerange.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_data_sampling_custom_timerange);
      }
    );

    // Data sampling scope
    var modal_input_data_sampling_custom_sourcetype_scope = new TextInput(
      {
        id: "modal_input_data_sampling_custom_sourcetype_scope",
        searchWhenChanged: false,
        initialValue: "*",
        default: "*",
        value: "$form.tk_data_sampling_custom_sourcetype_scope$",
        el: $("#modal_input_data_sampling_custom_sourcetype_scope"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_data_sampling_custom_sourcetype_scope.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_data_sampling_custom_sourcetype_scope
        );
      }
    );

    // Data sampling number of records per sample
    var modal_input_data_sampling_records_nr = new TextInput(
      {
        id: "modal_input_data_sampling_records_nr",
        searchWhenChanged: true,
        default: "50",
        initialValue: "50",
        value: "$form.tk_input_data_sampling_records_nr$",
        el: $("#modal_input_data_sampling_records_nr"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_data_sampling_records_nr.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_data_sampling_records_nr);
    });

    // data sampling dropdown
    var modal_input_data_sampling_dropdown = new DropdownInput(
      {
        id: "modal_input_data_sampling_dropdown",
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
        },
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "object",
        selectFirstChoice: false,
        valueField: "object",
        value: "$form.tk_input_data_sampling_dropdown$",
        width: 300,
        managerid: "searchPopulateDataSampling",
        el: $("#modal_input_data_sampling_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_data_sampling_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_data_sampling_dropdown);
    });

    // Data sampling

    // Simulation
    var tableDataSamplingSimulateCustomRule = new TableView(
      {
        id: "tableDataSamplingSimulateCustomRule",
        tokenDependencies: {
          depends: "$start_simulation_data_sampling_custom_rule$",
        },
        count: 20,
        drilldown: "row",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchDataSamplingSimulateCustomRule",
        el: $("#tableDataSamplingSimulateCustomRule"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableDataSamplingSimulateCustomRule = new ResultsLinkView({
      id: "resultsLinktableDataSamplingSimulateCustomRule",
      managerid: "searchDataSamplingSimulateCustomRule",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableDataSamplingSimulateCustomRule"),
    });

    resultsLinktableDataSamplingSimulateCustomRule
      .render()
      .$el.appendTo($("resultsLinktableDataSamplingSimulateCustomRule"));

    var tableDataSamplingSimulateCustomRuleLatestEvent = new EventsViewer(
      {
        id: "tableDataSamplingSimulateCustomRuleLatestEvent",
        tokenDependencies: {
          depends: "$start_simulation_data_sampling_custom_rule_show_events$",
        },
        count: 20,
        drilldown: "row",
        "refresh.display": "none",
        type: "raw",
        managerid: "searchDataSamplingSimulateCustomRuleLatestEvent",
        el: $("#tableDataSamplingSimulateCustomRuleLatestEvent"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableDataSamplingSimulateCustomRuleLatestEvent =
      new ResultsLinkView({
        id: "resultsLinktableDataSamplingSimulateCustomRuleLatestEvent",
        managerid: "searchDataSamplingSimulateCustomRuleLatestEvent",
        "link.exportResults.visible": false,
        el: $("#resultsLinktableDataSamplingSimulateCustomRuleLatestEvent"),
      });

    resultsLinktableDataSamplingSimulateCustomRuleLatestEvent
      .render()
      .$el.appendTo(
        $("resultsLinktableDataSamplingSimulateCustomRuleLatestEvent")
      );

    // input multiselect for queues
    var inputHostQueues = new MultiSelectInput(
      {
        id: "inputHostQueues",
        tokenDependencies: {
          depends: "$tk_start_indexers_queues_searches$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "host",
        valuePrefix: 'host="',
        valueSuffix: '"',
        delimiter: " OR ",
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "host",
        value: "$form.inputHostQueues$",
        managerid: "searchPopulateHostQueues",
        el: $("#inputHostQueues"),
      },
      {
        tokens: true,
      }
    ).render();

    inputHostQueues.on("change", function (newValue) {
      FormUtils.handleValueChange(inputHostQueues);
    });

    var inputHostQueuesBreak = new DropdownInput(
      {
        id: "inputHostQueuesBreak",
        choices: [
          {
            label: "Queue",
            value: "name",
          },
          {
            label: "Queue, Ingest pipe",
            value: 'name . ":" . ingest_pipe',
          },
          {
            label: "Queue, Ingest pipe, host",
            value: 'host . ":" . name . ":" . ingest_pipe',
          },
        ],
        default: "name",
        searchWhenChanged: true,
        selectFirstChoice: false,
        showClearButton: true,
        initialValue: "name",
        value: "$form.inputHostQueuesBreak$",
        el: $("#inputHostQueuesBreak"),
      },
      {
        tokens: true,
      }
    ).render();

    inputHostQueuesBreak.on("change", function (newValue) {
      FormUtils.handleValueChange(inputHostQueuesBreak);
    });

    // input link selection for modal window
    var inputLinkQueuesTime = new LinkListInput(
      {
        id: "inputLinkQueuesTime",
        choices: [
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "30d",
            label: "30d",
          },
        ],
        default: "4h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "4h",
        value: "$form.inputLinkQueuesTime$",
        el: $("#inputLinkQueuesTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkQueuesTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkQueuesTime);
    });

    inputLinkQueuesTime.on("valueChange", function (e) {
      if (e.value === "4h") {
        EventHandler.setToken(
          "inputLinkQueuesTime.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken("inputLinkQueuesTime.latest", "now", {}, e.data);
        EventHandler.setToken("inputLinkQueuesTime.span", "5m", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "inputLinkQueuesTime.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken("inputLinkQueuesTime.latest", "now", {}, e.data);
        EventHandler.setToken("inputLinkQueuesTime.span", "15m", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "inputLinkQueuesTime.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken("inputLinkQueuesTime.latest", "now", {}, e.data);
        EventHandler.setToken("inputLinkQueuesTime.span", "30m", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "inputLinkQueuesTime.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken("inputLinkQueuesTime.latest", "now", {}, e.data);
        EventHandler.setToken("inputLinkQueuesTime.span", "4h", {}, e.data);
      }
    });

    // Ops: Indexer Queues
    var elementChartQueueAll = new ChartView(
      {
        id: "elementChartQueueAll",
        "charting.chart.nullValueMode": "gaps",
        resizable: true,
        "trellis.enabled": "0",
        "charting.axisTitleX.visibility": "collapsed",
        "refresh.display": "progressbar",
        "charting.chart.stackMode": "stacked",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisY.abbreviation": "none",
        "charting.legend.placement": "bottom",
        "charting.axisY2.abbreviation": "none",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.chart.showDataLabels": "none",
        "charting.axisY2.enabled": "0",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.style": "shiny",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart": "line",
        "charting.axisX.scale": "linear",
        "trellis.scales.shared": "1",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        height: "350",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.drilldown": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "trellis.size": "medium",
        "charting.axisY.scale": "linear",
        "charting.chart.bubbleSizeBy": "area",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisX.abbreviation": "none",
        "charting.layout.splitSeries": "0",
        "charting.lineWidth": "2",
        "charting.axisY2.scale": "inherit",
        managerid: "searchQueueAll",
        el: $("#elementChartQueueAll"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartQueueAll = new ResultsLinkView({
      id: "resultsLinkelementChartQueueAll",
      managerid: "searchQueueAll",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartQueueAll"),
    });

    resultsLinkelementChartQueueAll
      .render()
      .$el.appendTo($("resultsLinkelementChartQueueAll"));

    var elementChartQueuesTreillis = new ChartView(
      {
        id: "elementChartQueuesTreillis",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "line",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "none",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "trellis.enabled": "1",
        "trellis.scales.shared": "0",
        "trellis.size": "large",
        height: "1200",
        managerid: "searchQueueTreillis",
        el: $("#elementChartQueuesTreillis"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartQueuesTreillis = new ResultsLinkView({
      id: "resultsLinkelementChartQueuesTreillis",
      managerid: "searchQueueTreillis",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartQueuesTreillis"),
    });

    resultsLinkelementChartQueuesTreillis
      .render()
      .$el.appendTo($("resultsLinkelementChartQueuesTreillis"));

    // input multiselect for parsing
    var inputHostParsing = new MultiSelectInput(
      {
        id: "inputHostParsing",
        tokenDependencies: {
          depends: "$tk_start_parsing_issues_searches$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "host",
        valuePrefix: 'host="',
        valueSuffix: '"',
        delimiter: " OR ",
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "host",
        value: "$form.inputHostParsing$",
        managerid: "searchPopulateHostParsing",
        el: $("#inputHostParsing"),
      },
      {
        tokens: true,
      }
    ).render();

    inputHostParsing.on("change", function (newValue) {
      FormUtils.handleValueChange(inputHostParsing);
    });

    // input link selection for modal window
    var inputLinkParsingIssuesTime = new LinkListInput(
      {
        id: "inputLinkParsingIssuesTime",
        choices: [
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "30d",
            label: "30d",
          },
        ],
        default: "4h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "4h",
        value: "$form.inputLinkParsingIssuesTime$",
        el: $("#inputLinkParsingIssuesTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkParsingIssuesTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkParsingIssuesTime);
    });

    inputLinkParsingIssuesTime.on("valueChange", function (e) {
      if (e.value === "4h") {
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.latest",
          "now",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.span",
          "5m",
          {},
          e.data
        );
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.latest",
          "now",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.span",
          "15m",
          {},
          e.data
        );
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.latest",
          "now",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.span",
          "30m",
          {},
          e.data
        );
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.latest",
          "now",
          {},
          e.data
        );
        EventHandler.setToken(
          "inputLinkParsingIssuesTime.span",
          "4h",
          {},
          e.data
        );
      }
    });

    // modal Single Lag
    var elementSingleParsingIssues = new SingleView(
      {
        id: "elementSingleParsingIssues",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "all",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "SUMMARY",
        managerid: "searchParsingIssuesSingle",
        el: $("#elementSingleParsingIssues"),
      },
      {
        tokens: true,
      }
    ).render();

    // Ops: Parsing Issues
    var elementChartParsingIssues = new ChartView(
      {
        id: "elementChartParsingIssues",
        "charting.chart.nullValueMode": "gaps",
        resizable: true,
        "trellis.enabled": "0",
        "charting.axisTitleX.visibility": "collapsed",
        "refresh.display": "progressbar",
        "charting.chart.stackMode": "stacked",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisY.abbreviation": "none",
        "charting.legend.placement": "bottom",
        "charting.axisY2.abbreviation": "none",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.chart.showDataLabels": "none",
        "charting.axisY2.enabled": "0",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.style": "shiny",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart": "column",
        "charting.axisX.scale": "linear",
        "trellis.scales.shared": "1",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        height: "300",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.drilldown": "all",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "trellis.size": "medium",
        "charting.axisY.scale": "linear",
        "charting.chart.bubbleSizeBy": "area",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisX.abbreviation": "none",
        "charting.layout.splitSeries": "0",
        "charting.lineWidth": "2",
        "charting.axisY2.scale": "inherit",
        managerid: "searchParsingIssuesChart",
        el: $("#elementChartParsingIssues"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartParsingIssues = new ResultsLinkView({
      id: "resultsLinkelementChartParsingIssues",
      managerid: "searchParsingIssuesChart",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartParsingIssues"),
    });

    resultsLinkelementChartParsingIssues
      .render()
      .$el.appendTo($("resultsLinkelementChartParsingIssues"));

    var chartLineBreakingProcessorTopSource = new ChartView(
      {
        id: "chartLineBreakingProcessorTopSource",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchLineBreakingProcessorTopSource",
        el: $("#chartLineBreakingProcessorTopSource"),
      },
      {
        tokens: true,
      }
    ).render();

    var chartLineBreakingProcessorTopHost = new ChartView(
      {
        id: "chartLineBreakingProcessorTopHost",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchLineBreakingProcessorTopHost",
        el: $("#chartLineBreakingProcessorTopHost"),
      },
      {
        tokens: true,
      }
    ).render();

    var chartLineBreakingProcessorTopSourcetype = new ChartView(
      {
        id: "chartLineBreakingProcessorTopSourcetype",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchLineBreakingProcessorTopSourcetype",
        el: $("#chartLineBreakingProcessorTopSourcetype"),
      },
      {
        tokens: true,
      }
    ).render();

    var tableLineBreakingProcessorTopSource = new TableElement(
      {
        id: "tableLineBreakingProcessorTopSource",
        drilldown: "all",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchLineBreakingProcessorTopSource",
        el: $("#tableLineBreakingProcessorTopSource"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableLineBreakingProcessorTopSource = new ResultsLinkView({
      id: "resultsLinktableLineBreakingProcessorTopSource",
      managerid: "searchLineBreakingProcessorTopSource",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableLineBreakingProcessorTopSource"),
    });

    resultsLinktableLineBreakingProcessorTopSource
      .render()
      .$el.appendTo($("resultsLinktableLineBreakingProcessorTopSource"));

    var tableLineBreakingProcessorTopHost = new TableElement(
      {
        id: "tableLineBreakingProcessorTopHost",
        drilldown: "all",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchLineBreakingProcessorTopHost",
        el: $("#tableLineBreakingProcessorTopHost"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableLineBreakingProcessorTopHost = new ResultsLinkView({
      id: "resultsLinktableLineBreakingProcessorTopHost",
      managerid: "searchLineBreakingProcessorTopHost",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableLineBreakingProcessorTopHost"),
    });

    resultsLinktableLineBreakingProcessorTopHost
      .render()
      .$el.appendTo($("resultsLinktableLineBreakingProcessorTopHost"));

    var tableLineBreakingProcessorTopSourcetype = new TableElement(
      {
        id: "tableLineBreakingProcessorTopSourcetype",
        drilldown: "all",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchLineBreakingProcessorTopSourcetype",
        el: $("#tableLineBreakingProcessorTopSourcetype"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableLineBreakingProcessorTopSourcetype =
      new ResultsLinkView({
        id: "resultsLinktableLineBreakingProcessorTopSourcetype",
        managerid: "searchLineBreakingProcessorTopSourcetype",
        "link.exportResults.visible": false,
        el: $("#resultsLinktableLineBreakingProcessorTopSourcetype"),
      });

    resultsLinktableLineBreakingProcessorTopSourcetype
      .render()
      .$el.appendTo($("resultsLinktableLineBreakingProcessorTopSourcetype"));

    var chartAggregatorMiningProcessorTopSource = new ChartView(
      {
        id: "chartAggregatorMiningProcessorTopSource",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchAggregatorMiningProcessorTopSource",
        el: $("#chartAggregatorMiningProcessorTopSource"),
      },
      {
        tokens: true,
      }
    ).render();

    var chartAggregatorMiningProcessorTopHost = new ChartView(
      {
        id: "chartAggregatorMiningProcessorTopHost",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchAggregatorMiningProcessorTopHost",
        el: $("#chartAggregatorMiningProcessorTopHost"),
      },
      {
        tokens: true,
      }
    ).render();

    var chartAggregatorMiningProcessorTopSourcetype = new ChartView(
      {
        id: "chartAggregatorMiningProcessorTopSourcetype",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchAggregatorMiningProcessorTopSourcetype",
        el: $("#chartAggregatorMiningProcessorTopSourcetype"),
      },
      {
        tokens: true,
      }
    ).render();

    var tableAggregatorMiningProcessorTopSource = new TableElement(
      {
        id: "tableAggregatorMiningProcessorTopSource",
        drilldown: "none",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchAggregatorMiningProcessorTopSource",
        el: $("#tableAggregatorMiningProcessorTopSource"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableAggregatorMiningProcessorTopSource =
      new ResultsLinkView({
        id: "resultsLinktableAggregatorMiningProcessorTopSource",
        managerid: "searchAggregatorMiningProcessorTopSource",
        "link.exportResults.visible": false,
        el: $("#resultsLinktableAggregatorMiningProcessorTopSource"),
      });

    resultsLinktableAggregatorMiningProcessorTopSource
      .render()
      .$el.appendTo($("resultsLinktableAggregatorMiningProcessorTopSource"));

    var tableAggregatorMiningProcessorTopHost = new TableElement(
      {
        id: "tableAggregatorMiningProcessorTopHost",
        drilldown: "none",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchAggregatorMiningProcessorTopHost",
        el: $("#tableAggregatorMiningProcessorTopHost"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableAggregatorMiningProcessorTopHost = new ResultsLinkView({
      id: "resultsLinktableAggregatorMiningProcessorTopHost",
      managerid: "searchAggregatorMiningProcessorTopHost",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableAggregatorMiningProcessorTopHost"),
    });

    resultsLinktableAggregatorMiningProcessorTopHost
      .render()
      .$el.appendTo($("resultsLinktableAggregatorMiningProcessorTopHost"));

    var tableAggregatorMiningProcessorTopSourcetype = new TableElement(
      {
        id: "tableAggregatorMiningProcessorTopSourcetype",
        drilldown: "none",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchAggregatorMiningProcessorTopSourcetype",
        el: $("#tableAggregatorMiningProcessorTopSourcetype"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableAggregatorMiningProcessorTopSourcetype =
      new ResultsLinkView({
        id: "resultsLinktableAggregatorMiningProcessorTopSourcetype",
        managerid: "searchAggregatorMiningProcessorTopSourcetype",
        "link.exportResults.visible": false,
        el: $("#resultsLinktableAggregatorMiningProcessorTopSourcetype"),
      });

    resultsLinktableAggregatorMiningProcessorTopSourcetype
      .render()
      .$el.appendTo(
        $("resultsLinktableAggregatorMiningProcessorTopSourcetype")
      );

    var chartDateParserVerboseTopSource = new ChartView(
      {
        id: "chartDateParserVerboseTopSource",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchDateParserVerboseTopSource",
        el: $("#chartDateParserVerboseTopSource"),
      },
      {
        tokens: true,
      }
    ).render();

    var tableDateParserVerboseTopSource = new TableElement(
      {
        id: "tableDateParserVerboseTopSource",
        drilldown: "all",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchDateParserVerboseTopSource",
        el: $("#tableDateParserVerboseTopSource"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableDateParserVerboseTopSource = new ResultsLinkView({
      id: "resultsLinktableDateParserVerboseTopSource",
      managerid: "searchDateParserVerboseTopSource",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableDateParserVerboseTopSource"),
    });

    resultsLinktableDateParserVerboseTopSource
      .render()
      .$el.appendTo($("resultsLinktableDateParserVerboseTopSource"));

    var chartDateParserVerboseTopHost = new ChartView(
      {
        id: "chartDateParserVerboseTopHost",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchDateParserVerboseTopHost",
        el: $("#chartDateParserVerboseTopHost"),
      },
      {
        tokens: true,
      }
    ).render();

    var tableDateParserVerboseTopHost = new TableElement(
      {
        id: "tableDateParserVerboseTopHost",
        drilldown: "all",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchDateParserVerboseTopHost",
        el: $("#tableDateParserVerboseTopHost"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableDateParserVerboseTopHost = new ResultsLinkView({
      id: "resultsLinktableDateParserVerboseTopHost",
      managerid: "searchDateParserVerboseTopHost",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableDateParserVerboseTopHost"),
    });

    resultsLinktableDateParserVerboseTopHost
      .render()
      .$el.appendTo($("resultsLinktableDateParserVerboseTopHost"));

    var chartDateParserVerboseTopSourcetype = new ChartView(
      {
        id: "chartDateParserVerboseTopSourcetype",
        resizable: true,
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisTitleX.visibility": "visible",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisX.abbreviation": "none",
        "charting.axisX.scale": "linear",
        "charting.axisY.abbreviation": "none",
        "charting.axisY.scale": "linear",
        "charting.axisY2.abbreviation": "none",
        "charting.axisY2.enabled": "0",
        "charting.axisY2.scale": "inherit",
        "charting.chart": "pie",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.nullValueMode": "gaps",
        "charting.chart.showDataLabels": "none",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.stackMode": "default",
        "charting.chart.style": "shiny",
        "charting.drilldown": "all",
        "charting.layout.splitSeries": "0",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.legend.mode": "standard",
        "charting.legend.placement": "right",
        "charting.lineWidth": "2",
        "refresh.display": "progressbar",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        managerid: "searchDateParserVerboseTopSourcetype",
        el: $("#chartDateParserVerboseTopSourcetype"),
      },
      {
        tokens: true,
      }
    ).render();

    var tableDateParserVerboseTopSourcetype = new TableElement(
      {
        id: "tableDateParserVerboseTopSourcetype",
        drilldown: "all",
        count: "5",
        "refresh.display": "progressbar",
        managerid: "searchDateParserVerboseTopSourcetype",
        el: $("#tableDateParserVerboseTopSourcetype"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinktableDateParserVerboseTopSourcetype = new ResultsLinkView({
      id: "resultsLinktableDateParserVerboseTopSourcetype",
      managerid: "searchDateParserVerboseTopSourcetype",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableDateParserVerboseTopSourcetype"),
    });

    resultsLinktableDateParserVerboseTopSourcetype
      .render()
      .$el.appendTo($("resultsLinktableDateParserVerboseTopSourcetype"));

    var EventLineBreakingProcessorEvent = new EventsViewer(
      {
        id: "EventLineBreakingProcessorEvent",
        count: 5,
        "list.drilldown": "all",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "raw",
        managerid: "searchLineBreakingProcessorEvent",
        el: $("#EventLineBreakingProcessorEvent"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkEventLineBreakingProcessorEvent = new ResultsLinkView({
      id: "resultsLinkEventLineBreakingProcessorEvent",
      managerid: "searchLineBreakingProcessorEvent",
      "link.exportResults.visible": false,
      el: $("#resultsLinkEventLineBreakingProcessorEvent"),
    });

    resultsLinkEventLineBreakingProcessorEvent
      .render()
      .$el.appendTo($("resultsLinkEventLineBreakingProcessorEvent"));

    var EventAggregatorMiningProcessorEvent = new EventsViewer(
      {
        id: "EventAggregatorMiningProcessorEvent",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "raw",
        managerid: "searchAggregatorMiningProcessorEvent",
        el: $("#EventAggregatorMiningProcessorEvent"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkEventAggregatorMiningProcessorEvent = new ResultsLinkView({
      id: "resultsLinkEventAggregatorMiningProcessorEvent",
      managerid: "searchAggregatorMiningProcessorEvent",
      "link.exportResults.visible": false,
      el: $("#resultsLinkEventAggregatorMiningProcessorEvent"),
    });

    resultsLinkEventAggregatorMiningProcessorEvent
      .render()
      .$el.appendTo($("resultsLinkEventAggregatorMiningProcessorEvent"));

    var EventDateParserVerboseEvent = new EventsViewer(
      {
        id: "EventDateParserVerboseEvent",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "raw",
        managerid: "searchDateParserVerboseEvent",
        el: $("#EventDateParserVerboseEvent"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkEventDateParserVerboseEvent = new ResultsLinkView({
      id: "resultsLinkEventDateParserVerboseEvent",
      managerid: "searchDateParserVerboseEvent",
      "link.exportResults.visible": false,
      el: $("#resultsLinkEventDateParserVerboseEvent"),
    });

    resultsLinkEventDateParserVerboseEvent
      .render()
      .$el.appendTo($("resultsLinkEventDateParserVerboseEvent"));

    // data sources main modal view

    // modal Single Lag
    var elementSingleLagPerc95 = new SingleView(
      {
        id: "elementSingleLagPerc95",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "PERC95 INGESTION LATENCY (sec or [D+]HH:MM:SS)",
        managerid: "searchSingleLagPerc95",
        el: $("#elementSingleLagPerc95"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleLagPerc95 = new ResultsLinkView({
      id: "resultsLinkelementSingleLagPerc95",
      managerid: "searchSingleLagPerc95",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleLagPerc95"),
    });

    resultsLinkelementSingleLagPerc95
      .render()
      .$el.appendTo($("resultsLinkelementSingleLagPerc95"));

    // input link selection for modal window
    var inputLinkTime = new LinkListInput(
      {
        id: "inputLinkTime",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.modalActionTime$",
        el: $("#inputLinkTime"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkTime.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkTime);
    });

    // to replace the earliest in the token search
    function replaceLinkTimeFilters(tokenName, earliestValue) {
      // dynamically replace the search
      var tokenValue = getToken(tokenName);
      if (tokenValue != null) {
        replaceStr = 'earliest="' + earliestValue + '"';
        var re = /(earliest=\"\-\d*\w\")/;
        tokenValue = tokenValue.replace(re, replaceStr);
        setToken(tokenName, tokenValue);
      }
    }

    // to replace the span in the token search
    function replaceSpan(tokenName, spanValue) {
      // dynamically replace the search
      var tokenValue = getToken(tokenName);
      if (tokenValue != null) {
        replaceStr = "timechart span=" + spanValue;
        var re = /(timechart span=\d*\w)/g;
        tokenValue = tokenValue.replace(re, replaceStr);
        setToken(tokenName, tokenValue);
      }
    }

    inputLinkTime.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken("modalTime.earliest", "-30m", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "1m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-30m");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-30m");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-30m");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-30m");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "1m");
        //
      } else if (e.value === "60m") {
        EventHandler.setToken("modalTime.earliest", "-60m", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "1m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-60m");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-60m");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-60m");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-60m");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "1m");
        //
      } else if (e.value === "2h") {
        EventHandler.setToken("modalTime.earliest", "-2h", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "5m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-2h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-2h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-2h");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-2h");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "5m");
        //
      } else if (e.value === "4h") {
        EventHandler.setToken("modalTime.earliest", "-4h", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "5m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-4h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-4h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-4h");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-4h");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "5m");
        //
      } else if (e.value === "8h") {
        EventHandler.setToken("modalTime.earliest", "-8h", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "5m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-8h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-8h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-8h");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-8h");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "5m");
        //
      } else if (e.value === "12h") {
        EventHandler.setToken("modalTime.earliest", "-12h", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "10m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-12h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-12h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-12h");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-12h");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "10m");
        //
      } else if (e.value === "24h") {
        EventHandler.setToken("modalTime.earliest", "-24h", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "15m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-24h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-24h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-24h");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-24h");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "15m");
        //
      } else if (e.value === "48h") {
        EventHandler.setToken("modalTime.earliest", "-48h", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "30m", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-48h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-48h");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-48h");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-48h");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "30m");
        //
      } else if (e.value === "7d") {
        EventHandler.setToken("modalTime.earliest", "-7d", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "1h", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-7d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-7d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-7d");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-7d");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "1h");
        //
      } else if (e.value === "15d") {
        EventHandler.setToken("modalTime.earliest", "-15d", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "2h", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-15d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-15d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-15d");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-15d");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "2h");
        //
      } else if (e.value === "30d") {
        EventHandler.setToken("modalTime.earliest", "-30d", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "4h", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-30d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-30d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-30d");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-30d");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "4h");
        //
      } else if (e.value === "60d") {
        EventHandler.setToken("modalTime.earliest", "-60d", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "8h", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-60d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-60d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-60d");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-60d");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "8h");
        //
      } else if (e.value === "90d") {
        EventHandler.setToken("modalTime.earliest", "-90d", {}, e.data);
        EventHandler.setToken("modalTime.latest", "now", {}, e.data);
        EventHandler.setToken("modalTime.span", "12h", {}, e.data);

        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dsm_overview_single_stats", "-90d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_timechart", "-90d");
        replaceLinkTimeFilters("tk_splk_dsm_overview_root_search", "-90d");
        replaceLinkTimeFilters("tk_splk_dsm_raw_search", "-90d");
        // dynamically replace the span
        replaceSpan("tk_splk_dsm_overview_timechart", "12h");
        //
      }
    });

    var elementSingleLagAvg = new SingleView(
      {
        id: "elementSingleLagAvg",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "AVG INGESTION LATENCY (sec or [D+]HH:MM:SS)",
        managerid: "searchSingleLagAvg",
        el: $("#elementSingleLagAvg"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleLagAvg = new ResultsLinkView({
      id: "resultsLinkelementSingleLagAvg",
      managerid: "searchSingleLagAvg",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleLagAvg"),
    });

    resultsLinkelementSingleLagAvg
      .render()
      .$el.appendTo($("resultsLinkelementSingleLagAvg"));

    var elementSingleEventLag = new SingleView(
      {
        id: "elementSingleEventLag",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "CURRENT EVENT DELAY (sec or [D+]HH:MM:SS)",
        managerid: "searchSingleEventLag",
        el: $("#elementSingleEventLag"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleEventLag = new ResultsLinkView({
      id: "resultsLinkelementSingleEventLag",
      managerid: "searchSingleEventLag",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleEventLag"),
    });

    resultsLinkelementSingleEventLag
      .render()
      .$el.appendTo($("resultsLinkelementSingleEventLag"));

    var elementSingleSLApct = new SingleView(
      {
        id: "elementSingleSLApct",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "all",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "%",
        rangeColors: '["0xdc4e41","0xf1813f","0x45D4BA"]',
        colorMode: "none",
        rangeValues: "[50,90]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useColors: "1",
        useThousandSeparators: "1",
        underLabel: "SLA PCT (% time spent in green/blue over 90d)",
        managerid: "searchSingleSLApct",
        el: $("#elementSingleSLApct"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleSLApct = new ResultsLinkView({
      id: "resultsLinkelementSingleSLApct",
      managerid: "searchSingleSLApct",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSLApct"),
    });

    resultsLinkelementSingleSLApct
      .render()
      .$el.appendTo($("resultsLinkelementSingleSLApct"));

    elementSingleSLApct.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        var url =
          "/app/trackme/trackMe_sla?form.tk_tenant_id=" +
          encodeURI(getToken("tenant_id")) +
          "&form.tk_object_category=splk-dsm&form.tk_object=" +
          encodeURI(getToken("tk_object"));
        utils.redirect(url, false, "_blank");
      }
    });

    // splk-dsm overview data provider
    var inputSplkDsmOverviewDataProvider = new DropdownInput(
      {
        id: "inputSplkDsmOverviewDataProvider",
        choices: [
          {
            label: "TrackMe metrics",
            value: "trackme",
          },
          {
            label: "Splunk query",
            value: "splunk",
          },
        ],
        default: "trackme",
        searchWhenChanged: true,
        selectFirstChoice: false,
        showClearButton: true,
        initialValue: "trackme",
        value: "$form.tk_input_splk_dsm_overview_data_provider$",
        el: $("#inputSplkDsmOverviewDataProvider"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkDsmOverviewDataProvider.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkDsmOverviewDataProvider);

      var tk_splk_dsm_overview_single_stats;
      var tk_splk_dsm_overview_timechart;

      // set searches dynamically
      if (newValue === "trackme") {
        $("#data-source-overview-selector-info").html(
          '<p style="font-style: italic;"><b>These metrics are calculated when the tracker is executed against the 5 last minutes of data:</b> latest_eventcount_5m: trend variation metric of the event count calc. against the last 5min (not the true eventcount) | avg_latency_5m: last 5min recorded ingestion latency (diff. bw _indextime vs _time) | last_dcount_host_5min: last 5min distinct count host variation</p>'
        );
        tk_splk_dsm_overview_single_stats = getToken(
          "tk_splk_dsm_overview_trackme_single_stats"
        );
        tk_splk_dsm_overview_timechart = getToken(
          "tk_splk_dsm_overview_trackme_timechart"
        );

        if (
          tk_splk_dsm_overview_single_stats != null &&
          tk_splk_dsm_overview_timechart != null
        ) {
          setToken(
            "tk_splk_dsm_overview_single_stats",
            tk_splk_dsm_overview_single_stats
          );
          setToken(
            "tk_splk_dsm_overview_timechart",
            tk_splk_dsm_overview_timechart
          );
        }
      } else if (newValue === "splunk") {
        $("#data-source-overview-selector-info").html(
          '<p style="font-style: italic;"><b>The metrics are calculated against the data source directly:</b> event_counts: true events count per x time span | ingest_latency: ingestion latency (diff. between _indextime vs _time) | dcount_host: distinct count of hosts per x time span</p>'
        );
        tk_splk_dsm_overview_single_stats = getToken(
          "tk_splk_dsm_overview_splunk_single_stats"
        );
        tk_splk_dsm_overview_timechart = getToken(
          "tk_splk_dsm_overview_splunk_timechart"
        );

        if (
          tk_splk_dsm_overview_single_stats != null &&
          tk_splk_dsm_overview_timechart != null
        ) {
          setToken(
            "tk_splk_dsm_overview_single_stats",
            getToken("tk_splk_dsm_overview_splunk_single_stats")
          );
          setToken(
            "tk_splk_dsm_overview_timechart",
            getToken("tk_splk_dsm_overview_splunk_timechart")
          );
        }
      }
    });

    // splk-dsm char selection

    var searchSplkDsmOverviewChartSeries = new SearchManager(
      {
        id: "searchSplkDsmOverviewChartSeries",
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
        },
        earliest_time: "-5m",
        latest_time: "now",
        sample_ratio: null,
        search:
          "| `trackme_splk_dsm_populate_overview($tk_input_splk_dsm_overview_data_provider$)`",
        status_buckets: 0,
        cancelOnUnload: true,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var inputSplkDsmOverviewChartSeries = new DropdownInput(
      {
        id: "inputSplkDsmOverviewChartSeries",
        searchWhenChanged: true,
        labelField: "label",
        valueField: "value",
        selectFirstChoice: true,
        showClearButton: true,
        value: "$form.tk_input_splk_dsm_overview_chart_series$",
        managerid: "searchSplkDsmOverviewChartSeries",
        el: $("#inputSplkDsmOverviewChartSeries"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkDsmOverviewChartSeries.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkDsmOverviewChartSeries);
    });

    // splk-dhm overview data provider
    var inputSplkDhmOverviewDataProvider = new DropdownInput(
      {
        id: "inputSplkDhmOverviewDataProvider",
        choices: [
          {
            label: "TrackMe metrics",
            value: "trackme",
          },
          {
            label: "Splunk query",
            value: "splunk",
          },
        ],
        default: "trackme",
        searchWhenChanged: true,
        selectFirstChoice: false,
        showClearButton: true,
        initialValue: "trackme",
        value: "$form.tk_input_splk_dhm_overview_data_provider$",
        el: $("#inputSplkDhmOverviewDataProvider"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkDhmOverviewDataProvider.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkDhmOverviewDataProvider);

      // set searches dynamically
      if (newValue === "trackme") {
        $("#data-host-overview-selector-info").html(
          '<p style="font-style: italic;"><b>These metrics are calculated when the tracker is executed against the 5 last minutes of data:</b> latest_eventcount_5m: trend variation metric of the event count calc. against the last 5min (not the true eventcount) | avg_latency_5m: last 5min recorded ingestion latency (diff. bw _indextime vs _time)</p>'
        );
        setToken(
          "tk_splk_dhm_overview_single_stats",
          getToken("tk_splk_dhm_overview_trackme_single_stats")
        );
        setToken(
          "tk_splk_dhm_overview_pie_root_search",
          getToken("tk_splk_dhm_overview_trackme_pie_root_search")
        );
        setToken(
          "tk_splk_dhm_overview_timechart",
          getToken("tk_splk_dhm_overview_trackme_timechart")
        );
      } else if (newValue === "splunk") {
        $("#data-host-overview-selector-info").html(
          '<p style="font-style: italic;"><b>The metrics are calculated against the data source directly:</b> event_counts: true events count per x time span | ingest_latency: ingestion latency (diff. between _indextime vs _time) | dcount_host: distinct count of hosts per x time span</p>'
        );
        setToken(
          "tk_splk_dhm_overview_single_stats",
          getToken("tk_splk_dhm_overview_splunk_single_stats")
        );
        setToken(
          "tk_splk_dhm_overview_pie_root_search",
          getToken("tk_splk_dhm_overview_splunk_pie_root_search")
        );
        setToken(
          "tk_splk_dhm_overview_timechart",
          getToken("tk_splk_dhm_overview_splunk_timechart")
        );
      }
    });

    // modal window chart
    var elementChartLag = new ChartView(
      {
        id: "elementChartLag",
        "charting.axisX.abbreviation": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.axisTitleY.text": "Events count",
        "refresh.display": "progressbar",
        "charting.chart.nullValueMode": "gaps",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.axisTitleY2.text": "$splk_dsm_overview_chart1_axis$",
        "charting.axisLabelsY2.majorUnit":
          "$splk_dsm_overview_chart1_axisUnit$",
        "charting.axisX.scale": "linear",
        "charting.drilldown": "none",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.chart.overlayFields":
          "avg_latency,dcount_host,avg_latency_5m,latest_dcount_host_5m,lag_event_sec",
        "charting.chart.showDataLabels": "none",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisY2.enabled": "1",
        "charting.axisY2.scale": "inherit",
        "trellis.scales.shared": "1",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.style": "shiny",
        "charting.axisY.scale": "linear",
        "charting.layout.splitSeries": "0",
        "charting.fieldColors":
          '{"events_count": 0x7fbfff, "latest_eventcount_5m": 0x7fbfff, "avg_latency": 0xff6961, "avg_latency_5m": 0xff6961, "latest_dcount_host_5m": 0xff6961, "dcount_host": 0xff6961, "lag_event_sec": 0xffbf7f}',
        resizable: true,
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.lineWidth": "2",
        "charting.axisTitleY.visibility": "visible",
        "charting.chart.stackMode": "default",
        "charting.legend.placement": "right",
        "trellis.size": "medium",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisY2.abbreviation": "none",
        "charting.chart": "column",
        "charting.axisY.abbreviation": "none",
        "trellis.enabled": "0",
        managerid: "searchChartLag",
        el: $("#elementChartLag"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartLag = new ResultsLinkView({
      id: "resultsLinkelementChartLag",
      managerid: "searchChartLag",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartLag"),
    });

    resultsLinkelementChartLag
      .render()
      .$el.appendTo($("resultsLinkelementChartLag"));

    // Outliers

    //
    // splk-dsm
    //

    var elementOutlierDsm = new OutliersViz(
      {
        id: "elementOutlierDsm",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartDsm",
        el: $("#elementOutlierDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierDsm = new ResultsLinkView({
      id: "resultsLinkelementOutlierDsm",
      managerid: "searchOutlierDetectionChartDsm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierDsm"),
    });

    resultsLinkelementOutlierDsm
      .render()
      .$el.appendTo($("resultsLinkelementOutlierDsm"));

    var elementOutlierSimulationDsm = new OutliersViz(
      {
        id: "elementOutlierSimulationDsm",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationDsm",
        el: $("#elementOutlierSimulationDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierSimulationDsm = new ResultsLinkView({
      id: "resultsLinkelementOutlierSimulationDsm",
      managerid: "searchOutlierDetectionChartSimulationDsm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierSimulationDsm"),
    });

    resultsLinkelementOutlierSimulationDsm
      .render()
      .$el.appendTo($("resultsLinkelementOutlierSimulationDsm"));

    //
    // splk-flx
    //

    var elementOutlierFlx = new OutliersViz(
      {
        id: "elementOutlierFlx",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartFlx",
        el: $("#elementOutlierFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierFlx = new ResultsLinkView({
      id: "resultsLinkelementOutlierFlx",
      managerid: "searchOutlierDetectionChartFlx",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierFlx"),
    });

    resultsLinkelementOutlierFlx
      .render()
      .$el.appendTo($("resultsLinkelementOutlierFlx"));

    var elementOutlierSimulationFlx = new OutliersViz(
      {
        id: "elementOutlierSimulationFlx",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationFlx",
        el: $("#elementOutlierSimulationFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierSimulationFlx = new ResultsLinkView({
      id: "resultsLinkelementOutlierSimulationFlx",
      managerid: "searchOutlierDetectionChartSimulationFlx",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierSimulationFlx"),
    });

    resultsLinkelementOutlierSimulationFlx
      .render()
      .$el.appendTo($("resultsLinkelementOutlierSimulationFlx"));

    //
    // splk-wlk
    //

    var elementOutlierWlk = new OutliersViz(
      {
        id: "elementOutlierWlk",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartWlk",
        el: $("#elementOutlierWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierWlk = new ResultsLinkView({
      id: "resultsLinkelementOutlierWlk",
      managerid: "searchOutlierDetectionChartWlk",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierWlk"),
    });

    resultsLinkelementOutlierWlk
      .render()
      .$el.appendTo($("resultsLinkelementOutlierWlk"));

    var elementOutlierSimulationWlk = new OutliersViz(
      {
        id: "elementOutlierSimulationWlk",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationWlk",
        el: $("#elementOutlierSimulationWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierSimulationWlk = new ResultsLinkView({
      id: "resultsLinkelementOutlierSimulationWlk",
      managerid: "searchOutlierDetectionChartSimulationWlk",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierSimulationWlk"),
    });

    resultsLinkelementOutlierSimulationWlk
      .render()
      .$el.appendTo($("resultsLinkelementOutlierSimulationWlk"));

    //
    // splk-cim
    //

    var elementOutlierCim = new OutliersViz(
      {
        id: "elementOutlierCim",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartCim",
        el: $("#elementOutlierCim"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierCim = new ResultsLinkView({
      id: "resultsLinkelementOutlierCim",
      managerid: "searchOutlierDetectionChartCim",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierCim"),
    });

    resultsLinkelementOutlierCim
      .render()
      .$el.appendTo($("resultsLinkelementOutlierCim"));

    var elementOutlierSimulationCim = new OutliersViz(
      {
        id: "elementOutlierSimulationCim",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationCim",
        el: $("#elementOutlierSimulationCim"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierSimulationCim = new ResultsLinkView({
      id: "resultsLinkelementOutlierSimulationCim",
      managerid: "searchOutlierDetectionChartSimulationCim",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierSimulationCim"),
    });

    resultsLinkelementOutlierSimulationCim
      .render()
      .$el.appendTo($("resultsLinkelementOutlierSimulationCim"));

    //
    // splk-dhm
    //

    var elementOutlierDhm = new OutliersViz(
      {
        id: "elementOutlierDhm",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartDhm",
        el: $("#elementOutlierDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierDhm = new ResultsLinkView({
      id: "resultsLinkelementOutlierDhm",
      managerid: "searchOutlierDetectionChartDhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierDhm"),
    });

    resultsLinkelementOutlierDhm
      .render()
      .$el.appendTo($("resultsLinkelementOutlierDhm"));

    var elementOutlierSimulationDhm = new OutliersViz(
      {
        id: "elementOutlierSimulationDhm",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationDhm",
        el: $("#elementOutlierSimulationDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierSimulationDhm = new ResultsLinkView({
      id: "resultsLinkelementOutlierSimulationDhm",
      managerid: "searchOutlierDetectionChartSimulationDhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierSimulationDhm"),
    });

    resultsLinkelementOutlierSimulationDhm
      .render()
      .$el.appendTo($("resultsLinkelementOutlierSimulationDhm"));

    // CMDB

    var eventCmdbSplkDsm = new EventsViewer(
      {
        id: "eventCmdbSplkDsm",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchCmdbSplkDsm",
        el: $("#eventCmdbSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventCmdbSplkDsm = new ResultsLinkView({
      id: "resultsLinkeventCmdbSplkDsm",
      managerid: "searchCmdbSplkDsm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventCmdbSplkDsm"),
    });

    resultsLinkeventCmdbSplkDsm
      .render()
      .$el.appendTo($("resultsLinkeventCmdbSplkDsm"));

    var eventCmdbSplkDhm = new EventsViewer(
      {
        id: "eventCmdbSplkDhm",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchCmdbSplkDhm",
        el: $("#eventCmdbSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventCmdbSplkDhm = new ResultsLinkView({
      id: "resultsLinkeventCmdbSplkDhm",
      managerid: "searchCmdbSplkDhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventCmdbSplkDhm"),
    });

    resultsLinkeventCmdbSplkDhm
      .render()
      .$el.appendTo($("resultsLinkeventCmdbSplkDhm"));

    var eventCmdbSplkMhm = new EventsViewer(
      {
        id: "eventCmdbSplkMhm",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchCmdbSplkMhm",
        el: $("#eventCmdbSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventCmdbSplkMhm = new ResultsLinkView({
      id: "resultsLinkeventCmdbSplkMhm",
      managerid: "searchCmdbSplkMhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventCmdbSplkMhm"),
    });

    resultsLinkeventCmdbSplkMhm
      .render()
      .$el.appendTo($("resultsLinkeventCmdbSplkMhm"));

    var eventCmdbSplkCim = new EventsViewer(
      {
        id: "eventCmdbSplkCim",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchCmdbSplkCim",
        el: $("#eventCmdbSplkCim"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventCmdbSplkCim = new ResultsLinkView({
      id: "resultsLinkeventCmdbSplkCim",
      managerid: "searchCmdbSplkCim",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventCmdbSplkCim"),
    });

    resultsLinkeventCmdbSplkCim
      .render()
      .$el.appendTo($("resultsLinkeventCmdbSplkCim"));

    var eventCmdbSplkFlx = new EventsViewer(
      {
        id: "eventCmdbSplkFlx",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchCmdbSplkFlx",
        el: $("#eventCmdbSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventCmdbSplkFlx = new ResultsLinkView({
      id: "resultsLinkeventCmdbSplkFlx",
      managerid: "searchCmdbSplkFlx",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventCmdbSplkFlx"),
    });

    resultsLinkeventCmdbSplkFlx
      .render()
      .$el.appendTo($("resultsLinkeventCmdbSplkFlx"));

    var eventCmdbSplkWlk = new EventsViewer(
      {
        id: "eventCmdbSplkWlk",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchCmdbSplkWlk",
        el: $("#eventCmdbSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventCmdbSplkWlk = new ResultsLinkView({
      id: "resultsLinkeventCmdbSplkWlk",
      managerid: "searchCmdbSplkWlk",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventCmdbSplkWlk"),
    });

    resultsLinkeventCmdbSplkWlk
      .render()
      .$el.appendTo($("resultsLinkeventCmdbSplkWlk"));

    // Smart Status

    var eventSmartStatusSplkDsm = new EventsViewer(
      {
        id: "eventSmartStatusSplkDsm",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchSmartStatusSplkDsm",
        el: $("#eventSmartStatusSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventSmartStatusSplkDsm = new ResultsLinkView({
      id: "resultsLinkeventSmartStatusSplkDsm",
      managerid: "searchSmartStatusSplkDsm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventSmartStatusSplkDsm"),
    });

    resultsLinkeventSmartStatusSplkDsm
      .render()
      .$el.appendTo($("resultsLinkeventSmartStatusSplkDsm"));

    var eventSmartStatusSplkDhm = new EventsViewer(
      {
        id: "eventSmartStatusSplkDhm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 20,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSmartStatusSplkDhm",
        el: $("#eventSmartStatusSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventSmartStatusSplkDhm = new ResultsLinkView({
      id: "resultsLinkeventSmartStatusSplkDhm",
      managerid: "searchSmartStatusSplkDhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventSmartStatusSplkDhm"),
    });

    resultsLinkeventSmartStatusSplkDhm
      .render()
      .$el.appendTo($("resultsLinkeventSmartStatusSplkDhm"));

    var eventSmartStatusSplkMhm = new EventsViewer(
      {
        id: "eventSmartStatusSplkMhm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 20,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSmartStatusSplkMhm",
        el: $("#eventSmartStatusSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventSmartStatusSplkMhm = new ResultsLinkView({
      id: "resultsLinkeventSmartStatusSplkMhm",
      managerid: "searchSmartStatusSplkMhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventSmartStatusSplkMhm"),
    });

    resultsLinkeventSmartStatusSplkMhm
      .render()
      .$el.appendTo($("resultsLinkeventSmartStatusSplkMhm"));

    var eventSmartStatusSplkWlk = new EventsViewer(
      {
        id: "eventSmartStatusSplkWlk",
        count: 5,
        "list.drilldown": "none",
        "raw.drilldown": "none",
        "table.drilldown": "none",
        type: "list",
        managerid: "searchSmartStatusSplkWlk",
        el: $("#eventSmartStatusSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventSmartStatusSplkWlk = new ResultsLinkView({
      id: "resultsLinkeventSmartStatusSplkWlk",
      managerid: "searchSmartStatusSplkWlk",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventSmartStatusSplkWlk"),
    });

    resultsLinkeventSmartStatusSplkWlk
      .render()
      .$el.appendTo($("resultsLinkeventSmartStatusSplkWlk"));

    // Data Parsing Quality
    var elementSearchSplkDsmParsingQualityChart = new ChartView(
      {
        id: "elementSearchSplkDsmParsingQualityChart",
        "charting.chart.nullValueMode": "gaps",
        resizable: true,
        "trellis.enabled": "0",
        "charting.axisTitleX.visibility": "collapsed",
        "refresh.display": "progressbar",
        "charting.chart.stackMode": "stacked",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisY.abbreviation": "none",
        "charting.legend.placement": "bottom",
        "charting.axisY2.abbreviation": "none",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.chart.showDataLabels": "none",
        "charting.axisY2.enabled": "0",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.style": "shiny",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart": "column",
        "charting.axisX.scale": "linear",
        "trellis.scales.shared": "1",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.drilldown": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "trellis.size": "medium",
        "charting.axisY.scale": "linear",
        "charting.chart.bubbleSizeBy": "area",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisX.abbreviation": "none",
        "charting.layout.splitSeries": "0",
        "charting.lineWidth": "2",
        "charting.axisY2.scale": "inherit",
        managerid: "SearchSplkDsmParsingQualityChart",
        el: $("#elementSearchSplkDsmParsingQualityChart"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSearchSplkDsmParsingQualityChart =
      new ResultsLinkView({
        id: "resultsLinkelementSearchSplkDsmParsingQualityChart",
        managerid: "SearchSplkDsmParsingQualityChart",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSearchSplkDsmParsingQualityChart"),
      });

    resultsLinkelementSearchSplkDsmParsingQualityChart
      .render()
      .$el.appendTo($("resultsLinkelementSearchSplkDsmParsingQualityChart"));

    // Lagging performance metrics
    var chartLaggingMetricSplkDsmOverTime = new ChartView(
      {
        id: "chartLaggingMetricSplkDsmOverTime",
        "charting.axisX.abbreviation": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.axisTitleY.text":
          "$splk_dsm_overview_metrics_chart1_axisy_title$",
        "refresh.display": "progressbar",
        "charting.chart.nullValueMode": "gaps",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.axisTitleY2.text": "$splk_dsm_overview_metrics_chart1_axis$",
        "charting.axisLabelsY2.majorUnit":
          "$splk_dsm_overview_metrics_chart1_axisUnit$",
        "charting.axisX.scale": "linear",
        "charting.drilldown": "none",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.chart.overlayFields":
          "lag_event_sec,lag_ingestion_sec,hostcount_4h",
        "charting.chart.showDataLabels": "none",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisY2.enabled": "1",
        "charting.axisY2.scale": "inherit",
        "trellis.scales.shared": "1",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.style": "shiny",
        "charting.axisY.scale": "linear",
        "charting.layout.splitSeries": "0",
        "charting.fieldColors":
          '{"eventcount_4h": 0xaec6cf, "lag_event_sec": 0x9542f5, "lag_ingestion_sec": 0xff6961, "hostcount_4h": 0xff6961}',
        resizable: true,
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.lineWidth": "2",
        "charting.axisTitleY.visibility": "visible",
        "charting.chart.stackMode": "default",
        "charting.legend.placement": "right",
        "trellis.size": "medium",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisY2.abbreviation": "none",
        "charting.chart": "$splk_dsm_overview_metrics_chart$",
        "charting.axisY.abbreviation": "none",
        "trellis.enabled": "0",
        height: "350",
        managerid: "searchLaggingMetricSplkDsm",
        el: $("#chartLaggingMetricSplkDsmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartLaggingMetricSplkDsmOverTime = new ResultsLinkView({
      id: "resultsLinkchartLaggingMetricSplkDsmOverTime",
      managerid: "searchLaggingMetricSplkDsm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartLaggingMetricSplkDsmOverTime"),
    });

    resultsLinkchartLaggingMetricSplkDsmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartLaggingMetricSplkDsmOverTime"));

    // cim metrics
    var inputSplkCimMetricsSeries = new DropdownInput(
      {
        id: "inputSplkCimMetricsSeries",
        choices: [
          {
            label: "pct_coverage_compliant",
            value: "pct_coverage_compliant",
          },
          {
            label: "pct_coverage_unknown",
            value: "pct_coverage_unknown",
          },
          {
            label: "count_unknown",
            value: "count_unknown",
          },
          {
            label: "count_not_unknown",
            value: "count_not_unknown",
          },
          {
            label: "total_count",
            value: "total_count",
          },
          {
            label: "status",
            value: "status",
          },
        ],
        default: "pct_coverage_compliant",
        searchWhenChanged: true,
        selectFirstChoice: false,
        showClearButton: true,
        initialValue: "pct_coverage_compliant",
        width: 300,
        value: "$form.tk_input_splk_cim_metrics_series$",
        el: $("#inputSplkCimMetricsSeries"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkCimMetricsSeries.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkCimMetricsSeries);
    });

    inputSplkCimMetricsSeries.on("valueChange", function (e) {
      if (e.value === "pct_coverage_compliant") {
        setToken("splk_cim_metrics_chart", "line");
        setToken("splk_cim_metrics_chart1_axis", "% coverage compliant");
        setToken("splk_cim_metrics_chart1_axisUnit", "1");
        setToken("splk_cim_metrics_chart1_axisy_title", "% coverage compliant");
        setToken(
          "splk_cim_metrics_mstats_search",
          "avg(trackme.splk.cim.pct_coverage_compliant) as pct_coverage_compliant"
        );
        setToken(
          "splk_cim_metrics_timechart_search",
          "avg(pct_coverage_compliant) as pct_coverage_compliant"
        );
      } else if (e.value === "pct_coverage_unknown") {
        setToken("splk_cim_metrics_chart", "line");
        setToken("splk_cim_metrics_chart1_axis", "% coverage not compliant");
        setToken("splk_cim_metrics_chart1_axisUnit", "1");
        setToken(
          "splk_cim_metrics_chart1_axisy_title",
          "% coverage not compliant"
        );
        setToken(
          "splk_cim_metrics_mstats_search",
          "avg(trackme.splk.cim.pct_coverage_unknown) as pct_coverage_unknown"
        );
        setToken(
          "splk_cim_metrics_timechart_search",
          "avg(pct_coverage_unknown) as pct_coverage_unknown"
        );
      } else if (e.value === "count_unknown") {
        setToken("splk_cim_metrics_chart", "line");
        setToken("splk_cim_metrics_chart1_axis", "eventcount");
        setToken("splk_cim_metrics_chart1_axisUnit", "1");
        setToken("splk_cim_metrics_chart1_axisy_title", "eventcount");
        setToken(
          "splk_cim_metrics_mstats_search",
          "avg(trackme.splk.cim.count_unknown) as count_unknown"
        );
        setToken(
          "splk_cim_metrics_timechart_search",
          "avg(count_unknown) as count_unknown"
        );
      } else if (e.value === "count_not_unknown") {
        setToken("splk_cim_metrics_chart", "line");
        setToken("splk_cim_metrics_chart1_axis", "eventcount");
        setToken("splk_cim_metrics_chart1_axisUnit", "1");
        setToken("splk_cim_metrics_chart1_axisy_title", "eventcount");
        setToken(
          "splk_cim_metrics_mstats_search",
          "avg(trackme.splk.cim.count_not_unknown) as count_not_unknown"
        );
        setToken(
          "splk_cim_metrics_timechart_search",
          "avg(count_not_unknown) as count_not_unknown"
        );
      } else if (e.value === "total_count") {
        setToken("splk_cim_metrics_chart", "line");
        setToken("splk_cim_metrics_chart1_axis", "eventcount");
        setToken("splk_cim_metrics_chart1_axisUnit", "1");
        setToken("splk_cim_metrics_chart1_axisy_title", "eventcount");
        setToken(
          "splk_cim_metrics_mstats_search",
          "avg(trackme.splk.cim.total_count) as total_count"
        );
        setToken(
          "splk_cim_metrics_timechart_search",
          "avg(total_count) as total_count"
        );
      } else if (e.value === "status") {
        setToken("splk_cim_metrics_chart", "line");
        setToken("splk_cim_metrics_chart1_axis", "status");
        setToken("splk_cim_metrics_chart1_axisUnit", "1");
        setToken("splk_cim_metrics_chart1_axisy_title", "status");
        setToken(
          "splk_cim_metrics_mstats_search",
          "max(trackme.splk.cim.status) as status"
        );
        setToken("splk_cim_metrics_timechart_search", "max(status) as status");
      }
    });

    var inputSplkCimMetricsEntities = new DropdownInput(
      {
        id: "inputSplkCimMetricsEntities",
        choices: [
          {
            label: "ANY",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        selectFirstChoice: false,
        default: "*",
        initialValue: "*",
        showClearButton: true,
        labelField: "label",
        width: 300,
        valueField: "label",
        value: "$form.tk_input_splk_cim_metrics_entities$",
        managerid: "searchPopulateMetricsCimEntities",
        el: $("#inputSplkCimMetricsEntities"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkCimMetricsEntities.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkCimMetricsEntities);
    });

    var inputSplkCimMetricsField = new DropdownInput(
      {
        id: "inputSplkCimMetricsField",
        choices: [
          {
            label: "ANY",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        selectFirstChoice: false,
        default: "*",
        initialValue: "*",
        showClearButton: true,
        labelField: "cim_field",
        width: 300,
        valueField: "cim_field",
        value: "$form.tk_input_splk_cim_metrics_field$",
        managerid: "searchPopulateMetricsCimFields",
        el: $("#inputSplkCimMetricsField"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkCimMetricsField.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkCimMetricsField);
    });

    //
    var inputSplkDsmOverviewMetricsChartSeries = new DropdownInput(
      {
        id: "inputSplkDsmOverviewMetricsChartSeries",
        choices: [
          {
            label: "Latency metrics",
            value: "latency_metrics",
          },
          {
            label: "Volume metrics",
            value: "volume_metrics",
          },
          {
            label: "Host Distinct count metrics",
            value: "host_dcount_metrics",
          },
          {
            label: "Eventcount / lag (4h)",
            value: "eventcount_4h, lag_event_sec, lag_ingestion_sec",
          },
          {
            label: "Eventcount / Host dcount (4h)",
            value: "eventcount_4h, hostcount_4h",
          },
        ],
        default: "latency_metrics",
        searchWhenChanged: true,
        selectFirstChoice: false,
        showClearButton: true,
        initialValue: "latency_metrics",
        width: 300,
        value: "$form.tk_input_splk_dsm_overview_metrics_chart_series$",
        el: $("#inputSplkDsmOverviewMetricsChartSeries"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkDsmOverviewMetricsChartSeries.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkDsmOverviewMetricsChartSeries);
    });

    inputSplkDsmOverviewMetricsChartSeries.on("valueChange", function (e) {
      if (e.value === "volume_metrics") {
        setToken("splk_dsm_overview_metrics_chart", "line");
        setToken("splk_dsm_overview_metrics_chart1_axis", "eventcount");
        setToken("splk_dsm_overview_metrics_chart1_axisUnit", "1");
        setToken("splk_dsm_overview_metrics_chart1_axisy_title", "eventcount");
        setToken(
          "splk_dsm_metrics_mstats_search",
          "avg(trackme.splk.feeds.avg_eventcount_5m) as avg_eventcount_5m, latest(trackme.splk.feeds.latest_eventcount_5m) as latest_eventcount_5m, avg(trackme.splk.feeds.perc95_eventcount_5m) as perc95_eventcount_5m, avg(trackme.splk.feeds.stdev_eventcount_5m) as stdev_eventcount_5m"
        );
        setToken(
          "splk_dsm_metrics_timechart_search",
          "avg(avg_eventcount_5m) as avg_eventcount_5m, sum(latest_eventcount_5m) as latest_eventcount_5m, avg(perc95_eventcount_5m) as perc95_eventcount_5m, avg(stdev_eventcount_5m) as stdev_eventcount_5m"
        );
      } else if (e.value === "latency_metrics") {
        setToken("splk_dsm_overview_metrics_chart", "line");
        setToken("splk_dsm_overview_metrics_chart1_axis", "latency (sec)");
        setToken("splk_dsm_overview_metrics_chart1_axisUnit", "0.1");
        setToken(
          "splk_dsm_overview_metrics_chart1_axisy_title",
          "latency (sec)"
        );
        setToken(
          "splk_dsm_metrics_mstats_search",
          "avg(trackme.splk.feeds.avg_latency_5m) as avg_latency_5m, avg(trackme.splk.feeds.latest_latency_5m) as latest_latency_5m, avg(trackme.splk.feeds.perc95_latency_5m) as perc95_latency_5m, avg(trackme.splk.feeds.stdev_latency_5m) as stdev_latency_5m"
        );
        setToken(
          "splk_dsm_metrics_timechart_search",
          "avg(avg_latency_5m) as avg_latency_5m, avg(latest_latency_5m) as latest_latency_5m, avg(perc95_latency_5m) as perc95_latency_5m, avg(stdev_latency_5m) as stdev_latency_5m"
        );
      } else if (e.value === "host_dcount_metrics") {
        setToken("splk_dsm_overview_metrics_chart", "line");
        setToken(
          "splk_dsm_overview_metrics_chart1_axis",
          "host dictinct count (#)"
        );
        setToken("splk_dsm_overview_metrics_chart1_axisUnit", "0.1");
        setToken(
          "splk_dsm_overview_metrics_chart1_axisy_title",
          "hosts distinct count (#)"
        );
        setToken(
          "splk_dsm_metrics_mstats_search",
          "avg(trackme.splk.feeds.avg_dcount_host_5m) as avg_dcount_host_5m, avg(trackme.splk.feeds.latest_dcount_host_5m) as latest_dcount_host_5m, avg(trackme.splk.feeds.perc95_dcount_host_5m) as perc95_dcount_host_5m, avg(trackme.splk.feeds.stdev_dcount_host_5m) as stdev_dcount_host_5m"
        );
        setToken(
          "splk_dsm_metrics_timechart_search",
          "avg(avg_dcount_host_5m) as avg_dcount_host_5m, avg(latest_dcount_host_5m) as latest_dcount_host_5m, avg(perc95_dcount_host_5m) as perc95_dcount_host_5m, avg(stdev_dcount_host_5m) as stdev_dcount_host_5m"
        );
      } else if (
        e.value === "eventcount_4h, lag_event_sec, lag_ingestion_sec"
      ) {
        setToken("splk_dsm_overview_metrics_chart", "column");
        setToken("splk_dsm_overview_metrics_chart1_axis", "lagging (sec)");
        setToken("splk_dsm_overview_metrics_chart1_axisUnit", "0.1");
        setToken(
          "splk_dsm_overview_metrics_chart1_axisy_title",
          "4h Events count"
        );
        setToken(
          "splk_dsm_metrics_mstats_search",
          "max(trackme.splk.feeds.eventcount_4h) as eventcount_4h, max(trackme.splk.feeds.lag_event_sec) as lag_event_sec, max(trackme.splk.feeds.lag_ingestion_sec) as lag_ingestion_sec"
        );
        setToken(
          "splk_dsm_metrics_timechart_search",
          "avg(eventcount_4h) as eventcount_4h, avg(lag_event_sec) as lag_event_sec, avg(lag_ingestion_sec) as lag_ingestion_sec"
        );
      } else if (e.value === "eventcount_4h, hostcount_4h") {
        setToken("splk_dsm_overview_metrics_chart", "column");
        setToken(
          "splk_dsm_overview_metrics_chart1_axis",
          "hosts distinct count"
        );
        setToken("splk_dsm_overview_metrics_chart1_axisUnit", "1");
        setToken(
          "splk_dsm_overview_metrics_chart1_axisy_title",
          "4h Events count"
        );
        setToken(
          "splk_dsm_metrics_mstats_search",
          "max(trackme.splk.feeds.eventcount_4h) as eventcount_4h, max(trackme.splk.feeds.hostcount_4h) as hostcount_4h"
        );
        setToken(
          "splk_dsm_metrics_timechart_search",
          "avg(eventcount_4h) as eventcount_4h, avg(hostcount_4h) as hostcount_4h"
        );
      }
    });

    // Audit Flip Data Source
    var elementMainTableAuditFlipSplkDsm = new TableView(
      {
        id: "elementMainTableAuditFlipSplkDsm",
        count: 5,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMainSplkDsmAuditFlipTable",
        el: $("#elementMainTableAuditFlipSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementMainTableAuditFlipSplkDsm);

    var resultsLinkelementMainTableAuditFlipSplkDsm = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditFlipSplkDsm",
      managerid: "searchMainSplkDsmAuditFlipTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditFlipSplkDsm"),
    });

    resultsLinkelementMainTableAuditFlipSplkDsm
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditFlipSplkDsm"));

    var chartAuditFlipSplkDsmOverTime = new ChartView(
      {
        id: "chartAuditFlipSplkDsmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors":
          '{"orange": 0xffd394, "blue": 0xcfebf9, "green": 0xb6edb6, "red": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkDsmFlipOverTime",
        el: $("#chartAuditFlipSplkDsmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditFlipSplkDsmOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditFlipSplkDsmOverTime",
      managerid: "searchAuditSplkDsmFlipOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditFlipSplkDsmOverTime"),
    });

    resultsLinkchartAuditFlipSplkDsmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditFlipSplkDsmOverTime"));

    var TimelineSplkDsm = new TimeLine(
      {
        id: "TimelineSplkDsm",
        type: "timeline_app.timeline",
        resizable: false,
        drilldown: "none",
        "timeline_app.timeline.axisTimeFormat": "DAYS",
        "timeline_app.timeline.colorMode": "categorical",
        "timeline_app.timeline.maxColor": "#DA5C5C",
        "timeline_app.timeline.minColor": "#FFE8E8",
        "timeline_app.timeline.numOfBins": "6",
        "timeline_app.timeline.tooltipTimeFormat": "DAYS",
        "timeline_app.timeline.useColors": "1",
        height: "150",
        managerid: "searchSplkDsmTimeline",
        el: $("#TimelineSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkTimelineSplkDsm = new ResultsLinkView({
      id: "resultsLinkTimelineSplkDsm",
      managerid: "searchSplkDsmTimeline",
      "link.exportResults.visible": false,
      el: $("#resultsLinkTimelineSplkDsm"),
    });

    resultsLinkTimelineSplkDsm
      .render()
      .$el.appendTo($("resultsLinkTimelineSplkDsm"));

    var TimelineSplkDhm = new TimeLine(
      {
        id: "TimelineSplkDhm",
        type: "timeline_app.timeline",
        resizable: false,
        drilldown: "none",
        "timeline_app.timeline.axisTimeFormat": "DAYS",
        "timeline_app.timeline.colorMode": "categorical",
        "timeline_app.timeline.maxColor": "#DA5C5C",
        "timeline_app.timeline.minColor": "#FFE8E8",
        "timeline_app.timeline.numOfBins": "6",
        "timeline_app.timeline.tooltipTimeFormat": "DAYS",
        "timeline_app.timeline.useColors": "1",
        height: "150",
        managerid: "searchSplkDhmTimeline",
        el: $("#TimelineSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkTimelineSplkDhm = new ResultsLinkView({
      id: "resultsLinkTimelineSplkDhm",
      managerid: "searchSplkDhmTimeline",
      "link.exportResults.visible": false,
      el: $("#resultsLinkTimelineSplkDhm"),
    });

    resultsLinkTimelineSplkDhm
      .render()
      .$el.appendTo($("resultsLinkTimelineSplkDhm"));

    var TimelineSplkMhm = new TimeLine(
      {
        id: "TimelineSplkMhm",
        type: "timeline_app.timeline",
        resizable: false,
        drilldown: "none",
        "timeline_app.timeline.axisTimeFormat": "DAYS",
        "timeline_app.timeline.colorMode": "categorical",
        "timeline_app.timeline.maxColor": "#DA5C5C",
        "timeline_app.timeline.minColor": "#FFE8E8",
        "timeline_app.timeline.numOfBins": "6",
        "timeline_app.timeline.tooltipTimeFormat": "DAYS",
        "timeline_app.timeline.useColors": "1",
        height: "150",
        managerid: "searchSplkMhmTimeline",
        el: $("#TimelineSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkTimelineSplkMhm = new ResultsLinkView({
      id: "resultsLinkTimelineSplkMhm",
      managerid: "searchSplkMhmTimeline",
      "link.exportResults.visible": false,
      el: $("#resultsLinkTimelineSplkMhm"),
    });

    resultsLinkTimelineSplkMhm
      .render()
      .$el.appendTo($("resultsLinkTimelineSplkMhm"));

    var TimelineSplkFlx = new TimeLine(
      {
        id: "TimelineSplkFlx",
        type: "timeline_app.timeline",
        resizable: false,
        drilldown: "none",
        "timeline_app.timeline.axisTimeFormat": "DAYS",
        "timeline_app.timeline.colorMode": "categorical",
        "timeline_app.timeline.maxColor": "#DA5C5C",
        "timeline_app.timeline.minColor": "#FFE8E8",
        "timeline_app.timeline.numOfBins": "6",
        "timeline_app.timeline.tooltipTimeFormat": "DAYS",
        "timeline_app.timeline.useColors": "1",
        height: "150",
        managerid: "searchSplkFlxTimeline",
        el: $("#TimelineSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkTimelineSplkFlx = new ResultsLinkView({
      id: "resultsLinkTimelineSplkFlx",
      managerid: "searchSplkFlxTimeline",
      "link.exportResults.visible": false,
      el: $("#resultsLinkTimelineSplkFlx"),
    });

    resultsLinkTimelineSplkFlx
      .render()
      .$el.appendTo($("resultsLinkTimelineSplkFlx"));

    var TimelineSplkWlk = new TimeLine(
      {
        id: "TimelineSplkWlk",
        type: "timeline_app.timeline",
        resizable: false,
        drilldown: "none",
        "timeline_app.timeline.axisTimeFormat": "DAYS",
        "timeline_app.timeline.colorMode": "categorical",
        "timeline_app.timeline.maxColor": "#DA5C5C",
        "timeline_app.timeline.minColor": "#FFE8E8",
        "timeline_app.timeline.numOfBins": "6",
        "timeline_app.timeline.tooltipTimeFormat": "DAYS",
        "timeline_app.timeline.useColors": "1",
        height: "150",
        managerid: "searchSplkWlkTimeline",
        el: $("#TimelineSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkTimelineSplkWlk = new ResultsLinkView({
      id: "resultsLinkTimelineSplkWlk",
      managerid: "searchSplkWlkTimeline",
      "link.exportResults.visible": false,
      el: $("#resultsLinkTimelineSplkWlk"),
    });

    resultsLinkTimelineSplkWlk
      .render()
      .$el.appendTo($("resultsLinkTimelineSplkWlk"));

    // Audit Changes Data Source
    var eventAuditChangesSplkDsm = new EventsViewer(
      {
        id: "eventAuditChangesSplkDsm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchMainSplkDsmAuditChangesTable",
        el: $("#eventAuditChangesSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAuditChangesSplkDsm = new ResultsLinkView({
      id: "resultsLinkeventAuditChangesSplkDsm",
      managerid: "searchMainSplkDsmAuditChangesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAuditChangesSplkDsm"),
    });

    resultsLinkeventAuditChangesSplkDsm
      .render()
      .$el.appendTo($("resultsLinkeventAuditChangesSplkDsm"));

    var chartAuditChangesSplkDsmOverTime = new ChartView(
      {
        id: "chartAuditChangesSplkDsmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkDsmAuditChangesOverTime",
        el: $("#chartAuditChangesSplkDsmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditChangesSplkDsmOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditChangesSplkDsmOverTime",
      managerid: "searchMainSplkDsmAuditChangesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditChangesSplkDsmOverTime"),
    });

    resultsLinkchartAuditChangesSplkDsmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditChangesSplkDsmOverTime"));

    // data source monitoring

    // input lag

    var modal_input_lag = new TextInput(
      {
        id: "modal_input_lag",
        searchWhenChanged: true,
        value: "$form.tk_input_lag$",
        el: $("#modal_input_lag"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_lag.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_lag);
    });

    var modal_input_delay = new TextInput(
      {
        id: "modal_input_delay",
        searchWhenChanged: true,
        value: "$form.tk_input_delay$",
        el: $("#modal_input_delay"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_delay.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_delay);
    });

    var modal_input_future_tolerance = new TextInput(
      {
        id: "modal_input_future_tolerance",
        default: "system",
        searchWhenChanged: true,
        value: "$form.tk_input_future_tolerance$",
        el: $("#modal_input_future_tolerance"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_future_tolerance.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_future_tolerance);
    });

    var modal_input_lag_override_class = new DropdownInput(
      {
        id: "modal_input_lag_override_class",
        choices: [
          {
            label: "true",
            value: "true",
          },
          {
            label: "false",
            value: "false",
          },
        ],
        searchWhenChanged: true,
        default: "true",
        showClearButton: true,
        initialValue: "true",
        selectFirstChoice: false,
        value: "$form.modal_input_lag_override_class$",
        el: $("#modal_input_lag_override_class"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_lag_override_class.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_lag_override_class);
    });

    var modal_input_allow_adaptive_delay = new DropdownInput(
      {
        id: "modal_input_allow_adaptive_delay",
        choices: [
          {
            label: "true",
            value: "true",
          },
          {
            label: "false",
            value: "false",
          },
        ],
        searchWhenChanged: true,
        default: "true",
        showClearButton: true,
        initialValue: "true",
        selectFirstChoice: false,
        value: "$form.modal_input_allow_adaptive_delay$",
        el: $("#modal_input_allow_adaptive_delay"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_allow_adaptive_delay.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_allow_adaptive_delay);
    });

    var modal_input_lag_alert_over = new DropdownInput(
      {
        id: "modal_input_lag_alert_over",
        choices: [
          {
            label: "delay / latency",
            value: "all_kpis",
          },
          {
            label: "latency only",
            value: "lag_ingestion_kpi",
          },
          {
            label: "delay only",
            value: "lag_event_kpi",
          },
        ],
        searchWhenChanged: true,
        default: "all_kpis",
        showClearButton: true,
        initialValue: "true",
        selectFirstChoice: false,
        value: "$form.tk_input_data_lag_alert_kpis$",
        el: $("#modal_input_lag_alert_over"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_lag_alert_over.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_lag_alert_over);
    });

    // data source threshold simulation

    // input link
    var inputLinkSplkDsmSimulateThreshold = new LinkListInput(
      {
        id: "inputLinkSplkDsmSimulateThreshold",
        choices: [
          {
            value: "chart",
            label: "Chart",
          },
          {
            value: "events",
            label: "Events",
          },
        ],
        default: "chart",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "chart",
        value: "$form.inputLinkSplkDsmSimulateThreshold$",
        el: $("#inputLinkSplkDsmSimulateThreshold"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkSplkDsmSimulateThreshold.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkSplkDsmSimulateThreshold);
    });

    inputLinkSplkDsmSimulateThreshold.on("valueChange", function (e) {
      if (e.value === "chart") {
        $("#SplkDsmSimulateThresholdsChartParent").css("display", "inherit");
        $("#SplkDsmSimulateThresholdsEventsParent").css("display", "none");
      } else if (e.value === "events") {
        $("#SplkDsmSimulateThresholdsChartParent").css("display", "none");
        $("#SplkDsmSimulateThresholdsEventsParent").css("display", "inherit");
      }
    });

    // input lag

    var modal_input_splk_dsm_simulate_latency = new TextInput(
      {
        id: "modal_input_splk_dsm_simulate_latency",
        searchWhenChanged: true,
        value: "$form.tk_input_splk_dsm_simulate_latency$",
        el: $("#modal_input_splk_dsm_simulate_latency"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dsm_simulate_latency.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_dsm_simulate_latency);
    });

    var modal_input_splk_dsm_simulate_delay = new TextInput(
      {
        id: "modal_input_splk_dsm_simulate_delay",
        searchWhenChanged: true,
        value: "$form.tk_input_splk_dsm_simulate_delay$",
        el: $("#modal_input_splk_dsm_simulate_delay"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dsm_simulate_delay.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_dsm_simulate_delay);
    });

    // timerange picker
    var SplkDsmSimulateThresholdsTimeRange = new TimeRangeInput(
      {
        id: "SplkDsmSimulateThresholdsTimeRange",
        searchWhenChanged: true,
        default: {
          latest_time: "now",
          earliest_time: "-24h",
        },
        earliest_time:
          "$form.timerange_simulation_thresholds_splk_dsm.earliest$",
        latest_time: "$form.timerange_simulation_thresholds_splk_dsm.latest$",
        el: $("#SplkDsmSimulateThresholdsTimeRange"),
      },
      {
        tokens: true,
      }
    ).render();

    SplkDsmSimulateThresholdsTimeRange.on("change", function (newValue) {
      FormUtils.handleValueChange(SplkDsmSimulateThresholdsTimeRange);
    });

    // chart
    var SplkDsmSimulateThresholdsChart = new ChartView(
      {
        id: "SplkDsmSimulateThresholdsChart",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors":
          '{"latency_breached": 0x7b56db, "delay_breached": 0xcb2196}',
        resizable: true,
        height: "350",
        managerid: "searchSplkDsmSimulateThresholds",
        el: $("#SplkDsmSimulateThresholdsChart"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkSplkDsmSimulateThresholdsChart = new ResultsLinkView({
      id: "resultsLinkSplkDsmSimulateThresholdsChart",
      managerid: "searchSplkDsmSimulateThresholds",
      "link.exportResults.visible": false,
      el: $("#resultsLinkSplkDsmSimulateThresholdsChart"),
    });

    resultsLinkSplkDsmSimulateThresholdsChart
      .render()
      .$el.appendTo($("resultsLinkSplkDsmSimulateThresholdsChart"));

    // events
    var SplkDsmSimulateThresholdsEvents = new TableView(
      {
        id: "SplkDsmSimulateThresholdsEvents",
        count: 8,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchSplkDsmSimulateThresholdsEvents",
        el: $("#SplkDsmSimulateThresholdsEvents"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkSplkDsmSimulateThresholdsEvents = new ResultsLinkView({
      id: "resultsLinkSplkDsmSimulateThresholdsEvents",
      managerid: "searchSplkDsmSimulateThresholdsEvents",
      "link.exportResults.visible": false,
      el: $("#resultsLinkSplkDsmSimulateThresholdsEvents"),
    });

    resultsLinkSplkDsmSimulateThresholdsEvents
      .render()
      .$el.appendTo($("resultsLinkSplkDsmSimulateThresholdsEvents"));

    // Single Latency
    var singleSplkDsmSimulateThresholdLatency = new SingleView(
      {
        id: "singleSplkDsmSimulateThresholdLatency",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LATENCY BREACHED",
        managerid: "searchSplkDsmSimulateThresholdsSingleLatency",
        el: $("#singleSplkDsmSimulateThresholdLatency"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinksingleSplkDsmSimulateThresholdLatency = new ResultsLinkView({
      id: "resultsLinksingleSplkDsmSimulateThresholdLatency",
      managerid: "searchSingleLagPerc95",
      "link.exportResults.visible": false,
      el: $("#resultsLinksingleSplkDsmSimulateThresholdLatency"),
    });

    resultsLinksingleSplkDsmSimulateThresholdLatency
      .render()
      .$el.appendTo($("resultsLinksingleSplkDsmSimulateThresholdLatency"));

    // Single delay
    var singleSplkDsmSimulateThresholdDelay = new SingleView(
      {
        id: "singleSplkDsmSimulateThresholdDelay",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "DELAY BREACHED",
        managerid: "searchSplkDsmSimulateThresholdsSingleDelay",
        el: $("#singleSplkDsmSimulateThresholdDelay"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinksingleSplkDsmSimulateThresholdDelay = new ResultsLinkView({
      id: "resultsLinksingleSplkDsmSimulateThresholdDelay",
      managerid: "searchSingleLagPerc95",
      "link.exportResults.visible": false,
      el: $("#resultsLinksingleSplkDsmSimulateThresholdDelay"),
    });

    resultsLinksingleSplkDsmSimulateThresholdDelay
      .render()
      .$el.appendTo($("resultsLinksingleSplkDsmSimulateThresholdDelay"));

    // search
    var searchSplkDsmSimulateThresholds = new SearchManager(
      {
        id: "searchSplkDsmSimulateThresholds",
        earliest_time: "$timerange_simulation_thresholds_splk_dsm.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_simulation_thresholds_splk_dsm.latest$",
        search:
          '| mstats latest(trackme.splk.feeds.lag_event_sec) as delay_sec, latest(trackme.splk.feeds.avg_latency_5m) as latency_sec where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-dsm" object="$tk_object$" by object span=5m | eval latency_threshold=$tk_input_splk_dsm_simulate_latency$, delay_threshold=$tk_input_splk_dsm_simulate_delay$, latency_breached=if(latency_sec>latency_threshold, "True", "False"), delay_breached=if(delay_sec>delay_threshold, "True", "False") | timechart bins=1000 minspan=10m count(eval(latency_breached=="True")) as latency_breached, count(eval(delay_breached=="True")) as delay_breached',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        autostart: false,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    searchSplkDsmSimulateThresholds.on("search:done", function (properties) {
      // notify
      notify("success", "bottom", "Thresholds simulation search finished", "5");
    });

    var searchSplkDsmSimulateThresholdsEvents = new SearchManager(
      {
        id: "searchSplkDsmSimulateThresholdsEvents",
        earliest_time: "$timerange_simulation_thresholds_splk_dsm.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$timerange_simulation_thresholds_splk_dsm.latest$",
        search:
          '| mstats latest(trackme.splk.feeds.lag_event_sec) as delay_sec, latest(trackme.splk.feeds.avg_latency_5m) as latency_sec where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-dsm" object="$tk_object$" by object span=5m | eval latency_threshold=$tk_input_splk_dsm_simulate_latency$, delay_threshold=$tk_input_splk_dsm_simulate_delay$, latency_breached=if(latency_sec>latency_threshold, "True", "False"), delay_breached=if(delay_sec>delay_threshold, "True", "False") | where (latency_breached=="True" OR delay_breached="True") | eval latency_sec=round(latency_sec, 3), delay_sec=round(delay_sec, 0) | fields _time, object, delay*, latency* | sort - 0 _time',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        autostart: false,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchSplkDsmSimulateThresholdsSingleLatency = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats sum(latency_breached) as latency_breached",
        managerid: "searchSplkDsmSimulateThresholds",
        id: "searchSplkDsmSimulateThresholdsSingleLatency",
      },
      {
        tokens: true,
      }
    );

    var searchSplkDsmSimulateThresholdsSingleDelay = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "stats sum(delay_breached) as delay_breached",
        managerid: "searchSplkDsmSimulateThresholds",
        id: "searchSplkDsmSimulateThresholdsSingleDelay",
      },
      {
        tokens: true,
      }
    );

    // data source priority

    var modal_input_priority = new DropdownInput(
      {
        id: "modal_input_priority",
        choices: [
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        searchWhenChanged: true,
        default: "medium",
        showClearButton: true,
        initialValue: "medium",
        selectFirstChoice: false,
        value: "$form.tk_input_priority$",
        el: $("#modal_input_priority"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_priority.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_priority);
    });

    // data source monitoring

    var modal_input_wdays = new DropdownInput(
      {
        id: "modal_input_wdays",
        choices: [
          {
            label: "manual:all_days",
            value: "manual:all_days",
          },
          {
            label: "manual:monday-to-friday",
            value: "manual:monday-to-friday",
          },
          {
            label: "manual:monday-to-saturday",
            value: "manual:monday-to-saturday",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_days",
        showClearButton: true,
        initialValue: "all_days",
        selectFirstChoice: false,
        value: "$form.tk_input_wdays$",
        el: $("#modal_input_wdays"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays);
    });

    modal_input_wdays.on("valueChange", function (e) {
      if (e.value === "manual:enter_days_numbers") {
        EventHandler.setToken("show_manual_wdays", "true", {}, e.data);
      } else {
        unsetToken("show_manual_wdays");
      }
    });

    var modal_input_wdays_no = new CheckboxGroupInput(
      {
        id: "modal_input_wdays_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_wdays_no$",
        el: $("#modal_input_wdays_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_no);
    });

    var modal_input_splk_flx_wdays_no = new CheckboxGroupInput(
      {
        id: "modal_input_splk_flx_wdays_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_splk_flx_wdays_no$",
        el: $("#modal_input_splk_flx_wdays_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_wdays_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_flx_wdays_no);
    });

    var modal_input_splk_cim_wdays_no = new CheckboxGroupInput(
      {
        id: "modal_input_splk_cim_wdays_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_splk_cim_wdays_no$",
        el: $("#modal_input_splk_cim_wdays_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_wdays_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_cim_wdays_no);
    });

    var modal_input_splk_wlk_wdays_no = new CheckboxGroupInput(
      {
        id: "modal_input_splk_wlk_wdays_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_splk_wlk_wdays_no$",
        el: $("#modal_input_splk_wlk_wdays_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_wdays_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_wlk_wdays_no);
    });

    var modal_input_hours_ranges = new DropdownInput(
      {
        id: "modal_input_hours_ranges",
        choices: [
          {
            label: "manual:all_ranges",
            value: "manual:all_ranges",
          },
          {
            label: "manual:08h-to-20h",
            value: "manual:08h-to-20h",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_ranges",
        showClearButton: true,
        initialValue: "all_ranges",
        selectFirstChoice: false,
        value: "$form.tk_input_hours_ranges$",
        el: $("#modal_input_hours_ranges"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hours_ranges.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hours_ranges);
    });

    modal_input_hours_ranges.on("valueChange", function (e) {
      if (e.value === "manual:enter_hours_ranges") {
        EventHandler.setToken("show_manual_hours_ranges", "true", {}, e.data);
      } else {
        unsetToken("show_manual_hours_ranges");
      }
    });

    var modal_input_hours_ranges_no = new CheckboxGroupInput(
      {
        id: "modal_input_hours_ranges_no",
        prefix: "manual:",
        searchWhenChanged: true,
        default: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        initialValue: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        delimiter: ",",
        managerid: "search_gen_hours_ranges",
        labelField: "label",
        valueField: "value",
        value: "$form.tk_input_hours_ranges_no$",
        el: $("#modal_input_hours_ranges_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hours_ranges_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hours_ranges_no);
    });

    var modal_input_splk_dhm_hours_ranges = new DropdownInput(
      {
        id: "modal_input_splk_dhm_hours_ranges",
        choices: [
          {
            label: "manual:all_ranges",
            value: "manual:all_ranges",
          },
          {
            label: "manual:08h-to-20h",
            value: "manual:08h-to-20h",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_ranges",
        showClearButton: true,
        initialValue: "all_ranges",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_dhm_hours_ranges$",
        el: $("#modal_input_splk_dhm_hours_ranges"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dhm_hours_ranges.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_dhm_hours_ranges);
    });

    modal_input_splk_dhm_hours_ranges.on("valueChange", function (e) {
      if (e.value === "manual:enter_hours_ranges") {
        EventHandler.setToken("show_manual_hours_ranges", "true", {}, e.data);
      } else {
        unsetToken("show_manual_hours_ranges");
      }
    });

    var modal_input_splk_dhm_hours_ranges_no = new CheckboxGroupInput(
      {
        id: "modal_input_splk_dhm_hours_ranges_no",
        prefix: "manual:",
        searchWhenChanged: true,
        default: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        initialValue: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        delimiter: ",",
        managerid: "search_gen_hours_ranges",
        labelField: "label",
        valueField: "value",
        value: "$form.tk_input_splk_dhm_hours_ranges_no$",
        el: $("#modal_input_splk_dhm_hours_ranges_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dhm_hours_ranges_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_dhm_hours_ranges_no);
    });

    var modal_input_splk_flx_hours_ranges = new DropdownInput(
      {
        id: "modal_input_splk_flx_hours_ranges",
        choices: [
          {
            label: "manual:all_ranges",
            value: "manual:all_ranges",
          },
          {
            label: "manual:08h-to-20h",
            value: "manual:08h-to-20h",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_ranges",
        showClearButton: true,
        initialValue: "all_ranges",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_flx_hours_ranges$",
        el: $("#modal_input_splk_flx_hours_ranges"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_hours_ranges.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_flx_hours_ranges);
    });

    modal_input_splk_flx_hours_ranges.on("valueChange", function (e) {
      if (e.value === "manual:enter_hours_ranges") {
        EventHandler.setToken("show_manual_hours_ranges", "true", {}, e.data);
      } else {
        unsetToken("show_manual_hours_ranges");
      }
    });

    var modal_input_splk_flx_hours_ranges_no = new CheckboxGroupInput(
      {
        id: "modal_input_splk_flx_hours_ranges_no",
        prefix: "manual:",
        searchWhenChanged: true,
        default: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        initialValue: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        delimiter: ",",
        managerid: "search_gen_hours_ranges",
        labelField: "label",
        valueField: "value",
        value: "$form.tk_input_splk_flx_hours_ranges_no$",
        el: $("#modal_input_splk_flx_hours_ranges_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_hours_ranges_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_flx_hours_ranges_no);
    });

    var modal_input_splk_cim_hours_ranges = new DropdownInput(
      {
        id: "modal_input_splk_cim_hours_ranges",
        choices: [
          {
            label: "manual:all_ranges",
            value: "manual:all_ranges",
          },
          {
            label: "manual:08h-to-20h",
            value: "manual:08h-to-20h",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_ranges",
        showClearButton: true,
        initialValue: "all_ranges",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_cim_hours_ranges$",
        el: $("#modal_input_splk_cim_hours_ranges"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_hours_ranges.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_cim_hours_ranges);
    });

    modal_input_splk_cim_hours_ranges.on("valueChange", function (e) {
      if (e.value === "manual:enter_hours_ranges") {
        EventHandler.setToken("show_manual_hours_ranges", "true", {}, e.data);
      } else {
        unsetToken("show_manual_hours_ranges");
      }
    });

    var modal_input_splk_cim_hours_ranges_no = new CheckboxGroupInput(
      {
        id: "modal_input_splk_cim_hours_ranges_no",
        prefix: "manual:",
        searchWhenChanged: true,
        default: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        initialValue: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        delimiter: ",",
        managerid: "search_gen_hours_ranges",
        labelField: "label",
        valueField: "value",
        value: "$form.tk_input_splk_cim_hours_ranges_no$",
        el: $("#modal_input_splk_cim_hours_ranges_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_hours_ranges_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_cim_hours_ranges_no);
    });

    var modal_input_splk_wlk_hours_ranges = new DropdownInput(
      {
        id: "modal_input_splk_wlk_hours_ranges",
        choices: [
          {
            label: "manual:all_ranges",
            value: "manual:all_ranges",
          },
          {
            label: "manual:08h-to-20h",
            value: "manual:08h-to-20h",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_ranges",
        showClearButton: true,
        initialValue: "all_ranges",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_wlk_hours_ranges$",
        el: $("#modal_input_splk_wlk_hours_ranges"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_hours_ranges.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_wlk_hours_ranges);
    });

    modal_input_splk_wlk_hours_ranges.on("valueChange", function (e) {
      if (e.value === "manual:enter_hours_ranges") {
        EventHandler.setToken("show_manual_hours_ranges", "true", {}, e.data);
      } else {
        unsetToken("show_manual_hours_ranges");
      }
    });

    var modal_input_splk_wlk_hours_ranges_no = new CheckboxGroupInput(
      {
        id: "modal_input_splk_wlk_hours_ranges_no",
        prefix: "manual:",
        searchWhenChanged: true,
        default: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        initialValue: [
          "0,1",
          "2,3",
          "4,5",
          "6,7",
          "8,9",
          "10,11",
          "12,13",
          "14,15",
          "16,17",
          "18,19",
          "20,21",
          "22,23",
        ],
        delimiter: ",",
        managerid: "search_gen_hours_ranges",
        labelField: "label",
        valueField: "value",
        value: "$form.tk_input_splk_wlk_hours_ranges_no$",
        el: $("#modal_input_splk_wlk_hours_ranges_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_hours_ranges_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_wlk_hours_ranges_no);
    });

    // distinct count hosts
    var modal_input_dcount_host = new TextInput(
      {
        id: "modal_input_dcount_host",
        searchWhenChanged: true,
        default: "any",
        initialValue: "any",
        value: "$form.tk_input_splk_dsm_dcount_host$",
        el: $("#modal_input_dcount_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_dcount_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_dcount_host);
    });

    var modal_input_dcount_field = new DropdownInput(
      {
        id: "modal_input_dcount_field",
        choices: [
          {
            label: "avg_dcount_host_5m",
            value: "avg_dcount_host_5m",
          },
          {
            label: "latest_dcount_host_5m",
            value: "latest_dcount_host_5m",
          },
          {
            label: "perc95_dcount_host_5m",
            value: "perc95_dcount_host_5m",
          },
          {
            label: "stdev_dcount_host_5m",
            value: "stdev_dcount_host_5m",
          },
        ],
        searchWhenChanged: true,
        default: "latest_dcount_host_5m",
        showClearButton: true,
        initialValue: "all_ranges",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_dsm_dcount_field$",
        el: $("#modal_input_dcount_field"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_dcount_field.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_dcount_field);
    });

    //
    // modal Single AutoLag (splk-dsm)
    //

    // latency

    var elementSplkDsmAutoLaggingSplkDsmSingleLagPerc95 = new SingleView(
      {
        id: "elementSplkDsmAutoLaggingSplkDsmSingleLagPerc95",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS PERCENTILE 95 LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDsm7dSingleLagPerc95",
        el: $("#elementSplkDsmAutoLaggingSplkDsmSingleLagPerc95"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95 =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95",
        managerid: "searchSingleLagAutoLaggingSplkDsm7dSingleLagPerc95",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95"),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95")
      );

    var elementSplkDsmAutoLaggingSplkDsmSingleLagAvg = new SingleView(
      {
        id: "elementSplkDsmAutoLaggingSplkDsmSingleLagAvg",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS AVERAGE LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDsm7dSingleLagAvg",
        el: $("#elementSplkDsmAutoLaggingSplkDsmSingleLagAvg"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvg =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvg",
        managerid: "searchSingleLagAutoLaggingSplkDsm7dSingleLagAvg",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvg"),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvg
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvg")
      );

    var elementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d = new SingleView(
      {
        id: "elementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 30 DAYS PERCENTILE 95 LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDsm30dSingleLagPerc95",
        el: $("#elementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d",
        managerid: "searchSingleLagAutoLaggingSplkDsm30dSingleLagPerc95",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d"
        ),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagPerc95Last30d")
      );

    var elementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d = new SingleView(
      {
        id: "elementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 30 DAYS AVERAGE LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDsm30dSingleLagAvg",
        el: $("#elementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d",
        managerid: "searchSingleLagAutoLaggingSplkDsm30dSingleLagAvg",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d"
        ),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleLagAvgLast30d")
      );

    // delay

    var elementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95 = new SingleView(
      {
        id: "elementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS PERCENTILE 95 DELAY",
        managerid: "searchSingleDelayAutoLaggingSplkDsm7dSingleDelayPerc95",
        el: $("#elementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95 =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95",
        managerid: "searchSingleDelayAutoLaggingSplkDsm7dSingleDelayPerc95",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95"),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95")
      );

    var elementSplkDsmAutoLaggingSplkDsmSingleDelayAvg = new SingleView(
      {
        id: "elementSplkDsmAutoLaggingSplkDsmSingleDelayAvg",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS AVERAGE DELAY",
        managerid: "searchSingleDelayAutoLaggingSplkDsm7dSingleDelayAvg",
        el: $("#elementSplkDsmAutoLaggingSplkDsmSingleDelayAvg"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvg =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvg",
        managerid: "searchSingleDelayAutoLaggingSplkDsm7dSingleDelayAvg",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvg"),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvg
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvg")
      );

    var elementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d =
      new SingleView(
        {
          id: "elementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d",
          trendDisplayMode: "absolute",
          numberPrecision: "0",
          drilldown: "none",
          "trellis.size": "medium",
          trendColorInterpretation: "standard",
          height: "95",
          useColors: "0",
          colorBy: "value",
          showTrendIndicator: "1",
          showSparkline: "1",
          "trellis.enabled": "0",
          rangeColors:
            '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
          colorMode: "none",
          rangeValues: "[0,30,70,100]",
          unitPosition: "after",
          "trellis.scales.shared": "1",
          useThousandSeparators: "1",
          underLabel: "LAST 30 DAYS PERCENTILE 95 DELAY",
          managerid: "searchSingleDelayAutoLaggingSplkDsm30dSingleDelayPerc95",
          el: $("#elementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d"),
        },
        {
          tokens: true,
        }
      ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d",
        managerid: "searchSingleDelayAutoLaggingSplkDsm30dSingleDelayPerc95",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d"
        ),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayPerc95Last30d")
      );

    var elementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d = new SingleView(
      {
        id: "elementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 30 DAYS AVERAGE DELAY",
        managerid: "searchSingleDelayAutoLaggingSplkDsm30dSingleDelayAvg",
        el: $("#elementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d",
        managerid: "searchSingleDelayAutoLaggingSplkDsm30dSingleDelayAvg",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d"
        ),
      });

    resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDsmAutoLaggingSplkDsmSingleDelayAvgLast30d")
      );

    //
    // modal Single AutoLag (splk-dhm)
    //

    // latency

    var elementSplkDhmAutoLaggingSplkDhmSingleLagPerc95 = new SingleView(
      {
        id: "elementSplkDhmAutoLaggingSplkDhmSingleLagPerc95",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS PERCENTILE 95 LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDhm7dSingleLagPerc95",
        el: $("#elementSplkDhmAutoLaggingSplkDhmSingleLagPerc95"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95 =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95",
        managerid: "searchSingleLagAutoLaggingSplkDhm7dSingleLagPerc95",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95"),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95")
      );

    var elementSplkDhmAutoLaggingSplkDhmSingleLagAvg = new SingleView(
      {
        id: "elementSplkDhmAutoLaggingSplkDhmSingleLagAvg",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS AVERAGE LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDhm7dSingleLagAvg",
        el: $("#elementSplkDhmAutoLaggingSplkDhmSingleLagAvg"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvg =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvg",
        managerid: "searchSingleLagAutoLaggingSplkDhm7dSingleLagAvg",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvg"),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvg
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvg")
      );

    var elementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d = new SingleView(
      {
        id: "elementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 30 DAYS PERCENTILE 95 LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDhm30dSingleLagPerc95",
        el: $("#elementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d",
        managerid: "searchSingleLagAutoLaggingSplkDhm30dSingleLagPerc95",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d"
        ),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagPerc95Last30d")
      );

    var elementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d = new SingleView(
      {
        id: "elementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 30 DAYS AVERAGE LATENCY",
        managerid: "searchSingleLagAutoLaggingSplkDhm30dSingleLagAvg",
        el: $("#elementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d",
        managerid: "searchSingleLagAutoLaggingSplkDhm30dSingleLagAvg",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d"
        ),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleLagAvgLast30d")
      );

    // delay

    var elementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95 = new SingleView(
      {
        id: "elementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS PERCENTILE 95 DELAY",
        managerid: "searchSingleDelayAutoLaggingSplkDhm7dSingleDelayPerc95",
        el: $("#elementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95 =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95",
        managerid: "searchSingleDelayAutoLaggingSplkDhm7dSingleDelayPerc95",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95"),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95")
      );

    var elementSplkDhmAutoLaggingSplkDhmSingleDelayAvg = new SingleView(
      {
        id: "elementSplkDhmAutoLaggingSplkDhmSingleDelayAvg",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 7 DAYS AVERAGE DELAY",
        managerid: "searchSingleDelayAutoLaggingSplkDhm7dSingleDelayAvg",
        el: $("#elementSplkDhmAutoLaggingSplkDhmSingleDelayAvg"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvg =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvg",
        managerid: "searchSingleDelayAutoLaggingSplkDhm7dSingleDelayAvg",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvg"),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvg
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvg")
      );

    var elementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d =
      new SingleView(
        {
          id: "elementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d",
          trendDisplayMode: "absolute",
          numberPrecision: "0",
          drilldown: "none",
          "trellis.size": "medium",
          trendColorInterpretation: "standard",
          height: "95",
          useColors: "0",
          colorBy: "value",
          showTrendIndicator: "1",
          showSparkline: "1",
          "trellis.enabled": "0",
          rangeColors:
            '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
          colorMode: "none",
          rangeValues: "[0,30,70,100]",
          unitPosition: "after",
          "trellis.scales.shared": "1",
          useThousandSeparators: "1",
          underLabel: "LAST 30 DAYS PERCENTILE 95 DELAY",
          managerid: "searchSingleDelayAutoLaggingSplkDhm30dSingleDelayPerc95",
          el: $("#elementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d"),
        },
        {
          tokens: true,
        }
      ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d",
        managerid: "searchSingleDelayAutoLaggingSplkDhm30dSingleDelayPerc95",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d"
        ),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayPerc95Last30d")
      );

    var elementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d = new SingleView(
      {
        id: "elementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "none",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        height: "95",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "LAST 30 DAYS AVERAGE DELAY",
        managerid: "searchSingleDelayAutoLaggingSplkDhm30dSingleDelayAvg",
        el: $("#elementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d =
      new ResultsLinkView({
        id: "resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d",
        managerid: "searchSingleDelayAutoLaggingSplkDhm30dSingleDelayAvg",
        "link.exportResults.visible": false,
        el: $(
          "#resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d"
        ),
      });

    resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d
      .render()
      .$el.appendTo(
        $("resultsLinkelementSplkDhmAutoLaggingSplkDhmSingleDelayAvgLast30d")
      );

    //
    //
    //

    // Ack
    var input_ack_duration = new DropdownInput(
      {
        id: "input_ack_duration",
        choices: [],
        searchWhenChanged: true,
        labelField: "label",
        valueField: "duration",
        selectFirstChoice: true,
        showClearButton: true,
        value: "$form.input_ack_duration$",
        managerid: "searchAckDuration",
        el: $("#input_ack_duration"),
      },
      {
        tokens: true,
      }
    ).render();

    input_ack_duration.on("change", function (newValue) {
      FormUtils.handleValueChange(input_ack_duration);
    });

    // Ack type
    var input_ack_type = new DropdownInput(
      {
        id: "input_ack_type",
        choices: [
          {
            label: "sticky",
            value: "sticky",
          },
          {
            label: "unsticky",
            value: "unsticky",
          },
        ],
        searchWhenChanged: true,
        default: "unsticky",
        selectFirstChoice: true,
        initialValue: "unsticky",
        value: "$form.input_ack_type$",
        el: $("#input_ack_type"),
      },
      {
        tokens: true,
      }
    ).render();

    input_ack_type.on("change", function (newValue) {
      FormUtils.handleValueChange(input_ack_type);
    });

    // tags
    var modal_input_tags_new = new TextInput(
      {
        id: "modal_input_tags_new",
        searchWhenChanged: true,
        value: "$form.modal_input_tags_new$",
        el: $("#modal_input_tags_new"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_tags_new.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_tags_new);
    });

    var modal_input_tags_update = new MultiSelectInput(
      {
        id: "modal_input_tags_update",
        tokenDependencies: {
          depends: "$show_tags_multiselect$",
        },
        choices: [],
        searchWhenChanged: true,
        labelField: "tags",
        valueField: "tags",
        delimiter: ",",
        value: "$form.modal_input_tags_update$",
        managerid: "searchShowTags",
        el: $("#modal_input_tags_update"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_tags_update.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_tags_update);
    });

    // Identify card
    var FilterIdentityCardTable = new TextInput(
      {
        id: "FilterIdentityCardTable",
        searchWhenChanged: true,
        default: "*",
        value: "$form.FilterIdentityCardTable$",
        el: $("#FilterIdentityCardTable"),
      },
      {
        tokens: true,
      }
    ).render();

    FilterIdentityCardTable.on("change", function (newValue) {
      FormUtils.handleValueChange(FilterIdentityCardTable);
    });

    // Identity card
    var elementIdentityCardTable = new TableView(
      {
        id: "elementIdentityCardTable",
        count: 100,
        drilldown: "row",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchIdentityCardTable",
        el: $("#elementIdentityCardTable"),
      },
      {
        tokens: true,
      }
    ).render();

    elementIdentityCardTable.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();

        var tk_input_doc_keyid = e.data["row.keyid"];
        setToken("tk_input_doc_keyid", tk_input_doc_keyid);
        var tk_input_doc_object = e.data["row.object"];
        setToken("tk_input_doc_object", tk_input_doc_object);
        var tk_input_doc_link = e.data["row.doc_link"];
        setToken("tk_input_doc_link", tk_input_doc_link);
        var tk_input_doc_note = e.data["ow.doc_note"];
        setToken("tk_input_doc_note", tk_input_doc_note);

        // Enable modal context
        $("#associate_identity_card").modal("hide");
        $("#confirm_associate_identity_card").modal();
      }
    });

    var resultsLinkelementIdentityCardTable = new ResultsLinkView({
      id: "resultsLinkelementIdentityCardTable",
      managerid: "searchIdentityCardTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementIdentityCardTable"),
    });

    resultsLinkelementIdentityCardTable
      .render()
      .$el.appendTo($("resultsLinkelementIdentityCardTable"));

    // ALERT summary

    var modal_input_custom_alert_name = new TextInput(
      {
        id: "modal_input_custom_alert_name",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_name$",
        default: "Alert custom on $create_alert_object_type$",
        el: $("#modal_input_custom_alert_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_name.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_name);
    });

    // dynamicall generate the Trackme components

    function genLinkAlertInputReturnChoices(
      componentSplkDsms,
      componentSplkDhms,
      componentSplkMhms,
      componentSplkFlxs,
      componentSplkWlks,
      componentCimTracking
    ) {
      var choices = [];

      if (componentSplkDsms === 1) {
        choices.push({
          value: "splk_dsm",
          label: "SPLK-DSM (DATA SOURCES)",
        });
      }

      if (componentCimTracking === 1) {
        choices.push({
          value: "splk_cim",
          label: "SPLK-CIM (CIM TRACKING)",
        });
      }

      if (componentSplkDhms === 1) {
        choices.push({
          value: "splk_dhm",
          label: "SPLK-DHM (DATA HOSTS)",
        });
      }

      if (componentSplkMhms === 1) {
        choices.push({
          value: "splk_mhm",
          label: "SPLK-MHM (METRIC HOSTS)",
        });
      }

      if (componentSplkFlxs === 1) {
        choices.push({
          value: "splk_flx",
          label: "SPLK-FLX (FLEX OBJECTS)",
        });
      }

      if (componentSplkWlks === 1) {
        choices.push({
          value: "splk_wlk",
          label: "SPLK-WLK (SPLUNK WORKLOAD)",
        });
      }

      // return the choices array
      return choices;
    }

    function genLinkAlertInput() {
      // retrieve the tenant_id
      tenant_id = getToken("tenant_id");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/configuration/components";

      var data = {
        tenant_id: tenant_id,
      };

      // Get the KV entry content first
      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        dataType: "json",
        data: JSON.stringify(data),
        contentType: "application/json",
        success: function (returneddata) {
          var componentSplkDsms = returneddata.component_splk_dsm;
          var componentSplkDhms = returneddata.component_splk_dhm;
          var componentSplkMhms = returneddata.component_splk_mhm;
          var componentSplkFlxs = returneddata.component_splk_flx;
          var componentSplkWlks = returneddata.component_splk_wlk;
          var componentCimTracking = returneddata.component_cim_tracking;
          var componentOwner = returneddata.component_owner;

          // set the component owner token
          setToken("tk_tenant_owner", componentOwner);

          // get the choices array
          var choicesArray = genLinkAlertInputReturnChoices(
            componentSplkDsms,
            componentSplkDhms,
            componentSplkMhms,
            componentSplkFlxs,
            componentSplkWlks,
            componentCimTracking
          );

          var modal_input_custom_alert_object_type = new LinkListInput(
            {
              id: "modal_input_custom_alert_object_type",
              choices: choicesArray,
              selectFirstChoice: true,
              searchWhenChanged: true,
              value: "$form.inputCustomAlertObjectType$",
              el: $("#modal_input_custom_alert_object_type"),
            },
            {
              tokens: true,
            }
          ).render();

          modal_input_custom_alert_object_type.on(
            "change",
            function (newValue) {
              FormUtils.handleValueChange(modal_input_custom_alert_object_type);
            }
          );

          modal_input_custom_alert_object_type.on("valueChange", function (e) {
            if (e.value === "splk_dsm") {
              EventHandler.setToken(
                "create_alert_object_type",
                "splk-dsm",
                {},
                e.data
              );
              EventHandler.setToken(
                "create_alert_splk_dsm",
                "true",
                {},
                e.data
              );
              EventHandler.setToken(
                "form.tk_input_custom_alert_suppress_fields",
                "object",
                {},
                e.data
              );
              $("#div_create_alert_splk_dsm").css("display", "inherit");
              $("#div_create_alert_cim_tracking").css("display", "none");
              $("#div_create_alert_splk_dhm").css("display", "none");
              $("#div_create_alert_splk_mhm").css("display", "none");
              $("#div_create_alert_splk_flx").css("display", "none");
              $("#div_create_alert_splk_wlk").css("display", "none");

              // handle false
              setToken("create_alert_splk_dhm", "false");
              setToken("create_alert_splk_mhm", "false");
              setToken("create_alert_splk_flx", "false");
              setToken("create_alert_splk_wlk", "false");
              setToken("create_alert_splk_cim", "false");
            } else if (e.value === "splk_dhm") {
              EventHandler.setToken(
                "create_alert_object_type",
                "splk-dhm",
                {},
                e.data
              );
              EventHandler.setToken(
                "create_alert_splk_dhm",
                "true",
                {},
                e.data
              );
              EventHandler.setToken(
                "form.tk_input_custom_alert_suppress_fields",
                "object",
                {},
                e.data
              );
              $("#div_create_alert_splk_dsm").css("display", "none");
              $("#div_create_alert_cim_tracking").css("display", "none");
              $("#div_create_alert_splk_dhm").css("display", "inherit");
              $("#div_create_alert_splk_mhm").css("display", "none");
              $("#div_create_alert_splk_flx").css("display", "none");
              $("#div_create_alert_splk_wlk").css("display", "none");

              // handle false
              setToken("create_alert_splk_dsm", "false");
              setToken("create_alert_splk_mhm", "false");
              setToken("create_alert_splk_flx", "false");
              setToken("create_alert_splk_wlk", "false");
              setToken("create_alert_splk_cim", "false");
            } else if (e.value === "splk_flx") {
              EventHandler.setToken(
                "create_alert_object_type",
                "splk-flx",
                {},
                e.data
              );
              EventHandler.setToken(
                "create_alert_splk_flx",
                "true",
                {},
                e.data
              );
              EventHandler.setToken(
                "form.tk_input_custom_alert_suppress_fields",
                "object",
                {},
                e.data
              );
              $("#div_create_alert_splk_dsm").css("display", "none");
              $("#div_create_alert_cim_tracking").css("display", "none");
              $("#div_create_alert_splk_dhm").css("display", "none");
              $("#div_create_alert_splk_mhm").css("display", "none");
              $("#div_create_alert_splk_flx").css("display", "inherit");
              $("#div_create_alert_splk_wlk").css("display", "none");

              // handle false
              setToken("create_alert_splk_dsm", "false");
              setToken("create_alert_splk_dhm", "false");
              setToken("create_alert_splk_mhm", "false");
              setToken("create_alert_splk_wlk", "false");
              setToken("create_alert_splk_cim", "false");
            } else if (e.value === "splk_wlk") {
              EventHandler.setToken(
                "create_alert_object_type",
                "splk-wlk",
                {},
                e.data
              );
              EventHandler.setToken(
                "create_alert_splk_wlk",
                "true",
                {},
                e.data
              );
              EventHandler.setToken(
                "form.tk_input_custom_alert_suppress_fields",
                "object",
                {},
                e.data
              );
              $("#div_create_alert_splk_dsm").css("display", "none");
              $("#div_create_alert_cim_tracking").css("display", "none");
              $("#div_create_alert_splk_dhm").css("display", "none");
              $("#div_create_alert_splk_mhm").css("display", "none");
              $("#div_create_alert_splk_flx").css("display", "none");
              $("#div_create_alert_splk_wlk").css("display", "inherit");

              // handle false
              setToken("create_alert_splk_dsm", "false");
              setToken("create_alert_splk_dhm", "false");
              setToken("create_alert_splk_mhm", "false");
              setToken("create_alert_splk_flx", "false");
              setToken("create_alert_splk_cim", "false");
            } else if (e.value === "splk_mhm") {
              EventHandler.setToken(
                "create_alert_object_type",
                "splk-mhm",
                {},
                e.data
              );
              EventHandler.setToken(
                "create_alert_splk_mhm",
                "true",
                {},
                e.data
              );
              EventHandler.setToken(
                "form.tk_input_custom_alert_suppress_fields",
                "object",
                {},
                e.data
              );
              $("#div_create_alert_splk_dsm").css("display", "none");
              $("#div_create_alert_splk_dhm").css("display", "none");
              $("#div_create_alert_cim_tracking").css("display", "none");
              $("#div_create_alert_splk_mhm").css("display", "inherit");
              $("#div_create_alert_splk_flx").css("display", "none");
              $("#div_create_alert_splk_wlk").css("display", "none");

              // handle false
              setToken("create_alert_splk_dsm", "false");
              setToken("create_alert_splk_dhm", "false");
              setToken("create_alert_splk_flx", "false");
              setToken("create_alert_splk_wlk", "false");
              setToken("create_alert_splk_cim", "false");
            } else if (e.value === "splk_cim") {
              EventHandler.setToken(
                "create_alert_object_type",
                "splk-cim",
                {},
                e.data
              );
              EventHandler.setToken(
                "create_alert_cim_tracking",
                "true",
                {},
                e.data
              );
              EventHandler.setToken(
                "form.tk_input_custom_alert_suppress_fields",
                "object",
                {},
                e.data
              );
              $("#div_create_alert_cim_tracking").css("display", "inherit");
              $("#div_create_alert_splk_dsm").css("display", "none");
              $("#div_create_alert_splk_dhm").css("display", "none");
              $("#div_create_alert_splk_mhm").css("display", "none");
              $("#div_create_alert_splk_flx").css("display", "none");
              $("#div_create_alert_splk_wlk").css("display", "none");

              // handle false
              setToken("create_alert_splk_dsm", "false");
              setToken("create_alert_splk_dhm", "false");
              setToken("create_alert_splk_mhm", "false");
              setToken("create_alert_splk_flx", "false");
              setToken("create_alert_splk_wlk", "false");
            }
          });
        },
        error: function (xhr, textStatus, error) {
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          cssloaderremove();
          $("#modal_load_components_error")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_load_components_error").modal();
        },
      });
    }

    // generate now
    genLinkAlertInput();

    var modal_input_custom_priority_levels = new MultiSelectInput(
      {
        id: "modal_input_custom_priority_levels",
        choices: [
          {
            label: "ANY",
            value: "*",
          },
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        valuePrefix: 'priority="',
        valueSuffix: '"',
        delimiter: " OR ",
        searchWhenChanged: true,
        initialValue: ["*"],
        value: "$form.tk_input_custom_alert_priority$",
        el: $("#modal_input_custom_priority_levels"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_priority_levels.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_priority_levels);
    });

    var modal_input_custom_state_levels = new MultiSelectInput(
      {
        id: "modal_input_custom_state_levels",
        choices: [
          {
            label: "red",
            value: "red",
          },
          {
            label: "orange",
            value: "orange",
          },
          {
            label: "Any (red/orange)",
            value: "*",
          },
        ],
        valuePrefix: 'object_state="',
        valueSuffix: '"',
        delimiter: " OR ",
        searchWhenChanged: true,
        initialValue: ["red"],
        value: "$form.tk_input_custom_alert_state$",
        el: $("#modal_input_custom_state_levels"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_state_levels.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_state_levels);
    });

    var modal_input_custom_alert_splk_dsm_filter = new TextInput(
      {
        id: "modal_input_custom_alert_splk_dsm_filter",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_splk_dsm_filter$",
        default: "*",
        el: $("#modal_input_custom_alert_splk_dsm_filter"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_splk_dsm_filter.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_splk_dsm_filter);
    });

    var modal_input_custom_alert_cim_tracking_filter = new TextInput(
      {
        id: "modal_input_custom_alert_cim_tracking_filter",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_cim_tracking_filter$",
        default: "*",
        el: $("#modal_input_custom_alert_cim_tracking_filter"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_cim_tracking_filter.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_custom_alert_cim_tracking_filter
        );
      }
    );

    var modal_input_custom_tags = new MultiSelectInput(
      {
        id: "modal_input_custom_tags",
        choices: [
          {
            label: "ANY",
            value: "*",
          },
        ],
        valuePrefix: 'tags="',
        valueSuffix: '"',
        delimiter: " OR ",
        labelField: "tags",
        searchWhenChanged: true,
        initialValue: ["*"],
        selectFirstChoice: false,
        valueField: "tags",
        value: "$form.tk_input_custom_tags$",
        managerid: "search_alerts_get_tags",
        el: $("#modal_input_custom_tags"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_tags.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_tags);
    });

    var modal_input_custom_alert_trigger_on_outliers = new DropdownInput(
      {
        id: "modal_input_custom_alert_trigger_on_outliers",
        choices: [
          {
            label: "true",
            value: "true",
          },
          {
            label: "false",
            value: "false",
          },
        ],
        searchWhenChanged: false,
        default: "true",
        showClearButton: true,
        initialValue: "true",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_alert_trigger_on_outliers$",
        el: $("#modal_input_custom_alert_trigger_on_outliers"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_trigger_on_outliers.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_custom_alert_trigger_on_outliers
        );
      }
    );

    var modal_input_custom_alert_trigger_on_data_sampling = new DropdownInput(
      {
        id: "modal_input_custom_alert_trigger_on_data_sampling",
        choices: [
          {
            label: "true",
            value: "true",
          },
          {
            label: "false",
            value: "false",
          },
        ],
        searchWhenChanged: false,
        default: "true",
        showClearButton: true,
        initialValue: "true",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_alert_trigger_on_data_sampling$",
        el: $("#modal_input_custom_alert_trigger_on_data_sampling"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_trigger_on_data_sampling.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_custom_alert_trigger_on_data_sampling
        );
      }
    );

    var modal_input_custom_alert_splk_dhm_filter = new TextInput(
      {
        id: "modal_input_custom_alert_splk_dhm_filter",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_splk_dhm_filter$",
        default: "*",
        el: $("#modal_input_custom_alert_splk_dhm_filter"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_splk_dhm_filter.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_splk_dhm_filter);
    });

    var modal_input_custom_alert_trigger_on_outliers_splk_dhm =
      new DropdownInput(
        {
          id: "modal_input_custom_alert_trigger_on_outliers_splk_dhm",
          choices: [
            {
              label: "true",
              value: "true",
            },
            {
              label: "false",
              value: "false",
            },
          ],
          searchWhenChanged: false,
          default: "true",
          showClearButton: true,
          initialValue: "true",
          selectFirstChoice: false,
          value: "$form.tk_input_custom_alert_trigger_on_outliers_splk_dhm$",
          el: $("#modal_input_custom_alert_trigger_on_outliers_splk_dhm"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_custom_alert_trigger_on_outliers_splk_dhm.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_custom_alert_trigger_on_outliers_splk_dhm
        );
      }
    );

    var modal_input_custom_alert_splk_mhm_filter = new TextInput(
      {
        id: "modal_input_custom_alert_splk_mhm_filter",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_splk_mhm_filter$",
        default: "*",
        el: $("#modal_input_custom_alert_splk_mhm_filter"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_splk_mhm_filter.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_splk_mhm_filter);
    });

    var modal_input_custom_alert_splk_flx_filter = new TextInput(
      {
        id: "modal_input_custom_alert_splk_flx_filter",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_splk_flx_filter$",
        default: "*",
        el: $("#modal_input_custom_alert_splk_flx_filter"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_splk_flx_filter.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_splk_flx_filter);
    });

    var modal_input_custom_alert_splk_wlk_filter = new TextInput(
      {
        id: "modal_input_custom_alert_splk_wlk_filter",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_splk_wlk_filter$",
        default: "*",
        el: $("#modal_input_custom_alert_splk_wlk_filter"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_splk_wlk_filter.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_splk_wlk_filter);
    });

    var modal_input_custom_alert_cron = new TextInput(
      {
        id: "modal_input_custom_alert_cron",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_cron$",
        default: "*/5 * * * *",
        el: $("#modal_input_custom_alert_cron"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_cron.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_cron);
    });

    var modal_input_custom_alert_suppress_fields = new TextInput(
      {
        id: "modal_input_custom_alert_suppress_fields",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_suppress_fields$",
        el: $("#modal_input_custom_alert_suppress_fields"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_suppress_fields.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_suppress_fields);
    });

    var modal_input_custom_alert_suppress_period = new TextInput(
      {
        id: "modal_input_custom_alert_suppress_period",
        searchWhenChanged: false,
        value: "$form.tk_input_custom_alert_suppress_period$",
        default: "15m",
        el: $("#modal_input_custom_alert_suppress_period"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_suppress_period.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_suppress_period);
    });

    var modal_input_custom_alert_time_filtering = new DropdownInput(
      {
        id: "modal_input_custom_alert_time_filtering",
        choices: [
          {
            label: "Any time",
            value: "AnyTime",
          },
          {
            label: "Days business (08h-20h)",
            value: "Day_BusinessDays_8h-20h",
          },
          {
            label: "Days WE only (08h-20h)",
            value: "Day_WeekEnd_8h-20h",
          },
          {
            label: "Days of the Week (08h-20h)",
            value: "Day_AllDays_8h-20h",
          },
          {
            label: "Night business (20h-08h)",
            value: "Night_BusinessDays_20h-8h",
          },
          {
            label: "Night WE only (20h-08h)",
            value: "Night_WeekEnd_20h-8h",
          },
          {
            label: "Night days of the week (20h-08h)",
            value: "Night_AllDays_20h-8h",
          },
        ],
        searchWhenChanged: false,
        default: "AnyTime",
        showClearButton: true,
        initialValue: "AnyTime",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_alert_time_filtering$",
        el: $("#modal_input_custom_alert_time_filtering"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_time_filtering.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_time_filtering);
    });

    var modal_input_custom_alert_auto_ack = new DropdownInput(
      {
        id: "modal_input_custom_alert_auto_ack",
        choices: [
          {
            label: "enabled",
            value: "1",
          },
          {
            label: "disabled",
            value: "0",
          },
        ],
        searchWhenChanged: false,
        default: "1",
        showClearButton: true,
        initialValue: "1",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_alert_auto_ack$",
        el: $("#modal_input_custom_alert_auto_ack"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_auto_ack.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_auto_ack);
    });

    var modal_input_custom_alert_auto_ack_period = new TextInput(
      {
        id: "modal_input_custom_alert_auto_ack_period",
        searchWhenChanged: false,
        default: "86400",
        initialValue: "86400",
        value: "$form.tk_input_custom_alert_auto_ack_period$",
        el: $("#modal_input_custom_alert_auto_ack_period"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_auto_ack_period.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_auto_ack_period);
    });

    var modal_input_custom_alert_auto_ack_type = new TextInput(
      {
        id: "modal_input_custom_alert_auto_ack_type",
        searchWhenChanged: false,
        default: "unsticky",
        initialValue: "unsticky",
        value: "$form.tk_input_custom_alert_auto_ack_type$",
        el: $("#modal_input_custom_alert_auto_ack_type"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_auto_ack_type.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_auto_ack_type);
    });

    var modal_input_custom_alert_smart_status = new DropdownInput(
      {
        id: "modal_input_custom_alert_smart_status",
        choices: [
          {
            label: "enabled",
            value: "1",
          },
          {
            label: "disabled",
            value: "0",
          },
        ],
        searchWhenChanged: false,
        default: "1",
        showClearButton: true,
        initialValue: "1",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_alert_smart_status$",
        el: $("#modal_input_custom_alert_smart_status"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_smart_status.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_smart_status);
    });

    var modal_input_custom_alert_notable = new DropdownInput(
      {
        id: "modal_input_custom_alert_notable",
        choices: [
          {
            label: "enabled",
            value: "1",
          },
          {
            label: "disabled",
            value: "0",
          },
        ],
        searchWhenChanged: false,
        default: "1",
        showClearButton: true,
        initialValue: "1",
        selectFirstChoice: false,
        value: "$form.tk_input_custom_alert_notable$",
        el: $("#modal_input_custom_alert_notable"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_custom_alert_notable.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_custom_alert_notable);
    });

    // show alerts
    // main data_source link input for modal window
    var inputLinkAlerts = new LinkListInput(
      {
        id: "inputLinkAlerts",
        choices: [
          {
            value: "overview",
            label: "Overview alert activity",
          },
          {
            value: "notables",
            label: "Notable alert actions",
          },
          {
            value: "auto_ack",
            label: "Auto Ack alert actions",
          },
          {
            value: "smart_status",
            label: "SmartStatus alert actions",
          },
        ],
        default: "overview",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "overview",
        value: "$form.inputLinkAlerts$",
        el: $("#inputLinkAlerts"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkAlerts.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkAlerts);
    });

    inputLinkAlerts.on("valueChange", function (e) {
      if (e.value === "overview") {
        // set and unset tokens
        setToken("show_alerts_overview", "true");
        unsetToken("show_alerts_notables");
        unsetToken("show_alerts_auto_ack");
        unsetToken("show_alerts_smartstatus");
        // show and hide elements
        $("#splk_alerts_overview").css("display", "inherit");
        $("#splk_alerts_notables").css("display", "none");
        $("#splk_alerts_ack").css("display", "none");
        $("#splk_alerts_smartstatus").css("display", "none");
      } else if (e.value === "notables") {
        // set and unset tokens
        unsetToken("show_alerts_overview");
        setToken("show_alerts_notables", "true");
        unsetToken("show_alerts_auto_ack");
        unsetToken("show_alerts_smartstatus");
        // show and hide elements
        $("#splk_alerts_overview").css("display", "none");
        $("#splk_alerts_notables").css("display", "inherit");
        $("#splk_alerts_ack").css("display", "none");
        $("#splk_alerts_smartstatus").css("display", "none");
      } else if (e.value === "auto_ack") {
        // set and unset tokens
        unsetToken("show_alerts_overview");
        unsetToken("show_alerts_notables");
        setToken("show_alerts_auto_ack", "true");
        unsetToken("show_alerts_smartstatus");
        // show and hide elements
        $("#splk_alerts_overview").css("display", "none");
        $("#splk_alerts_notables").css("display", "none");
        $("#splk_alerts_ack").css("display", "inherit");
        $("#splk_alerts_smartstatus").css("display", "none");
      } else if (e.value === "smart_status") {
        // set and unset tokens
        unsetToken("show_alerts_overview");
        unsetToken("show_alerts_notables");
        unsetToken("show_alerts_auto_ack");
        setToken("show_alerts_smartstatus", "true");
        // show and hide elements
        $("#splk_alerts_overview").css("display", "none");
        $("#splk_alerts_notables").css("display", "none");
        $("#splk_alerts_ack").css("display", "none");
        $("#splk_alerts_smartstatus").css("display", "inherit");
      }
    });

    var chartAlertTriggeredPerAlert = new ChartView(
      {
        id: "chartAlertTriggeredPerAlert",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.legend.placement": "top",
        height: "200",
        resizable: true,
        managerid: "searchAlertTriggeredOverTimePerAlert",
        el: $("#chartAlertTriggeredPerAlert"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAlertTriggeredPerAlert = new ResultsLinkView({
      id: "resultsLinkchartAlertTriggeredPerAlert",
      managerid: "searchAlertTriggeredOverTimePerAlert",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAlertTriggeredPerAlert"),
    });

    resultsLinkchartAlertTriggeredPerAlert
      .render()
      .$el.appendTo($("resultsLinkchartAlertTriggeredPerAlert"));

    var eventAlertActionsNotablesPerAlert = new EventsViewer(
      {
        id: "eventAlertActionsNotablesPerAlert",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 10,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchAlertActionsNotablesEventsOverTimePerAlert",
        el: $("#eventAlertActionsNotablesPerAlert"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAlertActionsNotablesPerAlert = new ResultsLinkView({
      id: "resultsLinkeventAlertActionsNotablesPerAlert",
      managerid: "searchAlertActionsNotablesOverTimePerAlert",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAlertActionsNotablesPerAlert"),
    });

    resultsLinkeventAlertActionsNotablesPerAlert
      .render()
      .$el.appendTo($("resultsLinkeventAlertActionsNotablesPerAlert"));

    var chartAlertActionsPerAlert = new ChartView(
      {
        id: "chartAlertActionsPerAlert",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.legend.placement": "top",
        height: "200",
        resizable: true,
        managerid: "searchAlertActionsTriggeredOverTimePerAlert",
        el: $("#chartAlertActionsPerAlert"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAlertActionsPerAlert = new ResultsLinkView({
      id: "resultsLinkchartAlertActionsPerAlert",
      managerid: "searchAlertActionsTriggeredOverTimePerAlert",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAlertActionsPerAlert"),
    });

    resultsLinkchartAlertActionsPerAlert
      .render()
      .$el.appendTo($("resultsLinkchartAlertActionsPerAlert"));

    // show alerts
    // input link selection for modal window
    var inputLinktAlertsTimeRange = new LinkListInput(
      {
        id: "inputLinktAlertsTimeRange",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.showAlertsTime$",
        el: $("#inputLinktAlertsTimeRange"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinktAlertsTimeRange.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinktAlertsTimeRange);
    });

    inputLinktAlertsTimeRange.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken("showAlertsTime.earliest", "-30m", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "1m", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken("showAlertsTime.earliest", "-60m", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "1m", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken("showAlertsTime.earliest", "-2h", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "5m", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken("showAlertsTime.earliest", "-4h", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "5m", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken("showAlertsTime.earliest", "-8h", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "5m", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken("showAlertsTime.earliest", "-12h", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "10m", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken("showAlertsTime.earliest", "-24h", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "15m", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken("showAlertsTime.earliest", "-48h", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "30m", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken("showAlertsTime.earliest", "-7d", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "1h", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken("showAlertsTime.earliest", "-15d", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "2h", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken("showAlertsTime.earliest", "-30d", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "4h", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken("showAlertsTime.earliest", "-60d", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "8h", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken("showAlertsTime.earliest", "-90d", {}, e.data);
        EventHandler.setToken("showAlertsTime.latest", "now", {}, e.data);
        EventHandler.setToken("showAlertsTime.span", "12h", {}, e.data);
      }
    });

    var eventAlertActionsAckPerAlert = new EventsViewer(
      {
        id: "eventAlertActionsAckPerAlert",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 10,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchAlertActionsAckEventsOverTimePerAlert",
        el: $("#eventAlertActionsAckPerAlert"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAlertActionsAckPerAlert = new ResultsLinkView({
      id: "resultsLinkeventAlertActionsAckPerAlert",
      managerid: "searchAlertActionsAckEventsOverTimePerAlert",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAlertActionsAckPerAlert"),
    });

    resultsLinkeventAlertActionsAckPerAlert
      .render()
      .$el.appendTo($("resultsLinkeventAlertActionsAckPerAlert"));

    var eventAlertActionsSmartStatusPerAlert = new EventsViewer(
      {
        id: "eventAlertActionsSmartStatusPerAlert",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 10,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchAlertActionsSmartStatusdEventsOverTimePerAlert",
        el: $("#eventAlertActionsSmartStatusPerAlert"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAlertActionsSmartStatusPerAlert = new ResultsLinkView({
      id: "resultsLinkeventAlertActionsSmartStatusPerAlert",
      managerid: "searchAlertActionsSmartStatusdEventsOverTimePerAlert",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAlertActionsSmartStatusPerAlert"),
    });

    resultsLinkeventAlertActionsSmartStatusPerAlert
      .render()
      .$el.appendTo($("resultsLinkeventAlertActionsSmartStatusPerAlert"));

    // input link selection for modal window
    var inputLinkTimeHost = new LinkListInput(
      {
        id: "inputLinkTimeHost",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.modalActionTimeHost$",
        el: $("#inputLinkTimeHost"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkTimeHost.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkTimeHost);
    });

    inputLinkTimeHost.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken("modalTimeHost.earliest", "-30m", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "1m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-30m");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-30m");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-30m");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "1m");
      } else if (e.value === "60m") {
        EventHandler.setToken("modalTimeHost.earliest", "-60m", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "1m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-60m");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-60m");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-60m");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "1m");
      } else if (e.value === "2h") {
        EventHandler.setToken("modalTimeHost.earliest", "-2h", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "5m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-2h");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-2h");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-2h");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "5m");
      } else if (e.value === "4h") {
        EventHandler.setToken("modalTimeHost.earliest", "-4h", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "5m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-4h");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-4h");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-4h");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "5m");
      } else if (e.value === "8h") {
        EventHandler.setToken("modalTimeHost.earliest", "-8h", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "5m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-8h");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-8h");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-8h");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "5m");
      } else if (e.value === "12h") {
        EventHandler.setToken("modalTimeHost.earliest", "-12h", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "10m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-12h");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-12h");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-12h");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "1m");
      } else if (e.value === "24h") {
        EventHandler.setToken("modalTimeHost.earliest", "-24h", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "15m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-24h");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-24h");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-24h");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "15m");
      } else if (e.value === "48h") {
        EventHandler.setToken("modalTimeHost.earliest", "-48h", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "30m", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-48h");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-48h");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-48h");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "30m");
      } else if (e.value === "7d") {
        EventHandler.setToken("modalTimeHost.earliest", "-7d", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "1h", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-7d");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-7d");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-7d");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "1h");
      } else if (e.value === "15d") {
        EventHandler.setToken("modalTimeHost.earliest", "-15d", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "2h", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-15d");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-15d");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-15d");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "2h");
      } else if (e.value === "30d") {
        EventHandler.setToken("modalTimeHost.earliest", "-30d", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "4h", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-30d");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-30d");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-30d");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "4h");
      } else if (e.value === "60d") {
        EventHandler.setToken("modalTimeHost.earliest", "-60d", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "8h", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-60d");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-60d");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-60d");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "8h");
      } else if (e.value === "90d") {
        EventHandler.setToken("modalTimeHost.earliest", "-90d", {}, e.data);
        EventHandler.setToken("modalTimeHost.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeHost.span", "12h", {}, e.data);
        // dynamically replace the search
        replaceLinkTimeFilters("tk_splk_dhm_overview_timechart", "-90d");
        replaceLinkTimeFilters("tk_splk_dhm_overview_pie_root_search", "-90d");
        replaceLinkTimeFilters("tk_splk_dhm_raw_search", "-90d");
        // dynamically replace the span
        replaceSpan("tk_splk_dhm_overview_timechart", "12h");
      }
    });

    // data host monitoring

    // main object link input for modal window
    var inputLinkSplkDhm = new LinkListInput(
      {
        id: "inputLinkSplkDhm",
        choices: [
          {
            value: "overview",
            label: "Overview data host",
          },
          {
            value: "notables",
            label: "Notables",
          },
          {
            value: "lagging_metrics",
            label: "Performance metrics",
          },
          {
            value: "outlier",
            label: "Outlier detection overview",
          },
          {
            value: "data_quality",
            label: "Data parsing quality",
          },
          {
            value: "flipping_status",
            label: "Status flipping",
          },
          {
            value: "status_message",
            label: "Status message",
          },
          {
            value: "audit_changes",
            label: "Audit changes",
          },
        ],
        default: "overview",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "overview",
        value: "$form.inputLinkSplkDhm$",
        el: $("#inputLinkSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkSplkDhm.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkSplkDhm);
    });

    inputLinkSplkDhm.on("valueChange", function (e) {
      if (e.value === "overview") {
        EventHandler.setToken("show_splk_dhm_overview", "true", {}, e.data);
        unsetToken("show_splk_dhm_notables");
        unsetToken("show_splk_dhm_outlier");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_status_message");
        unsetToken("show_splk_dhm_quality");
        unsetToken("show_splk_dhm_flipping_status");
        unsetToken("show_splk_dhm_audit_changes");
        unsetToken("show_splk_dhm_lagging_metrics");
        $("#splk_dhm_overview").css("display", "inherit");
        $("#splk_dhm_notables").css("display", "none");
        $("#splk_dhm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "none");
        $("#splk_dhm_data_parsing").css("display", "none");
        $("#splk_dhm_metrics").css("display", "none");
        $("#splk_dhm_flipping").css("display", "none");
        $("#splk_dhm_status").css("display", "none");
        $("#splk_dhm_changes").css("display", "none");
        $("#splk_dhm_timepicker").css("display", "inherit");
      } else if (e.value === "notables") {
        EventHandler.setToken("show_splk_dhm_notables", "true", {}, e.data);
        unsetToken("show_splk_dhm_overview");
        unsetToken("show_splk_dhm_outlier");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_status_message");
        unsetToken("show_splk_dhm_quality");
        unsetToken("show_splk_dhm_flipping_status");
        unsetToken("show_splk_dhm_audit_changes");
        unsetToken("show_splk_dhm_lagging_metrics");
        $("#splk_dhm_overview").css("display", "none");
        $("#splk_dhm_notables").css("display", "inherit");
        $("#splk_dhm_outliers").css("display", "none");
        // show the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "none");
        $("#splk_dhm_data_parsing").css("display", "none");
        $("#splk_dhm_metrics").css("display", "none");
        $("#splk_dhm_flipping").css("display", "none");
        $("#splk_dhm_status").css("display", "none");
        $("#splk_dhm_changes").css("display", "none");
        $("#splk_dhm_timepicker").css("display", "inherit");
      } else if (e.value === "outlier") {
        EventHandler.setToken("show_splk_dhm_outlier", "true", {}, e.data);
        searchOutlierDetectionChartDhm.startSearch();
        unsetToken("show_splk_dhm_overview");
        unsetToken("show_splk_dhm_notables");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_status_message");
        unsetToken("show_splk_dhm_quality");
        unsetToken("show_splk_dhm_flipping_status");
        unsetToken("show_splk_dhm_audit_changes");
        unsetToken("show_splk_dhm_lagging_metrics");
        $("#splk_dhm_overview").css("display", "none");
        $("#splk_dhm_notables").css("display", "none");
        $("#splk_dhm_outliers").css("display", "inherit");
        // show the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "inherit");
        $("#splk_dhm_data_parsing").css("display", "none");
        $("#splk_dhm_metrics").css("display", "none");
        $("#splk_dhm_flipping").css("display", "none");
        $("#splk_dhm_status").css("display", "none");
        $("#splk_dhm_changes").css("display", "none");
        $("#splk_dhm_timepicker").css("display", "inherit");
      } else if (e.value === "data_quality") {
        EventHandler.setToken("show_splk_dhm_quality", "true", {}, e.data);
        unsetToken("show_splk_dhm_overview");
        unsetToken("show_splk_dhm_notables");
        unsetToken("show_splk_dhm_outlier");
        unsetToken("show_splk_dhm_status_message");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_flipping_status");
        unsetToken("show_splk_dhm_audit_changes");
        unsetToken("show_splk_dhm_lagging_metrics");
        $("#splk_dhm_overview").css("display", "none");
        $("#splk_dhm_notables").css("display", "none");
        $("#splk_dhm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "none");
        $("#splk_dhm_data_parsing").css("display", "inherit");
        $("#splk_dhm_metrics").css("display", "none");
        $("#splk_dhm_flipping").css("display", "none");
        $("#splk_dhm_status").css("display", "none");
        $("#splk_dhm_changes").css("display", "none");
        $("#splk_dhm_timepicker").css("display", "inherit");
      } else if (e.value === "lagging_metrics") {
        EventHandler.setToken(
          "show_splk_dhm_lagging_metrics",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_dhm_overview");
        unsetToken("show_splk_dhm_notables");
        unsetToken("show_splk_dhm_outlier");
        unsetToken("show_splk_dhm_status_message");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_flipping_status");
        unsetToken("show_splk_dhm_audit_changes");
        unsetToken("show_splk_dhm_quality");
        $("#splk_dhm_overview").css("display", "none");
        $("#splk_dhm_notables").css("display", "none");
        $("#splk_dhm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "none");
        $("#splk_dhm_data_parsing").css("display", "none");
        $("#splk_dhm_metrics").css("display", "inherit");
        $("#splk_dhm_flipping").css("display", "none");
        $("#splk_dhm_status").css("display", "none");
        $("#splk_dhm_changes").css("display", "none");
        $("#splk_dhm_timepicker").css("display", "inherit");
      } else if (e.value === "flipping_status") {
        EventHandler.setToken(
          "show_splk_dhm_flipping_status",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_dhm_overview");
        unsetToken("show_splk_dhm_notables");
        unsetToken("show_splk_dhm_outlier");
        unsetToken("show_splk_dhm_status_message");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_quality");
        unsetToken("show_splk_dhm_audit_changes");
        unsetToken("show_splk_dhm_lagging_metrics");
        $("#splk_dhm_overview").css("display", "none");
        $("#splk_dhm_notables").css("display", "none");
        $("#splk_dhm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "none");
        $("#splk_dhm_data_parsing").css("display", "none");
        $("#splk_dhm_metrics").css("display", "none");
        $("#splk_dhm_flipping").css("display", "inherit");
        $("#splk_dhm_status").css("display", "none");
        $("#splk_dhm_changes").css("display", "none");
        $("#splk_dhm_timepicker").css("display", "inherit");
      } else if (e.value === "status_message") {
        EventHandler.setToken(
          "show_splk_dhm_status_message",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_dhm_overview");
        unsetToken("show_splk_dhm_notables");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_outlier");
        unsetToken("show_splk_dhm_quality");
        unsetToken("show_splk_dhm_flipping_status");
        unsetToken("show_splk_dhm_audit_changes");
        unsetToken("show_splk_dhm_lagging_metrics");
        $("#splk_dhm_overview").css("display", "none");
        $("#splk_dhm_notables").css("display", "none");
        $("#splk_dhm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "none");
        $("#splk_dhm_data_parsing").css("display", "none");
        $("#splk_dhm_metrics").css("display", "none");
        $("#splk_dhm_flipping").css("display", "none");
        $("#splk_dhm_status").css("display", "inherit");
        $("#splk_dhm_changes").css("display", "none");
        $("#splk_dhm_timepicker").css("display", "inherit");
      } else if (e.value === "audit_changes") {
        EventHandler.setToken(
          "show_splk_dhm_audit_changes",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_dhm_overview");
        unsetToken("show_splk_dhm_notables");
        unsetToken("show_splk_dhm_outlier_configuration");
        unsetToken("show_splk_dhm_outlier");
        unsetToken("show_splk_dhm_quality");
        unsetToken("show_splk_dhm_flipping_status");
        unsetToken("show_splk_dhm_status_message");
        unsetToken("show_splk_dhm_lagging_metrics");
        $("#splk_dhm_overview").css("display", "none");
        $("#splk_dhm_notables").css("display", "none");
        $("#splk_dhm_outliers").css("display", "none");
        // hide the manage outliers button
        $("#divBtnDhmManageOutliers").css("display", "none");
        $("#splk_dhm_data_parsing").css("display", "none");
        $("#splk_dhm_metrics").css("display", "none");
        $("#splk_dhm_flipping").css("display", "none");
        $("#splk_dhm_status").css("display", "none");
        $("#splk_dhm_changes").css("display", "inherit");
        $("#splk_dhm_timepicker").css("display", "inherit");
      }
    });

    // modal Single Lag
    var elementSingleLagHostPerc95 = new SingleView(
      {
        id: "elementSingleLagHostPerc95",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "none",
        height: "95",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "PERC95 INGESTION LATENCY (sec or [D+]HH:MM:SS)",
        managerid: "searchSingleLagHostPerc95",
        el: $("#elementSingleLagHostPerc95"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleLagHostPerc95 = new ResultsLinkView({
      id: "resultsLinkelementSingleLagHostPerc95",
      managerid: "searchSingleLagHostPerc95",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleLagHostPerc95"),
    });

    resultsLinkelementSingleLagHostPerc95
      .render()
      .$el.appendTo($("resultsLinkelementSingleLagHostPerc95"));

    var elementSingleLagHostAvg = new SingleView(
      {
        id: "elementSingleLagHostAvg",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "none",
        height: "95",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "AVG INGESTION LATENCY (sec or [D+]HH:MM:SS)",
        managerid: "searchSingleLagHostAvg",
        el: $("#elementSingleLagHostAvg"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleLagHostAvg = new ResultsLinkView({
      id: "resultsLinkelementSingleLagHostAvg",
      managerid: "searchSingleLagHostAvg",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleLagHostAvg"),
    });

    resultsLinkelementSingleLagHostAvg
      .render()
      .$el.appendTo($("resultsLinkelementSingleLagHostAvg"));

    var elementSingleLagHostEventLag = new SingleView(
      {
        id: "elementSingleLagHostEventLag",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "none",
        height: "95",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "CURRENT EVENT DELAY (sec or [D+]HH:MM:SS)",
        managerid: "searchSingleLagHostEventLag",
        el: $("#elementSingleLagHostEventLag"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleLagHostEventLag = new ResultsLinkView({
      id: "resultsLinkelementSingleLagHostEventLag",
      managerid: "searchSingleLagHostEventLag",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleLagHostEventLag"),
    });

    resultsLinkelementSingleLagHostEventLag
      .render()
      .$el.appendTo($("resultsLinkelementSingleLagHostEventLag"));

    var elementSingleSLAHostpct = new SingleView(
      {
        id: "elementSingleSLAHostpct",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "all",
        height: "95",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "%",
        rangeColors: '["0xdc4e41","0xf1813f","0x45D4BA"]',
        colorMode: "none",
        rangeValues: "[50,90]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useColors: "1",
        useThousandSeparators: "1",
        underLabel: "SLA PCT (% time spent in green/blue mode last 90d)",
        managerid: "searchSingleSLAHostpct",
        el: $("#elementSingleSLAHostpct"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleSLAHostpct = new ResultsLinkView({
      id: "resultsLinkelementSingleSLAHostpct",
      managerid: "searchSingleSLAHostpct",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSLAHostpct"),
    });

    resultsLinkelementSingleSLAHostpct
      .render()
      .$el.appendTo($("resultsLinkelementSingleSLAHostpct"));

    var elementChartHostIndexes = new ChartView(
      {
        id: "elementChartHostIndexes",
        "charting.drilldown": "all",
        resizable: true,
        "charting.chart": "pie",
        height: "160",
        managerid: "searchChartHostIndexes",
        el: $("#elementChartHostIndexes"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartHostIndexes = new ResultsLinkView({
      id: "resultsLinkelementChartHostIndexes",
      managerid: "searchChartHostIndexes",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartHostIndexes"),
    });

    resultsLinkelementChartHostIndexes
      .render()
      .$el.appendTo($("resultsLinkelementChartHostIndexes"));

    var elementChartHostSourcetypes = new ChartView(
      {
        id: "elementChartHostSourcetypes",
        "charting.drilldown": "all",
        resizable: true,
        "charting.chart": "pie",
        height: "160",
        managerid: "searchChartHostSourcetypes",
        el: $("#elementChartHostSourcetypes"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartHostSourcetypes = new ResultsLinkView({
      id: "resultsLinkelementChartHostSourcetypes",
      managerid: "searchChartHostSourcetypes",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartHostSourcetypes"),
    });

    resultsLinkelementChartHostSourcetypes
      .render()
      .$el.appendTo($("resultsLinkelementChartHostSourcetypes"));

    // modal window chart
    var elementChartLagHostOverTime = new ChartView(
      {
        id: "elementChartLagHostOverTime",
        "charting.axisX.abbreviation": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.axisTitleY.text": "Events count",
        "refresh.display": "progressbar",
        "charting.chart.nullValueMode": "gaps",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.axisTitleY2.text": "lag in seconds",
        "charting.axisX.scale": "linear",
        "charting.drilldown": "none",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.chart.overlayFields":
          "avg_latency,avg_latency_5m,lag_event_sec",
        "charting.chart.showDataLabels": "none",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisY2.enabled": "1",
        "charting.axisY2.scale": "inherit",
        "trellis.scales.shared": "1",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.style": "shiny",
        "charting.axisY.scale": "linear",
        "charting.layout.splitSeries": "0",
        resizable: true,
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.lineWidth": "2",
        "charting.axisTitleY.visibility": "visible",
        "charting.chart.stackMode": "default",
        "charting.legend.placement": "right",
        "trellis.size": "medium",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisY2.abbreviation": "none",
        "charting.chart": "column",
        "charting.axisY.abbreviation": "none",
        "charting.fieldColors":
          '{"events_count": 0x7fbfff, "latest_eventcount_5m": 0x7fbfff, "avg_latency": 0xff6961, "avg_latency_5m": 0xff6961, "lag_event_sec": 0xffbf7f}',
        "trellis.enabled": "0",
        height: "160",
        managerid: "searchChartLagHostOverTime",
        el: $("#elementChartLagHostOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementChartLagHostOverTime = new ResultsLinkView({
      id: "resultsLinkelementChartLagHostOverTime",
      managerid: "searchChartLagHostOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementChartLagHostOverTime"),
    });

    resultsLinkelementChartLagHostOverTime
      .render()
      .$el.appendTo($("resultsLinkelementChartLagHostOverTime"));

    // Data Parsing Quality
    var elementSearchSplkDhmParsingQualityChart = new ChartView(
      {
        id: "elementSearchSplkDhmParsingQualityChart",
        "charting.chart.nullValueMode": "gaps",
        resizable: true,
        "trellis.enabled": "0",
        "charting.axisTitleX.visibility": "collapsed",
        "refresh.display": "progressbar",
        "charting.chart.stackMode": "stacked",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.axisY.abbreviation": "none",
        "charting.legend.placement": "bottom",
        "charting.axisY2.abbreviation": "none",
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.chart.showDataLabels": "none",
        "charting.axisY2.enabled": "0",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.chart.style": "shiny",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart": "column",
        "charting.axisX.scale": "linear",
        "trellis.scales.shared": "1",
        "charting.axisTitleY.visibility": "visible",
        "charting.axisTitleY2.visibility": "visible",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.drilldown": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "trellis.size": "medium",
        "charting.axisY.scale": "linear",
        "charting.chart.bubbleSizeBy": "area",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisX.abbreviation": "none",
        "charting.layout.splitSeries": "0",
        "charting.lineWidth": "2",
        "charting.axisY2.scale": "inherit",
        managerid: "SearchSplkDhmParsingQualityChart",
        el: $("#elementSearchSplkDhmParsingQualityChart"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSearchSplkDhmParsingQualityChart =
      new ResultsLinkView({
        id: "resultsLinkelementSearchSplkDhmParsingQualityChart",
        managerid: "SearchSplkDhmParsingQualityChart",
        "link.exportResults.visible": false,
        el: $("#resultsLinkelementSearchSplkDhmParsingQualityChart"),
      });

    resultsLinkelementSearchSplkDhmParsingQualityChart
      .render()
      .$el.appendTo($("resultsLinkelementSearchSplkDhmParsingQualityChart"));

    var chartLaggingMetricSplkDhmOverTime = new ChartView(
      {
        id: "chartLaggingMetricSplkDhmOverTime",
        "charting.axisX.abbreviation": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.axisTitleY.text":
          "$splk_dhm_overview_metrics_chart1_axisy_title$",
        "refresh.display": "progressbar",
        "charting.chart.nullValueMode": "gaps",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.axisTitleY2.text": "$splk_dhm_overview_metrics_chart1_axis$",
        "charting.axisLabelsY2.majorUnit":
          "$splk_dhm_overview_metrics_chart1_axisUnit$",
        "charting.axisX.scale": "linear",
        "charting.drilldown": "none",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.chart.overlayFields": "lag_event_sec,lag_ingestion_sec",
        "charting.chart.showDataLabels": "none",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisY2.enabled": "1",
        "charting.axisY2.scale": "inherit",
        "trellis.scales.shared": "1",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.style": "shiny",
        "charting.axisY.scale": "linear",
        "charting.layout.splitSeries": "0",
        "charting.fieldColors":
          '{"eventcount_4h": 0xaec6cf, "lag_event_sec": 0x9542f5, "lag_ingestion_sec": 0xff6961}',
        resizable: true,
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.lineWidth": "2",
        "charting.axisTitleY.visibility": "visible",
        "charting.chart.stackMode": "default",
        "charting.legend.placement": "right",
        "trellis.size": "medium",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisY2.abbreviation": "none",
        "charting.chart": "$splk_dhm_overview_metrics_chart$",
        "charting.axisY.abbreviation": "none",
        "trellis.enabled": "0",
        height: "350",
        managerid: "searchLaggingMetricSplkDhm",
        el: $("#chartLaggingMetricSplkDhmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartLaggingMetricSplkDhmOverTime = new ResultsLinkView({
      id: "resultsLinkchartLaggingMetricSplkDhmOverTime",
      managerid: "searchLaggingMetricSplkDhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartLaggingMetricSplkDhmOverTime"),
    });

    resultsLinkchartLaggingMetricSplkDhmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartLaggingMetricSplkDhmOverTime"));

    var inputSplkDhmOverviewMetricsChartSeries = new DropdownInput(
      {
        id: "inputSplkDhmOverviewMetricsChartSeries",
        choices: [
          {
            label: "Latency metrics",
            value: "latency_metrics",
          },
          {
            label: "Volume metrics",
            value: "volume_metrics",
          },
          {
            label: "Eventcount / lag (4h)",
            value: "eventcount_4h, lag_event_sec, lag_ingestion_sec",
          },
        ],
        default: "latency_metrics",
        searchWhenChanged: true,
        selectFirstChoice: false,
        showClearButton: true,
        initialValue: "latency_metrics",
        width: 300,
        value: "$form.tk_input_splk_dhm_overview_metrics_chart_series$",
        el: $("#inputSplkDhmOverviewMetricsChartSeries"),
      },
      {
        tokens: true,
      }
    ).render();

    inputSplkDhmOverviewMetricsChartSeries.on("change", function (newValue) {
      FormUtils.handleValueChange(inputSplkDhmOverviewMetricsChartSeries);
    });

    inputSplkDhmOverviewMetricsChartSeries.on("valueChange", function (e) {
      if (e.value === "volume_metrics") {
        setToken("splk_dhm_overview_metrics_chart", "line");
        setToken("splk_dhm_overview_metrics_chart1_axis", "eventcount");
        setToken("splk_dhm_overview_metrics_chart1_axisUnit", "1");
        setToken("splk_dhm_overview_metrics_chart1_axisy_title", "eventcount");
        setToken(
          "splk_dhm_metrics_mstats_search",
          "avg(trackme.splk.feeds.avg_eventcount_5m) as avg_eventcount_5m, latest(trackme.splk.feeds.latest_eventcount_5m) as latest_eventcount_5m, avg(trackme.splk.feeds.perc95_eventcount_5m) as perc95_eventcount_5m, avg(trackme.splk.feeds.stdev_eventcount_5m) as stdev_eventcount_5m"
        );
        setToken(
          "splk_dhm_metrics_timechart_search",
          "avg(avg_eventcount_5m) as avg_eventcount_5m, sum(latest_eventcount_5m) as latest_eventcount_5m, avg(perc95_eventcount_5m) as perc95_eventcount_5m, avg(stdev_eventcount_5m) as stdev_eventcount_5m"
        );
      } else if (e.value === "latency_metrics") {
        setToken("splk_dhm_overview_metrics_chart", "line");
        setToken("splk_dhm_overview_metrics_chart1_axis", "latency (sec)");
        setToken("splk_dhm_overview_metrics_chart1_axisUnit", "0.1");
        setToken(
          "splk_dhm_overview_metrics_chart1_axisy_title",
          "latency (sec)"
        );
        setToken(
          "splk_dhm_metrics_mstats_search",
          "avg(trackme.splk.feeds.avg_latency_5m) as avg_latency_5m, avg(trackme.splk.feeds.latest_latency_5m) as latest_latency_5m, avg(trackme.splk.feeds.perc95_latency_5m) as perc95_latency_5m, avg(trackme.splk.feeds.stdev_latency_5m) as stdev_latency_5m"
        );
        setToken(
          "splk_dhm_metrics_timechart_search",
          "avg(avg_latency_5m) as avg_latency_5m, avg(latest_latency_5m) as latest_latency_5m, avg(perc95_latency_5m) as perc95_latency_5m, avg(stdev_latency_5m) as stdev_latency_5m"
        );
      } else if (
        e.value === "eventcount_4h, lag_event_sec, lag_ingestion_sec"
      ) {
        setToken("splk_dhm_overview_metrics_chart", "column");
        setToken("splk_dhm_overview_metrics_chart1_axis", "lagging (sec)");
        setToken("splk_dhm_overview_metrics_chart1_axisUnit", "0.1");
        setToken(
          "splk_dhm_overview_metrics_chart1_axisy_title",
          "4h Events count"
        );
        setToken(
          "splk_dhm_metrics_mstats_search",
          "max(trackme.splk.feeds.eventcount_4h) as eventcount_4h, max(trackme.splk.feeds.lag_event_sec) as lag_event_sec, max(trackme.splk.feeds.lag_ingestion_sec) as lag_ingestion_sec"
        );
        setToken(
          "splk_dhm_metrics_timechart_search",
          "avg(eventcount_4h) as eventcount_4h, avg(lag_event_sec) as lag_event_sec, avg(lag_ingestion_sec) as lag_ingestion_sec"
        );
      } else if (e.value === "eventcount_4h, hostcount_4h") {
        setToken("splk_dhm_overview_metrics_chart", "column");
        setToken(
          "splk_dhm_overview_metrics_chart1_axis",
          "hosts distinct count"
        );
        setToken("splk_dhm_overview_metrics_chart1_axisUnit", "1");
        setToken(
          "splk_dhm_overview_metrics_chart1_axisy_title",
          "4h Events count"
        );
        setToken(
          "splk_dhm_metrics_mstats_search",
          "max(trackme.splk.feeds.eventcount_4h) as eventcount_4h, max(trackme.splk.feeds.hostcount_4h) as hostcount_4h"
        );
        setToken(
          "splk_dhm_metrics_timechart_search",
          "avg(eventcount_4h) as eventcount_4h, avg(hostcount_4h) as hostcount_4h"
        );
      }
    });

    var chartAuditFlipSplkDhmOverTime = new ChartView(
      {
        id: "chartAuditFlipSplkDhmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors":
          '{"orange": 0xffd394, "blue": 0xcfebf9, "green": 0xb6edb6, "red": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkDhmFlipOverTime",
        el: $("#chartAuditFlipSplkDhmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditFlipSplkDhmOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditFlipSplkDhmOverTime",
      managerid: "searchAuditSplkDhmFlipOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditFlipSplkDhmOverTime"),
    });

    resultsLinkchartAuditFlipSplkDhmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditFlipSplkDhmOverTime"));

    // Audit Flip Data Host
    var elementMainTableAuditFlipSplkDhm = new TableView(
      {
        id: "elementMainTableAuditFlipSplkDhm",
        count: 5,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMainSplkDhmAuditFlipTable",
        el: $("#elementMainTableAuditFlipSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementMainTableAuditFlipSplkDhm);

    var resultsLinkelementMainTableAuditFlipSplkDhm = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditFlipSplkDhm",
      managerid: "searchMainSplkDhmAuditFlipTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditFlipSplkDhm"),
    });

    resultsLinkelementMainTableAuditFlipSplkDhm
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditFlipSplkDhm"));

    var chartAuditChangesSplkDhmOverTime = new ChartView(
      {
        id: "chartAuditChangesSplkDhmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkDhmAuditChangesOverTime",
        el: $("#chartAuditChangesSplkDhmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditChangesSplkDhmOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditChangesSplkDhmOverTime",
      managerid: "searchAuditSplkDhmAuditChangesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditChangesSplkDhmOverTime"),
    });

    resultsLinkchartAuditChangesSplkDhmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditChangesSplkDhmOverTime"));

    // Audit Changes Data Host
    var eventAuditChangesSplkDhm = new EventsViewer(
      {
        id: "eventAuditChangesSplkDhm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchMainSplkDhmAuditChangesTable",
        el: $("#eventAuditChangesSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAuditChangesSplkDhm = new ResultsLinkView({
      id: "resultsLinkeventAuditChangesSplkDhm",
      managerid: "searchMainSplkDhmAuditChangesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAuditChangesSplkDhm"),
    });

    resultsLinkeventAuditChangesSplkDhm
      .render()
      .$el.appendTo($("resultsLinkeventAuditChangesSplkDhm"));

    var LinkTimeOutlierConfigurationSplkDhmSpan = new LinkListInput(
      {
        id: "LinkTimeOutlierConfigurationSplkDhmSpan",
        choices: [
          {
            value: "5m",
            label: "5m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "1d",
            label: "1d",
          },
        ],
        default: "5m",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "5m",
        value: "$form.TimeOutlierConfigurationSplkDhmSpan$",
        el: $("#LinkTimeOutlierConfigurationSplkDhmSpan"),
      },
      {
        tokens: true,
      }
    ).render();

    LinkTimeOutlierConfigurationSplkDhmSpan.on("change", function (newValue) {
      FormUtils.handleValueChange(LinkTimeOutlierConfigurationSplkDhmSpan);
    });

    LinkTimeOutlierConfigurationSplkDhmSpan.on("valueChange", function (e) {
      if (e.value === "5m") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_span",
          "5m",
          {},
          e.data
        );
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_span",
          "60m",
          {},
          e.data
        );
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_span",
          "4h",
          {},
          e.data
        );
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_span",
          "12h",
          {},
          e.data
        );
      } else if (e.value === "1d") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_span",
          "1d",
          {},
          e.data
        );
      }
    });

    // outliers configuration object
    var LinkTimeOutlierConfigurationSplkDhm = new LinkListInput(
      {
        id: "LinkTimeOutlierConfigurationSplkDhm",
        choices: [
          {
            value: "-24h",
            label: "24h",
          },
          {
            value: "-48h",
            label: "48h",
          },
          {
            value: "-7d",
            label: "7d",
          },
          {
            value: "-30d",
            label: "30d",
          },
        ],
        default: "-7d",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "-7d",
        value: "$form.TimeOutlierConfigurationSplkDhm$",
        el: $("#LinkTimeOutlierConfigurationSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    LinkTimeOutlierConfigurationSplkDhm.on("change", function (newValue) {
      FormUtils.handleValueChange(LinkTimeOutlierConfigurationSplkDhm);
    });

    LinkTimeOutlierConfigurationSplkDhm.on("valueChange", function (e) {
      if (e.value === "-24h") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_period",
          "-24h",
          {},
          e.data
        );
      } else if (e.value === "-48h") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_period",
          "-48h",
          {},
          e.data
        );
      } else if (e.value === "-7d") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_period",
          "-7d",
          {},
          e.data
        );
      } else if (e.value === "-30d") {
        EventHandler.setToken(
          "tk_input_splk_dhm_outlier_period",
          "-30d",
          {},
          e.data
        );
      }
    });

    // Get assets tags
    var elementGetTagsSplkDhm = new TableView(
      {
        id: "elementGetTagsSplkDhm",
        count: 100,
        drilldown: "row",
        "refresh.display": "none",
        wrap: "true",
        managerid: "searchGetSplkDhmTags",
        el: $("#elementGetTagsSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementGetTagsSplkDhm = new ResultsLinkView({
      id: "resultsLinkelementGetTagsSplkDhm",
      managerid: "searchGetSplkDhmTags",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementGetTagsSplkDhm"),
    });

    resultsLinkelementGetTagsSplkDhm
      .render()
      .$el.appendTo($("resultsLinkelementGetTagsSplkDhm"));

    // data host monitoring

    // input lag

    var modal_input_lag_host = new TextInput(
      {
        id: "modal_input_lag_host",
        searchWhenChanged: true,
        value: "$form.tk_input_lag_host$",
        el: $("#modal_input_lag_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_lag_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_lag_host);
    });

    var modal_input_delay_host = new TextInput(
      {
        id: "modal_input_delay_host",
        searchWhenChanged: true,
        value: "$form.tk_input_delay_host$",
        el: $("#modal_input_delay_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_delay_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_delay_host);
    });

    var modal_input_future_tolerance_host = new TextInput(
      {
        id: "modal_input_future_tolerance_host",
        default: "system",
        searchWhenChanged: true,
        value: "$form.tk_input_future_tolerance_host$",
        el: $("#modal_input_future_tolerance_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_future_tolerance_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_future_tolerance_host);
    });

    var modal_input_lag_override_class_host = new DropdownInput(
      {
        id: "modal_input_lag_override_class_host",
        choices: [
          {
            label: "true",
            value: "true",
          },
          {
            label: "false",
            value: "false",
          },
        ],
        searchWhenChanged: true,
        default: "true",
        showClearButton: true,
        initialValue: "true",
        selectFirstChoice: false,
        value: "$form.modal_input_lag_override_class_host$",
        el: $("#modal_input_lag_override_class_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_lag_override_class_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_lag_override_class_host);
    });

    var modal_input_allow_adaptive_delay_host = new DropdownInput(
      {
        id: "modal_input_allow_adaptive_delay_host",
        choices: [
          {
            label: "true",
            value: "true",
          },
          {
            label: "false",
            value: "false",
          },
        ],
        searchWhenChanged: true,
        default: "true",
        showClearButton: true,
        initialValue: "true",
        selectFirstChoice: false,
        value: "$form.modal_input_allow_adaptive_delay_host$",
        el: $("#modal_input_allow_adaptive_delay_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_allow_adaptive_delay_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_allow_adaptive_delay_host);
    });

    var modal_input_lag_alert_over_host = new DropdownInput(
      {
        id: "modal_input_lag_alert_over_host",
        choices: [
          {
            label: "delay / latency",
            value: "all_kpis",
          },
          {
            label: "latency only",
            value: "lag_ingestion_kpi",
          },
          {
            label: "delay only",
            value: "lag_event_kpi",
          },
        ],
        searchWhenChanged: true,
        default: "all_kpis",
        showClearButton: true,
        initialValue: "all_kpis",
        selectFirstChoice: false,
        value: "$form.tk_input_data_lag_alert_kpis_host$",
        el: $("#modal_input_lag_alert_over_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_lag_alert_over_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_lag_alert_over_host);
    });

    var modal_input_host_alerting_policy = new DropdownInput(
      {
        id: "modal_input_host_alerting_policy",
        choices: [
          {
            label: "global policy",
            value: "global_policy",
          },
          {
            label: "red if at least one sourcetype is red",
            value: "track_per_sourcetype",
          },
          {
            label: "red only if all sourcetypes are red",
            value: "track_per_host",
          },
        ],
        searchWhenChanged: true,
        default: "global_policy",
        showClearButton: true,
        initialValue: "global_policy",
        selectFirstChoice: false,
        value: "$form.tk_input_host_alerting_policy$",
        el: $("#modal_input_host_alerting_policy"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_host_alerting_policy.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_host_alerting_policy);
    });

    // data host priority

    var modal_input_host_priority = new DropdownInput(
      {
        id: "modal_input_host_priority",
        choices: [
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        searchWhenChanged: true,
        default: "medium",
        showClearButton: true,
        initialValue: "medium",
        selectFirstChoice: false,
        value: "$form.tk_input_host_priority$",
        el: $("#modal_input_host_priority"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_host_priority.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_host_priority);
    });

    // data host monitoring

    var modal_input_wdays_host = new DropdownInput(
      {
        id: "modal_input_wdays_host",
        choices: [
          {
            label: "manual:all_days",
            value: "manual:all_days",
          },
          {
            label: "manual:monday-to-friday",
            value: "manual:monday-to-friday",
          },
          {
            label: "manual:monday-to-saturday",
            value: "manual:monday-to-saturday",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_days",
        showClearButton: true,
        initialValue: "all_days",
        selectFirstChoice: false,
        value: "$form.tk_input_wdays_host$",
        el: $("#modal_input_wdays_host"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_host.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_host);
    });

    modal_input_wdays_host.on("valueChange", function (e) {
      if (e.value === "manual:enter_days_numbers") {
        EventHandler.setToken("show_manual_wdays_host", "true", {}, e.data);
      } else {
        unsetToken("show_manual_wdays_host");
      }
    });

    var modal_input_wdays_host_no = new CheckboxGroupInput(
      {
        id: "modal_input_wdays_host_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_wdays_host_no$",
        el: $("#modal_input_wdays_host_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_host_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_host_no);
    });

    // splk-flx

    var modal_input_wdays_flx = new DropdownInput(
      {
        id: "modal_input_wdays_flx",
        choices: [
          {
            label: "manual:all_days",
            value: "manual:all_days",
          },
          {
            label: "manual:monday-to-friday",
            value: "manual:monday-to-friday",
          },
          {
            label: "manual:monday-to-saturday",
            value: "manual:monday-to-saturday",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_days",
        showClearButton: true,
        initialValue: "all_days",
        selectFirstChoice: false,
        value: "$form.tk_input_wdays_flx$",
        el: $("#modal_input_wdays_flx"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_flx.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_flx);
    });

    modal_input_wdays_flx.on("valueChange", function (e) {
      if (e.value === "manual:enter_days_numbers") {
        EventHandler.setToken("show_manual_wdays_flx", "true", {}, e.data);
      } else {
        unsetToken("show_manual_wdays_flx");
      }
    });

    var modal_input_wdays_flx_no = new CheckboxGroupInput(
      {
        id: "modal_input_wdays_flx_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_wdays_flx_no$",
        el: $("#modal_input_wdays_flx_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_flx_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_flx_no);
    });

    // splk-cim

    var modal_input_wdays_cim = new DropdownInput(
      {
        id: "modal_input_wdays_cim",
        choices: [
          {
            label: "manual:all_days",
            value: "manual:all_days",
          },
          {
            label: "manual:monday-to-friday",
            value: "manual:monday-to-friday",
          },
          {
            label: "manual:monday-to-saturday",
            value: "manual:monday-to-saturday",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_days",
        showClearButton: true,
        initialValue: "all_days",
        selectFirstChoice: false,
        value: "$form.tk_input_wdays_cim$",
        el: $("#modal_input_wdays_cim"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_cim.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_cim);
    });

    modal_input_wdays_cim.on("valueChange", function (e) {
      if (e.value === "manual:enter_days_numbers") {
        EventHandler.setToken("show_manual_wdays_cim", "true", {}, e.data);
      } else {
        unsetToken("show_manual_wdays_cim");
      }
    });

    var modal_input_wdays_cim_no = new CheckboxGroupInput(
      {
        id: "modal_input_wdays_cim_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_wdays_cim_no$",
        el: $("#modal_input_wdays_cim_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_cim_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_cim_no);
    });

    // splk-wlk

    var modal_input_wdays_wlk = new DropdownInput(
      {
        id: "modal_input_wdays_wlk",
        choices: [
          {
            label: "manual:all_days",
            value: "manual:all_days",
          },
          {
            label: "manual:monday-to-friday",
            value: "manual:monday-to-friday",
          },
          {
            label: "manual:monday-to-saturday",
            value: "manual:monday-to-saturday",
          },
        ],
        searchWhenChanged: true,
        default: "manual:all_days",
        showClearButton: true,
        initialValue: "all_days",
        selectFirstChoice: false,
        value: "$form.tk_input_wdays_wlk$",
        el: $("#modal_input_wdays_wlk"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_wlk.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_wlk);
    });

    modal_input_wdays_wlk.on("valueChange", function (e) {
      if (e.value === "manual:enter_days_numbers") {
        EventHandler.setToken("show_manual_wdays_wlk", "true", {}, e.data);
      } else {
        unsetToken("show_manual_wdays_wlk");
      }
    });

    var modal_input_wdays_wlk_no = new CheckboxGroupInput(
      {
        id: "modal_input_wdays_wlk_no",
        choices: [
          {
            label: "Monday",
            value: "1",
          },
          {
            label: "Tuesday",
            value: "2",
          },
          {
            label: "Wednesday",
            value: "3",
          },
          {
            label: "Thursday",
            value: "4",
          },
          {
            label: "Friday",
            value: "5",
          },
          {
            label: "Saturday",
            value: "6",
          },
          {
            label: "Sunday",
            value: "0",
          },
        ],
        prefix: "manual:",
        searchWhenChanged: true,
        default: ["1", "2", "3", "4", "5", "6", "0"],
        delimiter: ",",
        value: "$form.tk_input_wdays_wlk_no$",
        el: $("#modal_input_wdays_wlk_no"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_wdays_wlk_no.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_wdays_wlk_no);
    });

    // Logical group
    var elementLogicalGroupTable = new TableView(
      {
        id: "elementLogicalGroupTable",
        count: 100,
        drilldown: "row",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchLogicalGroupTable",
        el: $("#elementLogicalGroupTable"),
      },
      {
        tokens: true,
      }
    ).render();

    elementLogicalGroupTable.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();

        setToken("tk_keyid", e.data["row.keyid"]);
        setToken("tk_object_group_name", e.data["row.object_group_name"]);

        // Enable modal context
        $(".modal").modal("hide");
        $("#confirm_remove_from_logical_group").modal();
      }
    });

    var resultsLinkelementLogicalGroupTable = new ResultsLinkView({
      id: "resultsLinkelementLogicalGroupTable",
      managerid: "searchLogicalGroupTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementLogicalGroupTable"),
    });

    resultsLinkelementLogicalGroupTable
      .render()
      .$el.appendTo($("resultsLinkelementLogicalGroupTable"));

    // Logical group add member
    var elementLogicalGroupTableAddMember = new TableView(
      {
        id: "elementLogicalGroupTableAddMember",
        count: 5,
        drilldown: "row",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchLogicalGroupTableAddMember",
        el: $("#elementLogicalGroupTableAddMember"),
      },
      {
        tokens: true,
      }
    ).render();

    elementLogicalGroupTableAddMember.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();

        setToken("tk_keyid", e.data["row.keyid"]);
        setToken("tk_object_group_name", e.data["row.object_group_name"]);

        // Enable modal context
        $(".modal").modal("hide");
        $("#confirm_add_member_logical_group").modal();
      }
    });

    var resultsLinkelementLogicalGroupTableAddMember = new ResultsLinkView({
      id: "resultsLinkelementLogicalGroupTableAddMember",
      managerid: "searchLogicalGroupTableAddMember",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementLogicalGroupTableAddMember"),
    });

    resultsLinkelementLogicalGroupTableAddMember
      .render()
      .$el.appendTo($("resultsLinkelementLogicalGroupTableAddMember"));

    // Logical group
    var FilterLogicalGroupTable = new TextInput(
      {
        id: "FilterLogicalGroupTable",
        searchWhenChanged: true,
        default: "*",
        value: "$form.FilterLogicalGroupTable$",
        el: $("#FilterLogicalGroupTable"),
      },
      {
        tokens: true,
      }
    ).render();

    FilterLogicalGroupTable.on("change", function (newValue) {
      FormUtils.handleValueChange(FilterLogicalGroupTable);
    });

    // Logical group add
    var InputLogicalGroupName = new TextInput(
      {
        id: "InputLogicalGroupName",
        searchWhenChanged: true,
        value: "$form.InputLogicalGroupName$",
        el: $("#InputLogicalGroupName"),
      },
      {
        tokens: true,
      }
    ).render();

    InputLogicalGroupName.on("change", function (newValue) {
      FormUtils.handleValueChange(InputLogicalGroupName);
    });

    var InputLogicalGroupNamePercent = new DropdownInput(
      {
        id: "InputLogicalGroupNamePercent",
        choices: [
          {
            label: "50%",
            value: "50",
          },
          {
            label: "33.33%",
            value: "33.33",
          },
          {
            label: "25%",
            value: "25",
          },
          {
            label: "12.5%",
            value: "12.5",
          },
        ],
        searchWhenChanged: true,
        default: "50",
        showClearButton: true,
        initialValue: "50",
        selectFirstChoice: false,
        value: "$form.InputLogicalGroupNamePercent$",
        el: $("#InputLogicalGroupNamePercent"),
      },
      {
        tokens: true,
      }
    ).render();

    InputLogicalGroupNamePercent.on("change", function (newValue) {
      FormUtils.handleValueChange(InputLogicalGroupNamePercent);
    });

    // input link selection for modal window
    var inputLinkTimeSplkMhm = new LinkListInput(
      {
        id: "inputLinkTimeSplkMhm",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.modalActionTimeSplkMhm$",
        el: $("#inputLinkTimeSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkTimeSplkMhm.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkTimeSplkMhm);
    });

    inputLinkTimeSplkMhm.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-30m", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "1m", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-60m", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "1m", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-2h", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "5m", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-4h", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "5m", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-8h", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "5m", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-12h", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "10m", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-24h", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "15m", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-48h", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "30m", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-7d", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "1h", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-15d", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "2h", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-30d", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "4h", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-60d", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "8h", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken("modalTimeSplkMhm.earliest", "-90d", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkMhm.span", "12h", {}, e.data);
      }
    });

    // input link selection for modal window
    var inputLinkTimeSplkFlx = new LinkListInput(
      {
        id: "inputLinkTimeSplkFlx",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.modalActionTimeSplkFlx$",
        el: $("#inputLinkTimeSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkTimeSplkFlx.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkTimeSplkFlx);
    });

    inputLinkTimeSplkFlx.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-30m", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "5m", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-60m", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "5m", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-2h", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "5m", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-4h", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "5m", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-8h", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "5m", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-12h", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "10m", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-24h", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "15m", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-48h", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "30m", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-7d", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "1h", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-15d", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "2h", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-30d", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "4h", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-60d", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "8h", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken("modalTimeSplkFlx.earliest", "-90d", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkFlx.span", "12h", {}, e.data);
      }
    });

    // input link selection for modal window
    var inputLinkTimeSplkWlk = new LinkListInput(
      {
        id: "inputLinkTimeSplkWlk",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.modalActionTimeSplkWlk$",
        el: $("#inputLinkTimeSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkTimeSplkWlk.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkTimeSplkWlk);
    });

    inputLinkTimeSplkWlk.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-30m", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "5m", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-60m", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "5m", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-2h", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "5m", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-4h", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "5m", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-8h", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "5m", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-12h", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "10m", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-24h", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "15m", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-48h", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "30m", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-7d", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "1h", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-15d", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "2h", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-30d", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "4h", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-60d", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "8h", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken("modalTimeSplkWlk.earliest", "-90d", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeSplkWlk.span", "12h", {}, e.data);
      }
    });

    // input link selection for modal window
    var inputLinkTimeCim = new LinkListInput(
      {
        id: "inputLinkTimeCim",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.modalActionTimeCim$",
        el: $("#inputLinkTimeCim"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkTimeCim.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkTimeCim);
    });

    inputLinkTimeCim.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken("modalTimeCim.earliest", "-30m", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "1m", {}, e.data);
      } else if (e.value === "60m") {
        EventHandler.setToken("modalTimeCim.earliest", "-60m", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "1m", {}, e.data);
      } else if (e.value === "2h") {
        EventHandler.setToken("modalTimeCim.earliest", "-2h", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "5m", {}, e.data);
      } else if (e.value === "4h") {
        EventHandler.setToken("modalTimeCim.earliest", "-4h", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "5m", {}, e.data);
      } else if (e.value === "8h") {
        EventHandler.setToken("modalTimeCim.earliest", "-8h", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "5m", {}, e.data);
      } else if (e.value === "12h") {
        EventHandler.setToken("modalTimeCim.earliest", "-12h", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "10m", {}, e.data);
      } else if (e.value === "24h") {
        EventHandler.setToken("modalTimeCim.earliest", "-24h", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "15m", {}, e.data);
      } else if (e.value === "48h") {
        EventHandler.setToken("modalTimeCim.earliest", "-48h", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "30m", {}, e.data);
      } else if (e.value === "7d") {
        EventHandler.setToken("modalTimeCim.earliest", "-7d", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "1h", {}, e.data);
      } else if (e.value === "15d") {
        EventHandler.setToken("modalTimeCim.earliest", "-15d", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "2h", {}, e.data);
      } else if (e.value === "30d") {
        EventHandler.setToken("modalTimeCim.earliest", "-30d", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "4h", {}, e.data);
      } else if (e.value === "60d") {
        EventHandler.setToken("modalTimeCim.earliest", "-60d", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "8h", {}, e.data);
      } else if (e.value === "90d") {
        EventHandler.setToken("modalTimeCim.earliest", "-90d", {}, e.data);
        EventHandler.setToken("modalTimeCim.latest", "now", {}, e.data);
        EventHandler.setToken("modalTimeCim.span", "12h", {}, e.data);
      }
    });

    // modal link input
    var inputLinkSplkMhm = new LinkListInput(
      {
        id: "inputLinkSplkMhm",
        choices: [
          {
            value: "overview",
            label: "Overview metric host",
          },
          {
            value: "notables",
            label: "Notables",
          },
          {
            value: "flipping_status",
            label: "Status flipping",
          },
          {
            value: "status_message",
            label: "Status message",
          },
          {
            value: "audit_changes",
            label: "Audit changes",
          },
        ],
        default: "overview",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "overview",
        value: "$form.inputLinkSplkMhm$",
        el: $("#inputLinkSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkSplkMhm.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkSplkMhm);
    });

    inputLinkSplkMhm.on("valueChange", function (e) {
      if (e.value === "overview") {
        EventHandler.setToken("show_splk_mhm_overview", "true", {}, e.data);
        unsetToken("show_splk_mhm_notables");
        unsetToken("show_splk_mhm_status_message");
        unsetToken("show_splk_mhm_flipping_status");
        unsetToken("show_splk_mhm_audit_changes");
        $("#splk_mhm_overview").css("display", "inherit");
        $("#splk_mhm_notables").css("display", "none");
        $("#splk_mhm_flipping").css("display", "none");
        $("#splk_mhm_status").css("display", "none");
        $("#splk_mhm_changes").css("display", "none");
        $("#splk_mhm_timepicker").css("display", "none");
      } else if (e.value === "notables") {
        EventHandler.setToken("show_splk_mhm_notables", "true", {}, e.data);
        unsetToken("show_splk_mhm_overview");
        unsetToken("show_splk_mhm_flipping_status");
        unsetToken("show_splk_mhm_status_message");
        unsetToken("show_splk_mhm_audit_changes");
        $("#splk_mhm_overview").css("display", "none");
        $("#splk_mhm_notables").css("display", "inherit");
        $("#splk_mhm_flipping").css("display", "none");
        $("#splk_mhm_status").css("display", "none");
        $("#splk_mhm_changes").css("display", "none");
        $("#splk_mhm_timepicker").css("display", "inherit");
      } else if (e.value === "flipping_status") {
        EventHandler.setToken(
          "show_splk_mhm_flipping_status",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_mhm_overview");
        unsetToken("show_splk_mhm_notables");
        unsetToken("show_splk_mhm_status_message");
        unsetToken("show_splk_mhm_audit_changes");
        $("#splk_mhm_overview").css("display", "none");
        $("#splk_mhm_notables").css("display", "none");
        $("#splk_mhm_flipping").css("display", "inherit");
        $("#splk_mhm_status").css("display", "none");
        $("#splk_mhm_changes").css("display", "none");
        $("#splk_mhm_timepicker").css("display", "inherit");
      } else if (e.value === "status_message") {
        EventHandler.setToken(
          "show_splk_mhm_status_message",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_mhm_overview");
        unsetToken("show_splk_mhm_notables");
        unsetToken("show_splk_mhm_flipping_status");
        unsetToken("show_splk_mhm_audit_changes");
        $("#splk_mhm_overview").css("display", "none");
        $("#splk_mhm_notables").css("display", "none");
        $("#splk_mhm_flipping").css("display", "none");
        $("#splk_mhm_status").css("display", "inherit");
        $("#splk_mhm_changes").css("display", "none");
        $("#splk_mhm_timepicker").css("display", "none");
      } else if (e.value === "audit_changes") {
        EventHandler.setToken(
          "show_splk_mhm_audit_changes",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_mhm_overview");
        unsetToken("show_splk_mhm_notables");
        unsetToken("show_splk_mhm_flipping_status");
        unsetToken("show_splk_mhm_status_message");
        $("#splk_mhm_overview").css("display", "none");
        $("#splk_mhm_notables").css("display", "none");
        $("#splk_mhm_flipping").css("display", "none");
        $("#splk_mhm_status").css("display", "none");
        $("#splk_mhm_changes").css("display", "inherit");
        $("#splk_mhm_timepicker").css("display", "inherit");
      }
    });

    // modal link input
    var inputLinkSplkFlx = new LinkListInput(
      {
        id: "inputLinkSplkFlx",
        choices: [
          {
            value: "overview",
            label: "Overview entity",
          },
          {
            value: "notables",
            label: "Notables",
          },
          {
            value: "outlier",
            label: "Outliers anomaly detection",
          },
          {
            value: "flipping_status",
            label: "Status flipping",
          },
          {
            value: "status_message",
            label: "Status message",
          },
          {
            value: "audit_changes",
            label: "Audit changes",
          },
        ],
        default: "overview",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "overview",
        value: "$form.inputLinkSplkFlx$",
        el: $("#inputLinkSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkSplkFlx.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkSplkFlx);
    });

    inputLinkSplkFlx.on("valueChange", function (e) {
      if (e.value === "overview") {
        EventHandler.setToken("show_splk_flx_overview", "true", {}, e.data);
        unsetToken("show_splk_flx_notables");
        unsetToken("show_splk_flx_outlier");
        unsetToken("show_splk_flx_status_message");
        unsetToken("show_splk_flx_flipping_status");
        unsetToken("show_splk_flx_audit_changes");
        $("#splk_flx_overview").css("display", "inherit");
        $("#splk_flx_notables").css("display", "none");
        $("#splk_flx_outliers").css("display", "none");
        $("#splk_flx_flipping").css("display", "none");
        $("#splk_flx_status").css("display", "none");
        $("#splk_flx_changes").css("display", "none");
        $("#splk_flx_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnFlxManageOutliers").css("display", "none");
      } else if (e.value === "notables") {
        EventHandler.setToken("show_splk_flx_notables", "true", {}, e.data);
        unsetToken("show_splk_flx_overview");
        unsetToken("show_splk_flx_status_message");
        unsetToken("show_splk_flx_flipping_status");
        unsetToken("show_splk_flx_audit_changes");
        $("#splk_flx_overview").css("display", "none");
        $("#splk_flx_notables").css("display", "inherit");
        $("#splk_flx_outliers").css("display", "none");
        $("#splk_flx_flipping").css("display", "none");
        $("#splk_flx_status").css("display", "none");
        $("#splk_flx_changes").css("display", "none");
        $("#splk_flx_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnFlxManageOutliers").css("display", "inherit");
      } else if (e.value === "outlier") {
        EventHandler.setToken("show_splk_flx_outlier", "true", {}, e.data);
        searchOutlierDetectionChartFlx.startSearch();
        unsetToken("show_splk_flx_overview");
        unsetToken("show_splk_flx_notables");
        unsetToken("show_splk_flx_status_message");
        unsetToken("show_splk_flx_flipping_status");
        unsetToken("show_splk_flx_audit_changes");
        $("#splk_flx_overview").css("display", "none");
        $("#splk_flx_notables").css("display", "none");
        $("#splk_flx_outliers").css("display", "inherit");
        $("#splk_flx_flipping").css("display", "none");
        $("#splk_flx_status").css("display", "none");
        $("#splk_flx_changes").css("display", "none");
        $("#splk_flx_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnFlxManageOutliers").css("display", "inherit");
      } else if (e.value === "flipping_status") {
        EventHandler.setToken(
          "show_splk_flx_flipping_status",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_flx_overview");
        unsetToken("show_splk_flx_notables");
        unsetToken("show_splk_flx_outlier");
        unsetToken("show_splk_flx_status_message");
        unsetToken("show_splk_flx_audit_changes");
        $("#splk_flx_overview").css("display", "none");
        $("#splk_flx_notables").css("display", "none");
        $("#splk_flx_outliers").css("display", "none");
        $("#splk_flx_flipping").css("display", "inherit");
        $("#splk_flx_status").css("display", "none");
        $("#splk_flx_changes").css("display", "none");
        $("#splk_flx_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnFlxManageOutliers").css("display", "none");
      } else if (e.value === "status_message") {
        EventHandler.setToken(
          "show_splk_flx_status_message",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_flx_overview");
        unsetToken("show_splk_flx_notables");
        unsetToken("show_splk_flx_outlier");
        unsetToken("show_splk_flx_flipping_status");
        unsetToken("show_splk_flx_audit_changes");
        $("#splk_flx_overview").css("display", "none");
        $("#splk_flx_notables").css("display", "none");
        $("#splk_flx_outliers").css("display", "none");
        $("#splk_flx_flipping").css("display", "none");
        $("#splk_flx_status").css("display", "inherit");
        $("#splk_flx_changes").css("display", "none");
        $("#splk_flx_timepicker").css("display", "none");
        // manage buttons
        $("#divBtnFlxManageOutliers").css("display", "none");
      } else if (e.value === "audit_changes") {
        EventHandler.setToken(
          "show_splk_flx_audit_changes",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_flx_overview");
        unsetToken("show_splk_flx_notables");
        unsetToken("show_splk_flx_outlier");
        unsetToken("show_splk_flx_flipping_status");
        unsetToken("show_splk_flx_status_message");
        $("#splk_flx_overview").css("display", "none");
        $("#splk_flx_notables").css("display", "none");
        $("#splk_flx_outliers").css("display", "none");
        $("#splk_flx_flipping").css("display", "none");
        $("#splk_flx_status").css("display", "none");
        $("#splk_flx_changes").css("display", "inherit");
        $("#splk_flx_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnFlxManageOutliers").css("display", "none");
      }
    });

    // modal link input
    var inputLinkSplkWlk = new LinkListInput(
      {
        id: "inputLinkSplkWlk",
        choices: [
          {
            value: "overview",
            label: "Overview entity",
          },
          {
            value: "notables",
            label: "Notables",
          },
          {
            value: "outlier",
            label: "Outliers anomaly detection",
          },
          {
            value: "flipping_status",
            label: "Status flipping",
          },
          {
            value: "status_message",
            label: "Status message",
          },
          {
            value: "audit_changes",
            label: "Audit changes",
          },
          {
            value: "metadata",
            label: "Versioning Metadata",
          },
        ],
        default: "overview",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "overview",
        value: "$form.inputLinkSplkWlk$",
        el: $("#inputLinkSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkSplkWlk.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkSplkWlk);
    });

    inputLinkSplkWlk.on("valueChange", function (e) {
      if (e.value === "overview") {
        EventHandler.setToken("show_splk_wlk_overview", "true", {}, e.data);
        unsetToken("show_splk_wlk_notables");
        unsetToken("show_splk_wlk_outlier");
        unsetToken("show_splk_wlk_status_message");
        unsetToken("show_splk_wlk_flipping_status");
        unsetToken("show_splk_wlk_audit_changes");
        unsetToken("show_splk_wlk_metadata");
        $("#splk_wlk_overview").css("display", "inherit");
        $("#splk_wlk_notables").css("display", "none");
        $("#splk_wlk_outliers").css("display", "none");
        $("#splk_wlk_flipping").css("display", "none");
        $("#splk_wlk_status").css("display", "none");
        $("#splk_wlk_changes").css("display", "none");
        $("#splk_wlk_metadata").css("display", "none");
        $("#splk_wlk_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnWlkManageOutliers").css("display", "none");
      } else if (e.value === "notables") {
        EventHandler.setToken("show_splk_wlk_notables", "true", {}, e.data);
        unsetToken("show_splk_wlk_overview");
        unsetToken("show_splk_wlk_status_message");
        unsetToken("show_splk_wlk_flipping_status");
        unsetToken("show_splk_wlk_audit_changes");
        unsetToken("show_splk_wlk_metadata");
        $("#splk_wlk_overview").css("display", "none");
        $("#splk_wlk_notables").css("display", "inherit");
        $("#splk_wlk_outliers").css("display", "none");
        $("#splk_wlk_flipping").css("display", "none");
        $("#splk_wlk_status").css("display", "none");
        $("#splk_wlk_changes").css("display", "none");
        $("#splk_wlk_metadata").css("display", "none");
        $("#splk_wlk_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnWlkManageOutliers").css("display", "inherit");
      } else if (e.value === "outlier") {
        EventHandler.setToken("show_splk_wlk_outlier", "true", {}, e.data);
        searchOutlierDetectionChartWlk.startSearch();
        unsetToken("show_splk_wlk_overview");
        unsetToken("show_splk_wlk_notables");
        unsetToken("show_splk_wlk_status_message");
        unsetToken("show_splk_wlk_flipping_status");
        unsetToken("show_splk_wlk_audit_changes");
        unsetToken("show_splk_wlk_metadata");
        $("#splk_wlk_overview").css("display", "none");
        $("#splk_wlk_notables").css("display", "none");
        $("#splk_wlk_outliers").css("display", "inherit");
        $("#splk_wlk_flipping").css("display", "none");
        $("#splk_wlk_status").css("display", "none");
        $("#splk_wlk_changes").css("display", "none");
        $("#splk_wlk_metadata").css("display", "none");
        $("#splk_wlk_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnWlkManageOutliers").css("display", "inherit");
      } else if (e.value === "flipping_status") {
        EventHandler.setToken(
          "show_splk_wlk_flipping_status",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_wlk_overview");
        unsetToken("show_splk_wlk_notables");
        unsetToken("show_splk_wlk_outlier");
        unsetToken("show_splk_wlk_status_message");
        unsetToken("show_splk_wlk_audit_changes");
        unsetToken("show_splk_wlk_metadata");
        $("#splk_wlk_overview").css("display", "none");
        $("#splk_wlk_notables").css("display", "none");
        $("#splk_wlk_outliers").css("display", "none");
        $("#splk_wlk_flipping").css("display", "inherit");
        $("#splk_wlk_status").css("display", "none");
        $("#splk_wlk_changes").css("display", "none");
        $("#splk_wlk_metadata").css("display", "none");
        $("#splk_wlk_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnWlkManageOutliers").css("display", "none");
      } else if (e.value === "status_message") {
        EventHandler.setToken(
          "show_splk_wlk_status_message",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_wlk_overview");
        unsetToken("show_splk_wlk_notables");
        unsetToken("show_splk_wlk_outlier");
        unsetToken("show_splk_wlk_flipping_status");
        unsetToken("show_splk_wlk_audit_changes");
        unsetToken("show_splk_wlk_metadata");
        $("#splk_wlk_overview").css("display", "none");
        $("#splk_wlk_notables").css("display", "none");
        $("#splk_wlk_outliers").css("display", "none");
        $("#splk_wlk_flipping").css("display", "none");
        $("#splk_wlk_status").css("display", "inherit");
        $("#splk_wlk_changes").css("display", "none");
        $("#splk_wlk_metadata").css("display", "none");
        $("#splk_wlk_timepicker").css("display", "none");
        // manage buttons
        $("#divBtnWlkManageOutliers").css("display", "none");
      } else if (e.value === "audit_changes") {
        EventHandler.setToken(
          "show_splk_wlk_audit_changes",
          "true",
          {},
          e.data
        );
        unsetToken("show_splk_wlk_overview");
        unsetToken("show_splk_wlk_notables");
        unsetToken("show_splk_wlk_outlier");
        unsetToken("show_splk_wlk_flipping_status");
        unsetToken("show_splk_wlk_status_message");
        unsetToken("show_splk_wlk_metadata");
        $("#splk_wlk_overview").css("display", "none");
        $("#splk_wlk_notables").css("display", "none");
        $("#splk_wlk_outliers").css("display", "none");
        $("#splk_wlk_flipping").css("display", "none");
        $("#splk_wlk_status").css("display", "none");
        $("#splk_wlk_changes").css("display", "inherit");
        $("#splk_wlk_metadata").css("display", "none");
        $("#splk_wlk_timepicker").css("display", "inherit");
        // manage buttons
        $("#divBtnWlkManageOutliers").css("display", "none");
      } else if (e.value === "metadata") {
        EventHandler.setToken("show_splk_wlk_metadata", "true", {}, e.data);
        unsetToken("show_splk_wlk_overview");
        unsetToken("show_splk_wlk_notables");
        unsetToken("show_splk_wlk_outlier");
        unsetToken("show_splk_wlk_flipping_status");
        unsetToken("show_splk_wlk_status_message");
        unsetToken("show_splk_wlk_changes");
        $("#splk_wlk_overview").css("display", "none");
        $("#splk_wlk_notables").css("display", "none");
        $("#splk_wlk_outliers").css("display", "none");
        $("#splk_wlk_flipping").css("display", "none");
        $("#splk_wlk_status").css("display", "none");
        $("#splk_wlk_changes").css("display", "none");
        $("#splk_wlk_metadata").css("display", "inherit");
        $("#splk_wlk_timepicker").css("display", "none");
        // manage buttons
        $("#divBtnWlkManageOutliers").css("display", "none");
        // call function
        //splkWlkRenderMetadata(getToken("tenant_id"), getToken("tk_object"));
      }
    });

    // modal link input
    var inputLinkCim = new LinkListInput(
      {
        id: "inputLinkCim",
        choices: [
          {
            value: "overview",
            label: "Overview CIM entity",
          },
          {
            value: "notables",
            label: "Notables",
          },
          {
            value: "metrics",
            label: "Metrics",
          },
          {
            value: "outlier",
            label: "Outliers anomaly detection",
          },
          {
            value: "flipping_status",
            label: "Status flipping",
          },
          {
            value: "status_message",
            label: "Status message",
          },
          {
            value: "audit_changes",
            label: "Audit changes",
          },
        ],
        default: "overview",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "overview",
        value: "$form.inputLinkCim$",
        el: $("#inputLinkCim"),
      },
      {
        tokens: true,
      }
    ).render();

    inputLinkCim.on("change", function (newValue) {
      FormUtils.handleValueChange(inputLinkCim);
    });

    inputLinkCim.on("valueChange", function (e) {
      if (e.value === "overview") {
        EventHandler.setToken("show_cim_overview", "true", {}, e.data);
        unsetToken("show_cim_notables");
        unsetToken("show_cim_metrics");
        unsetToken("show_cim_outliers");
        unsetToken("show_cim_status_message");
        unsetToken("show_cim_flipping_status");
        unsetToken("show_cim_audit_changes");
        $("#cim_overview").css("display", "inherit");
        $("#cim_notables").css("display", "none");
        $("#cim_metrics").css("display", "none");
        $("#cim_outliers").css("display", "none");
        $("#cim_flipping").css("display", "none");
        $("#cim_status").css("display", "none");
        $("#cim_changes").css("display", "none");
        $("#cim_timepicker").css("display", "none");
        // hide the manage outliers button
        $("#divBtnCimManageOutliers").css("display", "none");
        // set/unset additional tokens
        unsetToken("show_splk_cim_outlier");
      } else if (e.value === "notables") {
        // start the search
        searchSplkCimNotables.startSearch();
        EventHandler.setToken("show_cim_notables", "true", {}, e.data);
        unsetToken("show_cim_overview");
        unsetToken("show_cim_metrics");
        unsetToken("show_cim_outliers");
        unsetToken("show_cim_flipping_status");
        unsetToken("show_cim_status_message");
        unsetToken("show_cim_audit_changes");
        $("#cim_overview").css("display", "none");
        $("#cim_notables").css("display", "inherit");
        $("#cim_metrics").css("display", "none");
        $("#cim_outliers").css("display", "none");
        $("#cim_flipping").css("display", "none");
        $("#cim_status").css("display", "none");
        $("#cim_changes").css("display", "notables");
        $("#cim_timepicker").css("display", "inherit");
        // hide the manage outliers button
        $("#divBtnCimManageOutliers").css("display", "none");
        // set/unset additional tokens
        unsetToken("show_splk_cim_outlier");
      } else if (e.value === "metrics") {
        EventHandler.setToken("show_cim_metrics", "true", {}, e.data);
        unsetToken("show_cim_notables");
        unsetToken("show_cim_overview");
        unsetToken("show_cim_outliers");
        unsetToken("show_cim_status_message");
        unsetToken("show_cim_flipping_status");
        unsetToken("show_cim_audit_changes");
        $("#cim_overview").css("display", "none");
        $("#cim_notables").css("display", "none");
        $("#cim_metrics").css("display", "inherit");
        $("#cim_outliers").css("display", "none");
        $("#cim_flipping").css("display", "none");
        $("#cim_status").css("display", "none");
        $("#cim_changes").css("display", "none");
        $("#cim_timepicker").css("display", "inherit");
        // hide the manage outliers button
        $("#divBtnCimManageOutliers").css("display", "none");
        // set/unset additional tokens
        EventHandler.setToken("show_splk_cim_outlier", "true", {}, e.data);
      } else if (e.value === "outlier") {
        EventHandler.setToken("show_cim_outliers", "true", {}, e.data);
        unsetToken("show_cim_overview");
        unsetToken("show_cim_notables");
        unsetToken("show_cim_metrics");
        unsetToken("show_cim_status_message");
        unsetToken("show_cim_flipping_status");
        unsetToken("show_cim_audit_changes");
        $("#cim_overview").css("display", "none");
        $("#cim_notables").css("display", "none");
        $("#cim_metrics").css("display", "none");
        $("#cim_outliers").css("display", "inherit");
        $("#cim_flipping").css("display", "none");
        $("#cim_status").css("display", "none");
        $("#cim_changes").css("display", "none");
        $("#cim_timepicker").css("display", "inherit");
        // show the manage outliers button
        $("#divBtnCimManageOutliers").css("display", "inherit");
        // set/unset additional tokens
        EventHandler.setToken("show_splk_cim_outlier", "true", {}, e.data);
      } else if (e.value === "flipping_status") {
        EventHandler.setToken("show_cim_flipping_status", "true", {}, e.data);
        unsetToken("show_cim_overview");
        unsetToken("show_cim_notables");
        unsetToken("show_cim_metrics");
        unsetToken("show_cim_outliers");
        unsetToken("show_cim_status_message");
        unsetToken("show_cim_audit_changes");
        $("#cim_overview").css("display", "none");
        $("#cim_notables").css("display", "none");
        $("#cim_metrics").css("display", "none");
        $("#cim_outliers").css("display", "none");
        $("#cim_flipping").css("display", "inherit");
        $("#cim_status").css("display", "none");
        $("#cim_changes").css("display", "none");
        $("#cim_timepicker").css("display", "inherit");
        // hide the manage outliers button
        $("#divBtnCimManageOutliers").css("display", "none");
        // set/unset additional tokens
        unsetToken("show_splk_cim_outlier");
      } else if (e.value === "status_message") {
        EventHandler.setToken("show_cim_status_message", "true", {}, e.data);
        unsetToken("show_cim_overview");
        unsetToken("show_cim_notables");
        unsetToken("show_cim_metrics");
        unsetToken("show_cim_outliers");
        unsetToken("show_cim_flipping_status");
        unsetToken("show_cim_audit_changes");
        $("#cim_overview").css("display", "none");
        $("#cim_notables").css("display", "none");
        $("#cim_metrics").css("display", "none");
        $("#cim_outliers").css("display", "none");
        $("#cim_flipping").css("display", "none");
        $("#cim_status").css("display", "inherit");
        $("#cim_changes").css("display", "none");
        $("#cim_timepicker").css("display", "none");
        // hide the manage outliers button
        $("#divBtnCimManageOutliers").css("display", "none");
        // set/unset additional tokens
        unsetToken("show_splk_cim_outlier");
      } else if (e.value === "audit_changes") {
        EventHandler.setToken("show_cim_audit_changes", "true", {}, e.data);
        unsetToken("show_cim_overview");
        unsetToken("show_cim_notables");
        unsetToken("show_cim_metrics");
        unsetToken("show_cim_outliers");
        unsetToken("show_cim_flipping_status");
        unsetToken("show_cim_status_message");
        $("#cim_overview").css("display", "none");
        $("#cim_notables").css("display", "none");
        $("#cim_metrics").css("display", "none");
        $("#cim_outliers").css("display", "none");
        $("#cim_flipping").css("display", "none");
        $("#cim_status").css("display", "none");
        $("#cim_changes").css("display", "inherit");
        $("#cim_timepicker").css("display", "inherit");
        // hide the manage outliers button
        $("#divBtnCimManageOutliers").css("display", "none");
        // set/unset additional tokens
        unsetToken("show_splk_cim_outlier");
      }
    });

    var elementHostChartSplkMhm = new ChartView(
      {
        id: "elementHostChartSplkMhm",
        "charting.chart": "pie",
        "charting.drilldown": "all",
        "charting.fieldColors":
          '{"red": 0xff6961, "orange": 0xffb347, "blue": 0x89cff0, "green": 0x45D4BA}',
        height: "180",
        resizable: true,
        managerid: "searchHostChartSplkMhm",
        el: $("#elementHostChartSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementHostChartSplkMhm = new ResultsLinkView({
      id: "resultsLinkelementHostChartSplkMhm",
      managerid: "searchHostChartSplkMhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementHostChartSplkMhm"),
    });

    resultsLinkelementHostChartSplkMhm
      .render()
      .$el.appendTo($("resultsLinkelementHostChartSplkMhm"));

    var elementSingleSLASplkMhmpct = new SingleView(
      {
        id: "elementSingleSLASplkMhmpct",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "all",
        height: "95",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "%",
        rangeColors: '["0xdc4e41","0xf1813f","0x45D4BA"]',
        colorMode: "none",
        rangeValues: "[50,90]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useColors: "1",
        useThousandSeparators: "1",
        underLabel: "SLA PCT (% time spent in green/blue over 90d)",
        managerid: "searchSingleSLASplkMhmpct",
        el: $("#elementSingleSLASplkMhmpct"),
      },
      {
        tokens: true,
      }
    ).render();

    elementSingleSLASplkMhmpct.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        var url =
          "/app/trackme/trackMe_sla?form.tk_tenant_id=" +
          encodeURI(getToken("tenant_id")) +
          "&form.tk_object_category=splk-mhm&form.tk_object=" +
          encodeURI(getToken("tk_object"));
        utils.redirect(url, false, "_blank");
      }
    });

    var resultsLinkelementSingleSLASplkMhmpct = new ResultsLinkView({
      id: "resultsLinkelementSingleSLASplkMhmpct",
      managerid: "searchSingleSLASplkMhmpct",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSLASplkMhmpct"),
    });

    resultsLinkelementSingleSLASplkMhmpct
      .render()
      .$el.appendTo($("resultsLinkelementSingleSLASplkMhmpct"));

    var elementSingleSLASplkFlxpct = new SingleView(
      {
        id: "elementSingleSLASplkFlxpct",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "all",
        height: "95",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "%",
        rangeColors: '["0xdc4e41","0xf1813f","0x45D4BA"]',
        colorMode: "none",
        rangeValues: "[50,90]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useColors: "1",
        useThousandSeparators: "1",
        underLabel: "SLA PCT (% time spent in green/blue over 90d)",
        managerid: "searchSingleSLASplkFlxpct",
        el: $("#elementSingleSLASplkFlxpct"),
      },
      {
        tokens: true,
      }
    ).render();

    elementSingleSLASplkFlxpct.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        var url =
          "/app/trackme/trackMe_sla?form.tk_tenant_id=" +
          encodeURI(getToken("tenant_id")) +
          "&form.tk_object_category=splk-flx&form.tk_object=" +
          encodeURI(getToken("tk_object"));
        utils.redirect(url, false, "_blank");
      }
    });

    var resultsLinkelementSingleSLASplkFlxpct = new ResultsLinkView({
      id: "resultsLinkelementSingleSLASplkFlxpct",
      managerid: "searchSingleSLASplkFlxpct",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSLASplkFlxpct"),
    });

    resultsLinkelementSingleSLASplkFlxpct
      .render()
      .$el.appendTo($("resultsLinkelementSingleSLASplkFlxpct"));

    // SLA pct single for CIM trackers
    var elementSingleSLASplkCimpct = new SingleView(
      {
        id: "elementSingleSLASplkCimpct",
        trendDisplayMode: "absolute",
        numberPrecision: "0.00",
        drilldown: "all",
        height: "95",
        "trellis.size": "medium",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        unit: "%",
        rangeColors: '["0xdc4e41","0xf1813f","0x45D4BA"]',
        colorMode: "none",
        rangeValues: "[50,90]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useColors: "1",
        useThousandSeparators: "1",
        underLabel: "SLA PCT (% time spent in green/blue over 90d)",
        managerid: "searchSingleSLASplkCimpct",
        el: $("#elementSingleSLASplkCimpct"),
      },
      {
        tokens: true,
      }
    ).render();

    elementSingleSLASplkCimpct.on("click", function (e) {
      if (e.field !== undefined) {
        e.preventDefault();
        var url =
          "/app/trackme/trackMe_sla?form.tk_tenant_id=" +
          encodeURI(getToken("tenant_id")) +
          "&form.tk_object_category=splk-cim&form.tk_object=" +
          encodeURI(getToken("tk_object"));
        utils.redirect(url, false, "_blank");
      }
    });

    var resultsLinkelementSingleSLASplkCimpct = new ResultsLinkView({
      id: "resultsLinkelementSingleSLASplkCimpct",
      managerid: "searchSingleSLASplkCimpct",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSLASplkCimpct"),
    });

    resultsLinkelementSingleSLASplkCimpct
      .render()
      .$el.appendTo($("resultsLinkelementSingleSLASplkCimpct"));

    var elementHostTableSplkMhm = new TableView(
      {
        id: "elementHostTableSplkMhm",
        count: 5,
        drilldown: "none",
        fields:
          "metric_index, metric_category, metric_last_time_seen, lag_summary, metric_max_lag_allowed, time_measure, state_icon",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchHostTableSplkMhm",
        el: $("#elementHostTableSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementHostTableSplkMhm);

    var resultsLinkelementHostTableSplkMhm = new ResultsLinkView({
      id: "resultsLinkelementHostTableSplkMhm",
      managerid: "searchHostTableSplkMhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementHostTableSplkMhm"),
    });

    resultsLinkelementHostTableSplkMhm
      .render()
      .$el.appendTo($("resultsLinkelementHostTableSplkMhm"));

    var chartAuditFlipSplkMhmOverTime = new ChartView(
      {
        id: "chartAuditFlipSplkMhmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors":
          '{"orange": 0xffd394, "blue": 0xcfebf9, "green": 0xb6edb6, "red": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditmetricHostFlipOverTime",
        el: $("#chartAuditFlipSplkMhmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditFlipSplkMhmOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditFlipSplkMhmOverTime",
      managerid: "searchAuditmetricHostFlipOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditFlipSplkMhmOverTime"),
    });

    resultsLinkchartAuditFlipSplkMhmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditFlipSplkMhmOverTime"));

    var chartAuditFlipSplkFlxOverTime = new ChartView(
      {
        id: "chartAuditFlipSplkFlxOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors":
          '{"orange": 0xffd394, "blue": 0xcfebf9, "green": 0xb6edb6, "red": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkFlxFlipOverTime",
        el: $("#chartAuditFlipSplkFlxOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditFlipSplkFlxOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditFlipSplkFlxOverTime",
      managerid: "searchAuditmetricHostFlipOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditFlipSplkFlxOverTime"),
    });

    resultsLinkchartAuditFlipSplkFlxOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditFlipSplkFlxOverTime"));

    var chartAuditFlipSplkWlkOverTime = new ChartView(
      {
        id: "chartAuditFlipSplkWlkOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors":
          '{"orange": 0xffd394, "blue": 0xcfebf9, "green": 0xb6edb6, "red": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkWlkFlipOverTime",
        el: $("#chartAuditFlipSplkWlkOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditFlipSplkWlkOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditFlipSplkWlkOverTime",
      managerid: "searchAuditmetricHostFlipOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditFlipSplkWlkOverTime"),
    });

    resultsLinkchartAuditFlipSplkWlkOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditFlipSplkWlkOverTime"));

    // Audit Flip Metric Host
    var elementMainTableAuditFlipSplkMhm = new TableView(
      {
        id: "elementMainTableAuditFlipSplkMhm",
        count: 5,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMainSplkMhmAuditFlipTable",
        el: $("#elementMainTableAuditFlipSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementMainTableAuditFlipSplkMhm);

    var resultsLinkelementMainTableAuditFlipSplkMhm = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditFlipSplkMhm",
      managerid: "searchMainSplkMhmAuditFlipTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditFlipSplkMhm"),
    });

    resultsLinkelementMainTableAuditFlipSplkMhm
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditFlipSplkMhm"));

    // Audit Flip Metric Host
    var elementMainTableAuditFlipSplkFlx = new TableView(
      {
        id: "elementMainTableAuditFlipSplkFlx",
        count: 5,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMainSplkFlxAuditFlipTable",
        el: $("#elementMainTableAuditFlipSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementMainTableAuditFlipSplkFlx);

    var resultsLinkelementMainTableAuditFlipSplkFlx = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditFlipSplkFlx",
      managerid: "searchMainSplkFlxAuditFlipTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditFlipSplkFlx"),
    });

    resultsLinkelementMainTableAuditFlipSplkFlx
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditFlipSplkFlx"));

    // Audit Flip Metric Host
    var elementMainTableAuditFlipSplkWlk = new TableView(
      {
        id: "elementMainTableAuditFlipSplkWlk",
        count: 5,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMainSplkWlkAuditFlipTable",
        el: $("#elementMainTableAuditFlipSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementMainTableAuditFlipSplkWlk);

    var resultsLinkelementMainTableAuditFlipSplkWlk = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditFlipSplkWlk",
      managerid: "searchMainSplkWlkAuditFlipTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditFlipSplkWlk"),
    });

    resultsLinkelementMainTableAuditFlipSplkWlk
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditFlipSplkWlk"));

    var chartAuditChangesSplkMhmOverTime = new ChartView(
      {
        id: "chartAuditChangesSplkMhmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkMhmAuditChangesOverTime",
        el: $("#chartAuditChangesSplkMhmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditChangesSplkMhmOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditChangesSplkMhmOverTime",
      managerid: "searchAuditSplkMhmAuditChangesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditChangesSplkMhmOverTime"),
    });

    resultsLinkchartAuditChangesSplkMhmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditChangesSplkMhmOverTime"));

    var chartAuditChangesSplkFlxOverTime = new ChartView(
      {
        id: "chartAuditChangesSplkFlxOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkFlxAuditChangesOverTime",
        el: $("#chartAuditChangesSplkFlxOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditChangesSplkFlxOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditChangesSplkFlxOverTime",
      managerid: "searchAuditSplkFlxAuditChangesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditChangesSplkFlxOverTime"),
    });

    resultsLinkchartAuditChangesSplkFlxOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditChangesSplkFlxOverTime"));

    var chartAuditChangesSplkWlkOverTime = new ChartView(
      {
        id: "chartAuditChangesSplkWlkOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditSplkWlkAuditChangesOverTime",
        el: $("#chartAuditChangesSplkWlkOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditChangesSplkWlkOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditChangesSplkWlkOverTime",
      managerid: "searchAuditSplkWlkAuditChangesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditChangesSplkWlkOverTime"),
    });

    resultsLinkchartAuditChangesSplkWlkOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditChangesSplkWlkOverTime"));

    // Audit Changes splk-flx
    var eventAuditChangesSplkFlx = new EventsViewer(
      {
        id: "eventAuditChangesSplkFlx",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchMainSplkFlxAuditChangesTable",
        el: $("#eventAuditChangesSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAuditChangesSplkFlx = new ResultsLinkView({
      id: "resultsLinkeventAuditChangesSplkFlx",
      managerid: "searchMainSplkFlxAuditChangesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAuditChangesSplkFlx"),
    });

    resultsLinkeventAuditChangesSplkFlx
      .render()
      .$el.appendTo($("resultsLinkeventAuditChangesSplkFlx"));

    // Audit Changes splk-wlk
    var eventAuditChangesSplkWlk = new EventsViewer(
      {
        id: "eventAuditChangesSplkWlk",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchMainSplkWlkAuditChangesTable",
        el: $("#eventAuditChangesSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAuditChangesSplkWlk = new ResultsLinkView({
      id: "resultsLinkeventAuditChangesSplkWlk",
      managerid: "searchMainSplkWlkAuditChangesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAuditChangesSplkWlk"),
    });

    resultsLinkeventAuditChangesSplkWlk
      .render()
      .$el.appendTo($("resultsLinkeventAuditChangesSplkWlk"));

    // Audit Changes splk-wlk
    var eventMetadataSplkWlk = new EventsViewer(
      {
        id: "eventMetadataSplkWlk",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 100,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchMainSplkWlkMetadataTable",
        el: $("#eventMetadataSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventMetadataSplkWlk = new ResultsLinkView({
      id: "resultsLinkeventMetadataSplkWlk",
      managerid: "searchMainSplkWlkMetadataTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventMetadataSplkWlk"),
    });

    resultsLinkeventMetadataSplkWlk
      .render()
      .$el.appendTo($("resultsLinkeventMetadataSplkWlk"));

    // Audit Changes Metric Host
    var eventAuditChangesSplkMhm = new EventsViewer(
      {
        id: "eventAuditChangesSplkMhm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchMainSplkMhmAuditChangesTable",
        el: $("#eventAuditChangesSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAuditChangesSplkMhm = new ResultsLinkView({
      id: "resultsLinkeventAuditChangesSplkMhm",
      managerid: "searchMainSplkMhmAuditChangesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAuditChangesSplkMhm"),
    });

    resultsLinkeventAuditChangesSplkMhm
      .render()
      .$el.appendTo($("resultsLinkeventAuditChangesSplkMhm"));

    var elementGetTagsSplkMhm = new TableView(
      {
        id: "elementGetTagsSplkMhm",
        count: 100,
        drilldown: "row",
        "refresh.display": "none",
        wrap: "true",
        managerid: "searchGetSplkMhmTags",
        el: $("#elementGetTagsSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementGetTagsSplkMhm = new ResultsLinkView({
      id: "resultsLinkelementGetTagsSplkMhm",
      managerid: "searchGetSplkMhmTags",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementGetTagsSplkMhm"),
    });

    resultsLinkelementGetTagsSplkMhm
      .render()
      .$el.appendTo($("resultsLinkelementGetTagsSplkMhm"));

    var modal_input_splk_mhm_priority = new DropdownInput(
      {
        id: "modal_input_splk_mhm_priority",
        choices: [
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        searchWhenChanged: true,
        default: "medium",
        showClearButton: true,
        initialValue: "medium",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_mhm_priority$",
        el: $("#modal_input_splk_mhm_priority"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_mhm_priority.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_mhm_priority);
    });

    var modal_input_splk_flx_priority = new DropdownInput(
      {
        id: "modal_input_splk_flx_priority",
        choices: [
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        searchWhenChanged: true,
        default: "medium",
        showClearButton: true,
        initialValue: "medium",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_flx_priority$",
        el: $("#modal_input_splk_flx_priority"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_priority.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_flx_priority);
    });

    var modal_input_splk_wlk_priority = new DropdownInput(
      {
        id: "modal_input_splk_wlk_priority",
        choices: [
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        searchWhenChanged: true,
        default: "medium",
        showClearButton: true,
        initialValue: "medium",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_wlk_priority$",
        el: $("#modal_input_splk_wlk_priority"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_priority.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_wlk_priority);
    });

    var modal_input_splk_cim_priority = new DropdownInput(
      {
        id: "modal_input_splk_cim_priority",
        choices: [
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        searchWhenChanged: true,
        default: "medium",
        showClearButton: true,
        initialValue: "medium",
        selectFirstChoice: false,
        value: "$form.tk_input_splk_cim_priority$",
        el: $("#modal_input_splk_cim_priority"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_priority.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_splk_cim_priority);
    });

    var inputMetricPolicySLA_category = new DropdownInput(
      {
        id: "inputMetricPolicySLA_category",
        tokenDependencies: {
          depends: "$show_splk_mhm_tracker$",
        },
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "metric_category",
        selectFirstChoice: false,
        valueField: "metric_category",
        value: "$form.tk_input_metric_policy_metric_category$",
        managerid: "searchPopulateSplkMhmsCategories",
        el: $("#inputMetricPolicySLA_category"),
      },
      {
        tokens: true,
      }
    ).render();

    inputMetricPolicySLA_category.on("change", function (newValue) {
      FormUtils.handleValueChange(inputMetricPolicySLA_category);
    });

    var inputMetricPolicySLA_value = new TextInput(
      {
        id: "inputMetricPolicySLA_value",
        searchWhenChanged: true,
        value: "$form.tk_input_metric_policy_metric_value$",
        el: $("#inputMetricPolicySLA_value"),
      },
      {
        tokens: true,
      }
    ).render();

    inputMetricPolicySLA_value.on("change", function (newValue) {
      FormUtils.handleValueChange(inputMetricPolicySLA_value);
    });

    // metric sla policies
    var SingleMetricPolicies = new SingleView(
      {
        id: "SingleMetricPolicies",
        trendDisplayMode: "absolute",
        drilldown: "none",
        trendColorInterpretation: "standard",
        useColors: "0",
        colorBy: "value",
        showTrendIndicator: "1",
        showSparkline: "1",
        "trellis.enabled": "0",
        numberPrecision: "0",
        rangeColors: '["0x45D4BA","0x0877a6","0xf8be34","0xf1813f","0xdc4e41"]',
        "trellis.size": "medium",
        colorMode: "none",
        rangeValues: "[0,30,70,100]",
        unitPosition: "after",
        "trellis.scales.shared": "1",
        useThousandSeparators: "1",
        underLabel: "metric policies",
        managerid: "searchSingleMetricPolicies",
        el: $("#SingleMetricPolicies"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkSingleMetricPolicies = new ResultsLinkView({
      id: "resultsLinkSingleMetricPolicies",
      managerid: "searchSingleMetricPolicies",
      "link.exportResults.visible": false,
      el: $("#resultsLinkSingleMetricPolicies"),
    });

    resultsLinkSingleMetricPolicies
      .render()
      .$el.appendTo($("resultsLinkSingleMetricPolicies"));

    // Metric SLA policies

    var tableMetricPolicies = new TableElement(
      {
        id: "tableMetricPolicies",
        tokenDependencies: {
          depends: "$show_table_metric_policies$",
        },
        count: 8,
        drilldown: "none",
        fields: "metric_category, metric_max_lag_allowed, select",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMetricPolicies",
        el: $("#tableMetricPolicies"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableCheckBox("tableMetricPolicies", "removeMetricPolicies");

    var resultsLinktableMetricPolicies = new ResultsLinkView({
      id: "resultsLinktableMetricPolicies",
      managerid: "searchMetricPolicies",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableMetricPolicies"),
    });

    resultsLinktableMetricPolicies
      .render()
      .$el.appendTo($("resultsLinktableMetricPolicies"));

    //
    // Hybrid trackers
    //

    // dsm

    var modal_input_hybrid_remote_dsm_cron = new TextInput(
      {
        id: "modal_input_hybrid_remote_dsm_cron",
        searchWhenChanged: false,
        default: "*/5 * * * *",
        initialValue: "*/5 * * * *",
        value: "$form.tk_input_hybrid_remote_tracker_dsm_cron$",
        el: $("#modal_input_hybrid_remote_dsm_cron"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dsm_cron.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dsm_cron);
    });

    var modal_input_hybrid_remote_dsm_earliest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dsm_earliest",
        searchWhenChanged: false,
        default: "-4h",
        initialValue: "-4h",
        value: "$form.tk_input_hybrid_remote_tracker_dsm_earliest$",
        el: $("#modal_input_hybrid_remote_dsm_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dsm_earliest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dsm_earliest);
    });

    var modal_input_hybrid_remote_dsm_latest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dsm_latest",
        searchWhenChanged: false,
        default: "+4h",
        initialValue: "+4h",
        value: "$form.tk_input_hybrid_remote_tracker_dsm_latest$",
        el: $("#modal_input_hybrid_remote_dsm_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dsm_latest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dsm_latest);
    });

    var modal_input_hybrid_remote_dsm_index_earliest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dsm_index_earliest",
        searchWhenChanged: false,
        default: "-4h",
        initialValue: "-4h",
        value: "$form.tk_input_hybrid_remote_tracker_dsm_index_earliest$",
        el: $("#modal_input_hybrid_remote_dsm_index_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dsm_index_earliest.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_dsm_index_earliest
        );
      }
    );

    var modal_input_hybrid_remote_dsm_index_latest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dsm_index_latest",
        searchWhenChanged: false,
        default: "+4h",
        initialValue: "+4h",
        value: "$form.tk_input_hybrid_remote_tracker_dsm_index_latest$",
        el: $("#modal_input_hybrid_remote_dsm_index_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dsm_index_latest.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_hybrid_remote_dsm_index_latest);
      }
    );

    var modal_input_hybrid_remote_search_dsm_mode = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_search_dsm_mode",
        choices: [
          {
            label: "tstats",
            value: "tstats",
          },
          {
            label: "raw",
            value: "raw",
          },
        ],
        searchWhenChanged: false,
        default: "tstats",
        showClearButton: true,
        initialValue: "tstats",
        selectFirstChoice: false,
        value: "$form.tk_input_hybrid_remote_search_dsm_mode$",
        el: $("#modal_input_hybrid_remote_search_dsm_mode"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_search_dsm_mode.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_search_dsm_mode);
      if (newValue === "tstats") {
        $("#divParentHybridDsmBreakByAdditionals").show();
      } else if (newValue === "raw") {
        $("#divParentHybridDsmBreakByAdditionals").hide();
      }
    });

    var modal_input_hybrid_remote_search_dsm_tstats_root_span =
      new DropdownInput(
        {
          id: "modal_input_hybrid_remote_search_dsm_tstats_root_span",
          choices: [
            {
              label: "1s",
              value: "1s",
            },
            {
              label: "10s",
              value: "10s",
            },
            {
              label: "30s",
              value: "30s",
            },
            {
              label: "1m",
              value: "1m",
            },
            {
              label: "5m",
              value: "5m",
            },
            {
              label: "1ms",
              value: "1ms",
            },
          ],
          searchWhenChanged: false,
          default: "1s",
          showClearButton: true,
          initialValue: "1s",
          selectFirstChoice: false,
          value: "$form.tk_hybrid_dsm_tstats_root_span$",
          el: $("#modal_input_hybrid_remote_search_dsm_tstats_root_span"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_hybrid_remote_search_dsm_tstats_root_span.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_search_dsm_tstats_root_span
        );
      }
    );

    var modal_input_hybrid_remote_search_dsm_tstats_include_splunk_server =
      new DropdownInput(
        {
          id: "modal_input_hybrid_remote_search_dsm_tstats_include_splunk_server",
          choices: [
            {
              label: "True",
              value: "True",
            },
            {
              label: "False",
              value: "False",
            },
          ],
          searchWhenChanged: false,
          default: "False",
          showClearButton: true,
          initialValue: "False",
          selectFirstChoice: false,
          value: "$form.tk_hybrid_dsm_include_splunk_server$",
          el: $(
            "#modal_input_hybrid_remote_search_dsm_tstats_include_splunk_server"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_hybrid_remote_search_dsm_tstats_include_splunk_server.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_search_dsm_tstats_include_splunk_server
        );
      }
    );

    var modal_input_hybrid_remote_search_dsm_tstats_include_host =
      new DropdownInput(
        {
          id: "modal_input_hybrid_remote_search_dsm_tstats_include_host",
          choices: [
            {
              label: "True",
              value: "True",
            },
            {
              label: "False",
              value: "False",
            },
          ],
          searchWhenChanged: false,
          default: "False",
          showClearButton: true,
          initialValue: "False",
          selectFirstChoice: false,
          value: "$form.tk_hybrid_dsm_include_host$",
          el: $("#modal_input_hybrid_remote_search_dsm_tstats_include_host"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_hybrid_remote_search_dsm_tstats_include_host.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_search_dsm_tstats_include_host
        );
      }
    );

    //
    // function to check the remote connectivity
    //

    // check the remote account connectivity
    function checkSplkFeedsRemoteAccount(component, account) {
      // Set the element ids
      if (component === "dsm") {
        parentDiv = "divParentCreateDsmHybridValidateRemoteConnectivity";
        spinnerDiv = "divCreateDsmHybridValidateRemoteConnectivityLoader";
        childDiv = "divCreateDsmHybridValidateRemoteConnectivity";
      } else if (component === "dhm") {
        parentDiv = "divParentCreateDhmHybridValidateRemoteConnectivity";
        spinnerDiv = "divCreateDhmHybridValidateRemoteConnectivityLoader";
        childDiv = "divCreateDhmHybridValidateRemoteConnectivity";
      } else if (component === "mhm") {
        parentDiv = "divParentCreateMhmHybridValidateRemoteConnectivity";
        spinnerDiv = "divCreateMhmHybridValidateRemoteConnectivityLoader";
        childDiv = "divCreateMhmHybridValidateRemoteConnectivity";
      } else if (component === "elastic") {
        parentDiv = "divParentCreateElasticValidateRemoteConnectivity";
        spinnerDiv = "divCreateElasticValidateRemoteConnectivityLoader";
        childDiv = "divCreateElasticValidateRemoteConnectivity";
      } else if (component === "flx") {
        parentDiv = "divParentCreateFlxHybridValidateRemoteConnectivity";
        spinnerDiv = "divCreateFlxHybridValidateRemoteConnectivityLoader";
        childDiv = "divCreateFlxHybridValidateRemoteConnectivity";
      } else if (component === "wlk") {
        parentDiv = "divParentCreateWlkHybridValidateRemoteConnectivity";
        spinnerDiv = "divCreateWlkHybridValidateRemoteConnectivityLoader";
        childDiv = "divCreateWlkHybridValidateRemoteConnectivity";
      }

      // notify
      notify(
        "info",
        "bottom",
        "Please wait while we verify the connectivity and authentication to the remote Splunk deployment, this can take a few minutes if the target cannot be reached, hold on...",
        "150"
      );
      // Show the parent
      $("#" + parentDiv).css("display", "inherit");
      // Show the spinner
      $("#" + spinnerDiv).css("display", "inherit");
      // hide the result viewer
      $("#" + childDiv).css("display", "none");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/configuration/test_remote_account";

      // Create a dictionary to store the field names and values
      var record = {
        account: account,
      };

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "json",
        data: JSON.stringify(record),
        success: function (returneddata) {
          // hide
          $("#" + spinnerDiv).css("display", "none");
          // notify
          notify(
            "success",
            "bottom",
            "Successfully passed the connectivity check to the remote Splunk deployment.",
            "5"
          );
          // show
          // creation via template
          $("#" + childDiv).html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
              "</pre>"
          );
          $("#" + childDiv).css("display", "inherit");
        },
        error: function (xhr, textStatus, error) {
          // hide
          $("#" + spinnerDiv).css("display", "none");
          // notify
          notify(
            "error",
            "bottom",
            "Failed to verify the connectivity to the Splunk remote deployment.",
            "5"
          );
          // creation via template
          $("#" + childDiv).html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(xhr, null, 2)) +
              "</pre>"
          );
          $("#" + childDiv).css("display", "inherit");
        },
      });
    }

    // splk-flx

    //
    // Function to render the pre-loaded use case information
    //

    // check the remote account connectivity
    function returnSplkFlxUseCaseInfo(record) {
      // Set the element ids
      var parentDiv = "divParentFlxUseCaseInfo";
      var spinnerDiv = "divFlxUseCaseInfoLoader";
      var childDiv = "divFlxUseCaseInfo";

      // Show the parent
      $("#" + parentDiv).css("display", "inherit");
      // Show the spinner
      $("#" + spinnerDiv).css("display", "inherit");
      // hide the result viewer
      $("#" + childDiv).css("display", "none");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/admin/flx_load_uc";

      // Create a dictionary to store the field names and values
      var recordToSend = {
        uc_ref: record["uc_ref"],
        tenant_id: record["tenant_id"],
        group: record["group"],
      };

      var textArea = $("#modal_input_hybrid_remote_root_constraint_flx");

      function resizeTextArea() {
        textArea.css("overflow", "hidden"); // This prevents scroll bar from messing up the sizing
        textArea.css("height", 0); // Temporarily collapse the textarea to measure its intrinsic height
        textArea.css("height", textArea.prop("scrollHeight") + "px");
      }

      resizeTextArea(); // Resize on page load

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "json",
        data: JSON.stringify(recordToSend),
        success: function (returneddata) {
          var response = returneddata["response"];

          // load search
          textArea.val(response["uc_search"]);
          textArea.trigger("input"); // trigger input event to resize textarea

          // remove uc_search from the response
          delete response["uc_search"];

          // set tokens
          $("#modal_input_hybrid_remote_tracker_flx_name").val(
            response["uc_ref"]
          );
          setToken(
            "form.tk_input_hybrid_remote_tracker_flx_earliest",
            response["uc_earliest"]
          );
          setToken(
            "form.tk_input_hybrid_remote_tracker_flx_latest",
            response["uc_latest"]
          );
          setToken(
            "form.tk_input_hybrid_remote_tracker_flx_cron",
            response["uc_cron"]
          );

          // hide
          $("#" + spinnerDiv).css("display", "none");
          // show
          // creation via template
          $("#" + childDiv).html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(response, null, 2)) +
              "</pre>"
          );
          $("#" + childDiv).css("display", "inherit");
        },
        error: function (xhr, textStatus, error) {
          // hide
          $("#" + spinnerDiv).css("display", "none");
          // notify
          notify(
            "error",
            "bottom",
            "Failed to load the Flex use case information.",
            "5"
          );
          // creation via template
          $("#" + childDiv).html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(xhr, null, 2)) +
              "</pre>"
          );
          $("#" + childDiv).css("display", "inherit");
        },
      });

      textArea.on("input", resizeTextArea); // Resize when content changes
    }

    // splk-wlk

    //
    // function to render the versioning json dict
    //

    // check the remote account connectivity
    function splkWlkRenderMetadata(tenant_id, object_name) {
      // Set the element ids

      parentDiv = "divParentSplkWlkRenderMetadata";
      spinnerDiv = "divSplkWlkRenderMetadataLoader";
      childDiv = "divSplkWlkRenderMetadata";

      // notify
      notify(
        "info",
        "bottom",
        "Please wait while retrieving report's versioning metadata, hold on...",
        "150"
      );
      // Show the parent
      $("#" + parentDiv).css("display", "inherit");
      // Show the spinner
      $("#" + spinnerDiv).css("display", "inherit");
      // hide the result viewer
      $("#" + childDiv).css("display", "none");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_entity_metadata";

      // Create a dictionary to store the field names and values
      var record = {
        tenant_id: tenant_id,
        object: object_name,
      };

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "json",
        data: JSON.stringify(record),
        success: function (returneddata) {
          // hide
          $("#" + spinnerDiv).css("display", "none");
          // notify
          notify(
            "success",
            "bottom",
            "Successfully retrieved report's versioning metadata.",
            "5"
          );
          // show
          // creation via template
          $("#" + childDiv).html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
              "</pre>"
          );
          $("#" + childDiv).css("display", "inherit");
        },
        error: function (xhr, textStatus, error) {
          // hide
          $("#" + spinnerDiv).css("display", "none");
          // notify
          notify(
            "error",
            "bottom",
            "Failed to retrieve report's versioning metadata.",
            "5"
          );
          // creation via template
          $("#" + childDiv).html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(xhr, null, 2)) +
              "</pre>"
          );
          $("#" + childDiv).css("display", "inherit");
        },
      });
    }

    // Replica trackers

    var searchPopulateReplicaTenants = new SearchManager(
      {
        id: "searchPopulateReplicaTenants",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "+5m",
        search:
          '| inputlookup trackme_virtual_tenants where (tenant_status="enabled" AND tenant_replica=0) | table tenant_name | sort 0 tenant_name',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_modify_replica_trackers$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var modal_input_replica_tracker_tenant = new DropdownInput(
      {
        id: "modal_input_replica_tracker_tenant",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "tenant_name",
        valueField: "tenant_name",
        managerid: "searchPopulateReplicaTenants",
        value: "$form.tk_input_replica_tracker_tenant$",
        el: $("#modal_input_replica_tracker_tenant"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_replica_tracker_tenant.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_replica_tracker_tenant);
    });

    // splk-dsm hybrid account

    var modal_input_hybrid_remote_dsm_account = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_dsm_account",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "account",
        valueField: "account",
        managerid: "searchPopulateConfigurationAccountDsm",
        value: "$form.tk_input_hybrid_remote_dsm_account$",
        el: $("#modal_input_hybrid_remote_dsm_account"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dsm_account.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dsm_account);
      // check the connectivity if the account is not local
      if (newValue != undefined) {
        if (newValue != "local") {
          checkSplkFeedsRemoteAccount("dsm", newValue);
        } else {
          $("#divParentCreateDsmHybridValidateRemoteConnectivity").css(
            "display",
            "none"
          );
        }
      }
    });

    var modal_input_hybrid_remote_tracker_dsm_name = new TextInput(
      {
        id: "modal_input_hybrid_remote_tracker_dsm_name",
        searchWhenChanged: false,
        value: "$form.tk_input_hybrid_remote_tracker_name_dsm$",
        el: $("#modal_input_hybrid_remote_tracker_dsm_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_tracker_dsm_name.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_hybrid_remote_tracker_dsm_name);
      }
    );

    var modal_input_hybrid_remote_dsm_break_by_field = new TextInput(
      {
        id: "modal_input_hybrid_remote_dsm_break_by_field",
        searchWhenChanged: false,
        default: "none",
        initialValue: "none",
        value: "$form.tk_input_hybrid_remote_dsm_break_by_field$",
        el: $("#modal_input_hybrid_remote_dsm_break_by_field"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dsm_break_by_field.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_dsm_break_by_field
        );
      }
    );

    //
    // flx
    //

    // accoount
    var modal_input_hybrid_remote_flx_account = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_flx_account",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "account",
        valueField: "account",
        managerid: "searchPopulateConfigurationAccountFlx",
        value: "$form.tk_input_hybrid_remote_flx_account$",
        el: $("#modal_input_hybrid_remote_flx_account"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_flx_account.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_flx_account);
      // check the connectivity if the account is not local
      if (newValue != undefined) {
        if (newValue != "local") {
          checkSplkFeedsRemoteAccount("flx", newValue);
        } else {
          $("#divParentCreateFlxHybridValidateRemoteConnectivity").css(
            "display",
            "none"
          );
        }
      }
    });

    // tracker name
    var modal_input_hybrid_remote_tracker_flx_name = new TextInput(
      {
        id: "modal_input_hybrid_remote_tracker_flx_name",
        searchWhenChanged: false,
        value: "$form.tk_input_hybrid_remote_tracker_name_flx$",
        el: $("#modal_input_hybrid_remote_tracker_flx_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_tracker_flx_name.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_hybrid_remote_tracker_flx_name);
      }
    );

    // search manager to preload library use cases
    var searchFlxLoadUseCases = new SearchManager(
      {
        id: "searchFlxLoadUseCases",
        earliest_time: "-5m",
        cancelOnUnload: true,
        autostart: false,
        sample_ratio: null,
        latest_time: "+5m",
        search:
          "| trackmesplkflxgetuc | table uc_vendor, uc_description, uc_vendor, uc_category, uc_ref | sort 0 uc_vendor, uc_category, uc_ref",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchFlxLoadUseCasesVendor = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          "stats count by uc_vendor | fields uc_vendor | sort 0 uc_vendor",
        managerid: "searchFlxLoadUseCases",
        id: "searchFlxLoadUseCasesVendor",
      },
      {
        tokens: true,
      }
    );

    var searchFlxLoadUseCasesCat = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'search uc_vendor="$tk_input_flx_uc_vendor$" | stats count by uc_category | fields uc_category | sort 0 uc_category',
        managerid: "searchFlxLoadUseCases",
        id: "searchFlxLoadUseCasesCat",
      },
      {
        tokens: true,
      }
    );

    var searchFlxLoadUseCasesRef = new PostProcessManager(
      {
        tokenDependencies: {},
        search:
          'search uc_vendor="$tk_input_flx_uc_vendor$" uc_category="$tk_input_flx_uc_category$"| stats count by uc_ref | fields uc_ref | sort 0 uc_ref',
        managerid: "searchFlxLoadUseCases",
        id: "searchFlxLoadUseCasesRef",
      },
      {
        tokens: true,
      }
    );

    // uc_vendor
    var modal_input_flx_uc_vendor = new DropdownInput(
      {
        id: "modal_input_flx_uc_vendor",
        searchWhenChanged: true,
        showClearButton: true,
        selectFirstChoice: false,
        labelField: "uc_vendor",
        valueField: "uc_vendor",
        managerid: "searchFlxLoadUseCasesVendor",
        value: "$form.tk_input_flx_uc_vendor$",
        el: $("#modal_input_flx_uc_vendor"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_flx_uc_vendor.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_flx_uc_vendor);
    });

    // uc_category
    var modal_input_flx_uc_category = new DropdownInput(
      {
        id: "modal_input_flx_uc_category",
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        default: "*",
        showClearButton: true,
        initialValue: "*",
        selectFirstChoice: false,
        labelField: "uc_category",
        valueField: "uc_category",
        managerid: "searchFlxLoadUseCasesCat",
        value: "$form.tk_input_flx_uc_category$",
        el: $("#modal_input_flx_uc_category"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_flx_uc_category.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_flx_uc_category);
    });

    // uc_ref
    var modal_input_flx_uc_ref = new DropdownInput(
      {
        id: "modal_input_flx_uc_ref",
        searchWhenChanged: true,
        showClearButton: true,
        selectFirstChoice: false,
        labelField: "uc_ref",
        valueField: "uc_ref",
        managerid: "searchFlxLoadUseCasesRef",
        value: "$form.tk_input_flx_uc_ref$",
        el: $("#modal_input_flx_uc_ref"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_flx_uc_ref.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_flx_uc_ref);
      if (newValue != undefined) {
        var record = {
          uc_ref: newValue,
          tenant_id: getToken("tenant_id"),
          group: document.getElementById(
            "modal_input_hybrid_remote_tracker_flx_name"
          ).value,
        };
        returnSplkFlxUseCaseInfo(record);
      } else {
        $("#divParentFlxUseCaseInfo").css("display", "none");
      }
    });

    // earliest
    var modal_input_hybrid_remote_flx_earliest = new TextInput(
      {
        id: "modal_input_hybrid_remote_flx_earliest",
        searchWhenChanged: false,
        default: "-5m",
        initialValue: "-5m",
        value: "$form.tk_input_hybrid_remote_tracker_flx_earliest$",
        el: $("#modal_input_hybrid_remote_flx_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_flx_earliest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_flx_earliest);
    });

    // latest
    var modal_input_hybrid_remote_flx_latest = new TextInput(
      {
        id: "modal_input_hybrid_remote_flx_latest",
        searchWhenChanged: false,
        default: "now",
        initialValue: "now",
        value: "$form.tk_input_hybrid_remote_tracker_flx_latest$",
        el: $("#modal_input_hybrid_remote_flx_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_flx_latest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_flx_latest);
    });

    // cron
    var modal_input_hybrid_remote_flx_cron = new TextInput(
      {
        id: "modal_input_hybrid_remote_flx_cron",
        searchWhenChanged: false,
        default: "*/5 * * * *",
        initialValue: "*/5 * * * *",
        value: "$form.tk_input_hybrid_remote_tracker_flx_cron$",
        el: $("#modal_input_hybrid_remote_flx_cron"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_flx_cron.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_flx_cron);
    });

    // wlk

    var modal_input_hybrid_remote_wlk_account = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_wlk_account",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "account",
        valueField: "account",
        managerid: "searchPopulateConfigurationAccountWlk",
        value: "$form.tk_input_hybrid_remote_wlk_account$",
        el: $("#modal_input_hybrid_remote_wlk_account"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_wlk_account.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_wlk_account);
      // check the connectivity if the account is not local
      if (newValue != undefined) {
        if (newValue != "local") {
          checkSplkFeedsRemoteAccount("wlk", newValue);
        } else {
          $("#divParentCreateWlkHybridValidateRemoteConnectivity").css(
            "display",
            "none"
          );
        }
      }
    });

    var modal_input_hybrid_remote_tracker_wlk_type = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_tracker_wlk_type",
        choices: [
          {
            label: "introspection",
            value: "introspection",
          },
          {
            label: "scheduler",
            value: "scheduler",
          },
          {
            label: "splunkcloud_svc",
            value: "splunkcloud_svc",
          },
          {
            label: "notable",
            value: "notable",
          },
          {
            label: "main",
            value: "main",
          },
          {
            label: "orphan",
            value: "orphan",
          },
          {
            label: "inactive_entities",
            value: "inactive_entities",
          },
          {
            label: "metadata",
            value: "metadata",
          },
        ],
        searchWhenChanged: false,
        default: "introspection",
        showClearButton: true,
        initialValue: "introspection",
        selectFirstChoice: false,
        value: "$form.tk_input_hybrid_remote_tracker_wlk_type$",
        el: $("#modal_input_hybrid_remote_tracker_wlk_type"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_tracker_wlk_type.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_hybrid_remote_tracker_wlk_type);
        if (
          newValue === "main" ||
          newValue === "orphan" ||
          newValue === "inactive_entities" ||
          newValue === "metadata"
        ) {
          $("#modal_input_hybrid_remote_root_constraint_wlk").prop(
            "disabled",
            true
          );
          $("#btn_modal_input_hybrid_remote_wlk_add_simulate").prop(
            "disabled",
            true
          );
          $("#btn_modal_input_hybrid_remote_wlk_add_new").prop(
            "disabled",
            false
          );
          notify(
            "info",
            "bottom",
            "The selected type of Workload tracker does not require search constraint and deployment target, nor it needs to be simulated, click on the Creation button when you are ready, note that there should only one tracker of this type for the current tenant.",
            "5"
          );
        } else {
          $("#modal_input_hybrid_remote_root_constraint_wlk").prop(
            "disabled",
            false
          );
          $("#btn_modal_input_hybrid_remote_wlk_add_simulate").prop(
            "disabled",
            false
          );
          $("#btn_modal_input_hybrid_remote_wlk_add_new").prop(
            "disabled",
            true
          );
        }
      }
    );

    // dhm

    var modal_input_hybrid_remote_dhm_cron = new TextInput(
      {
        id: "modal_input_hybrid_remote_dhm_cron",
        searchWhenChanged: false,
        default: "*/5 * * * *",
        initialValue: "*/5 * * * *",
        value: "$form.tk_input_hybrid_remote_tracker_dhm_cron$",
        el: $("#modal_input_hybrid_remote_dhm_cron"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dhm_cron.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dhm_cron);
    });

    var modal_input_hybrid_remote_dhm_earliest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dhm_earliest",
        searchWhenChanged: false,
        default: "-4h",
        initialValue: "-4h",
        value: "$form.tk_input_hybrid_remote_tracker_dhm_earliest$",
        el: $("#modal_input_hybrid_remote_dhm_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dhm_earliest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dhm_earliest);
    });

    var modal_input_hybrid_remote_dhm_latest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dhm_latest",
        searchWhenChanged: false,
        default: "+4h",
        initialValue: "+4h",
        value: "$form.tk_input_hybrid_remote_tracker_dhm_latest$",
        el: $("#modal_input_hybrid_remote_dhm_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dhm_latest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dhm_latest);
    });

    var modal_input_hybrid_remote_dhm_index_earliest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dhm_index_earliest",
        searchWhenChanged: false,
        default: "-4h",
        initialValue: "-4h",
        value: "$form.tk_input_hybrid_remote_tracker_dhm_index_earliest$",
        el: $("#modal_input_hybrid_remote_dhm_index_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dhm_index_earliest.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_dhm_index_earliest
        );
      }
    );

    var modal_input_hybrid_remote_dhm_index_latest = new TextInput(
      {
        id: "modal_input_hybrid_remote_dhm_index_latest",
        searchWhenChanged: false,
        default: "+4h",
        initialValue: "+4h",
        value: "$form.tk_input_hybrid_remote_tracker_dhm_index_latest$",
        el: $("#modal_input_hybrid_remote_dhm_index_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dhm_index_latest.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_hybrid_remote_dhm_index_latest);
      }
    );

    var modal_input_hybrid_remote_search_dhm_mode = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_search_dhm_mode",
        choices: [
          {
            label: "tstats",
            value: "tstats",
          },
          {
            label: "raw",
            value: "raw",
          },
        ],
        searchWhenChanged: false,
        default: "tstats",
        showClearButton: true,
        initialValue: "tstats",
        selectFirstChoice: false,
        value: "$form.tk_input_hybrid_remote_search_dhm_mode$",
        el: $("#modal_input_hybrid_remote_search_dhm_mode"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_search_dhm_mode.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_search_dhm_mode);
      if (newValue === "tstats") {
        $("#divParentHybridDhmBreakByAdditionals").show();
      } else if (newValue === "raw") {
        $("#divParentHybridDhmBreakByAdditionals").hide();
      }
    });

    var modal_input_hybrid_remote_search_dhm_tstats_root_span =
      new DropdownInput(
        {
          id: "modal_input_hybrid_remote_search_dhm_tstats_root_span",
          choices: [
            {
              label: "1s",
              value: "1s",
            },
            {
              label: "10s",
              value: "10s",
            },
            {
              label: "30s",
              value: "30s",
            },
            {
              label: "1m",
              value: "1m",
            },
            {
              label: "5m",
              value: "5m",
            },
            {
              label: "1ms",
              value: "1ms",
            },
          ],
          searchWhenChanged: false,
          default: "1s",
          showClearButton: true,
          initialValue: "1s",
          selectFirstChoice: false,
          value: "$form.tk_hybrid_dhm_tstats_root_span$",
          el: $("#modal_input_hybrid_remote_search_dhm_tstats_root_span"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_hybrid_remote_search_dhm_tstats_root_span.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_search_dhm_tstats_root_span
        );
      }
    );

    var modal_input_hybrid_remote_search_dhm_tstats_include_splunk_server =
      new DropdownInput(
        {
          id: "modal_input_hybrid_remote_search_dhm_tstats_include_splunk_server",
          choices: [
            {
              label: "True",
              value: "True",
            },
            {
              label: "False",
              value: "False",
            },
          ],
          searchWhenChanged: false,
          default: "False",
          showClearButton: true,
          initialValue: "False",
          selectFirstChoice: false,
          value: "$form.tk_hybrid_dhm_include_splunk_server$",
          el: $(
            "#modal_input_hybrid_remote_search_dhm_tstats_include_splunk_server"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_hybrid_remote_search_dhm_tstats_include_splunk_server.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_search_dhm_tstats_include_splunk_server
        );
      }
    );

    var modal_input_hybrid_remote_dhm_account = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_dhm_account",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "account",
        valueField: "account",
        managerid: "searchPopulateConfigurationAccountDhm",
        value: "$form.tk_input_hybrid_remote_dhm_account$",
        el: $("#modal_input_hybrid_remote_dhm_account"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dhm_account.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_dhm_account);
      // check the connectivity if the account is not local
      if (newValue != undefined) {
        if (newValue != "local") {
          checkSplkFeedsRemoteAccount("dhm", newValue);
        } else {
          $("#divParentCreateDhmHybridValidateRemoteConnectivity").css(
            "display",
            "none"
          );
        }
      }
    });

    var modal_input_hybrid_remote_tracker_dhm_name = new TextInput(
      {
        id: "modal_input_hybrid_remote_tracker_dhm_name",
        searchWhenChanged: false,
        value: "$form.tk_input_hybrid_remote_tracker_name_dhm$",
        el: $("#modal_input_hybrid_remote_tracker_dhm_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_tracker_dhm_name.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_hybrid_remote_tracker_dhm_name);
      }
    );

    var modal_input_hybrid_remote_dhm_break_by_field = new TextInput(
      {
        id: "modal_input_hybrid_remote_dhm_break_by_field",
        searchWhenChanged: false,
        default: "host",
        initialValue: "host",
        value: "$form.tk_input_hybrid_remote_dhm_break_by_field$",
        el: $("#modal_input_hybrid_remote_dhm_break_by_field"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_dhm_break_by_field.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_dhm_break_by_field
        );
      }
    );

    // mhm

    var modal_input_hybrid_remote_mhm_cron = new TextInput(
      {
        id: "modal_input_hybrid_remote_mhm_cron",
        searchWhenChanged: false,
        default: "*/5 * * * *",
        initialValue: "*/5 * * * *",
        value: "$form.tk_input_hybrid_remote_tracker_mhm_cron$",
        el: $("#modal_input_hybrid_remote_mhm_cron"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_mhm_cron.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_mhm_cron);
    });

    var modal_input_hybrid_remote_mhm_earliest = new TextInput(
      {
        id: "modal_input_hybrid_remote_mhm_earliest",
        searchWhenChanged: false,
        default: "-5m",
        initialValue: "-5m",
        value: "$form.tk_input_hybrid_remote_tracker_mhm_earliest$",
        el: $("#modal_input_hybrid_remote_mhm_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_mhm_earliest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_mhm_earliest);
    });

    var modal_input_hybrid_remote_mhm_latest = new TextInput(
      {
        id: "modal_input_hybrid_remote_mhm_latest",
        searchWhenChanged: false,
        default: "+5m",
        initialValue: "+5m",
        value: "$form.tk_input_hybrid_remote_tracker_mhm_latest$",
        el: $("#modal_input_hybrid_remote_mhm_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_mhm_latest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_mhm_latest);
    });

    var modal_input_hybrid_remote_mhm_account = new DropdownInput(
      {
        id: "modal_input_hybrid_remote_mhm_account",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "account",
        valueField: "account",
        managerid: "searchPopulateConfigurationAccountMhm",
        value: "$form.tk_input_hybrid_remote_mhm_account$",
        el: $("#modal_input_hybrid_remote_mhm_account"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_mhm_account.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_remote_mhm_account);
      // check the connectivity if the account is not local
      if (newValue != undefined) {
        if (newValue != "local") {
          checkSplkFeedsRemoteAccount("mhm", newValue);
        } else {
          $("#divParentCreateMhmHybridValidateRemoteConnectivity").css(
            "display",
            "none"
          );
        }
      }
    });

    var modal_input_hybrid_remote_tracker_mhm_name = new TextInput(
      {
        id: "modal_input_hybrid_remote_tracker_mhm_name",
        searchWhenChanged: false,
        value: "$form.tk_input_hybrid_remote_tracker_name_mhm$",
        el: $("#modal_input_hybrid_remote_tracker_mhm_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_tracker_mhm_name.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_hybrid_remote_tracker_mhm_name);
      }
    );

    var modal_input_hybrid_remote_mhm_break_by_field = new TextInput(
      {
        id: "modal_input_hybrid_remote_mhm_break_by_field",
        searchWhenChanged: false,
        default: "host",
        initialValue: "host",
        value: "$form.tk_input_hybrid_remote_mhm_break_by_field$",
        el: $("#modal_input_hybrid_remote_mhm_break_by_field"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_remote_mhm_break_by_field.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_hybrid_remote_mhm_break_by_field
        );
      }
    );

    //

    var chartAuditFlipCimOverTime = new ChartView(
      {
        id: "chartAuditFlipCimOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors":
          '{"orange": 0xffd394, "blue": 0xcfebf9, "green": 0xb6edb6, "red": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditCimFlipOverTime",
        el: $("#chartAuditFlipCimOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditFlipCimOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditFlipCimOverTime",
      managerid: "searchAuditCimFlipOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditFlipCimOverTime"),
    });

    // CIM Metrics
    var chartMetricsCimOverTime = new ChartView(
      {
        id: "chartMetricsCimOverTime",
        "charting.axisX.abbreviation": "none",
        "charting.legend.mode": "standard",
        "charting.chart.bubbleMaximumSize": "50",
        "charting.chart.sliceCollapsingThreshold": "0.01",
        "charting.axisTitleY.text": "$splk_cim_metrics_chart1_axisy_title$",
        "refresh.display": "progressbar",
        "charting.chart.nullValueMode": "gaps",
        "charting.axisTitleX.visibility": "collapsed",
        "charting.axisTitleY2.text": "$splk_cim_metrics_chart1_axis$",
        "charting.axisLabelsY2.majorUnit": "$splk_cim_metrics_chart1_axisUnit$",
        "charting.axisX.scale": "linear",
        "charting.drilldown": "none",
        "charting.axisLabelsX.majorLabelStyle.overflowMode": "ellipsisNone",
        "charting.chart.overlayFields":
          "lag_event_sec,lag_ingestion_sec,hostcount_4h",
        "charting.chart.showDataLabels": "none",
        "charting.axisTitleY2.visibility": "visible",
        "charting.axisY2.enabled": "1",
        "charting.axisY2.scale": "inherit",
        "trellis.scales.shared": "1",
        "charting.layout.splitSeries.allowIndependentYRanges": "0",
        "charting.chart.bubbleSizeBy": "area",
        "charting.chart.bubbleMinimumSize": "10",
        "charting.chart.style": "shiny",
        "charting.axisY.scale": "linear",
        "charting.layout.splitSeries": "0",
        resizable: true,
        "charting.legend.labelStyle.overflowMode": "ellipsisMiddle",
        "charting.lineWidth": "2",
        "charting.axisTitleY.visibility": "visible",
        "charting.chart.stackMode": "default",
        "charting.legend.placement": "right",
        "trellis.size": "medium",
        "charting.axisLabelsX.majorLabelStyle.rotation": "0",
        "charting.axisY2.abbreviation": "none",
        "charting.chart": "$splk_cim_metrics_chart$",
        "charting.axisY.abbreviation": "none",
        "trellis.enabled": "0",
        height: "350",
        managerid: "searchSplkCimMetricsOverTime",
        el: $("#chartMetricsCimOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartMetricsCimOverTime = new ResultsLinkView({
      id: "resultsLinkchartMetricsCimOverTime",
      managerid: "searchSplkCimMetricsOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartMetricsCimOverTime"),
    });

    resultsLinkchartMetricsCimOverTime
      .render()
      .$el.appendTo($("resultsLinkchartMetricsCimOverTime"));

    // Audit Flip Metric Host
    var elementMainTableAuditFlipCim = new TableView(
      {
        id: "elementMainTableAuditFlipCim",
        count: 5,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "false",
        managerid: "searchMainCimAuditFlipTable",
        el: $("#elementMainTableAuditFlipCim"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementMainTableAuditFlipCim);

    var resultsLinkelementMainTableAuditFlipCim = new ResultsLinkView({
      id: "resultsLinkelementMainTableAuditFlipCim",
      managerid: "searchMainCimAuditFlipTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementMainTableAuditFlipCim"),
    });

    resultsLinkelementMainTableAuditFlipCim
      .render()
      .$el.appendTo($("resultsLinkelementMainTableAuditFlipCim"));

    var chartAuditChangesCimOverTime = new ChartView(
      {
        id: "chartAuditChangesCimOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchAuditCimAuditChangesOverTime",
        el: $("#chartAuditChangesCimOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartAuditChangesCimOverTime = new ResultsLinkView({
      id: "resultsLinkchartAuditChangesCimOverTime",
      managerid: "searchAuditCimAuditChangesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartAuditChangesCimOverTime"),
    });

    resultsLinkchartAuditChangesCimOverTime
      .render()
      .$el.appendTo($("resultsLinkchartAuditChangesCimOverTime"));

    // Audit Changes splk-cim
    var eventAuditChangesCim = new EventsViewer(
      {
        id: "eventAuditChangesCim",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchMainCimAuditChangesTable",
        el: $("#eventAuditChangesCim"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventAuditChangesCim = new ResultsLinkView({
      id: "resultsLinkeventAuditChangesCim",
      managerid: "searchMainCimAuditChangesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventAuditChangesCim"),
    });

    resultsLinkeventAuditChangesCim
      .render()
      .$el.appendTo($("resultsLinkeventAuditChangesCim"));

    var inputCimFilter = new TextInput(
      {
        id: "inputCimFilter",
        searchWhenChanged: true,
        prefix: 'object="*',
        suffix: '*"',
        initialValue: "*",
        value: "$form.inputCimFilter$",
        el: $("#inputCimFilter"),
      },
      {
        tokens: true,
      }
    ).render();

    inputCimFilter.on("change", function (newValue) {
      FormUtils.handleValueChange(inputCimFilter);
    });

    var inputCim = new MultiSelectInput(
      {
        id: "inputCim",
        tokenDependencies: {
          depends: "$show_cim_tracker$",
        },
        choices: [
          {
            label: "ALL",
            value: "*",
          },
        ],
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "object",
        valuePrefix: 'object="',
        valueSuffix: '"',
        delimiter: " OR ",
        initialValue: "*",
        selectFirstChoice: false,
        valueField: "object",
        value: "$form.inputCim$",
        managerid: "searchPopulateCim",
        el: $("#inputCim"),
      },
      {
        tokens: true,
      }
    ).render();

    inputCim.on("change", function (newValue) {
      FormUtils.handleValueChange(inputCim);
      multiselectAll(inputCim);
    });

    var inputCimCloneSelector = new DropdownInput(
      {
        id: "inputCimCloneSelector",
        tokenDependencies: {
          depends: "$show_configuration_account_cim_tracker$",
        },
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "object",
        selectFirstChoice: false,
        valueField: "object",
        value: "$form.inputCimCloneSelector$",
        managerid: "searchSplkCimPopulateClone",
        el: $("#inputCimCloneSelector"),
      },
      {
        tokens: true,
      }
    ).render();

    inputCimCloneSelector.on("change", function (newValue) {
      FormUtils.handleValueChange(inputCimCloneSelector);
    });

    var inputCimState = new MultiSelectInput(
      {
        id: "inputCimState",
        choices: [
          {
            label: "ALL",
            value: "*",
          },
          {
            label: "Green",
            value: "green",
          },
          {
            label: "Orange",
            value: "orange",
          },
          {
            label: "Red",
            value: "red",
          },
        ],
        valuePrefix: 'status="',
        valueSuffix: '"',
        delimiter: " OR ",
        searchWhenChanged: true,
        initialValue: ["*"],
        value: "$form.object_state$",
        el: $("#inputCimState"),
      },
      {
        tokens: true,
      }
    ).render();

    inputCimState.on("change", function (newValue) {
      FormUtils.handleValueChange(inputCimState);
      multiselectAll(inputCimState);
    });

    var inputCimMonitoredState = new DropdownInput(
      {
        id: "inputCimMonitoredState",
        choices: [
          {
            label: "ALL",
            value: "*",
          },
          {
            label: "Enabled",
            value: "enabled",
          },
          {
            label: "Disabled",
            value: "disabled",
          },
        ],
        searchWhenChanged: true,
        default: "enabled",
        showClearButton: true,
        prefix: 'monitored_state="',
        suffix: '"',
        initialValue: "enabled",
        selectFirstChoice: false,
        value: "$form.monitored_state$",
        el: $("#inputCimMonitoredState"),
      },
      {
        tokens: true,
      }
    ).render();

    inputCimMonitoredState.on("change", function (newValue) {
      FormUtils.handleValueChange(inputCimMonitoredState);
    });

    var inputCimPriority = new MultiSelectInput(
      {
        id: "inputCimPriority",
        choices: [
          {
            label: "ALL",
            value: "*",
          },
          {
            label: "low",
            value: "low",
          },
          {
            label: "medium",
            value: "medium",
          },
          {
            label: "high",
            value: "high",
          },
        ],
        valuePrefix: 'priority="',
        valueSuffix: '"',
        delimiter: " OR ",
        searchWhenChanged: true,
        initialValue: ["*"],
        value: "$form.inputCimPriority$",
        el: $("#inputCimPriority"),
      },
      {
        tokens: true,
      }
    ).render();

    inputCimPriority.on("change", function (newValue) {
      FormUtils.handleValueChange(inputCimPriority);
      multiselectAll(inputCimPriority);
    });

    var refreshCimForm = new DropdownInput(
      {
        id: "refreshCimForm",
        choices: [
          {
            value: "60",
            label: "1 min",
          },
          {
            value: "120",
            label: "2 min",
          },
          {
            value: "300",
            label: "5 min",
          },
          {
            value: "none",
            label: "none",
          },
        ],
        selectFirstChoice: false,
        default: "300",
        showClearButton: true,
        initialValue: "300",
        searchWhenChanged: true,
        value: "$refresh$",
        el: $("#refreshCimForm"),
      },
      {
        tokens: true,
      }
    ).render();

    refreshCimForm.on("change", function (newValue) {
      FormUtils.handleValueChange(refreshCimForm);
    });

    var elementTableMSplkCim = new TableView(
      {
        id: "elementTableMSplkCim",
        count: 5,
        drilldown: "none",
        fields: "object_state, cim_tracking_results, cim_tracking_rules",
        "refresh.display": "none",
        wrap: "true",
        managerid: "searchHostTableMSplkCim",
        el: $("#elementTableMSplkCim"),
      },
      {
        tokens: true,
      }
    ).render();

    renderTableIcon(elementTableMSplkCim);

    var resultsLinkelementTableMSplkCim = new ResultsLinkView({
      id: "resultsLinkelementTableMSplkCim",
      managerid: "searchHostTableMSplkCim",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementTableMSplkCim"),
    });

    resultsLinkelementTableMSplkCim
      .render()
      .$el.appendTo($("resultsLinkelementTableMSplkCim"));

    var TimelineCim = new TimeLine(
      {
        id: "TimelineCim",
        type: "timeline_app.timeline",
        resizable: false,
        drilldown: "none",
        "timeline_app.timeline.axisTimeFormat": "DAYS",
        "timeline_app.timeline.colorMode": "categorical",
        "timeline_app.timeline.maxColor": "#DA5C5C",
        "timeline_app.timeline.minColor": "#FFE8E8",
        "timeline_app.timeline.numOfBins": "6",
        "timeline_app.timeline.tooltipTimeFormat": "DAYS",
        "timeline_app.timeline.useColors": "1",
        height: "150",
        managerid: "searchSplkCimTimeline",
        el: $("#TimelineCim"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkTimelineCim = new ResultsLinkView({
      id: "resultsLinkTimelineCim",
      managerid: "searchSplkCimTimeline",
      "link.exportResults.visible": false,
      el: $("#resultsLinkTimelineCim"),
    });

    resultsLinkTimelineCim.render().$el.appendTo($("resultsLinkTimelineCim"));

    var modal_input_cim_tracker_search = new TextInput(
      {
        id: "modal_input_cim_tracker_search",
        default: "*",
        searchWhenChanged: true,
        value: "$form.tk_input_cim_tracker_search$",
        el: $("#modal_input_cim_tracker_search"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_search.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_search);
    });

    var modal_input_object_name = new TextInput(
      {
        id: "modal_input_object_name",
        searchWhenChanged: false,
        value: "$form.input_object_name$",
        el: $("#modal_input_object_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_object_name.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_object_name);
      if (newValue && newValue.length) {
        setToken(
          "input_object_name_formated",
          newValue.toLowerCase().replace(/\s+/g, "_").replace(/\-/g, "_")
        );
        checkSplkCimExists(newValue);
      }
    });

    var modal_input_cim_tracker_account = new DropdownInput(
      {
        id: "modal_input_cim_tracker_account",
        searchWhenChanged: false,
        showClearButton: true,
        selectFirstChoice: true,
        labelField: "account",
        valueField: "account",
        managerid: "searchPopulateConfigurationAccountSplkCim",
        value: "$form.input_cim_tracker_account$",
        el: $("#modal_input_cim_tracker_account"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_account.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_account);
      // check the connectivity if the account is not local
      if (newValue != undefined) {
        if (newValue != "local") {
          checkCimRemoteAccount(newValue);
        } else {
          $("#divParentCreateCimValidateRemoteConnectivity").css(
            "display",
            "none"
          );
        }
      }
    });

    var modal_input_cim_tracker_datamodel_name = new TextInput(
      {
        id: "modal_input_cim_tracker_datamodel_name",
        searchWhenChanged: false,
        value: "$form.input_cim_tracker_datamodel_name$",
        el: $("#modal_input_cim_tracker_datamodel_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_datamodel_name.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_datamodel_name);
      // search preview
      previewCimSplunkSearch();
    });

    var modal_input_cim_tracker_datamodel_nodename = new TextInput(
      {
        id: "modal_input_cim_tracker_datamodel_nodename",
        searchWhenChanged: false,
        value: "$form.input_cim_tracker_datamodel_nodename$",
        el: $("#modal_input_cim_tracker_datamodel_nodename"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_datamodel_nodename.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(modal_input_cim_tracker_datamodel_nodename);
        // preset the value for
        var tk_input_cim_tracker_datamodel_nodename = getToken(
          "input_cim_tracker_datamodel_nodename"
        );
        // only if value is set
        if (
          tk_input_cim_tracker_datamodel_nodename != null &&
          tk_input_cim_tracker_datamodel_nodename != "null"
        ) {
          setToken(
            "form.input_cim_tracker_add_field_drop_dm_object_name",
            tk_input_cim_tracker_datamodel_nodename
          );
          setToken(
            "form.input_cim_tracker_breakby_prefix",
            tk_input_cim_tracker_datamodel_nodename
          );
          // search preview
          previewCimSplunkSearch();
        }
      }
    );

    var modal_input_cim_tracker_add_field_name = new TextInput(
      {
        id: "modal_input_cim_tracker_add_field_name",
        searchWhenChanged: false,
        value: "$form.input_cim_tracker_add_field_name$",
        el: $("#modal_input_cim_tracker_add_field_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_add_field_name.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_add_field_name);
      // pre-set the datamodel field version
      var tk_input_cim_tracker_datamodel_nodename = getToken(
        "input_cim_tracker_datamodel_nodename"
      );
      // pre-set the regex validation expression
      presetCimRegex();

      if (
        tk_input_cim_tracker_datamodel_nodename != null &&
        tk_input_cim_tracker_datamodel_nodename != "null"
      ) {
        setToken(
          "form.input_cim_tracker_add_field_datamodel_fieldname",
          tk_input_cim_tracker_datamodel_nodename + "." + newValue
        );
      }
    });

    var modal_input_cim_tracker_add_field_drop_dm_object_name = new TextInput(
      {
        id: "modal_input_cim_tracker_add_field_drop_dm_object_name",
        searchWhenChanged: false,
        value: "$form.input_cim_tracker_add_field_drop_dm_object_name$",
        el: $("#modal_input_cim_tracker_add_field_drop_dm_object_name"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_add_field_drop_dm_object_name.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_cim_tracker_add_field_drop_dm_object_name
        );
        // search preview
        previewCimSplunkSearch();
      }
    );

    var modal_input_cim_tracker_add_field_datamodel_fieldname = new TextInput(
      {
        id: "modal_input_cim_tracker_add_field_datamodel_fieldname",
        searchWhenChanged: false,
        value: "$form.input_cim_tracker_add_field_datamodel_fieldname$",
        el: $("#modal_input_cim_tracker_add_field_datamodel_fieldname"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_add_field_datamodel_fieldname.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_cim_tracker_add_field_datamodel_fieldname
        );
      }
    );

    var modal_input_cim_tracker_summariesonly = new DropdownInput(
      {
        id: "modal_input_cim_tracker_summariesonly",
        choices: [
          {
            label: "True",
            value: "True",
          },
          {
            label: "False",
            value: "False",
          },
        ],
        searchWhenChanged: true,
        default: "True",
        showClearButton: true,
        initialValue: "True",
        selectFirstChoice: false,
        value: "$form.input_cim_tracker_summariesonly$",
        el: $("#modal_input_cim_tracker_summariesonly"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_summariesonly.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_summariesonly);
    });

    var modal_input_cim_tracker_breakby_prefix = new TextInput(
      {
        id: "modal_input_cim_tracker_breakby_prefix",
        searchWhenChanged: false,
        value: "$form.input_cim_tracker_breakby_prefix$",
        el: $("#modal_input_cim_tracker_breakby_prefix"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_breakby_prefix.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_breakby_prefix);
    });

    var modal_input_cim_tracker_breakby = new TextInput(
      {
        id: "modal_input_cim_tracker_breakby",
        searchWhenChanged: false,
        initialValue: "none",
        value: "$form.input_cim_tracker_breakby$",
        el: $("#modal_input_cim_tracker_breakby"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_breakby.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_breakby);
    });

    var modal_input_cim_tracker_add_field_max_unknown_pct = new TextInput(
      {
        id: "modal_input_cim_tracker_add_field_max_unknown_pct",
        searchWhenChanged: false,
        default: "5",
        initialValue: "5",
        value: "$form.input_cim_tracker_add_field_max_unknown_pct$",
        el: $("#modal_input_cim_tracker_add_field_max_unknown_pct"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_add_field_max_unknown_pct.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_cim_tracker_add_field_max_unknown_pct
        );
      }
    );

    var modal_input_cim_tracker_add_field_regex = new TextInput(
      {
        id: "modal_input_cim_tracker_add_field_regex",
        searchWhenChanged: false,
        default: ".*",
        initialValue: ".*",
        value: "$form.input_cim_tracker_add_field_regex$",
        el: $("#modal_input_cim_tracker_add_field_regex"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_add_field_regex.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_add_field_regex);
    });

    var modal_input_cim_tracker_add_field_min_compliant_pct = new TextInput(
      {
        id: "modal_input_cim_tracker_add_field_min_compliant_pct",
        searchWhenChanged: false,
        default: "95",
        initialValue: "95",
        value: "$form.input_cim_tracker_add_field_min_compliant_pct$",
        el: $("#modal_input_cim_tracker_add_field_min_compliant_pct"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_add_field_min_compliant_pct.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_cim_tracker_add_field_min_compliant_pct
        );
      }
    );

    // hybrid remote tracker simulation

    // earliest and latest quantifiers
    var modal_input_cim_tracker_simulate_earliest = new TextInput(
      {
        id: "modal_input_cim_tracker_simulate_earliest",
        searchWhenChanged: false,
        default: "-65m",
        initialValue: "-65m",
        value: "$form.input_cim_tracker_simulation_earliest$",
        el: $("#modal_input_cim_tracker_simulate_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_simulate_earliest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_simulate_earliest);
    });

    var modal_input_cim_tracker_simulate_latest = new TextInput(
      {
        id: "modal_input_cim_tracker_simulate_latest",
        searchWhenChanged: false,
        default: "-5m",
        initialValue: "-5m",
        value: "$form.input_cim_tracker_simulation_latest$",
        el: $("#modal_input_cim_tracker_simulate_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_simulate_latest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_simulate_latest);
    });

    var tableCreateCimJsonSimulationExec = new TableView(
      {
        id: "tableCreateCimJsonSimulationExec",
        tokenDependencies: {
          depends: "$start_create_cim_json_simulation_exec$",
        },
        count: 1,
        drilldown: "none",
        "refresh.display": "none",
        wrap: "true",
        managerid: "searchCreateCimJsonSimulationExec",
        el: $("#tableCreateCimJsonSimulationExec"),
      },
      {
        tokens: true,
      }
    ).render();

    // render icons
    renderTableIcon(tableCreateCimJsonSimulationExec);

    var resultsLinktableCreateCimJsonSimulationExec = new ResultsLinkView({
      id: "resultsLinktableCreateCimJsonSimulationExec",
      managerid: "searchCreateCimJsonSimulationExec",
      "link.exportResults.visible": false,
      el: $("#resultsLinktableCreateCimJsonSimulationExec"),
    });

    resultsLinktableCreateCimJsonSimulationExec
      .render()
      .$el.appendTo($("resultsLinktableCreateCimJsonSimulationExec"));

    // earliest and latest for promote live

    // earliest and latest quantifiers
    var modal_input_cim_tracker_promote_earliest = new TextInput(
      {
        id: "modal_input_cim_tracker_promote_earliest",
        searchWhenChanged: false,
        default: "-65m",
        initialValue: "-65m",
        value: "$form.input_cim_tracker_promote_earliest$",
        el: $("#modal_input_cim_tracker_promote_earliest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_promote_earliest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_promote_earliest);
    });

    var modal_input_cim_tracker_promote_latest = new TextInput(
      {
        id: "modal_input_cim_tracker_promote_latest",
        searchWhenChanged: false,
        default: "-5m",
        initialValue: "-5m",
        value: "$form.input_cim_tracker_promote_latest$",
        el: $("#modal_input_cim_tracker_promote_latest"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_promote_latest.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_promote_latest);
    });

    var modal_input_cim_tracker_promote_cron = new TextInput(
      {
        id: "modal_input_cim_tracker_promote_cron",
        searchWhenChanged: false,
        default: "*/60 * * * *",
        initialValue: "*/60 * * * *",
        value: "$form.input_cim_tracker_promote_cron$",
        el: $("#modal_input_cim_tracker_promote_cron"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_cim_tracker_promote_cron.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_cim_tracker_promote_cron);
    });

    var elementSingleSplkCimFieldsGreen = new SingleView(
      {
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "all",
        height: "95",
        "trellis.size": "medium",
        colorBy: "value",
        colorMode: "none",
        rangeColors: '["0xdc4e41","0x45D4BA"]',
        rangeValues: "[0]",
        useColors: "1",
        trendColorInterpretation: "standard",
        unitPosition: "after",
        useThousandSeparators: "1",
        underLabel: "NUMBER OF CIM FIELDS GREEN",
        managerid: "searchSingleSplkCimFieldsGreen",
        el: $("#elementSingleSplkCimFieldsGreen"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleSplkCimFieldsGreen = new ResultsLinkView({
      id: "resultsLinkelementSingleSplkCimFieldsGreen",
      managerid: "searchSingleSplkCimFieldsGreen",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSplkCimFieldsGreen"),
    });

    resultsLinkelementSingleSplkCimFieldsGreen
      .render()
      .$el.appendTo($("resultsLinkelementSingleSplkCimFieldsGreen"));

    var elementSingleSplkCimFieldsRed = new SingleView(
      {
        id: "elementSingleSplkCimFieldsRed",
        trendDisplayMode: "absolute",
        numberPrecision: "0",
        drilldown: "all",
        height: "95",
        "trellis.size": "medium",
        colorBy: "value",
        colorMode: "none",
        rangeColors: '["0x45D4BA","0xdc4e41"]',
        rangeValues: "[0]",
        useColors: "1",
        trendColorInterpretation: "standard",
        unitPosition: "after",
        useThousandSeparators: "1",
        underLabel: "NUMBER OF CIM FIELDS RED",
        managerid: "searchSingleSplkCimFieldsRed",
        el: $("#elementSingleSplkCimFieldsRed"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementSingleSplkCimFieldsRed = new ResultsLinkView({
      id: "resultsLinkelementSingleSplkCimFieldsRed",
      managerid: "searchSingleSplkCimFieldsRed",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementSingleSplkCimFieldsRed"),
    });

    resultsLinkelementSingleSplkCimFieldsRed
      .render()
      .$el.appendTo($("resultsLinkelementSingleSplkCimFieldsRed"));

    //
    // Hybrid tracker manual run
    //

    // dsm

    var searchPopulateHybridTrackerDsm = new SearchManager(
      {
        id: "searchPopulateHybridTrackerDsm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: false,
        search:
          '| inputlookup trackme_virtual_tenants where tenant_id="$tenant_id$" | table tenant_dsm_hybrid_objects | spath input=tenant_dsm_hybrid_objects | rename "reports{}" as reports | fields reports | mvexpand reports | where match(reports, "_tracker_tenant_")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_search_input_hybrid_tracker_dsm_dropdown$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // dhm

    var searchPopulateHybridTrackerDhm = new SearchManager(
      {
        id: "searchPopulateHybridTrackerDhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: false,
        search:
          '| inputlookup trackme_virtual_tenants where tenant_id="$tenant_id$" | table tenant_dhm_hybrid_objects | spath input=tenant_dhm_hybrid_objects | rename "reports{}" as reports | fields reports | mvexpand reports | where match(reports, "_tracker_tenant_")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_search_input_hybrid_tracker_dhm_dropdown$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // mhm

    var searchPopulateHybridTrackerMhm = new SearchManager(
      {
        id: "searchPopulateHybridTrackerMhm",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: false,
        search:
          '| inputlookup trackme_virtual_tenants where tenant_id="$tenant_id$" | table tenant_mhm_hybrid_objects | spath input=tenant_mhm_hybrid_objects | rename "reports{}" as reports | fields reports | mvexpand reports | where match(reports, "_tracker_tenant_")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_search_input_hybrid_tracker_mhm_dropdown$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // flx

    var searchPopulateHybridTrackerFlx = new SearchManager(
      {
        id: "searchPopulateHybridTrackerFlx",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: false,
        search:
          '| inputlookup trackme_virtual_tenants where tenant_id="$tenant_id$" | table tenant_flx_hybrid_objects | spath input=tenant_flx_hybrid_objects | rename "reports{}" as reports | fields reports | mvexpand reports | where match(reports, "_tracker_tenant_")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_search_input_hybrid_tracker_flx_dropdown$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // wlk

    var searchPopulateHybridTrackerWlk = new SearchManager(
      {
        id: "searchPopulateHybridTrackerWlk",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: false,
        search:
          '| inputlookup trackme_virtual_tenants where tenant_id="$tenant_id$" | table tenant_wlk_hybrid_objects | spath input=tenant_wlk_hybrid_objects | rename "reports{}" as reports | fields reports | mvexpand reports | where match(reports, "_tracker_tenant_")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_search_input_hybrid_tracker_wlk_dropdown$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    //
    // hybrid tracker dropdown
    //

    // dsm

    var modal_input_hybrid_tracker_dsm_dropdown = new DropdownInput(
      {
        id: "modal_input_hybrid_tracker_dsm_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "reports",
        selectFirstChoice: true,
        width: 600,
        valueField: "reports",
        value: "$form.tk_input_hybrid_tracker_dsm_dropdown$",
        managerid: "searchPopulateHybridTrackerDsm",
        el: $("#modal_input_hybrid_tracker_dsm_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_tracker_dsm_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_tracker_dsm_dropdown);
    });

    // dhm

    var modal_input_hybrid_tracker_dhm_dropdown = new DropdownInput(
      {
        id: "modal_input_hybrid_tracker_dhm_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "reports",
        selectFirstChoice: true,
        width: 600,
        valueField: "reports",
        value: "$form.tk_input_hybrid_tracker_dhm_dropdown$",
        managerid: "searchPopulateHybridTrackerDhm",
        el: $("#modal_input_hybrid_tracker_dhm_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_tracker_dhm_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_tracker_dhm_dropdown);
    });

    // mhm

    var modal_input_hybrid_tracker_mhm_dropdown = new DropdownInput(
      {
        id: "modal_input_hybrid_tracker_mhm_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "reports",
        selectFirstChoice: true,
        width: 600,
        valueField: "reports",
        value: "$form.tk_input_hybrid_tracker_mhm_dropdown$",
        managerid: "searchPopulateHybridTrackerMhm",
        el: $("#modal_input_hybrid_tracker_mhm_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_tracker_mhm_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_tracker_mhm_dropdown);
    });

    // flx

    var modal_input_hybrid_tracker_flx_dropdown = new DropdownInput(
      {
        id: "modal_input_hybrid_tracker_flx_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "reports",
        selectFirstChoice: true,
        width: 600,
        valueField: "reports",
        value: "$form.tk_input_hybrid_tracker_flx_dropdown$",
        managerid: "searchPopulateHybridTrackerFlx",
        el: $("#modal_input_hybrid_tracker_flx_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_tracker_flx_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_tracker_flx_dropdown);
    });

    // wlk

    var modal_input_hybrid_tracker_wlk_dropdown = new DropdownInput(
      {
        id: "modal_input_hybrid_tracker_wlk_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "reports",
        selectFirstChoice: true,
        width: 600,
        valueField: "reports",
        value: "$form.tk_input_hybrid_tracker_wlk_dropdown$",
        managerid: "searchPopulateHybridTrackerWlk",
        el: $("#modal_input_hybrid_tracker_wlk_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_hybrid_tracker_wlk_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_hybrid_tracker_wlk_dropdown);
    });

    // elastic tracker dropdown
    var searchPopulateElasticTracker = new SearchManager(
      {
        id: "searchPopulateElasticTracker",
        earliest_time: "-5m",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "now",
        autostart: false,
        search:
          "| inputlookup trackme_dsm_elastic_dedicated_tenant_$tenant_id$ | fields elastic_report | rename elastic_report as reports",
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$start_search_input_elastic_tracker_dropdown$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // elastic tracker dropdown
    var modal_input_elastic_tracker_dropdown = new DropdownInput(
      {
        id: "modal_input_elastic_tracker_dropdown",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "reports",
        selectFirstChoice: true,
        width: 600,
        valueField: "reports",
        value: "$form.tk_input_elastic_tracker_dropdown$",
        managerid: "searchPopulateElasticTracker",
        el: $("#modal_input_elastic_tracker_dropdown"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_elastic_tracker_dropdown.on("change", function (newValue) {
      FormUtils.handleValueChange(modal_input_elastic_tracker_dropdown);
    });

    //
    // CIM metrics fields dropdown populate
    //

    var searchPopulateMetricsCimEntities = new SearchManager(
      {
        id: "searchPopulateMetricsCimEntities",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        autostart: true,
        search:
          '| mcatalog values(metric_name) as metrics where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" object_category="splk-cim" object="$tk_object$" by $tk_cim_breakby$ | stats count by $tk_cim_breakby$ | rename $tk_cim_breakby$ as label | sort 0 label',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_metrics$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    var searchPopulateMetricsCimFields = new SearchManager(
      {
        id: "searchPopulateMetricsCimFields",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        autostart: true,
        search:
          '| mcatalog values(metric_name) as metrics where `trackme_metrics_idx($tenant_id$)` tenant_id="$tenant_id$" $tk_cim_breakby$="$tk_input_splk_cim_metrics_entities$" object_category="splk-cim" object="$tk_object$" by cim_field | stats count by cim_field | sort 0 cim_field',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_metrics$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    //
    // notables
    //

    //
    // splk-dsm
    //

    // searches

    var searchSplkDsmNotables = new SearchManager(
      {
        id: "searchSplkDsmNotables",
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTime.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-dsm")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // set the panel visibility
    searchSplkDsmNotables.on("search:start", function (properties) {
      $("#SplkDsmNotablesLoader").css("display", "inherit");
      $("#divSplkDsmNotablesNotFound").css("display", "none");
      $("#divSplkDsmNotablesChart").css("display", "none");
      $("#divSplkDsmNotablesTable").css("display", "none");
    });

    searchSplkDsmNotables.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkDsmNotablesLoader").css("display", "none");
        $("#divSplkDsmNotablesNotFound").css("display", "inherit");
        $("#divSplkDsmNotablesChart").css("display", "none");
        $("#divSplkDsmNotablesTable").css("display", "none");
        // reduce the size
        $("#splk_dsm_notables")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkDsmNotablesLoader").css("display", "none");
        $("#divSplkDsmNotablesNotFound").css("display", "none");
        $("#divSplkDsmNotablesChart").css("display", "inherit");
        $("#divSplkDsmNotablesTable").css("display", "inherit");
        // increase the size
        $("#splk_dsm_notables")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchSplkDsmNotablesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkDsmNotables",
        id: "searchSplkDsmNotablesTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkDsmNotablesOverTime = new SearchManager(
      {
        id: "searchSplkDsmNotablesOverTime",
        earliest_time: "$modalTime.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTime.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-dsm") | timechart limit=40 useother=t minspan=5m bins=1000 count by object',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dsm_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // chart

    var chartNotablesSplkDsmOverTime = new ChartView(
      {
        id: "chartNotablesSplkDsmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchSplkDsmNotablesOverTime",
        el: $("#chartNotablesSplkDsmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartNotablesSplkDsmOverTime = new ResultsLinkView({
      id: "resultsLinkchartNotablesSplkDsmOverTime",
      managerid: "searchSplkDsmNotablesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartNotablesSplkDsmOverTime"),
    });

    resultsLinkchartNotablesSplkDsmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartNotablesSplkDsmOverTime"));

    // event

    // Notables splk-dsm
    var eventNotablesSplkDsm = new EventsViewer(
      {
        id: "eventNotablesSplkDsm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSplkDsmNotablesTable",
        el: $("#eventNotablesSplkDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventNotablesSplkDsm = new ResultsLinkView({
      id: "resultsLinkeventNotablesSplkDsm",
      managerid: "searchMainSplkDsmNotablesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventNotablesSplkDsm"),
    });

    resultsLinkeventNotablesSplkDsm
      .render()
      .$el.appendTo($("resultsLinkeventNotablesSplkDsm"));

    //
    // splk-dhm
    //

    // searches

    var searchSplkDhmNotables = new SearchManager(
      {
        id: "searchSplkDhmNotables",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeHost.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-dhm")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // set the panel visibility
    searchSplkDhmNotables.on("search:start", function (properties) {
      $("#SplkDhmNotablesLoader").css("display", "inherit");
      $("#divSplkDhmNotablesNotFound").css("display", "none");
      $("#divSplkDhmNotablesChart").css("display", "none");
      $("#divSplkDhmNotablesTable").css("display", "none");
    });

    searchSplkDhmNotables.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkDhmNotablesLoader").css("display", "none");
        $("#divSplkDhmNotablesNotFound").css("display", "inherit");
        $("#divSplkDhmNotablesChart").css("display", "none");
        $("#divSplkDhmNotablesTable").css("display", "none");
        // reduce the size
        $("#splk_dhm_notables")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkDhmNotablesLoader").css("display", "none");
        $("#divSplkDhmNotablesNotFound").css("display", "none");
        $("#divSplkDhmNotablesChart").css("display", "inherit");
        $("#divSplkDhmNotablesTable").css("display", "inherit");
        // increase the size
        $("#splk_dhm_notables")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchSplkDhmNotablesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkDhmNotables",
        id: "searchSplkDhmNotablesTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkDhmNotablesOverTime = new SearchManager(
      {
        id: "searchSplkDhmNotablesOverTime",
        earliest_time: "$modalTimeHost.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeHost.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-dhm") | timechart limit=40 useother=t minspan=5m bins=1000 count by object',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_dhm_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // chart

    var chartNotablesSplkDhmOverTime = new ChartView(
      {
        id: "chartNotablesSplkDhmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchSplkDhmNotablesOverTime",
        el: $("#chartNotablesSplkDhmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartNotablesSplkDhmOverTime = new ResultsLinkView({
      id: "resultsLinkchartNotablesSplkDhmOverTime",
      managerid: "searchSplkDhmNotablesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartNotablesSplkDhmOverTime"),
    });

    resultsLinkchartNotablesSplkDhmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartNotablesSplkDhmOverTime"));

    // event

    // Notables splk-dhm
    var eventNotablesSplkDhm = new EventsViewer(
      {
        id: "eventNotablesSplkDhm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSplkDhmNotablesTable",
        el: $("#eventNotablesSplkDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventNotablesSplkDhm = new ResultsLinkView({
      id: "resultsLinkeventNotablesSplkDhm",
      managerid: "searchMainSplkDhmNotablesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventNotablesSplkDhm"),
    });

    resultsLinkeventNotablesSplkDhm
      .render()
      .$el.appendTo($("resultsLinkeventNotablesSplkDhm"));

    //
    // splk-mhm
    //

    // searches

    var searchSplkMhmNotables = new SearchManager(
      {
        id: "searchSplkMhmNotables",
        earliest_time: "$modalTimeSplkMhm.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkMhm.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-mhm")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // set the panel visibility
    searchSplkMhmNotables.on("search:start", function (properties) {
      $("#SplkMhmNotablesLoader").css("display", "inherit");
      $("#divSplkMhmNotablesNotFound").css("display", "none");
      $("#divSplkMhmNotablesChart").css("display", "none");
      $("#divSplkMhmNotablesTable").css("display", "none");
    });

    searchSplkMhmNotables.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkMhmNotablesLoader").css("display", "none");
        $("#divSplkMhmNotablesNotFound").css("display", "inherit");
        $("#divSplkMhmNotablesChart").css("display", "none");
        $("#divSplkMhmNotablesTable").css("display", "none");
        // reduce the size
        $("#splk_mhm_notables")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkMhmNotablesLoader").css("display", "none");
        $("#divSplkMhmNotablesNotFound").css("display", "none");
        $("#divSplkMhmNotablesChart").css("display", "inherit");
        $("#divSplkMhmNotablesTable").css("display", "inherit");
        // increase the size
        $("#splk_mhm_notables")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchSplkMhmNotablesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkMhmNotables",
        id: "searchSplkMhmNotablesTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkMhmNotablesOverTime = new SearchManager(
      {
        id: "searchSplkMhmNotablesOverTime",
        earliest_time: "$modalTimeSplkMhm.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkMhm.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-mhm") | timechart limit=40 useother=t minspan=5m bins=1000 count by object',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_mhm_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // chart

    var chartNotablesSplkMhmOverTime = new ChartView(
      {
        id: "chartNotablesSplkMhmOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchSplkMhmNotablesOverTime",
        el: $("#chartNotablesSplkMhmOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartNotablesSplkMhmOverTime = new ResultsLinkView({
      id: "resultsLinkchartNotablesSplkMhmOverTime",
      managerid: "searchSplkMhmNotablesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartNotablesSplkMhmOverTime"),
    });

    resultsLinkchartNotablesSplkMhmOverTime
      .render()
      .$el.appendTo($("resultsLinkchartNotablesSplkMhmOverTime"));

    // event

    // Notables splk-mhm
    var eventNotablesSplkMhm = new EventsViewer(
      {
        id: "eventNotablesSplkMhm",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSplkMhmNotablesTable",
        el: $("#eventNotablesSplkMhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventNotablesSplkMhm = new ResultsLinkView({
      id: "resultsLinkeventNotablesSplkMhm",
      managerid: "searchMainSplkMhmNotablesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventNotablesSplkMhm"),
    });

    resultsLinkeventNotablesSplkMhm
      .render()
      .$el.appendTo($("resultsLinkeventNotablesSplkMhm"));

    //
    // splk-flx
    //

    // searches

    var searchSplkFlxNotables = new SearchManager(
      {
        id: "searchSplkFlxNotables",
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkFlx.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-flx")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // set the panel visibility
    searchSplkFlxNotables.on("search:start", function (properties) {
      $("#SplkFlxNotablesLoader").css("display", "inherit");
      $("#divSplkFlxNotablesNotFound").css("display", "none");
      $("#divSplkFlxNotablesChart").css("display", "none");
      $("#divSplkFlxNotablesTable").css("display", "none");
    });

    searchSplkFlxNotables.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkFlxNotablesLoader").css("display", "none");
        $("#divSplkFlxNotablesNotFound").css("display", "inherit");
        $("#divSplkFlxNotablesChart").css("display", "none");
        $("#divSplkFlxNotablesTable").css("display", "none");
        // reduce the size
        $("#splk_flx_notables")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkFlxNotablesLoader").css("display", "none");
        $("#divSplkFlxNotablesNotFound").css("display", "none");
        $("#divSplkFlxNotablesChart").css("display", "inherit");
        $("#divSplkFlxNotablesTable").css("display", "inherit");
        // increase the size
        $("#splk_flx_notables")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchSplkFlxNotablesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkFlxNotables",
        id: "searchSplkFlxNotablesTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkFlxNotablesOverTime = new SearchManager(
      {
        id: "searchSplkFlxNotablesOverTime",
        earliest_time: "$modalTimeSplkFlx.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkFlx.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-flx") | timechart limit=40 useother=t minspan=5m bins=1000 count by object',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_flx_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // chart

    var chartNotablesSplkFlxOverTime = new ChartView(
      {
        id: "chartNotablesSplkFlxOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchSplkFlxNotablesOverTime",
        el: $("#chartNotablesSplkFlxOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartNotablesSplkFlxOverTime = new ResultsLinkView({
      id: "resultsLinkchartNotablesSplkFlxOverTime",
      managerid: "searchSplkFlxNotablesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartNotablesSplkFlxOverTime"),
    });

    resultsLinkchartNotablesSplkFlxOverTime
      .render()
      .$el.appendTo($("resultsLinkchartNotablesSplkFlxOverTime"));

    // event

    // Notables splk-flx
    var eventNotablesSplkFlx = new EventsViewer(
      {
        id: "eventNotablesSplkFlx",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSplkFlxNotablesTable",
        el: $("#eventNotablesSplkFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventNotablesSplkFlx = new ResultsLinkView({
      id: "resultsLinkeventNotablesSplkFlx",
      managerid: "searchMainSplkFlxNotablesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventNotablesSplkFlx"),
    });

    resultsLinkeventNotablesSplkFlx
      .render()
      .$el.appendTo($("resultsLinkeventNotablesSplkFlx"));

    //
    // splk-wlk
    //

    // searches

    var searchSplkWlkNotables = new SearchManager(
      {
        id: "searchSplkWlkNotables",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-wlk")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // set the panel visibility
    searchSplkWlkNotables.on("search:start", function (properties) {
      $("#SplkWlkNotablesLoader").css("display", "inherit");
      $("#divSplkWlkNotablesNotFound").css("display", "none");
      $("#divSplkWlkNotablesChart").css("display", "none");
      $("#divSplkWlkNotablesTable").css("display", "none");
    });

    searchSplkWlkNotables.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#SplkWlkNotablesLoader").css("display", "none");
        $("#divSplkWlkNotablesNotFound").css("display", "inherit");
        $("#divSplkWlkNotablesChart").css("display", "none");
        $("#divSplkWlkNotablesTable").css("display", "none");
        // reduce the size
        $("#splk_wlk_notables")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#SplkWlkNotablesLoader").css("display", "none");
        $("#divSplkWlkNotablesNotFound").css("display", "none");
        $("#divSplkWlkNotablesChart").css("display", "inherit");
        $("#divSplkWlkNotablesTable").css("display", "inherit");
        // increase the size
        $("#splk_wlk_notables")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchSplkWlkNotablesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkWlkNotables",
        id: "searchSplkWlkNotablesTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkWlkNotablesOverTime = new SearchManager(
      {
        id: "searchSplkWlkNotablesOverTime",
        earliest_time: "$modalTimeSplkWlk.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeSplkWlk.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-wlk") | timechart limit=40 useother=t minspan=5m bins=1000 count by object',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_splk_wlk_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // chart

    var chartNotablesSplkWlkOverTime = new ChartView(
      {
        id: "chartNotablesSplkWlkOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchSplkWlkNotablesOverTime",
        el: $("#chartNotablesSplkWlkOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartNotablesSplkWlkOverTime = new ResultsLinkView({
      id: "resultsLinkchartNotablesSplkWlkOverTime",
      managerid: "searchSplkWlkNotablesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartNotablesSplkWlkOverTime"),
    });

    resultsLinkchartNotablesSplkWlkOverTime
      .render()
      .$el.appendTo($("resultsLinkchartNotablesSplkWlkOverTime"));

    // event

    // Notables splk-wlk
    var eventNotablesSplkWlk = new EventsViewer(
      {
        id: "eventNotablesSplkWlk",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSplkWlkNotablesTable",
        el: $("#eventNotablesSplkWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventNotablesSplkWlk = new ResultsLinkView({
      id: "resultsLinkeventNotablesSplkWlk",
      managerid: "searchMainSplkWlkNotablesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventNotablesSplkWlk"),
    });

    resultsLinkeventNotablesSplkWlk
      .render()
      .$el.appendTo($("resultsLinkeventNotablesSplkWlk"));

    // splk-cim

    // searches

    // Notables CIM tracker
    var searchSplkCimNotables = new SearchManager(
      {
        id: "searchSplkCimNotables",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-cim")',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // set the panel visibility
    searchSplkCimNotables.on("search:start", function (properties) {
      $("#CimNotablesLoader").css("display", "inherit");
      $("#divCimNotablesNotFound").css("display", "none");
      $("#divCimNotablesChart").css("display", "none");
      $("#divCimNotablesTable").css("display", "none");
    });

    searchSplkCimNotables.on("search:done", function (properties) {
      var eventCount = properties.content.eventCount;
      if (eventCount == 0) {
        $("#CimNotablesLoader").css("display", "none");
        $("#divCimNotablesNotFound").css("display", "inherit");
        $("#divCimNotablesChart").css("display", "none");
        $("#divCimNotablesTable").css("display", "none");
        // reduce the size
        $("#cim_notables")
          .removeClass("custom-modal-body")
          .addClass("custom-modal-body-small");
      } else {
        $("#CimNotablesLoader").css("display", "none");
        $("#divCimNotablesNotFound").css("display", "none");
        $("#divCimNotablesChart").css("display", "inherit");
        $("#divCimNotablesTable").css("display", "inherit");
        // increase the size
        $("#cim_notables")
          .removeClass("custom-modal-body-small")
          .addClass("custom-modal-body");
      }
    });

    var searchSplkCimNotablesTable = new PostProcessManager(
      {
        tokenDependencies: {},
        search: "sort - limit=10000 _time",
        managerid: "searchSplkCimNotables",
        id: "searchSplkCimNotablesTable",
      },
      {
        tokens: true,
      }
    );

    var searchSplkCimNotablesOverTime = new SearchManager(
      {
        id: "searchSplkCimNotablesOverTime",
        earliest_time: "$modalTimeCim.earliest$",
        cancelOnUnload: true,
        sample_ratio: null,
        latest_time: "$modalTimeCim.latest$",
        search:
          '`trackme_notable_idx($tenant_id$)` (tenant_id="$tenant_id$" AND object="$tk_object$" AND object_category="splk-cim") | timechart limit=40 useother=t minspan=5m bins=1000 count by object',
        status_buckets: 0,
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        preview: true,
        tokenDependencies: {
          depends: "$show_cim_notables$",
        },
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // event

    // Notables splk-cim
    var eventNotablesCim = new EventsViewer(
      {
        id: "eventNotablesCim",
        "list.drilldown": "none",
        "table.drilldown": "all",
        "list.wrap": "1",
        "table.wrap": "1",
        rowNumbers: "0",
        "table.sortDirection": "asc",
        count: 1,
        "raw.drilldown": "full",
        type: "list",
        maxLines: 5,
        managerid: "searchSplkCimNotablesTable",
        el: $("#eventNotablesCim"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkeventNotablesCim = new ResultsLinkView({
      id: "resultsLinkeventNotablesCim",
      managerid: "searchMainCimNotablesTable",
      "link.exportResults.visible": false,
      el: $("#resultsLinkeventNotablesCim"),
    });

    resultsLinkeventNotablesCim
      .render()
      .$el.appendTo($("resultsLinkeventNotablesCim"));

    // chart
    var chartNotablesCimOverTime = new ChartView(
      {
        id: "chartNotablesCimOverTime",
        "charting.chart.stackMode": "stacked",
        "charting.chart": "column",
        "charting.drilldown": "all",
        "charting.axisLabelsY.majorUnit": "1",
        "charting.fieldColors": '{"success": 0xb6edb6, "failure": 0xFFBABA}',
        resizable: true,
        height: "150",
        managerid: "searchSplkCimNotablesOverTime",
        el: $("#chartNotablesCimOverTime"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkchartNotablesCimOverTime = new ResultsLinkView({
      id: "resultsLinkchartNotablesCimOverTime",
      managerid: "searchSplkCimNotablesOverTime",
      "link.exportResults.visible": false,
      el: $("#resultsLinkchartNotablesCimOverTime"),
    });

    resultsLinkchartNotablesCimOverTime
      .render()
      .$el.appendTo($("resultsLinkchartNotablesCimOverTime"));

    //
    // BEGIN OPERATIONS
    //

    // Audit changes
    var tokens = mvc.Components.get("default");
    var currentUser = Splunk.util.getConfigValue("USERNAME");
    setToken("currentUser", currentUser);

    // FUNCTIONS

    // close all opened modals
    function closeModals() {
      $(".modal").modal("hide");
    }

    // setnull
    function setNull(str) {
      if (!str || str.length === 0 || str === null) {
        return "null";
      }
    }

    function updateSplkCim(tk_object, tk_keyid, actionNotify) {
      // Perform a target search to update key values
      var tk_tenant_id = getToken("tenant_id");
      // run async
      var doAsync = asyncAjax(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/get_cim_table",
        "POST",
        { tenant_id: tk_tenant_id, key_id: tk_keyid, object: tk_object }
      ).then(function (resultCall) {
        // keep the first record
        jsonData = resultCall[0];

        // update
        updateSplkCimHeader(jsonData);

        // notify
        if (actionNotify === "true") {
          notify("info", "bottom", "Refresh completed.", "5");
        }

        // Refresh tabulator
        $("#splk-cim-table-refresh-hidden").click();
      });
    }

    function updateSplkCimHeader(jsonData) {
      var tk_object = jsonData["object"];
      var tk_alias = jsonData["alias"];
      var tk_object_state = jsonData["object_state"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_cim_monitored_state = jsonData["monitored_state"];
      var tk_priority = jsonData["priority"];
      var tk_tracker_runtime = jsonData["tracker_runtime"];
      var tk_tracker_last_duration = jsonData["tracker_last_duration"];
      var tk_account = jsonData["account"];
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      // define an information span
      var tk_location;
      if (tk_account === "local") {
        tk_location = "local";
      } else {
        tk_location = "remote (account=" + tk_account + ")";
      }

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_cim_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_cim_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_cim_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_cim_status_message_class = "status_message_json_red";
      }

      // Dynamically manage buttons states
      var tk_cim_monitored_state_class;
      if (tk_cim_monitored_state == "enabled") {
        document.getElementById("btn_enable_cim").disabled = true;
        document.getElementById("btn_disable_cim").disabled = false;
        tk_cim_monitored_state_class = "title_green";
      } else {
        document.getElementById("btn_enable_cim").disabled = false;
        document.getElementById("btn_disable_cim").disabled = true;
        tk_cim_monitored_state_class = "title_grey";
      }

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divCimOutliersInfo").css("display", "none");
        $("#divCimOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divCimOutliersSimulationInfo").css("display", "none");
        $("#divCimOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_cim_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_cim_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divCimOutliersInfo").css("display", "inherit");
        $("#divCimOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-cim-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divCimOutliersSimulationInfo").css("display", "inherit");
        $("#divCimOutliersSimulationRender").css("display", "none");
        $("#child-cim-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_cim_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_cim_save").prop("disabled", true);
      }

      // replace info panels
      $("#parent-cim-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for CIM entity: ' +
          tk_object +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-cim-top-info1").html(
        '<h3>monitored state:</b> <span class="' +
          tk_cim_monitored_state_class +
          '">' +
          tk_cim_monitored_state +
          "</span></h3>" +
          '<h3>entity state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-cim-top-info2").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-cim-top-info3").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span>" +
          '<h3>location: <span style="color: dodgerblue;">' +
          tk_location +
          "</span></h3>"
      );

      $("#child-cim-top-info4").html(
        '<h3>tracker last runtime: <span style="color: dodgerblue;">' +
          tk_tracker_runtime +
          '<span style="color: dodgerblue;">' +
          '<h3>tracker last duration: <span style="color: dodgerblue;">' +
          tk_tracker_last_duration +
          '<span style="color: dodgerblue;">'
      );

      $("#child-cim-status-message").html(
        '<div class="' +
          tk_cim_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );
    }

    // Update the entity header info from a JSON object
    function updateSplkDsmHeader(jsonData) {
      // set
      var tk_object = jsonData["object"];
      var tk_alias = jsonData["alias"];
      var tk_data_index = jsonData["data_index"];
      var tk_splk_dsmtype = jsonData["data_sourcetype"];
      var tk_data_lag_summary = jsonData["lag_summary"];
      var tk_data_last_time_seen_human = jsonData["last_time"];
      var tk_data_last_ingest_human = jsonData["last_ingest"];
      var tk_data_max_lag_allowed = jsonData["data_max_lag_allowed"];
      var tk_data_max_lag_allowed_duration =
        jsonData["data_max_lag_allowed_duration"];
      var tk_data_max_delay_allowed = jsonData["data_max_delay_allowed"];
      var tk_data_max_delay_allowed_duration =
        jsonData["data_max_delay_allowed_duration"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_priority = jsonData["priority"];
      var tk_object_state = jsonData["object_state"];
      var tk_data_monitored_state = jsonData["monitored_state"];
      var tk_doc_identity_card_is_global =
        jsonData["doc_identity_card_is_global"];
      var tk_doc_key_match = jsonData["doc_key_match"];
      var tk_doc_link = jsonData["doc_link"];
      var tk_doc_note = jsonData["doc_note"];
      var tk_tags = jsonData["tags"];
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);
      var tk_data_sampling_status_message =
        jsonData["data_sample_status_message"];
      var tk_data_sampling_status_colour =
        jsonData["data_sample_status_colour"];

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      var tk_splk_dsm_status_message_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_dsm_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_dsm_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_dsm_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_dsm_status_message_class = "status_message_json_red";
      }

      // Dynamically manage buttons states
      var tk_data_monitored_state_class;

      if (tk_data_monitored_state == "enabled") {
        document.getElementById("btn_enable_monitoring").disabled = true;
        document.getElementById("btn_disable_monitoring").disabled = false;
        tk_data_monitored_state_class = "title_green";
      } else {
        document.getElementById("btn_enable_monitoring").disabled = false;
        document.getElementById("btn_disable_monitoring").disabled = true;
        tk_data_monitored_state_class = "title_grey";
      }

      // href docs
      var tk_doc_link_main;
      var tk_doc_modal_target;

      // If the documentation reference has not been set, define the href format
      if (tk_doc_link === "null" || tk_doc_link === null) {
        tk_doc_link_main = "Click here to define a documentation reference";
        tk_doc_modal_target = "define_identity_card";
        // replace the textinput for modification requests
        document.getElementById("input_doc_link").value =
          "link to documentation";
      } else {
        tk_doc_link_main = "Show data source identity card";
        tk_doc_modal_target = "manage_identity_card";
        // replace the textinput for modification requests
        document.getElementById("input_doc_link").value = tk_doc_link;
      }

      if (tk_doc_note === "null" || tk_doc_note === null) {
        tk_doc_link = "No documentation defined.";
        // replace the textarea for modification requests
        document.getElementById("input_doc_note").value = "documentation note";
      } else {
        // replace the textarea for modification requests
        document.getElementById("input_doc_note").value = tk_doc_note;
      }

      // If the identity card info is global, disable the delete card
      if (tk_doc_identity_card_is_global == "true") {
        document.getElementById(
          "btn_delete_manage_identity_card"
        ).disabled = true;
        document.getElementById(
          "btn_modify_manage_identity_card"
        ).disabled = false;
        tk_msg_doc_identity_card_is_global =
          "TrackMe info: this is a default identity card configured at the system level, you cannot delete this card but you can create a new card linked to this specific data source, consult: ";
      } else if (tk_doc_key_match == "wildcard") {
        document.getElementById(
          "btn_delete_manage_identity_card"
        ).disabled = true;
        document.getElementById(
          "btn_modify_manage_identity_card"
        ).disabled = true;
        tk_msg_doc_identity_card_is_global =
          "TrackMe info: this is a wildcard matching identity card, this card has to be managed via the API endpoints, consult: ";
      } else {
        document.getElementById(
          "btn_delete_manage_identity_card"
        ).disabled = false;
        document.getElementById(
          "btn_modify_manage_identity_card"
        ).disabled = false;
        tk_msg_doc_identity_card_is_global =
          "TrackMe info: this identity card was associated to this data source, you can update or delete this card, consult: ";
      }

      // Update the div
      $("#child-data-source-identity-card1").html(
        '<h2 style="font-weight: bold; color: darkslategray;">' +
          tk_doc_note +
          "</h2>"
      );

      $("#child-data-source-identity-card2").html(
        '<a target="_blank" href=' + tk_doc_link + '">' + tk_doc_link + "</a>"
      );

      $("#child-data-source-identity-card3").html(
        "<i>" + tk_msg_doc_identity_card_is_global + "</i>"
      );

      // tags
      var tk_tags_link_main;
      // define the href depending on the tags
      if (tk_tags == "null") {
        tk_tags_link_main = "Click here to define tags";
        tk_tags_modal_target = "manage_tags";
        $("#child-data-source-tag-header").html(
          '<h1 style="font-size: 18px;">Tags for data source: ' +
            tk_object +
            "</h1>"
        );
        $("#child-data-source-tag-content").html(
          '<h2 style="font-weight: bold; color: darkslategray;">' +
            "No tags defined, click on Update tags to define one or more tags to be associated with this data source." +
            "</h2>"
        );
      } else {
        tk_tags_link_main = "Show tags";
        tk_tags_modal_target = "manage_tags";
        $("#child-data-source-tag-header").html(
          '<h1 style="font-size: 18px;">Tags for data source: ' +
            tk_object +
            "</h1>"
        );
        $("#child-data-source-tag-content").html(
          '<h2 style="font-weight: bold; color: darkslategray;">' +
            tk_tags +
            "</h2>"
        );
      }

      // data sampling
      var tk_data_sampling_status_message_class;
      if (tk_data_sampling_status_colour == "green") {
        var tk_data_sampling_status_message_class = "status_message_green";
      } else if (tk_data_sampling_status_colour == "orange") {
        var tk_data_sampling_status_message_class = "status_message_orange";
      } else if (tk_data_sampling_status_colour == "blue") {
        var tk_data_sampling_status_message_class = "status_message_blue";
      } else if (tk_data_sampling_status_colour == "red") {
        var tk_data_sampling_status_message_class = "status_message_red";
      } else {
        var tk_data_sampling_status_message_class = "status_message_blue";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_dsm").disabled = false;
        $("#btn_ack_splk_dsm").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_dsm").disabled = false;
        $("#btn_ack_splk_dsm").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_dsm").disabled = false;
        $("#btn_ack_splk_dsm").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_dsm").disabled = true;
        $("#btn_ack_splk_dsm").html("Acknowledge alert");
      }

      // replace info panels
      $("#parent-data-source-main").html(
        "<h1>Actions for entity: " +
          tk_object +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-data-source-top-info1").html(
        '<h3>Index: <span style="color: dodgerblue;">' +
          tk_data_index +
          "</span></h3>" +
          '<h3>Sourcetype: <span style="color: dodgerblue;">' +
          tk_splk_dsmtype +
          '<span style="color: dodgerblue;">' +
          '<h3>Delay event / latency ingestion: ([D+]HH:MM:SS) <span style="color: dodgerblue;">' +
          tk_data_lag_summary +
          '<span style="color: dodgerblue;">' +
          '<h3>Last time seen: <span style="color: dodgerblue;">' +
          tk_data_last_time_seen_human +
          '<span style="color: dodgerblue;">'
      );

      $("#child-data-source-top-info2").html(
        '<h3>Last ingest: <span style="color: dodgerblue;">' +
          tk_data_last_ingest_human +
          '<span style="color: dodgerblue;">' +
          "</span></h3>" +
          '<h3>Threshold latency ingestion: <span style="color: dodgerblue;">' +
          tk_data_max_lag_allowed +
          " sec (duration: " +
          tk_data_max_lag_allowed_duration +
          ")" +
          "</span></h3>" +
          '<h3>Threshold events delay: <span style="color: dodgerblue;">' +
          tk_data_max_delay_allowed +
          " sec (duration: " +
          tk_data_max_delay_allowed_duration +
          ")" +
          "</span></h3>" +
          '<h3>Monitored state:</b> <span class="' +
          tk_data_monitored_state_class +
          '">' +
          tk_data_monitored_state +
          "</span></h3>"
      );

      $("#child-data-source-top-info3").html(
        '<h3>Latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>Latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">' +
          '<h3>State:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></p>" +
          '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></p>"
      );

      $("#child-data-source-top-docs-tags").html(
        '<h3><span><a id="doc_link_splk_dsm" data-toggle="modal" data-dismiss="modal" data-target="#' +
          tk_doc_modal_target +
          '">' +
          tk_doc_link_main +
          "</a>" +
          " / " +
          '<a id="tags_splk_dsm" data-toggle="modal" data-dismiss="modal" data-target="#' +
          tk_tags_modal_target +
          '">' +
          tk_tags_link_main +
          "</a>" +
          "</span>" +
          "</h3>"
      );

      $("#child-data-source-status-message").html(
        '<div class="' +
          tk_splk_dsm_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );

      $("#child-data-source-data-sampling").html(
        '<div class="' +
          tk_data_sampling_status_message_class +
          '">' +
          '<h2 style="font-weight: bold; color: darkslategray;">' +
          tk_data_sampling_status_message +
          "</h2>" +
          "</div>"
      );
    }

    function updateSplkDsm(tk_keyid) {
      // Perform a target search to update key values
      var tk_tenant_id = getToken("tenant_id");
      // run async
      var doAsync = asyncAjax(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_table",
        "POST",
        { tenant_id: tk_tenant_id, key_id: tk_keyid }
      ).then(function (resultCall) {
        // keep the first record
        jsonData = resultCall[0];

        // update
        updateSplkDsmHeader(jsonData);

        // Refresh tabulator
        $("#splk-dsm-table-refresh-hidden").click();
      });
    }

    // Update the data host header info from a JSON object
    function updateSplkDhmHeader(jsonData) {
      var tk_splk_dhm = jsonData["object"];
      var tk_alias = jsonData["alias"];
      var tk_data_lag_summary = jsonData["lag_summary"];
      var tk_data_last_time_seen_human = jsonData["last_time"];
      var tk_data_last_ingest_human = jsonData["last_ingest"];
      var tk_data_max_lag_allowed = jsonData["data_max_lag_allowed"];
      var tk_data_max_lag_allowed_duration =
        jsonData["data_max_lag_allowed_duration"];
      var tk_data_max_delay_allowed = jsonData["data_max_delay_allowed"];
      var tk_data_max_delay_allowed_duration =
        jsonData["data_max_delay_allowed_duration"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_priority = jsonData["priority"];
      var tk_object_state = jsonData["object_state"];
      var tk_data_monitored_state = jsonData["monitored_state"];
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      if (tk_data_monitored_state == "enabled") {
        document.getElementById("btn_enable_monitoring_host").disabled = true;
        document.getElementById("btn_disable_monitoring_host").disabled = false;
        tk_data_monitored_state_class = "title_green";
      } else {
        document.getElementById("btn_enable_monitoring_host").disabled = false;
        document.getElementById("btn_disable_monitoring_host").disabled = true;
        tk_data_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_dhm_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_dhm_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_dhm_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_dhm_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_dhm").disabled = false;
        $("#btn_ack_splk_dhm").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_dhm").disabled = false;
        $("#btn_ack_splk_dhm").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_dhm").disabled = false;
        $("#btn_ack_splk_dhm").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_dhm").disabled = true;
        $("#btn_ack_splk_dhm").html("Acknowledge alert");
      }

      // replace info panels
      $("#parent-data-host-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_splk_dhm +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-data-host-top-info1").html(
        '<h3>Delay event / latency ingestion: ([D+]HH:MM:SS) <span style="color: dodgerblue;">' +
          tk_data_lag_summary +
          '<span style="color: dodgerblue;">' +
          '<h3>Last time seen: <span style="color: dodgerblue;">' +
          tk_data_last_time_seen_human +
          '<span style="color: dodgerblue;">' +
          '<h3>Last ingest: <span style="color: dodgerblue;">' +
          tk_data_last_ingest_human +
          '<span style="color: dodgerblue;">'
      );

      $("#child-data-host-top-info2").html(
        '<h3>Threshold lag ingestion / delay: <span style="color: dodgerblue;">' +
          tk_data_max_lag_allowed +
          " sec (" +
          tk_data_max_lag_allowed_duration +
          ") / " +
          tk_data_max_delay_allowed +
          " sec (" +
          tk_data_max_delay_allowed_duration +
          ")" +
          '<span style="color: dodgerblue;">' +
          '<h3>Monitored state:</b> <span class="' +
          tk_data_monitored_state_class +
          '">' +
          tk_data_monitored_state +
          "</span></h3>" +
          '<h3>State:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></p>"
      );

      $("#child-data-host-top-info3").html(
        '<h3>Latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>Latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">' +
          '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></p>"
      );

      $("#child-data-host-status-message").html(
        '<div class="' +
          tk_splk_dhm_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );
    }

    function updateSplkDhm(tk_object) {
      // Perform a target search to update key values
      var tk_tenant_id = getToken("tenant_id");
      var tk_keyid = getToken("tk_keyid");
      var tk_object = getToken("tk_object");

      // get viz mode
      var modeView = document.getElementById("splk-dhm-table-mode").value;

      // run async
      var doAsync = asyncAjax(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/dh_get_table",
        "POST",
        { tenant_id: tk_tenant_id, mode: modeView, key_id: tk_keyid }
      ).then(function (resultCall) {
        // keep the first record
        jsonData = resultCall[0];

        // update header
        updateSplkDhmHeader(jsonData);

        // Refresh tabulator
        $("#splk-dhm-table-refresh-hidden").click();
      });
    }

    function clearSplkDhm(tk_object, tk_comment) {
      // Create the endpoint URL
      var tk_tenant_id = getToken("tenant_id");
      var tk_keyid = getToken("tk_keyid");

      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_reset";

      // Create a dictionary to store the field names and values
      var record = {
        tenant_id: tk_tenant_id,
        object_list: tk_object,
        update_comment: tk_comment,
      };

      // spinner
      cssloader("Requested action is in progress, please wait...");

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "text",
        beforeSend: function (xhr) {
          xhr.overrideMimeType("text/plain; charset=x-user-defined");
        },
        data: JSON.stringify(record),
        success: function (returneddata) {
          // spinner
          cssloaderremove();
          // call update data source
          updateSplkDhm(tk_object);

          // update various searches
          searchSingleLagHost.startSearch();
          searchSingleLagByMetricsHost.startSearch();
          searchChartHostBaseSearch.startSearch();
          searchChartLagHostOverTime.startSearch();
          searchSingleSLAHostpct.startSearch();
          searchLaggingMetricSplkDhm.startSearch();
          searchSplkDhmMainAuditFlip.startSearch();
          searchSplkDhmMainAuditChanges.startSearch();
          SearchSplkDhmParsingQualityMain.startSearch();
          searchSplkDhmTimeline.startSearch();

          // refresh tabulator
          $("#splk-dhm-table-refresh-hidden").click();
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;

          // Audit
          action = "failure";
          change_type = "reset data";
          object = tk_object;
          object_category = "object";
          object_attrs = "N/A";
          result = message;
          comment = tk_comment;
          auditRecord(
            action,
            change_type,
            object,
            object_category,
            object_attrs,
            result,
            comment
          );

          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });
    }

    function clearSplkMhm(tk_object, tk_comment) {
      // Get tenant
      var tk_tenant_id = getToken("tenant_id");
      var tk_keyid = getToken("tk_keyid");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_reset";

      // Create a dictionary to store the field names and values
      var record = {
        tenant_id: tk_tenant_id,
        keys_list: tk_keyid,
        update_comment: tk_comment,
      };

      // spinner
      cssloader("Requested action is in progress, please wait...");

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "text",
        beforeSend: function (xhr) {
          xhr.overrideMimeType("text/plain; charset=x-user-defined");
        },
        data: JSON.stringify(record),
        success: function (returneddata) {
          // spinner
          cssloaderremove();
          // refresh
          updateSplkMhm(tk_keyid);
          // Refresh searches
          searchHostTableSplkMhm.startSearch();
          searchSingleSLASplkMhmpct.startSearch();
          searchSplkMhmMainAuditFlip.startSearch();
          searchSplkMhmMainAuditChanges.startSearch();
          // refresh tabulator
          $("#splk-mhm-table-refresh-hidden").click();
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;

          // Audit
          action = "failure";
          change_type = "reset metrics";
          object = tk_object;
          object_category = "object";
          object_attrs = "N/A";
          result = message;
          comment = tk_comment;
          auditRecord(
            action,
            change_type,
            object,
            object_category,
            object_attrs,
            result,
            comment
          );

          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });

      // Perform a target search to update key values
    }

    // Update the header info from a JSON object
    function updateSplkMhmHeader(jsonData) {
      var tk_splk_mhm = jsonData["object"];
      var tk_alias = jsonData["alias"];
      var tk_metric_last_lag_seen = jsonData["last_lag_seen"];
      var tk_metric_last_time_seen_human = jsonData["last_time"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_priority = jsonData["priority"];
      var tk_object_state = jsonData["object_state"];
      var tk_metric_monitored_state = jsonData["monitored_state"];
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      var tk_metric_monitored_state_class;
      if (tk_metric_monitored_state == "enabled") {
        document.getElementById(
          "btn_enable_monitoring_splk_mhm"
        ).disabled = true;
        document.getElementById(
          "btn_disable_monitoring_splk_mhm"
        ).disabled = false;
        tk_metric_monitored_state_class = "title_green";
      } else {
        document.getElementById(
          "btn_enable_monitoring_splk_mhm"
        ).disabled = false;
        document.getElementById(
          "btn_disable_monitoring_splk_mhm"
        ).disabled = true;
        tk_metric_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_mhm_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_mhm_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_mhm_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_mhm_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_mhm").disabled = false;
        $("#btn_ack_splk_mhm").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_mhm").disabled = false;
        $("#btn_ack_splk_mhm").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_mhm").disabled = false;
        $("#btn_ack_splk_mhm").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_mhm").disabled = true;
        $("#btn_ack_splk_mhm").html("Acknowledge alert");
      }

      // Explicitly refresh the get tags search
      searchGetSplkMhmTags.startSearch();

      // replace info panels
      $("#parent-metric-host-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_splk_mhm +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-metric-host-top-info1").html(
        '<h3>last lag seen: <span style="color: dodgerblue;">' +
          tk_metric_last_lag_seen +
          '<span style="color: dodgerblue;">' +
          '<h3>last time seen: <span style="color: dodgerblue;">' +
          tk_metric_last_time_seen_human +
          '<span style="color: dodgerblue;">'
      );

      $("#child-metric-host-top-info2").html(
        '<h3>monitored state:</b> <span class="' +
          tk_metric_monitored_state_class +
          '">' +
          tk_metric_monitored_state +
          "</span></h3>" +
          '<h3>host state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-metric-host-top-info3").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-metric-host-top-info4").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></p>"
      );

      $("#child-metric-host-status-message").html(
        '<div class="' +
          tk_splk_mhm_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );
    }

    function updateSplkMhm(tk_keyid) {
      // Perform a target search to update key values
      var tk_tenant_id = getToken("tenant_id");
      // get viz mode
      var modeView = document.getElementById("splk-mhm-table-mode").value;
      // run async
      var doAsync = asyncAjax(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/mh_get_table",
        "POST",
        { tenant_id: tk_tenant_id, mode: modeView, key_id: tk_keyid }
      ).then(function (resultCall) {
        // keep the first record
        jsonData = resultCall[0];

        // update
        updateSplkMhmHeader(jsonData);

        // Refresh tabulator
        $("#splk-mhm-table-refresh-hidden").click();
      });
    }

    // Update the header info from a JSON object
    function updateSplkFlxHeader(jsonData) {
      var tk_object = jsonData["object"];
      var tk_alias = jsonData["alias"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_priority = jsonData["priority"];
      var tk_object_state = jsonData["object_state"];
      var tk_monitored_state = jsonData["monitored_state"];
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      // specific to splk-flx
      var tk_status = jsonData["status"];
      var tk_status_description = jsonData["status_description"];
      var tk_description = jsonData["object_description"];

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divFlxOutliersInfo").css("display", "none");
        $("#divFlxOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divFlxOutliersSimulationInfo").css("display", "none");
        $("#divFlxOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_flx_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_flx_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divFlxOutliersInfo").css("display", "inherit");
        $("#divFlxOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-flx-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divFlxOutliersSimulationInfo").css("display", "inherit");
        $("#divFlxOutliersSimulationRender").css("display", "none");
        $("#child-flx-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_flx_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_flx_save").prop("disabled", true);
      }

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      var tk_monitored_state_class;
      if (tk_monitored_state == "enabled") {
        document.getElementById(
          "btn_enable_monitoring_splk_flx"
        ).disabled = true;
        document.getElementById(
          "btn_disable_monitoring_splk_flx"
        ).disabled = false;
        tk_monitored_state_class = "title_green";
      } else {
        document.getElementById(
          "btn_enable_monitoring_splk_flx"
        ).disabled = false;
        document.getElementById(
          "btn_disable_monitoring_splk_flx"
        ).disabled = true;
        tk_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_flx_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_flx_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_flx_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_flx_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      var tk_ack_state = jsonData["ack_state"];
      if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state != "active"
      ) {
        document.getElementById("btn_ack_splk_flx").disabled = false;
        $("#btn_ack_splk_flx").html("Acknowledge alert");
      } else if (
        (tk_object_state == "red" ||
          tk_object_state == "orange" ||
          tk_object_state == "blue") &&
        tk_ack_state == "active"
      ) {
        document.getElementById("btn_ack_splk_flx").disabled = false;
        $("#btn_ack_splk_flx").html("Manage Acknowledgement");
      } else if (tk_ack_state == "active") {
        document.getElementById("btn_ack_splk_flx").disabled = false;
        $("#btn_ack_splk_flx").html("Manage Acknowledgement");
      } else {
        document.getElementById("btn_ack_splk_flx").disabled = true;
        $("#btn_ack_splk_flx").html("Acknowledge alert");
      }

      // replace info panels
      $("#parent-splk-flx-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_object +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-splk-flx-top-info1").html(
        '<h3>Status: <span style="color: dodgerblue;">' +
          tk_status +
          '<span style="color: dodgerblue;">' +
          '<h3>Status description: <span style="color: dodgerblue;">' +
          truncate(tk_status_description, 200) +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-flx-top-info2").html(
        '<h3>monitored state:</b> <span class="' +
          tk_monitored_state_class +
          '">' +
          tk_monitored_state +
          "</span></h3>" +
          '<h3>host state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-splk-flx-top-info3").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-flx-top-info4").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></h3>" +
          '<h3>Description: <span style="color: dodgerblue;">' +
          truncate(tk_description, 200) +
          "</span></h3>"
      );

      $("#child-splk-flx-status-message").html(
        '<div class="' +
          tk_splk_flx_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );
    }

    function updateSplkFlx(tk_keyid) {
      // run async
      var doAsync = asyncAjax(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/flx_get_table",
        "POST",
        {
          tenant_id: getToken("tenant_id"),
          key_id: getToken("tk_keyid"),
          object: getToken("tk_object"),
        }
      ).then(function (resultCall) {
        // keep the first record
        jsonData = resultCall[0];

        // update
        updateSplkFlxHeader(jsonData);

        // Refresh tabulator
        $("#splk-flx-table-refresh-hidden").click();
      });
    }

    // Update the header info from a JSON object
    function updateSplkWlkHeader(jsonData) {
      var tk_object = jsonData["object"];
      var tk_alias = jsonData["alias"];
      var tk_latest_flip_time_human = jsonData["latest_flip_time_human"];
      var tk_latest_flip_state = jsonData["latest_flip_state"];
      var tk_priority = jsonData["priority"];
      var tk_object_state = jsonData["object_state"];
      var tk_monitored_state = jsonData["monitored_state"];
      var tk_status_message = jsonData["status_message"];
      var tk_status_message_json = JSON.parse(jsonData["status_message_json"]);

      // specific to splk-wlk
      var tk_status = jsonData["status"];
      var tk_status_description = jsonData["status_description"];
      var tk_description = jsonData["object_description"];

      // outlier
      var tk_outliers_readiness = jsonData["outliers_readiness"];

      if (tk_outliers_readiness === "True") {
        // Outliers render
        $("#divWlkOutliersInfo").css("display", "none");
        $("#divWlkOutliersRender").css("display", "inherit");
        setToken("tk_outliers_readiness", tk_outliers_readiness);
        // Outliers settings
        $("#divWlkOutliersSimulationInfo").css("display", "none");
        $("#divWlkOutliersSimulationRender").css("display", "inherit");
        $("#btn_outlier_config_splk_wlk_simulate").prop("disabled", false);
        $("#btn_outlier_config_splk_wlk_save").prop("disabled", false);
        //
      } else if (tk_outliers_readiness === "False") {
        // Outliers render
        $("#divWlkOutliersInfo").css("display", "inherit");
        $("#divWlkOutliersRender").css("display", "none");
        unsetToken("tk_outliers_readiness");
        $("#child-wlk-outliers-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning Outliers Anomaly Detection is not ready yet for this entity, models need to be trained first or there are no models defined yet . Click on Manage outliers detection to manage it now.</h2></div>'
        );
        // Outliers settings
        $("#divWlkOutliersSimulationInfo").css("display", "inherit");
        $("#divWlkOutliersSimulationRender").css("display", "none");
        $("#child-wlk-outliers-simulation-info").html(
          '<div class="status_message_orange"><h2 style="font-weight: bold; color: darkslategray;">Machine Learning models have not been trained yet for this entity as models need to be trained first, if needed, perform the models settings and click on Train ML models now before you can start any simulation.</h2></div>'
        );
        $("#btn_outlier_config_splk_wlk_simulate").prop("disabled", true);
        $("#btn_outlier_config_splk_wlk_save").prop("disabled", true);
      }

      // Dynamically manage priority color
      var tk_priority_class;
      if (tk_priority == "low") {
        tk_priority_class = "title_low_priority";
      } else if (tk_priority == "medium") {
        tk_priority_class = "title_medium_priority";
      } else if (tk_priority == "high") {
        tk_priority_class = "title_high_priority";
      }

      // Dynamically manage buttons states
      var tk_monitored_state_class;
      if (tk_monitored_state == "enabled") {
        document.getElementById(
          "btn_enable_monitoring_splk_wlk"
        ).disabled = true;
        document.getElementById(
          "btn_disable_monitoring_splk_wlk"
        ).disabled = false;
        tk_monitored_state_class = "title_green";
      } else {
        document.getElementById(
          "btn_enable_monitoring_splk_wlk"
        ).disabled = false;
        document.getElementById(
          "btn_disable_monitoring_splk_wlk"
        ).disabled = true;
        tk_monitored_state_class = "title_grey";
      }

      // Dynamically manage state color
      var tk_object_state_class;
      if (tk_object_state == "green") {
        tk_object_state_class = "title_green";
        tk_splk_wlk_status_message_class = "status_message_json_green";
      } else if (tk_object_state == "orange") {
        tk_object_state_class = "title_orange";
        tk_splk_wlk_status_message_class = "status_message_json_orange";
      } else if (tk_object_state == "blue") {
        tk_object_state_class = "title_blue";
        tk_splk_wlk_status_message_class = "status_message_json_blue";
      } else if (tk_object_state == "red") {
        tk_object_state_class = "title_red";
        tk_splk_wlk_status_message_class = "status_message_json_red";
      }

      // Dynamically manage Ack button
      if (tk_object_state == "red") {
        document.getElementById("btn_ack_splk_wlk").disabled = false;
      } else {
        document.getElementById("btn_ack_splk_wlk").disabled = true;
      }

      // replace info panels
      $("#parent-splk-wlk-main").html(
        '<h1><i class="bi bi-display text-primary"></i> Actions for entity: ' +
          tk_object +
          " (alias: " +
          tk_alias +
          ")" +
          "</h1>"
      );

      $("#child-splk-wlk-top-info1").html(
        '<h3>Status: <span style="color: dodgerblue;">' +
          tk_status +
          '<span style="color: dodgerblue;">' +
          '<h3>Status description: <span style="color: dodgerblue;">' +
          truncate(tk_status_description, 200) +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-wlk-top-info2").html(
        '<h3>monitored state:</b> <span class="' +
          tk_monitored_state_class +
          '">' +
          tk_monitored_state +
          "</span></h3>" +
          '<h3>host state:</b> <span class="' +
          tk_object_state_class +
          '">' +
          tk_object_state +
          "</span></h3>"
      );

      $("#child-splk-wlk-top-info3").html(
        '<h3>latest flip time: <span style="color: dodgerblue;">' +
          tk_latest_flip_time_human +
          '<span style="color: dodgerblue;">' +
          '<h3>latest flip state: <span style="color: dodgerblue;">' +
          tk_latest_flip_state +
          '<span style="color: dodgerblue;">'
      );

      $("#child-splk-wlk-top-info4").html(
        '<h3>Priority:</b> <span class="' +
          tk_priority_class +
          '">' +
          tk_priority +
          "</span></h3>" +
          '<h3>Description: <span style="color: dodgerblue;">' +
          truncate(tk_description, 200) +
          "</span></h3>"
      );

      $("#cchild-splk-wlk-status-message").html(
        '<div class="' +
          tk_splk_wlk_status_message_class +
          '">' +
          '<div><pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(JSON.stringify(tk_status_message_json, null, 2)) +
          "</pre></div>" +
          "</div>"
      );
    }

    function updateSplkWlk(tk_keyid) {
      // run async
      var doAsync = asyncAjax(
        "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_get_table",
        "POST",
        {
          tenant_id: getToken("tenant_id"),
          key_id: getToken("tk_keyid"),
          object: getToken("tk_object"),
        }
      ).then(function (resultCall) {
        // keep the first record
        jsonData = resultCall[0];

        // update
        updateSplkWlkHeader(jsonData);

        // Refresh tabulator
        $("#splk-wlk-table-refresh-hidden").click();
      });
    }

    // This function generates outliers statistics and be called when the outliers period calculaton is changed

    function metricOutliersGen(
      object_category,
      object,
      TargetOutlierTimePeriod
    ) {
      // get tenant
      var tk_tenant_id = getToken("tenant_id");
      // Perform a target search to update key values
      var searchQuery =
        "| `trackme_outliers_gen_metrics(" +
        tk_tenant_id +
        "," +
        object_category +
        "," +
        object +
        "," +
        TargetOutlierTimePeriod +
        ")`";

      // Set the search parameters
      var searchParams = {
        exec_mode: "normal",
        earliest_time: "-30d",
      };

      service.search(searchQuery, searchParams, function (err, job) {
        // Poll the status of the search job
        job.track(
          {
            period: 200,
          },
          {
            done: function (job) {
              // Get the results and print them
              job.results({}, function (err, results, job) {
                var fields = results.fields;
                var rows = results.rows;
                for (var i = 0; i < rows.length; i++) {
                  var values = rows[i];
                  for (var j = 0; j < values.length; j++) {
                    var field = fields[j];
                    var value = values[j];
                  }
                }

                // Perform a target search to update key values
                var searchQuery =
                  "| `trackme_summary_investigator_mstats(" +
                  tk_tenant_id +
                  "," +
                  object_category +
                  "," +
                  object +
                  ")`" +
                  ' `trackme_summary_investigator_define_bound_abstract` | eval key = md5(object_category . ":" . object) | `trackme_outputlookup(' +
                  "trackme_volume_outliers_tenant_" +
                  tk_tenant_id +
                  ", key)` | stats c";

                // Set the search parameters
                var searchParams = {
                  exec_mode: "normal",
                  earliest_time: "-30d",
                };

                service.search(searchQuery, searchParams, function (err, job) {
                  // Poll the status of the search job
                  job.track(
                    {
                      period: 200,
                    },
                    {
                      done: function (job) {
                        // Get the results and print them
                        job.results({}, function (err, results, job) {
                          var fields = results.fields;
                          var rows = results.rows;
                          for (var i = 0; i < rows.length; i++) {
                            var values = rows[i];
                            for (var j = 0; j < values.length; j++) {
                              var field = fields[j];
                              var value = values[j];
                            }
                          }
                        });
                      },
                      failed: function (job) {},
                      error: function (err) {
                        done(err);
                      },
                    }
                  );
                });
              });
            },
            failed: function (job) {},
            error: function (err) {
              done(err);
            },
          }
        );
      });
    }

    //
    // ALERT SUMMARY
    //

    $("#btn_refresh_alerts")
      .unbind()
      .click(function () {
        // refresh tabulator
        getAlertTable();
        search_alerts_main_table.startSearch();
        searchDonutAlertsTriggered.startSearch();
        searchAlertTriggeredOverTime.startSearch();
      });

    $("#btn_refresh_alert_tracking")
      .unbind()
      .click(function () {
        searchAlertTriggeredOverTimePerAlert.startSearch();
        searchAlertActionsNotablesEventsOverTimePerAlert.startSearch();
        searchPopulateAlertActionsAck.startSearch();
        searchPopulateAlertActionsSmartStatus.startSearch();
        searchAlertActionsTriggeredOverTimePerAlert.startSearch();
        searchAlertActionsAckEventsOverTimePerAlert.startSearch();
        searchAlertActionsSmartStatusdEventsOverTimePerAlert.startSearch();
      });

    $("#btn_create_alert")
      .unbind()
      .click(function () {
        // fire up some searches
        setToken("start_get_tags_for_custom_alert", "true");
        search_alerts_get_tags.startSearch();

        $("#add_custom_alert").modal();
      });

    $("#btn_modal_custom_alert_add_new")
      .unbind()
      .click(function () {
        // spinner
        cssloader("Please wait creating the new TrackMe alert...");

        // tenant
        var tk_tenant_id = getToken("tenant_id");

        // When the Submit button is clicked, get all the form fields by accessing token values
        var tk_input_custom_alert_name = getToken("tk_input_custom_alert_name");

        // automatically add a prefix
        tk_input_custom_alert_name =
          "TrackMe alert tenant_id:" +
          tk_tenant_id +
          " - " +
          tk_input_custom_alert_name;

        var tk_input_create_alert_splk_dsm = getToken("create_alert_splk_dsm");
        var tk_input_create_alert_cim_tracking = getToken(
          "create_alert_cim_tracking"
        );
        var tk_input_create_alert_splk_dhm = getToken("create_alert_splk_dhm");
        var tk_input_create_alert_splk_mhm = getToken("create_alert_splk_mhm");
        var tk_input_create_alert_splk_flx = getToken("create_alert_splk_flx");
        var tk_input_create_alert_splk_wlk = getToken("create_alert_splk_wlk");
        var tk_input_custom_alert_priority = getToken(
          "tk_input_custom_alert_priority"
        );
        var tk_input_custom_alert_state = getToken(
          "tk_input_custom_alert_state"
        );
        var tk_input_custom_alert_splk_dsm_filter = getToken(
          "tk_input_custom_alert_splk_dsm_filter"
        );
        var tk_input_custom_alert_cim_tracking_filter = getToken(
          "tk_input_custom_alert_cim_tracking_filter"
        );
        var tk_input_custom_alert_splk_dhm_filter = getToken(
          "tk_input_custom_alert_splk_dhm_filter"
        );
        var tk_input_custom_alert_splk_mhm_filter = getToken(
          "tk_input_custom_alert_splk_mhm_filter"
        );
        var tk_input_custom_alert_splk_flx_filter = getToken(
          "tk_input_custom_alert_splk_flx_filter"
        );
        var tk_input_custom_alert_splk_wlk_filter = getToken(
          "tk_input_custom_alert_splk_wlk_filter"
        );
        var tk_input_custom_tags = getToken("tk_input_custom_tags");
        var tk_input_custom_alert_trigger_on_outliers = getToken(
          "tk_input_custom_alert_trigger_on_outliers"
        );
        var tk_input_custom_alert_trigger_on_outliers_splk_dhm = getToken(
          "tk_input_custom_alert_trigger_on_outliers_splk_dhm"
        );
        var tk_input_custom_alert_trigger_on_data_sampling = getToken(
          "tk_input_custom_alert_trigger_on_data_sampling"
        );
        var tk_input_custom_alert_cron = getToken("tk_input_custom_alert_cron");
        var tk_input_custom_alert_suppress_fields = getToken(
          "tk_input_custom_alert_suppress_fields"
        );
        var tk_input_custom_alert_suppress_period = getToken(
          "tk_input_custom_alert_suppress_period"
        );
        var tk_input_custom_alert_time_filtering = getToken(
          "tk_input_custom_alert_time_filtering"
        );
        var tk_input_custom_alert_smart_status = getToken(
          "tk_input_custom_alert_smart_status"
        );
        var tk_input_custom_alert_auto_ack = getToken(
          "tk_input_custom_alert_auto_ack"
        );
        var tk_input_custom_alert_notable = getToken(
          "tk_input_custom_alert_notable"
        );

        // Splunk limits report names to max 100 chars, and will refuse otherwise
        var tk_tracker_name = tk_input_custom_alert_name.substring(0, 100);

        // define the alert search
        var tk_custom_alert;
        var tk_object_category;

        //
        // SPLK-DSM
        //

        if (tk_input_create_alert_splk_dsm == "true") {
          tk_object_category = "data_source";

          // load
          tk_custom_alert = "| `get_splk_dsm_table(" + tk_tenant_id + ",*)`";

          // where monitored
          tk_custom_alert =
            tk_custom_alert + '\n| where monitored_state="enabled"';

          // maintenance mode
          tk_custom_alert =
            tk_custom_alert +
            '\n| appendcols [ | inputlookup trackme_maintenance_mode ] | filldown maintenance_mode | where NOT maintenance_mode="enabled"';

          // add the object filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| search object="' +
            tk_input_custom_alert_splk_dsm_filter +
            '"';

          // add the priority filter
          tk_custom_alert =
            tk_custom_alert + "\n| search " + tk_input_custom_alert_priority;

          // add the state filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| where (object_state="red" OR object_state="orange") | search ' +
            tk_input_custom_alert_state;

          // handle tags
          if (tk_input_custom_tags != 'tags="*"') {
            tk_custom_alert =
              tk_custom_alert +
              '\n| makemv delim="," tags | search ' +
              tk_input_custom_tags;
          }

          // handle outliers
          if (tk_input_custom_alert_trigger_on_outliers == "false") {
            tk_custom_alert = tk_custom_alert + "\n| where isOutlier=0 ";
          }

          // handle data sampling
          if (tk_input_custom_alert_trigger_on_data_sampling == "false") {
            tk_custom_alert = tk_custom_alert + "\n| where isAnomaly=0";
          }

          // handle time filtering
          tk_custom_alert =
            tk_custom_alert +
            "\n| `" +
            tk_input_custom_alert_time_filtering +
            "`";

          // handle Ack
          tk_custom_alert = tk_custom_alert + '\n| where ack_state!="active"';
        }

        //
        // SPLK-DHM
        //
        else if (tk_input_create_alert_splk_dhm == "true") {
          tk_object_category = "object";

          // load
          tk_custom_alert =
            "| `get_splk_dhm_table(" + tk_tenant_id + ", compact, *, *)`";

          // where monitored
          tk_custom_alert =
            tk_custom_alert + '\n| where monitored_state="enabled"';

          // maintenance mode
          tk_custom_alert =
            tk_custom_alert +
            '\n| appendcols [ | inputlookup trackme_maintenance_mode ] | filldown maintenance_mode | where NOT maintenance_mode="enabled"';

          // add the object filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| search object="' +
            tk_input_custom_alert_splk_dhm_filter +
            '"';

          // add the priority filter
          tk_custom_alert =
            tk_custom_alert + "\n| search " + tk_input_custom_alert_priority;

          // add the state filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| where (object_state="red" OR object_state="orange") | search ' +
            tk_input_custom_alert_state;

          // handle outliers
          if (tk_input_custom_alert_trigger_on_outliers == "false") {
            tk_custom_alert = tk_custom_alert + "\n| where isOutlier=0 ";
          }

          // handle time filtering
          tk_custom_alert =
            tk_custom_alert +
            "\n| `" +
            tk_input_custom_alert_time_filtering +
            "`";

          // handle Ack
          tk_custom_alert = tk_custom_alert + '\n| where ack_state!="active"';
        }
        //
        // SPLK-MHM
        //
        else if (tk_input_create_alert_splk_mhm == "true") {
          tk_object_category = "object";

          // load
          tk_custom_alert =
            "| `get_splk_mhm_table(" + tk_tenant_id + ",compact,*,*)`";

          // where monitored
          tk_custom_alert =
            tk_custom_alert + '\n| where monitored_state="enabled"';

          // maintenance mode
          tk_custom_alert =
            tk_custom_alert +
            '\n| appendcols [ | inputlookup trackme_maintenance_mode ] | filldown maintenance_mode | where NOT maintenance_mode="enabled"';

          // add the object filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| search object="' +
            tk_input_custom_alert_splk_mhm_filter +
            '"';

          // add the priority filter
          tk_custom_alert =
            tk_custom_alert + "\n| search " + tk_input_custom_alert_priority;

          // add the state filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| where (object_state="red" OR object_state="orange") | search ' +
            tk_input_custom_alert_state;

          // handle time filtering
          tk_custom_alert =
            tk_custom_alert +
            "\n| `" +
            tk_input_custom_alert_time_filtering +
            "`";

          // handle Ack
          tk_custom_alert = tk_custom_alert + '\n| where ack_state!="active"';
        }

        //
        // SPLK-FLX
        //

        if (tk_input_create_alert_splk_flx == "true") {
          tk_object_category = "splk-dsm";

          // load
          tk_custom_alert = "| `get_splk_flx_table(" + tk_tenant_id + ",*,*)`";

          // where monitored
          tk_custom_alert =
            tk_custom_alert + '\n| where monitored_state="enabled"';

          // maintenance mode
          tk_custom_alert =
            tk_custom_alert +
            '\n| appendcols [ | inputlookup trackme_maintenance_mode ] | filldown maintenance_mode | where NOT maintenance_mode="enabled"';

          // add the object filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| search object="' +
            tk_input_custom_alert_splk_flx_filter +
            '"';

          // add the priority filter
          tk_custom_alert =
            tk_custom_alert + "\n| search " + tk_input_custom_alert_priority;

          // add the state filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| where (object_state="red" OR object_state="orange") | search ' +
            tk_input_custom_alert_state;

          // handle time filtering
          tk_custom_alert =
            tk_custom_alert +
            "\n| `" +
            tk_input_custom_alert_time_filtering +
            "`";

          // handle Ack
          tk_custom_alert = tk_custom_alert + '\n| where ack_state!="active"';
        }

        //
        // SPLK-WLK
        //

        if (tk_input_create_alert_splk_wlk == "true") {
          tk_object_category = "splk-dsm";

          // load
          tk_custom_alert = "| `get_splk_wlk_table(" + tk_tenant_id + ",*,*)`";

          // where monitored
          tk_custom_alert =
            tk_custom_alert + '\n| where monitored_state="enabled"';

          // maintenance mode
          tk_custom_alert =
            tk_custom_alert +
            '\n| appendcols [ | inputlookup trackme_maintenance_mode ] | filldown maintenance_mode | where NOT maintenance_mode="enabled"';

          // add the object filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| search object="' +
            tk_input_custom_alert_splk_wlk_filter +
            '"';

          // add the priority filter
          tk_custom_alert =
            tk_custom_alert + "\n| search " + tk_input_custom_alert_priority;

          // add the state filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| where (object_state="red" OR object_state="orange") | search ' +
            tk_input_custom_alert_state;

          // handle time filtering
          tk_custom_alert =
            tk_custom_alert +
            "\n| `" +
            tk_input_custom_alert_time_filtering +
            "`";

          // handle Ack
          tk_custom_alert = tk_custom_alert + '\n| where ack_state!="active"';
        }

        //
        // SPLK-CIM
        //
        else if (tk_input_create_alert_cim_tracking == "true") {
          tk_object_category = "cim_tracking";

          // load
          tk_custom_alert =
            '| `get_splk_cim_table("' +
            tk_tenant_id +
            '", "*", "*")`\n | rename status as state\n';

          // where monitored
          tk_custom_alert =
            tk_custom_alert + '\n| where monitored_state="enabled"';

          // maintenance mode
          tk_custom_alert =
            tk_custom_alert +
            '\n| appendcols [ | inputlookup trackme_maintenance_mode ] | filldown maintenance_mode | where NOT maintenance_mode="enabled"';

          // add the priority filter
          tk_custom_alert =
            tk_custom_alert + "\n| search " + tk_input_custom_alert_priority;

          // add the cim entities filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| search object="' +
            tk_input_custom_alert_cim_tracking_filter +
            '"';

          // add the state filter
          tk_custom_alert =
            tk_custom_alert +
            '\n| where (object_state="red" OR object_state="orange") | search ' +
            tk_input_custom_alert_state;

          // handle time filtering
          tk_custom_alert =
            tk_custom_alert +
            "\n| `" +
            tk_input_custom_alert_time_filtering +
            "`";

          // handle Ack
          tk_custom_alert = tk_custom_alert + '\n| where ack_state!="active"';
        }

        function done(err) {
          //error handling logic here
        }

        var alertOptions;
        var alertActions = [];

        if (tk_input_custom_alert_notable == "1") {
          alertActions.push("trackme_notable");
        }

        if (tk_input_custom_alert_auto_ack == "1") {
          alertActions.push("trackme_auto_ack");
        }

        if (tk_input_custom_alert_smart_status == "1") {
          alertActions.push("trackme_smart_status");
        }

        // Specify properties for the alert
        alertOptions = {
          description: "TrackMe alert",
          alert_type: "always",
          "alert.severity": "5",
          "alert.suppress": "1",
          "alert.suppress.fields": tk_input_custom_alert_suppress_fields,
          "alert.suppress.period": tk_input_custom_alert_suppress_period,
          "alert.track": "1",
          "dispatch.earliest_time": "-5m",
          "dispatch.latest_time": "now",
          is_scheduled: "1",
          schedule_window: "auto",
          alert_comparator: "greater than",
          alert_type: "number of events",
          alert_threshold: "0",
          "alert.digest_mode": "0",
          cron_schedule: tk_input_custom_alert_cron,
          actions: alertActions.toString(),
          "action.trackme_notable.title": "$name$",
          "action.trackme_smart_status.param.tenant_id": "$result.tenant_id$",
          "action.trackme_auto_ack.param.object_category":
            "$result.object_category$",
          "action.trackme_auto_ack.param.object_name": "$result.object$",
          "action.trackme_auto_ack.param.ack_period": getToken(
            "tk_input_custom_alert_auto_ack_period"
          ),
          "action.trackme_auto_ack.param.ack_type": getToken(
            "tk_input_custom_alert_auto_ack_type"
          ),
          "action.trackme_smart_status.param.object_category":
            "$result.object_category$",
          "action.trackme_smart_status.param.object_name": "$result.object$",
        };

        // run ajax call
        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/alerting/admin/create_alert";

        // Create a dictionary to store the field names and values
        var record = {
          tenant_id: tk_tenant_id,
          alert_name: tk_tracker_name,
          alert_search: tk_custom_alert,
          alert_properties: alertOptions,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "text",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            cssloaderremove();
            message =
              "Created alert: " +
              JSON.stringify(JSON.parse(returneddata), null, 4);
            $("#modal_alert_creation_success")
              .find(".modal-success-message p")
              .text(message);
            $("#add_custom_alert").modal("hide");
            $("#modal_alert_creation_success").modal();
            // refresh tabulator
            getAlertTable();
            search_alerts_main_table.startSearch();
            searchDonutAlertsTriggered.startSearch();
            searchAlertTriggeredOverTime.startSearch();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;

            // Audit
            action = "failure";
            change_type = "add custom alert";
            object = tk_tracker_name;
            object_category = tk_object_category;
            object_attrs = tk_custom_alert;
            result = message;
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            cssloaderremove();
            $("#modal_alert_creation_error")
              .find(".modal-error-message p")
              .text(message);
            closeModals();
            $("#modal_alert_creation_error").modal();
          },
        });
      });

    // enable monitoring

    $("#btn_enable_monitoring")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                object_list: tk_object,
                action: "enable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_object +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "enable monitoring";
                  object = tk_object;
                  object_category = "data_source";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    $("#btn_enable_monitoring_host")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_dhm").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_splk_dhm");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                object_list: tk_splk_dhm,
                action: "enable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_dhm +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkDhmMain.startSearch();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "enable monitoring";
                  object = tk_splk_dhm;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    // refresh data_source
    $("#btn_refresh_splk_dsm")
      .unbind()
      .click(function (mode) {
        // notify
        notify("info", "bottom", "Refreshing entity, please wait...", "5");
        searchSingleLag.startSearch();
        searchSingleByMetricsLag.startSearch();
        searchChartLag.startSearch();
        searchSingleSLApct.startSearch();
        searchOutlierDetectionChartDsm.startSearch();
        searchLaggingMetricSplkDsm.startSearch();
        searchSplkDsmMainAuditFlip.startSearch();
        searchSplkDsmMainAuditChanges.startSearch();
        searchAuditSplkDsmAuditChangesOverTime.startSearch();
        SearchSplkDsmParsingQualityMain.startSearch();
        searchSplkDsmTimeline.startSearch();
        // Dropdown for outliers
        searchPopulateSplkDsmOutliersModelsSettings.startSearch();
        searchPopulateSplkDsmOutliersModels.startSearch();

        // call update data source
        var tk_keyid = getToken("tk_keyid");
        updateSplkDsm(tk_keyid);
        notify("info", "bottom", "Refresh completed.", "5");
      });

    // refresh object
    $("#btn_refresh_splk_dhm")
      .unbind()
      .click(function (mode) {
        // notify
        notify("info", "bottom", "Refreshing entity, please wait...", "5");
        searchSingleLagHost.startSearch();
        searchSingleLagByMetricsHost.startSearch();
        searchChartHostBaseSearch.startSearch();
        searchChartLagHostOverTime.startSearch();
        searchSingleSLAHostpct.startSearch();
        searchOutlierDetectionChartDhm.startSearch();
        searchLaggingMetricSplkDhm.startSearch();
        searchSplkDhmMainAuditFlip.startSearch();
        searchSplkDhmMainAuditChanges.startSearch();
        searchAuditSplkDhmAuditChangesOverTime.startSearch();
        SearchSplkDhmParsingQualityMain.startSearch();
        searchSplkDhmTimeline.startSearch();

        // call update data host
        var tk_object = getToken("tk_object");
        updateSplkDhm(tk_object);
        notify("info", "bottom", "Refresh completed.", "5");
      });

    // refresh object
    $("#btn_refresh_splk_flx")
      .unbind()
      .click(function (mode) {
        // notify
        notify("info", "bottom", "Refreshing entity, please wait...", "5");
        searchChartSplkFlx.startSearch();
        searchSingleSLASplkFlxpct.startSearch();
        searchOutlierDetectionChartFlx.startSearch();
        searchSplkFlxMainAuditFlip.startSearch();
        searchSplkFlxMainAuditChanges.startSearch();
        searchAuditSplkFlxAuditChangesOverTime.startSearch();
        searchSplkFlxTimeline.startSearch();

        var tk_keyid = getToken("tk_keyid");
        // call update metric host
        updateSplkFlx(tk_keyid);
        notify("info", "bottom", "Refresh completed.", "5");
      });

    // refresh object
    $("#btn_refresh_splk_wlk")
      .unbind()
      .click(function (mode) {
        // notify
        notify("info", "bottom", "Refreshing entity, please wait...", "5");
        searchChartSplkWlk.startSearch();
        //searchSingleSLASplkWlkpct.startSearch();
        searchOutlierDetectionChartWlk.startSearch();
        searchSplkWlkMainAuditFlip.startSearch();
        searchSplkWlkMainAuditChanges.startSearch();
        searchAuditSplkWlkAuditChangesOverTime.startSearch();
        searchSplkWlkMainMetadata.startSearch();
        searchSplkWlkTimeline.startSearch();

        var tk_keyid = getToken("tk_keyid");
        // call update metric host
        updateSplkWlk(tk_keyid);
        notify("info", "bottom", "Refresh completed.", "5");
      });

    // refresh object
    $("#btn_refresh_splk_mhm")
      .unbind()
      .click(function (mode) {
        // notify
        notify("info", "bottom", "Refreshing entity, please wait...", "5");
        searchHostTableSplkMhm.startSearch();
        searchSingleSLASplkMhmpct.startSearch();
        searchSplkMhmMainAuditFlip.startSearch();
        searchSplkMhmMainAuditChanges.startSearch();
        searchAuditSplkMhmAuditChangesOverTime.startSearch();
        searchSplkMhmTimeline.startSearch();

        var tk_keyid = getToken("tk_keyid");
        // call update metric host
        updateSplkMhm(tk_keyid);
        notify("info", "bottom", "Refresh completed.", "5");
      });

    $("#btn_enable_monitoring_splk_mhm")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_mhm").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_mhm = getToken("tk_splk_mhm");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                keys_list: tk_keyid,
                action: "enable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_mhm +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkMhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-mhm-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "enable monitoring";
                  object = tk_splk_mhm;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    // splk-flx

    $("#btn_enable_monitoring_splk_flx")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_flx").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_flx = getToken("tk_splk_flx");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                keys_list: tk_keyid,
                action: "enable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_flx +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkFlxMain.startSearch();
                  // refresh tabulator
                  $("#splk-flx-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "enable monitoring";
                  object = tk_splk_flx;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    // splk-wlk

    $("#btn_enable_monitoring_splk_wlk")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_wlk").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_wlk = getToken("tk_splk_wlk");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                keys_list: tk_keyid,
                action: "enable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_wlk +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkWlkMain.startSearch();
                  // refresh tabulator
                  $("#splk-wlk-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "enable monitoring";
                  object = tk_splk_wlk;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    // cancel button: returns to selected
    $("#btn_close_splk_flx_unified")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_flx").modal();
      });

    // cancel button: returns to selected
    $("#btn_close_splk_wlk_unified")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_wlk").modal();
      });

    // cancel button: returns to selected
    $("#btn_close_splk_mhm_unified")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_mhm").modal();
      });

    // metric host priority
    $("#btn_modal_modify_priority_splk_mhm_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_mhm = getToken("tk_splk_mhm");
        var tk_priority = getToken("tk_priority");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_update_priority";

        var tk_origin_priority = tk_priority;
        var tk_new_priority = getToken("tk_input_splk_mhm_priority");

        if (!tk_new_priority || !tk_new_priority.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            priority: tk_new_priority,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkMhmMain.startSearch();

              // refresh tabulator
              $("#splk-mhm-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Priority updated successfully.",
                "5"
              );

              // call update data source
              updateSplkMhm(tk_keyid);

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify priority";
              object = tk_splk_mhm;
              object_category = "object";
              object_attrs =
                "priority changed from:" +
                tk_origin_priority +
                " to:" +
                tk_new_priority;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // disable monitoring

    $("#btn_disable_monitoring")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                object_list: tk_object,
                action: "disable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_object +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "disable monitoring";
                  object = tk_object;
                  object_category = "data_source";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    $("#btn_disable_monitoring_host")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_dhm").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_splk_dhm");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                object_list: tk_splk_dhm,
                action: "disable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_dhm +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkDhmMain.startSearch();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "disable monitoring";
                  object = tk_splk_dhm;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    $("#btn_disable_monitoring_splk_mhm")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_mhm").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_mhm = getToken("tk_splk_mhm");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                keys_list: tk_keyid,
                action: "disable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_mhm +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkMhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-mhm-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "disable monitoring";
                  object = tk_splk_mhm;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    $("#btn_disable_monitoring_splk_flx")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_flx").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_flx = getToken("tk_splk_flx");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                keys_list: tk_keyid,
                action: "disable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_flx +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkFlxMain.startSearch();
                  // refresh tabulator
                  $("#splk-flx-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "disable monitoring";
                  object = tk_splk_flx;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    $("#btn_disable_monitoring_splk_wlk")
      .unbind()
      .click(function (mode) {
        // Hide main modal
        $("#modal_manage_splk_wlk").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_wlk = getToken("tk_splk_wlk");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_monitoring";

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: tk_tenant_id,
                keys_list: tk_keyid,
                action: "disable",
                update_comment: tk_comment,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "text",
                beforeSend: function (xhr) {
                  xhr.overrideMimeType("text/plain; charset=x-user-defined");
                },
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The entity " +
                    tk_splk_wlk +
                    " has been updated successfully.";
                  notify("success", "bottom", msg, "5");
                  // Run the search again to update the table
                  searchSplkWlkMain.startSearch();
                  // refresh tabulator
                  $("#splk-wlk-table-refresh-hidden").click();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "disable monitoring";
                  object = tk_splk_wlk;
                  object_category = "object";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = tk_comment;
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            });
        }
      });

    //
    // RESET BUTTON
    //

    $("#btn_reset_splk_mhm")
      .unbind()
      .click(function (mode) {
        // Get tokens
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Hide main modal
        $("#modal_manage_splk_mhm").modal("hide");

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // notify
              var msg =
                "Please wait while performing the reset of the entity " +
                tk_object;
              notify("info", "bottom", msg, "60");

              // call reset metric host
              clearSplkMhm(tk_object, tk_comment);

              // Return to modal
              $("#modal_manage_splk_mhm").modal();
            });
        }
      });

    //
    // DELETE BUTTON
    //

    $("#btn_delete_splk_mhm")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_splk_mhm").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_mhm = getToken("tk_splk_mhm");

        if (tk_keyid && tk_keyid.length) {
          $("#modal_entry_deletion").modal();

          $("#btn_modal_entry_deletion_temporary")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "temporary",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_mhm +
                        " has been temporary deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkMhmMain.startSearch();
                      // refresh tabulator
                      $("#splk-mhm-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete temporary";
                      object = tk_splk_mhm;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });

          $("#btn_modal_entry_deletion")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_mhm/write/mh_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "permanent",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_mhm +
                        " has been permanenlty deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkMhmMain.startSearch();
                      // refresh tabulator
                      $("#splk-mhm-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete permanent";
                      object = tk_splk_mhm;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });
        }
      });

    $("#btn_delete_splk_flx")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_splk_flx").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_flx = getToken("tk_splk_flx");

        if (tk_keyid && tk_keyid.length) {
          $("#modal_entry_deletion").modal();

          $("#btn_modal_entry_deletion_temporary")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "temporary",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_flx +
                        " has been temporary deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkFlxMain.startSearch();
                      // refresh tabulator
                      $("#splk-flx-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete temporary";
                      object = tk_splk_flx;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });

          $("#btn_modal_entry_deletion")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "permanent",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_flx +
                        " has been permanenlty deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkFlxMain.startSearch();
                      // refresh tabulator
                      $("#splk-flx-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete permanent";
                      object = tk_splk_flx;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });
        }
      });

    $("#btn_delete_splk_wlk")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_splk_wlk").modal("hide");

        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_wlk = getToken("tk_splk_wlk");

        if (tk_keyid && tk_keyid.length) {
          $("#modal_entry_deletion").modal();

          $("#btn_modal_entry_deletion_temporary")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "temporary",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_wlk +
                        " has been temporary deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkWlkMain.startSearch();
                      // refresh tabulator
                      $("#splk-wlk-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete temporary";
                      object = tk_splk_wlk;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });

          $("#btn_modal_entry_deletion")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "permanent",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_wlk +
                        " has been permanenlty deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkWlkMain.startSearch();
                      // refresh tabulator
                      $("#splk-wlk-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete permanent";
                      object = tk_splk_wlk;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });
        }
      });

    // delete entry

    $("#btn_delete_splk_dsm")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage").modal("hide");

        // When the Submit button is clicked, get all the form fields by accessing token values
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        if (tk_keyid && tk_keyid.length) {
          $("#modal_entry_deletion").modal();

          $("#btn_modal_entry_deletion_temporary")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "temporary",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_object +
                        " has been temporary deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkDsmMain.startSearch();
                      // refresh tabulator
                      $("#splk-dsm-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete temporary";
                      object = tk_object;
                      object_category = "data_source";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });

          $("#btn_modal_entry_deletion")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "temporary",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_object +
                        " has been permanently deleted.";
                      notify("success", "bottom", msg, "5");
                      // Run the search again to update the table
                      searchSplkDsmMain.startSearch();
                      // refresh tabulator
                      $("#splk-dsm-table-refresh-hidden").click();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete permanent";
                      object = tk_object;
                      object_category = "data_source";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });
        }
      });

    //
    // RESET BUTTON
    //

    $("#btn_reset_splk_dhm")
      .unbind()
      .click(function (mode) {
        // Get tokens
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Hide main modal
        $("#modal_manage_splk_dhm").modal("hide");

        if (!tk_keyid || !tk_keyid.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          $("#modal_entry_modification").modal();

          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              // Retrieve update comment if any
              var tk_comment = getComment("input_update_comment");

              // notify
              var msg =
                "Please wait while performing the reset of the entity " +
                tk_object;
              notify("info", "bottom", msg, "60");

              // call reset data host
              clearSplkDhm(tk_object, tk_comment);

              // Return to modal
              $("#modal_manage_splk_dhm").modal();
            });
        }
      });

    //
    // DELETE BUTTON
    //

    $("#btn_delete_splk_dhm")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_splk_dhm").modal("hide");

        // When the Submit button is clicked, get all the form fields by accessing token values
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_splk_dhm");

        if (tk_keyid && tk_keyid.length) {
          $("#modal_entry_deletion").modal();

          $("#btn_modal_entry_deletion_temporary")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "temporary",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_dhm +
                        " has been temporary deleted.";
                      notify("success", "bottom", msg, "5");
                      // Update
                      $("#splk-dhm-table-refresh-hidden").click();
                      searchSplkDhmMain.startSearch();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete temporary";
                      object = tk_splk_dhm;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });

          $("#btn_modal_entry_deletion")
            .unbind("click")
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler

              $("#modal_entry_modification").modal();

              $("#btn_modal_entry_modification")
                .unbind()
                .click(function () {
                  var that = $(this);
                  that.off("click"); // remove handler

                  // Retrieve update comment if any
                  var tk_comment = getComment("input_update_comment");

                  // Create the endpoint URL
                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_delete";

                  // Create a dictionary to store the field names and values
                  var record = {
                    tenant_id: tk_tenant_id,
                    keys_list: tk_keyid,
                    deletion_type: "permanent",
                    update_comment: tk_comment,
                  };

                  // spinner
                  cssloader("Requested action is in progress, please wait...");

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    contentType: "application/json",
                    dataType: "text",
                    beforeSend: function (xhr) {
                      xhr.overrideMimeType(
                        "text/plain; charset=x-user-defined"
                      );
                    },
                    data: JSON.stringify(record),
                    success: function (returneddata) {
                      // spinner
                      cssloaderremove();
                      // notify
                      var msg =
                        "The entity " +
                        tk_splk_mhm +
                        " has been permanently deleted.";
                      notify("success", "bottom", msg, "5");
                      // Update
                      $("#splk-dhm-table-refresh-hidden").click();
                      searchSplkDhmMain.startSearch();
                    },
                    error: function (xhr, textStatus, error) {
                      // spinner
                      cssloaderremove();
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;

                      // Audit
                      action = "failure";
                      change_type = "delete permanent";
                      object = tk_splk_dhm;
                      object_category = "object";
                      object_attrs = JSON.stringify(record, null, "\t");
                      result = message;
                      comment = tk_comment;
                      auditRecord(
                        action,
                        change_type,
                        object,
                        object_category,
                        object_attrs,
                        result,
                        comment
                      );

                      $("#modal_update_collection_failure_return")
                        .find(".modal-error-message p")
                        .text(message);
                      closeModals();
                      $("#modal_update_collection_failure_return").modal();
                    },
                  });
                });
            });
        }
      });

    // metrics sla policy

    // add policy

    $("#btn_modal_metric_policy_add")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // When the Submit button is clicked, get all the form fields by accessing token values
        var tk_input_metric_policy_metric_category = getToken(
          "tk_input_metric_policy_metric_category"
        );
        var tk_input_metric_policy_metric_value = getToken(
          "tk_input_metric_policy_metric_value"
        );

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/write/lagging_classes_metrics_add";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          metric_category: tk_input_metric_policy_metric_category,
          metric_max_lag_allowed: tk_input_metric_policy_metric_value,
          update_comment: "N/A",
        };

        // spinner
        cssloader("Requested action is in progress, please wait...");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // spinner
            cssloaderremove();
            // notify
            notify(
              "success",
              "bottom",
              "Lagging class successfully added.",
              "5"
            );
            laggingClassesMetricsHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
              "POST",
              {
                tenant_id: tk_tenant_id,
                lagging_class_type: "metrics",
              },
              "mhm"
            );
            $("#modal_metric_sla_policies").modal();
          },
          error: function (xhr, textStatus, error) {
            // spinner
            cssloaderremove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add lagging classes";
            object = tk_input_metric_policy_metric_category;
            object_category = "all";
            object_attrs = JSON.stringify(record);
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // Custom lagging
    $("#btn_modal_custom_lagging_add")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_input_custom_lagging_type = getToken(
          "tk_input_custom_lagging_type"
        );
        var tk_input_custom_lagging_name = getToken(
          "tk_input_custom_lagging_name"
        );
        var tk_input_custom_lagging_value = getToken(
          "tk_input_custom_lagging_value"
        );
        var tk_input_custom_delay_value = getToken(
          "tk_input_custom_delay_value"
        );
        var tk_input_custom_lagging_object = getToken(
          "tk_input_custom_lagging_object"
        );

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/write/lagging_classes_add";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          lagging_class_type: "events",
          name: tk_input_custom_lagging_name,
          level: tk_input_custom_lagging_type,
          object: tk_input_custom_lagging_object,
          value_lag: tk_input_custom_lagging_value,
          value_delay: tk_input_custom_delay_value,
          update_comment: "N/A",
        };

        // spinner
        cssloader("Requested action is in progress, please wait...");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // spinner
            cssloaderremove();
            // notify
            notify(
              "success",
              "bottom",
              "Lagging class successfully added.",
              "5"
            );
            laggingClassesHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
              "POST",
              {
                tenant_id: tk_tenant_id,
                lagging_class_type: "events",
              },
              "dsmdhm"
            );
          },
          error: function (xhr, textStatus, error) {
            // spinner
            cssloaderremove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add lagging classes";
            object = tk_input_custom_lagging_object;
            object_category = "all";
            object_attrs = JSON.stringify(record);
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // Lagging classes update
    //

    $("#btn_confirm_modal_laggingclasses_mhm_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_laggingclasses_mhm_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/write/lagging_classes_update";

        // retrieve comment, if any
        comment = getComment("comment_modal_laggingclasses_mhm_confirm_save");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          lagging_class_type: "metrics",
          component: "mhm",
          records_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update lagging class",
          tk_multi_table_array,
          "mhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Lagging classe(s) successfully updated.",
                "5"
              );
              // refresh the tabulator
              laggingClassesMetricsHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
                "POST",
                { tenant_id: tk_tenant_id, lagging_class_type: "metrics" },
                "mhm"
              );
              // return modal
              $("#modal_metric_sla_policies").modal();
            }
          }
        });
      });

    //
    // Lagging classes delete
    //

    $("#btn_confirm_modal_laggingclasses_mhm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_laggingclasses_mhm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/write/lagging_classes_del";

        // retrieve comment, if any
        comment = getComment("comment_modal_laggingclasses_mhm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          lagging_class_type: "metrics",
          component: "mhm",
          keys_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete lagging class",
          tk_multi_table_array,
          "mhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Lagging classe(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              laggingClassesMetricsHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
                "POST",
                { tenant_id: tk_tenant_id, lagging_class_type: "metrics" },
                "mhm"
              );
              // return modal
              $("#modal_metric_sla_policies").modal();
            }
          }
        });
      });

    //
    // Lagging classes update
    //

    $("#btn_confirm_modal_laggingclasses_dsmdhm_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_laggingclasses_dsmdhm_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/write/lagging_classes_update";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_laggingclasses_dsmdhm_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          lagging_class_type: "events",
          component: "dsm",
          records_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "dsmdhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Lagging classe(s) successfully updated.",
                "5"
              );
              // refresh the tabulator
              laggingClassesHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
                "POST",
                { tenant_id: tk_tenant_id, lagging_class_type: "events" },
                "dsmdhm"
              );
            }
          }
        });
      });

    //
    // Lagging classes delete
    //

    $("#btn_confirm_modal_laggingclasses_dsmdhm_confirm_delete").click(
      function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_laggingclasses_dsmdhm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/write/lagging_classes_del";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_laggingclasses_dsmdhm_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          lagging_class_type: "events",
          component: "splk-dsm",
          keys_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete lagging class",
          tk_multi_table_array,
          "dsmdhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Lagging classe(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              laggingClassesHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
                "POST",
                { tenant_id: tk_tenant_id, lagging_class_type: "events" },
                "dsmdhm"
              );
            }
          }
        });
      }
    );

    //
    // DSM dataset add new entry
    //

    $("#btn_add_modal_dsm_dataset_handler")
      .unbind()
      .click(function () {
        // loader
        cssloader("Adding the new dataset object, please wait...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Get object_category, object and action
        var tk_object_category = getToken(
          "input_dataset_handler_dsm_object_category"
        );
        var tk_object = getToken("input_dataset_handler_dsm_object");
        var tk_action = "block";

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_add";

        // set data for the POST call
        var record = {
          component: "dsm",
          tenant_id: tk_tenant_id,
          object_category: tk_object_category,
          object: tk_object,
          action: tk_action,
          update_comment: "N/A",
        };

        // spinner
        cssloader("Requested action is in progress, please wait...");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // spinner
            cssloaderremove();
            // Once the job is done, update all searches
            searchSplkDsmMain.startSearch();
            // refresh tabulator
            $("#splk-dsm-table-refresh-hidden").click();
            // notify
            notify("success", "bottom", "Allowlist successfully added.", "5");
            dataSetHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
              "POST",
              { tenant_id: tk_tenant_id, component: "dsm" },
              "dsm"
            );
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            // spinner
            cssloaderremove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add allowlist index";
            object = tk_object;
            object_category = "data_source";
            object_attrs = "{" + '"data_index": "' + tk_object + '"}';
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // DSM dataset update
    //

    $("#btn_confirm_modal_dataset_dsm_confirm_save")
      .unbind()
      .click(function () {
        cssloader("Please wait while performing the operation requested...");

        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_dataset_dsm_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_update";

        // retrieve comment, if any
        comment = getComment("comment_modal_dataset_dsm_confirm_save");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dsm",
          records_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "data_source",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Allowlist(s) successfully updated.",
                "5"
              );
              // refresh the tabulator
              dataSetHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
                "POST",
                record,
                "dsm"
              );
              // refresh searches
              refreshDsmAllowLists();
              refreshDsm;
              // remove loader
              cssloaderremove();
            }
          }
        });
      });

    //
    // DSM dataset delete
    //

    $("#btn_confirm_modal_dataset_dsm_confirm_delete")
      .unbind()
      .click(function () {
        cssloader("Please wait while performing the operation requested...");

        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_dataset_dsm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_del";

        // retrieve comment, if any
        comment = getComment("comment_modal_dataset_dsm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dsm",
          keys_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete allowlist index",
          tk_multi_table_array,
          "data_source",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Allowlist(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              dataSetHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
                "POST",
                record,
                "dsm"
              );
              // refresh searches
              refreshDsmAllowLists();
              refreshDsm;
              // remove loader
              cssloaderremove();
            }
          }
        });
      });

    //
    // DHM dataset add new entry
    //

    $("#btn_add_modal_dhm_dataset_handler")
      .unbind()
      .click(function () {
        // loader
        cssloader("Adding the new dataset object, please wait...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Get object_category, object and action
        var tk_object_category = getToken(
          "input_dataset_handler_dhm_object_category"
        );
        var tk_object = getToken("input_dataset_handler_dhm_object");
        var tk_action = "block";

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_add";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dhm",
          object_category: tk_object_category,
          object: tk_object,
          action: tk_action,
          update_comment: "N/A",
        };

        // spinner
        cssloader("Requested action is in progress, please wait...");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // spinner
            cssloaderremove();
            // Once the job is done, update all searches
            searchSplkDsmMain.startSearch();
            // refresh tabulator
            $("#splk-dsm-table-refresh-hidden").click();
            // notify
            notify("success", "bottom", "Allowlist successfully added.", "5");
            dataSetHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
              "POST",
              { tenant_id: tk_tenant_id, component: "dhm" },
              "dhm"
            );
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            // spinner
            cssloaderremove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add allowlist index";
            object = tk_object;
            object_category = "data_source";
            object_attrs = "{" + '"data_index": "' + tk_object + '"}';
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // DHM dataset update
    //

    $("#btn_confirm_modal_dataset_dhm_confirm_save")
      .unbind()
      .click(function () {
        cssloader("Please wait while performing the operation requested...");

        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_dataset_dhm_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_update";

        // retrieve comment, if any
        comment = getComment("comment_modal_dataset_dhm_confirm_save");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dhm",
          records_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "data_source",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Allowlist(s) successfully updated.",
                "5"
              );
              // refresh the tabulator
              dataSetHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
                "POST",
                record,
                "dhm"
              );
              // refresh searches
              refreshDhmAllowLists();
              refreshDhm;
              // remove loader
              cssloaderremove();
            }
          }
        });
      });

    //
    // DHM dataset delete
    //

    $("#btn_confirm_modal_dataset_dhm_confirm_delete")
      .unbind()
      .click(function () {
        cssloader("Please wait while performing the operation requested...");

        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_dataset_dhm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_del";

        // retrieve comment, if any
        comment = getComment("comment_modal_dataset_dhm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dhm",
          keys_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete allowlist index",
          tk_multi_table_array,
          "data_source",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Allowlist(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              dataSetHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
                "POST",
                record,
                "dhm"
              );
              // refresh searches
              refreshDhmAllowLists();
              refreshDhm;
              // remove loader
              cssloaderremove();
            }
          }
        });
      });

    //
    // MHM dataset add new entry
    //

    $("#btn_add_modal_mhm_dataset_handler")
      .unbind()
      .click(function () {
        // loader
        cssloader("Adding the new dataset object, please wait...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Get object_category, object and action
        var tk_object_category = getToken(
          "input_dataset_handler_mhm_object_category"
        );
        var tk_object = getToken("input_dataset_handler_mhm_object");
        var tk_action = "block";

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_add";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "mhm",
          object_category: tk_object_category,
          object: tk_object,
          action: tk_action,
          update_comment: "N/A",
        };

        // spinner
        cssloader("Requested action is in progress, please wait...");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // spinner
            cssloaderremove();
            // Once the job is done, update all searches
            searchSplkDsmMain.startSearch();
            // refresh tabulator
            $("#splk-dsm-table-refresh-hidden").click();
            // notify
            notify("success", "bottom", "Allowlist successfully added.", "5");
            dataSetHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
              "POST",
              { tenant_id: tk_tenant_id, component: "mhm" },
              "mhm"
            );
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            // spinner
            cssloaderremove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add allowlist index";
            object = tk_object;
            object_category = "data_source";
            object_attrs = "{" + '"data_index": "' + tk_object + '"}';
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // MHM dataset update
    //

    $("#btn_confirm_modal_dataset_mhm_confirm_save")
      .unbind()
      .click(function () {
        cssloader("Please wait while performing the operation requested...");

        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_dataset_mhm_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_update";

        // retrieve comment, if any
        comment = getComment("comment_modal_dataset_mhm_confirm_save");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "mhm",
          records_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "data_source",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Allowlist(s) successfully updated.",
                "5"
              );
              // refresh the tabulator
              dataSetHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
                "POST",
                record,
                "mhm"
              );
              // refresh searches
              refreshMhmAllowLists();
              refreshMhm;
              // remove loader
              cssloaderremove();
            }
          }
        });
      });

    //
    // MHM dataset delete
    //

    $("#btn_confirm_modal_dataset_mhm_confirm_delete")
      .unbind()
      .click(function () {
        cssloader("Please wait while performing the operation requested...");

        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_dataset_mhm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/write/dataset_del";

        // retrieve comment, if any
        comment = getComment("comment_modal_dataset_mhm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "mhm",
          keys_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete allowlist index",
          tk_multi_table_array,
          "data_source",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Allowlist(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              dataSetHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
                "POST",
                record,
                "mhm"
              );
              // refresh searches
              refreshMhmAllowLists();
              refreshMhm;
              // remove loader
              cssloaderremove();
            }
          }
        });
      });

    // data sources monitoring

    $("#btn_modal_modify_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_dsm").modal();
      });

    // data hosts monitoring

    $("#btn_modal_modify_host_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_dhm").modal();
      });

    //
    // Replica trackers
    //

    // show main modal
    $(".btn_modify_replica_trackers_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("start_modify_replica_trackers", "true");

        // Show input modal
        $("#modify_replica_trackers_main").modal();
      });
    });

    // show add new remote tracker modal
    $("#btn_modal_replica_remote_tracker_add")
      .unbind()
      .click(function () {
        // get the number of active replica trackers
        var license_is_valid = licenseCall["license_is_valid"];
        var license_active_replica_trackers =
          licenseCall["license_active_splk_replica_trackers"];
        var license_active_replica_trackers_total =
          licenseCall["license_active_replica_trackers"];
        var license_subscription_class =
          licenseCall["license_subscription_class"];

        // proceed
        if (license_active_replica_trackers >= 2 && license_is_valid != 1) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_replica_trackers +
                " splk-dsm active replica trackers and this deployment is currently running in Free limited edition mode. The Free limited edition mode is limited to 2 active replica trackers per component at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_replica_trackers_total >= 6 &&
          license_subscription_class === "free_extended"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_replica_trackers_total +
                " active replica trackers in total and this deployment is currently running in Free extended edition mode. The Free extended edition mode is limited to 6 active replica trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_replica_trackers_total >= 16 &&
          license_subscription_class === "enterprise"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_replica_trackers_total +
                " active replica trackers in total and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 16 active replica trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid Unlimited license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else {
          // show current component
          $("#divReplicaCurrentComponent").html(
            '<h1><span style="color: #a7c7e7;">Current component: splk-' +
              getToken("tk_component") +
              "</span></h1>"
          );
          // Show input modal
          $("#add_replica_remote_tracker").modal();
          // disable creation button
          document.getElementById(
            "modal_input_replica_tracker_add"
          ).disabled = true;
        }
      });

    // go back to main from replica remote new tracker
    $("#btn_modal_replica_remote_tracker_add_new_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_replica_trackers_main").modal();
      });

    // Create the new replica tracker
    $("#modal_input_replica_tracker_add")
      .unbind()
      .click(function () {
        // show modal
        $("#modal_confirm_replica_tracker").modal();
      });

    // Create the new replica tracker
    $("#btn_modal_input_replica_add_new_confirm")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get target tenant_id
        var parent_tenant_id = getToken("tk_input_replica_tracker_tenant");

        // get the current tenant
        var tenant_id = getToken("tenant_id");

        // get the current component
        var tk_component = getToken("tk_component");

        // This is not a Splunk form
        var tk_replica_root_constraint = document.getElementById(
          "modal_input_replica_remote_root_constraint"
        ).value;

        // if unset, but users continues
        if (
          tk_replica_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_replica_root_constraint = "object=*";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("replica_tracker_creation_comment");

        // spinner
        cssloader("Please wait while creating the replica tracker...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_replica_trackers/admin/replica_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          source_tenant_id: parent_tenant_id,
          component: tk_component,
          root_constraint: tk_replica_root_constraint,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // get tracker from response
            var tk_tracker_name = returneddata.wrapper_report;
            // set token for later usage
            setToken("tk_replica_final_report", tk_tracker_name);
            // notify
            var msg =
              "The new replica tracker " +
              tk_tracker_name +
              " has been created successfully.";
            notify("success", "bottom", msg, "5");
            // set the message to be returned and show modal
            $("#modal_replica_tracker_creation_success")
              .find(".modal-success-message p")
              .text(JSON.stringify(returneddata));
            closeModals();
            cssloaderremove();
            $("#modal_replica_tracker_creation_success").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add replica tracker";
            object = tenant_id;
            object_category = "replica_tracker";
            object_attrs = JSON.stringify(record, null, "\t");
            result = message;
            comment = tk_comment;
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // run replica tracker now
    $("#modal_replica_tracker_run_tracker")
      .unbind()
      .click(function () {
        // Get the tracker name
        var tk_tracker_name = getToken("tk_replica_final_report");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the replica tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // create a mapping of components to their corresponding functions and actions
                  const componentMap = {
                    dsm: {
                      search: searchSplkDsmMain,
                      refreshId: "splk-dsm-table-refresh-hidden",
                    },
                    dhm: {
                      search: searchSplkDhmMain,
                      refreshId: "splk-dhm-table-refresh-hidden",
                    },
                    mhm: {
                      search: searchSplkMhmMain,
                      refreshId: "splk-mhm-table-refresh-hidden",
                    },
                    flx: {
                      search: searchSplkFlxMain,
                      refreshId: "splk-flx-table-refresh-hidden",
                    },
                    cim: {
                      search: searchSplkCimMain,
                      refreshId: "splk-cim-table-refresh-hidden",
                    },
                    wlk: {
                      search: searchSplkWlkMain,
                      refreshId: "splk-wlk-table-refresh-hidden",
                    },
                  };

                  // Once the job is done, update all searches
                  let component = getToken("tk_component");
                  if (componentMap.hasOwnProperty(component)) {
                    componentMap[component].search.startSearch();
                    // refresh tabulator
                    $("#" + componentMap[component].refreshId).click();
                  }

                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    //
    // Simulate replica trackers
    //

    // simulate remote tracker
    $("#modal_input_replica_tracker_simulate")
      .unbind()
      .click(function () {
        // get target tenant_id
        var parent_tenant_id = getToken("tk_input_replica_tracker_tenant");

        // get the current tenant
        var tenant_id = getToken("tenant_id");

        // get the current component
        var tk_component = getToken("tk_component");

        // This is not a Splunk form
        var tk_replica_root_constraint = document.getElementById(
          "modal_input_replica_remote_root_constraint"
        ).value;

        // if unset, but users continues
        if (
          tk_replica_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_replica_root_constraint = "object=*";
        }

        // Set the search syntax
        var tk_hybrid_replica_tracker_simulation_search =
          "| inputlookup trackme_" +
          tk_component +
          "_tenant_" +
          parent_tenant_id +
          "\n| search " +
          tk_replica_root_constraint +
          "\n| `trackme_replica_tracker_simulation`";

        setToken(
          "tk_hybrid_replica_tracker_simulation_search",
          tk_hybrid_replica_tracker_simulation_search
        );

        // free the search
        setToken("start_simulation_replica_tracker", "true");

        // start the search explicitely
        searchReplicaTrackerTest.startSearch();

        // show the view
        $("#divReplicaTrackerTest").css("display", "inherit");

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while starting some Splunky searches!",
          "30"
        );
      });

    //
    // Manage replica trackers
    //

    $("#btn_modal_replica_remote_tracker_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("root_tenant_id"),
        };
        replicaTrackingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_replica_trackers/replica_tracker_show",
          "POST",
          record
        );
      });

    // back
    $("#btn_modal_replica_back")
      .unbind()
      .click(function () {
        $("#modify_replica_trackers_main").modal();
      });

    // mass delete
    $("#btn_confirm_modal_replica_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_replica_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_replica_trackers/admin/replica_tracker_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_replica_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          replica_trackers_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete replica tracker",
          tk_multi_table_array,
          "replica",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Replica tracker(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              replicaTrackingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_replica_trackers/replica_tracker_show",
                "POST",
                record
              );
            }
          }
        });
      });

    //
    // Hybrid trackers
    //

    // dsm

    // show main modal
    $(".btn_modify_hybrid_trackers_dsm_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("start_modify_hybrid_trackers", "true");

        // Show input modal
        $("#modify_hybrid_trackers_main_dsm").modal();
      });
    });

    // show add new remote tracker modal
    $("#btn_modal_hybrid_remote_tracker_dsm_add")
      .unbind()
      .click(function () {
        // get the number of active hybrid trackers
        var license_is_valid = licenseCall["license_is_valid"];
        var license_active_hybrid_trackers =
          licenseCall["license_active_splk_dsm_hybrid_trackers"];
        var license_active_hybrid_trackers_total =
          licenseCall["license_active_hybrid_trackers"];
        var license_subscription_class =
          licenseCall["license_subscription_class"];

        // proceed
        if (license_active_hybrid_trackers >= 2 && license_is_valid != 1) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers +
                " splk-dsm active hybrid trackers and this deployment is currently running in Free limited edition mode. The Free limited edition mode is limited to 2 active hybrid trackers per component at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_hybrid_trackers_total >= 6 &&
          license_subscription_class === "free_extended"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers_total +
                " active hybrid trackers in total and this deployment is currently running in Free extended edition mode. The Free extended edition mode is limited to 6 active hybrid trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_hybrid_trackers_total >= 16 &&
          license_subscription_class === "enterprise"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers_total +
                " active hybrid trackers in total and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 16 active hybrid trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid Unlimited license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else {
          // Allow populating search
          setToken("show_configuration_account_dsm", "true");
          // force refresh search
          searchPopulateConfigurationAccountDsm.startSearch();
          // Show input modal
          $("#add_hybrid_remote_tracker_dsm").modal();
          // disable creation button
          document.getElementById(
            "btn_modal_input_hybrid_remote_dsm_add_new"
          ).disabled = true;
        }
      });

    // go back to main from hybrid remote new tracker
    $("#btn_modal_hybrid_remote_tracker_dsm_add_new_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_hybrid_trackers_main_dsm").modal();
      });

    // simulate remote tracker
    $("#btn_modal_input_hybrid_remote_dsm_add_simulate")
      .unbind()
      .click(function () {
        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dsm"
        ).value;

        // if unset, but users continues
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        // form the breakby logic
        var breakby_field = getToken(
          "tk_input_hybrid_remote_dsm_break_by_field"
        );
        if (breakby_field != "none" || breakby_field != "merged") {
          // convert to an array
          breakby_field_array = breakby_field.split(",");

          // remove index if present
          if (breakby_field_array.includes("index")) {
            breakby_field_array.splice(breakby_field_array.indexOf("index"), 1); //deleting
          }

          // remove sourcetype if present
          if (breakby_field_array.includes("sourcetype")) {
            breakby_field_array.splice(
              breakby_field_array.indexOf("sourcetype"),
              1
            ); //deleting
          }

          // convert back
          breakby_field = String(breakby_field_array);
        }

        var record = {
          run_simulation: false,
          component: "dsm",
          account: getToken("tk_input_hybrid_remote_dsm_account"),
          search_mode: getToken("tk_input_hybrid_remote_search_dsm_mode"),
          earliest_time: getToken(
            "tk_input_hybrid_remote_tracker_dsm_earliest"
          ),
          latest_time: getToken("tk_input_hybrid_remote_tracker_dsm_latest"),
          cron_schedule: getToken("tk_input_hybrid_remote_tracker_dsm_cron"),
          index_earliest_time: getToken(
            "tk_input_hybrid_remote_tracker_dsm_index_earliest"
          ),
          index_latest_time: getToken(
            "tk_input_hybrid_remote_tracker_dsm_index_latest"
          ),
          search_constraint: tk_hybrid_root_constraint,
          breakby_field: breakby_field,
        };

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while starting some Splunky searches!",
          "30"
        );

        // Retrieve entity info from REST and set actions
        $.ajax({
          url: "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_simulation",
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // search results
            simulation_results = returneddata["results"];

            setToken(
              "tk_hybrid_remote_tracker_simulation_search",
              returneddata["tracker_simulation_search"]
            );

            // free the search
            setToken("start_simulation_hybrid_remote_dsm_tracker", "true");

            // start the search explicitely
            searchHybridRemoteTrackerDsmTest.startSearch();

            // show the view
            $("#divHybridRemoteTrackerDsmTest").css("display", "inherit");

            //
          },
          error: function (xhr, textStatus, error) {
            $("#cssloader").remove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            notify("error", "bottom", message, "30");
          },
        });
      });

    // burn test peformance benchmark
    $("#btn_modal_input_hybrid_remote_dsm_add_burn_test_show")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_dsm"
        );
        var tk_hybrid_search_mode = getToken(
          "tk_input_hybrid_remote_search_dsm_mode"
        );

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dsm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_dsm_break_by_field"
        );

        // only for tstats but has no effects on raw
        var tk_hybrid_dsm_tstats_root_span = getToken(
          "tk_hybrid_dsm_tstats_root_span"
        );
        var tk_hybrid_dsm_include_splunk_server = getToken(
          "tk_hybrid_dsm_include_splunk_server"
        );
        var tk_hybrid_dsm_include_host = getToken("tk_hybrid_dsm_include_host");

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_latest"
        );

        var tk_hybrid_index_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_index_earliest"
        );
        var tk_hybrid_index_latest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_index_latest"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_dsm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_dsm_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dsm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          dsm_tstats_root_time_span: tk_hybrid_dsm_tstats_root_span,
          dsm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dsm_include_splunk_server,
          dsm_tstats_root_breakby_include_host: tk_hybrid_dsm_include_host,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          index_earliest_time: tk_hybrid_index_earliest,
          index_latest_time: tk_hybrid_index_latest,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
          burn_test_runsearch: "False",
        };

        // set divs
        parentDiv = "divParentCreateDsmHybridBurnTestShow";
        spinnerDiv = "divCreateDsmHybridBurnTestShowLoader";
        childDiv = "divCreateDsmHybridBurnTestShow";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while retrieving the burn test benchmark search, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "success",
              "bottom",
              "Review the burn benchmark search, the root constraint macro has been expanded and replaced automatically, click on Burn test benchmark to execute the search effectively.",
              "5"
            );
            // show
            // creation via template
            $("#" + childDiv).html("<pre>" + returneddata["search"] + "</pre>");
            $("#" + childDiv).css("display", "inherit");
          },
          error: function (xhr, textStatus, error) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "error",
              "bottom",
              "Failed to run the burn test performance benchmark.",
              "5"
            );
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
        });
      });

    // burn test peformance benchmark
    // Splunk Cloud tends to gen time out here due to the Web proxy, we use a search instead for splk-feeds which remain simple enough
    $("#btn_modal_input_hybrid_remote_dsm_add_burn_test")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_dsm"
        );
        var tk_hybrid_search_mode = getToken(
          "tk_input_hybrid_remote_search_dsm_mode"
        );

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dsm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_dsm_break_by_field"
        );

        // only for tstats but has no effects on raw
        var tk_hybrid_dsm_tstats_root_span = getToken(
          "tk_hybrid_dsm_tstats_root_span"
        );
        var tk_hybrid_dsm_include_splunk_server = getToken(
          "tk_hybrid_dsm_include_splunk_server"
        );
        var tk_hybrid_dsm_include_host = getToken("tk_hybrid_dsm_include_host");

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_latest"
        );

        var tk_hybrid_index_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_index_earliest"
        );
        var tk_hybrid_index_latest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_index_latest"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_dsm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_dsm_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dsm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          dsm_tstats_root_time_span: tk_hybrid_dsm_tstats_root_span,
          dsm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dsm_include_splunk_server,
          dsm_tstats_root_breakby_include_host: tk_hybrid_dsm_include_host,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          index_earliest_time: tk_hybrid_index_earliest,
          index_latest_time: tk_hybrid_index_latest,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
        };

        // Define the query
        var searchQuery =
          '| trackme url="/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create" mode="post" body="' +
          JSON.stringify(record).replace(/"/g, '\\"') +
          '"| table _raw';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // set divs
        parentDiv = "divParentCreateDsmHybridBurnTest";
        spinnerDiv = "divCreateDsmHybridBurnTestLoader";
        childDiv = "divCreateDsmHybridBurnTest";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while running the Hybrid tracker burn test performance benchmark, once the job is terminated, review the run time performance, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        // Run a oneshot search that returns the job's results
        service.search(searchQuery, searchParams, function (err, job) {
          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            // notify error
            message =
              "ERROR: hum, something went quite wrong there! Splunk returned an error while while attempting to run the search: " +
              errorStr;
            notify("error", "bottom", message, "30");
            console.error("Review the Splunk search query: " + searchQuery);
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Get the results
                  job.results({}, function (err, results, job) {
                    var fields = results.fields;
                    var rows = results.rows;
                    var jobResult;
                    for (var i = 0; i < rows.length; i++) {
                      var values = rows[i];
                      for (var j = 0; j < values.length; j++) {
                        var field = fields[j];
                        var value = values[j];
                        // get the _raw
                        if (field === "_raw") {
                          jobResult = value;
                        }
                      }

                      // hide
                      $("#" + spinnerDiv).css("display", "none");
                      // notify
                      notify(
                        "success",
                        "bottom",
                        "Burn benchmark is now terminated, review the run time performance results.",
                        "5"
                      );
                      // show
                      // creation via template
                      $("#" + childDiv).html(
                        '<pre class="create-cim-json-rules-preview">' +
                          syntaxHighlight(
                            JSON.stringify(JSON.parse(jobResult), null, 2)
                          ) +
                          "</pre>"
                      );
                      $("#" + childDiv).css("display", "inherit");
                    }

                    // no results were found or we have no _raw
                    if (
                      jobResult == "" ||
                      typeof jobResult === "undefined" ||
                      jobResult == "null"
                    ) {
                      // hide
                      $("#" + spinnerDiv).css("display", "none");
                      // notify
                      notify(
                        "error",
                        "bottom",
                        "Failed to run the burn test performance benchmark.",
                        "5"
                      );
                      // creation via template
                      $("#" + childDiv).html(
                        '<pre class="create-cim-json-rules-preview">' +
                          syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                          "</pre>"
                      );
                      $("#" + childDiv).css("display", "inherit");
                    }
                  });
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }

                  // hide
                  $("#" + spinnerDiv).css("display", "none");
                  // notify
                  notify(
                    "error",
                    "bottom",
                    "Failed to run the burn test performance benchmark.",
                    "5"
                  );
                  // creation via template
                  $("#" + childDiv).html("<pre>" + err + "</pre>");
                  $("#" + childDiv).css("display", "inherit");
                },
                error: function (err) {
                  done(err);

                  // hide
                  $("#" + spinnerDiv).css("display", "none");
                  // notify
                  notify(
                    "error",
                    "bottom",
                    "Failed to run the burn test performance benchmark.",
                    "5"
                  );
                  // creation via template
                  $("#" + childDiv).html("<pre>" + err + "</pre>");
                  $("#" + childDiv).css("display", "inherit");
                },
              }
            );
          }
        });
      });

    // Create the new hybrid tracker
    $("#btn_modal_input_hybrid_remote_dsm_add_new")
      .unbind()
      .click(function () {
        // show modal
        $("#modal_confirm_hybrid_tracker_dsm").modal();
      });

    // Create the new hybrid remote tracker
    $("#btn_modal_input_hybrid_remote_dsm_add_new_confirm")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_dsm"
        );
        var tk_hybrid_search_mode = getToken(
          "tk_input_hybrid_remote_search_dsm_mode"
        );

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dsm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_dsm_break_by_field"
        );

        // only for tstats but has no effects on raw
        var tk_hybrid_dsm_tstats_root_span = getToken(
          "tk_hybrid_dsm_tstats_root_span"
        );
        var tk_hybrid_dsm_include_splunk_server = getToken(
          "tk_hybrid_dsm_include_splunk_server"
        );
        var tk_hybrid_dsm_include_host = getToken("tk_hybrid_dsm_include_host");

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_latest"
        );

        var tk_hybrid_index_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_index_earliest"
        );
        var tk_hybrid_index_latest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_index_latest"
        );

        var tk_hybrid_cron_schedule = getToken(
          "tk_input_hybrid_remote_tracker_dsm_cron"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_dsm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_dsm_creation_comment");

        // spinner
        cssloader("Please wait while creating the hybrid tracker...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dsm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          dsm_tstats_root_time_span: tk_hybrid_dsm_tstats_root_span,
          dsm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dsm_include_splunk_server,
          dsm_tstats_root_breakby_include_host: tk_hybrid_dsm_include_host,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          index_earliest_time: tk_hybrid_index_earliest,
          index_latest_time: tk_hybrid_index_latest,
          cron_schedule: tk_hybrid_cron_schedule,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // get tracker from response
            var tk_tracker_name = returneddata.tracker_report;
            // set token for later usage
            setToken("tk_hybrid_final_report", tk_tracker_name);
            // notify
            var msg =
              "The new tracker " +
              tk_tracker_name +
              " has been created successfully.";
            notify("success", "bottom", msg, "5");
            // set the message to be returned and show modal
            $("#modal_hybrid_tracker_dsm_creation_success")
              .find(".modal-success-message p")
              .text(JSON.stringify(returneddata));
            closeModals();
            cssloaderremove();
            $("#modal_hybrid_tracker_dsm_creation_success").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add hybrid remote tracker";
            object = tk_hybrid_tracker_name;
            object_category = "hybrid_tracker";
            object_attrs = JSON.stringify(record, null, "\t");
            result = message;
            comment = tk_comment;
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // run hybrid tracker now
    $("#modal_hybrid_tracker_dsm_run_tracker")
      .unbind()
      .click(function () {
        // Get the tracker name
        var tk_tracker_name = getToken("tk_hybrid_final_report");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // get earliest and latest, as defined during the creation
        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dsm_latest"
        );

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the hybrid tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    //
    // Manage hybrid trackers
    //

    $("#btn_modal_hybrid_remote_tracker_dsm_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
        };
        hybridTrackingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/hybrid_tracker_show",
          "POST",
          record,
          "dsm"
        );
      });

    // back
    $("#btn_modal_hybrid_dsm_back")
      .unbind()
      .click(function () {
        $("#modify_hybrid_trackers_main_dsm").modal();
      });

    // mass delete
    $("#btn_confirm_modal_hybrid_dsm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_hybrid_dsm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_hybrid_dsm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dsm",
          hybrid_trackers_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete hybrid tracker",
          tk_multi_table_array,
          "hybrid",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Hybrid tracker(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              hybridTrackingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/hybrid_tracker_show",
                "POST",
                record,
                "dsm"
              );
            }
          }
        });
      });

    // wlk

    // show apps management modal
    $(".btn_modify_apps_wlk_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);
        var record = {
          tenant_id: getToken("tenant_id"),
        };
        splkWlkAppsManageTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_apps_enablement",
          "POST",
          record,
          "wlk"
        );
      });
    });

    $("#btn_confirm_modal_wlk_apps_enablement_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_wlk_apps_management_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_apps_enablement_bulk_edit";

        // retrieve comment, if any
        comment = getComment("comment_modal_wlk_apps_enablement_confirm_save");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          json_data: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update workload apps enablement",
          tk_multi_table_array,
          "wlk",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Workload Apps enablement successfully updated.",
                "5"
              );
              // refresh the tabulator
              splkWlkAppsManageTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_apps_enablement",
                "POST",
                { tenant_id: tk_tenant_id }
              );
              // Once the job is done, update all searches
              searchSplkWlkMain.startSearch();
              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();
            }
          }
        });
      });

    $("#btn_confirm_modal_wlk_apps_enablement_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_wlk_apps_management_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_apps_enablement_delete";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_wlk_apps_enablement_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          apps_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update workload apps enablement",
          tk_multi_table_array,
          "wlk",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Workload Apps enablement successfully updated.",
                "5"
              );
              // refresh the tabulator
              splkWlkAppsManageTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_apps_enablement",
                "POST",
                { tenant_id: tk_tenant_id }
              );
              // Once the job is done, update all searches
              searchSplkWlkMain.startSearch();
              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();
            }
          }
        });
      });

    // show main modal
    $(".btn_modify_hybrid_trackers_wlk_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);
        setToken("start_modify_hybrid_trackers", "true");
        // Show input modal
        $("#modify_hybrid_trackers_main_wlk").modal();
      });
    });

    // show add new remote tracker modal
    $("#btn_modal_hybrid_remote_tracker_wlk_add")
      .unbind()
      .click(function () {
        // get the number of active hybrid trackers
        var license_is_valid = licenseCall["license_is_valid"];
        var license_active_flex_trackers =
          licenseCall["license_active_flex_trackers"];
        var license_subscription_class =
          licenseCall["license_subscription_class"];

        // proceed
        if (
          license_active_flex_trackers >= 32 &&
          license_subscription_class === "enterprise"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_flex_trackers +
                " active Flex trackers in total and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 32 active Flex trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid Unlimited license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else {
          // Allow populating search
          setToken("show_configuration_account_wlk", "true");
          // force refresh search
          searchPopulateConfigurationAccountWlk.startSearch();
          // Show input modal
          $("#add_hybrid_remote_tracker_wlk").modal();
          // disable creation button
          document.getElementById(
            "btn_modal_input_hybrid_remote_wlk_add_new"
          ).disabled = true;
        }
      });

    // go back to main from hybrid remote new tracker
    $("#btn_modal_hybrid_remote_tracker_wlk_add_new_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_hybrid_trackers_main_wlk").modal();
      });

    // simulate remote tracker
    $("#btn_modal_input_hybrid_remote_wlk_add_simulate")
      .unbind()
      .click(function () {
        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_wlk"
        ).value;

        // if unset, but users continues
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "(host=* splunk_server=*)";
        }

        // set tracker_type
        tk_tracker_type = getToken("tk_input_hybrid_remote_tracker_wlk_type");

        // set earliest and latest
        if (
          tk_tracker_type === "introspection" ||
          tk_tracker_type === "scheduler"
        ) {
          setToken("tk_input_hybrid_remote_tracker_wlk_earliest", "-10m");
          setToken("tk_input_hybrid_remote_tracker_wlk_latest", "now");
        } else if (tk_tracker_type === "notable") {
          setToken("tk_input_hybrid_remote_tracker_wlk_earliest", "-24h");
          setToken("tk_input_hybrid_remote_tracker_wlk_latest", "now");
        } else if (tk_tracker_type === "splunkcloud_svc") {
          setToken("tk_input_hybrid_remote_tracker_wlk_earliest", "-3h");
          setToken("tk_input_hybrid_remote_tracker_wlk_latest", "now");
        }

        var record = {
          run_simulation: false,
          component: "wlk",
          tenant_id: getToken("tenant_id"),
          tracker_type: tk_tracker_type,
          account: getToken("tk_input_hybrid_remote_wlk_account"),
          root_constraint: tk_hybrid_root_constraint,
        };

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while starting some Splunky searches!",
          "30"
        );

        // Retrieve entity info from REST and set actions
        $.ajax({
          url: "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/admin/wlk_tracker_simulation",
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // search results
            simulation_results = returneddata["results"];

            setToken(
              "tk_hybrid_remote_tracker_simulation_search",
              returneddata["tracker_simulation_search"]
            );

            // free the search
            setToken("start_simulation_hybrid_remote_wlk_tracker", "true");

            // start the search explicitely
            searchHybridRemoteTrackerWlkTest.startSearch();

            // show the view
            $("#divHybridRemoteTrackerWlkTest").css("display", "inherit");

            //
          },
          error: function (xhr, textStatus, error) {
            $("#cssloader").remove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            notify("error", "bottom", message, "30");
          },
        });
      });

    // burn test peformance benchmark
    $("#btn_modal_input_hybrid_remote_wlk_add_burn_test")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_wlk"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "(host=* splunk_server=*)";
        }

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_wlk_account");

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_wlk_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/admin/wlk_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "wlk",
          tracker_type: getToken("tk_input_hybrid_remote_tracker_wlk_type"),
          account: tk_hybrid_account,
          root_constraint: tk_hybrid_root_constraint,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
        };

        // set divs
        parentDiv = "divParentCreateWlkHybridBurnTest";
        spinnerDiv = "divCreateWlkHybridBurnTestLoader";
        childDiv = "divCreateWlkHybridBurnTest";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while running the Hybrid tracker burn test performance benchmark, once the job is terminated, review the run time performance, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "success",
              "bottom",
              "Burn benchmark is now terminated, review the run time performance results.",
              "5"
            );
            // show
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
          error: function (xhr, textStatus, error) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "error",
              "bottom",
              "Failed to run the burn test performance benchmark.",
              "5"
            );
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
        });
      });

    // Create the new hybrid tracker
    $("#btn_modal_input_hybrid_remote_wlk_add_new")
      .unbind()
      .click(function () {
        // show modal
        $("#modal_confirm_hybrid_tracker_wlk").modal();
      });

    // Create the new hybrid remote tracker
    $("#btn_modal_input_hybrid_remote_wlk_add_new_confirm")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_wlk"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        // This is not a Splunk form
        var tk_hybrid_overgroup = document.getElementById(
          "modal_input_hybrid_overgroup_wlk"
        ).value;

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_wlk_creation_comment");

        // spinner
        cssloader("Please wait while creating the hybrid tracker...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/admin/wlk_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "wlk",
          tracker_type: getToken("tk_input_hybrid_remote_tracker_wlk_type"),
          account: getToken("tk_input_hybrid_remote_wlk_account"),
          root_constraint: tk_hybrid_root_constraint,
          overgroup: tk_hybrid_overgroup,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // get tracker from response
            var tk_tracker_name = returneddata.tracker_report;
            // set token for later usage
            setToken("tk_hybrid_final_report", tk_tracker_name);
            // notify
            var msg =
              "The new tracker " +
              tk_tracker_name +
              " has been created successfully.";
            notify("success", "bottom", msg, "5");
            // set the message to be returned and show modal
            $("#modal_hybrid_tracker_wlk_creation_success")
              .find(".modal-success-message p")
              .text(JSON.stringify(returneddata));
            closeModals();
            cssloaderremove();
            $("#modal_hybrid_tracker_wlk_creation_success").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add hybrid remote tracker";
            object = getToken("tk_input_hybrid_remote_tracker_wlk_type");
            object_category = "hybrid_tracker";
            object_attrs = JSON.stringify(record, null, "\t");
            result = message;
            comment = tk_comment;
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // run hybrid tracker now
    $("#modal_hybrid_tracker_wlk_run_tracker")
      .unbind()
      .click(function () {
        // Get the tracker name
        var tk_tracker_name = getToken("tk_hybrid_final_report");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // get earliest and latest, as defined during the creation
        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_wlk_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_wlk_latest"
        );

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the hybrid tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkWlkMain.startSearch();
                  // refresh tabulator
                  $("#splk-wlk-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // flx

    // show main modal
    $(".btn_modify_hybrid_trackers_flx_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("start_modify_hybrid_trackers", "true");

        // Show input modal
        $("#modify_hybrid_trackers_main_flx").modal();
      });
    });

    // show add new remote tracker modal
    $("#btn_modal_hybrid_remote_tracker_flx_add")
      .unbind()
      .click(function () {
        // get the number of active hybrid trackers
        var license_is_valid = licenseCall["license_is_valid"];
        var license_active_flex_trackers =
          licenseCall["license_active_flex_trackers"];
        var license_subscription_class =
          licenseCall["license_subscription_class"];

        // proceed
        if (
          license_active_flex_trackers >= 32 &&
          license_subscription_class === "enterprise"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_flex_trackers +
                " active Flex trackers in total and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 32 active Flex trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid Unlimited license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else {
          // clear out textarea
          document.getElementById(
            "modal_input_hybrid_remote_tracker_flx_name"
          ).value = "";
          // Allow populating search
          setToken("show_configuration_account_flx", "true");
          // force refresh search
          searchPopulateConfigurationAccountFlx.startSearch();
          // populare uc dropdowns
          searchFlxLoadUseCases.startSearch();
          // Show input modal
          $("#add_hybrid_remote_tracker_flx").modal();
          // disable creation button
          document.getElementById(
            "btn_modal_input_hybrid_remote_flx_add_new"
          ).disabled = true;
          // preset a random name for the flex object tracker
          let myobject = "my_flx_object_"; // Replace this with your actual object.
          let randomDigits = Math.floor(Math.random() * 900) + 100;
          let flxObjectKey = myobject + randomDigits.toString();
          $("#modal_input_hybrid_remote_tracker_flx_name").val(flxObjectKey);
        }
      });

    // copy example1 to clipboard
    $("#btn_flx_copy_example1")
      .unbind()
      .click(function () {
        var content = $("#flx_example1").text();
        copyToClipboard(content);
      });

    // go back to main from hybrid remote new tracker
    $("#btn_modal_hybrid_remote_tracker_flx_add_new_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_hybrid_trackers_main_flx").modal();
      });

    // verify that the tracker is unique
    $(function () {
      $("#modal_input_hybrid_remote_tracker_flx_name").keyup(function () {
        if ($(this).val() == "") {
          // Check to see if there is any text entered
          // If there is no text within the input ten disable the button
          $("#btn_modal_input_hybrid_remote_flx_add_simulate").prop(
            "disabled",
            true
          );
        } else {
          // Perform a query and verify if this tenant exists already

          var tracker_name = $(this).val();
          // replace some chars, the API endpoint will do the same
          tracker_name = tracker_name.replace(/" "/g, "-");
          tracker_name = tracker_name.replace(/":"/g, "-");

          var queryString = encodeURI(
            '{ "tracker_id": "' + tracker_name + '" }'
          );
          var myendpoint_URl =
            "/en-US/splunkd/__raw/servicesNS/nobody/trackme/storage/collections/data/kv_trackme_flx_hybrid_trackers_tenant_" +
            getToken("tenant_id") +
            "?query=" +
            queryString;
          $.ajax({
            url: myendpoint_URl,
            type: "GET",
            async: true,
            contentType: "application/json",
            success: function (returneddata) {
              if (returneddata.length > 0) {
                notify(
                  "error",
                  "bottom",
                  "ERROR: A tracker with the same identifier already exists, it has to be unique for this tenant, update the tracker name to continue!",
                  "600"
                );
                $("#btn_modal_input_hybrid_remote_flx_add_simulate").prop(
                  "disabled",
                  true
                );
              } else {
                notify(
                  "success",
                  "bottom",
                  "OK! This tracker name is valid and does not exist yet in this tenant",
                  "5"
                );
                $("#btn_modal_input_hybrid_remote_flx_add_simulate").prop(
                  "disabled",
                  false
                );
              }
            },
            error: function (xhr, textStatus, error) {
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              notify(
                "error",
                "bottom",
                "ERROR: failure to communicate with Splunk daemon! " + message,
                "600"
              );
              $("#btn_modal_input_hybrid_remote_flx_add_simulate").prop(
                "disabled",
                true
              );
            },
          });
        }
      });
    });

    // simulate remote tracker
    $("#btn_modal_input_hybrid_remote_flx_add_simulate")
      .unbind()
      .click(function () {
        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_flx"
        ).value;

        // if unset, but users continues
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var record = {
          run_simulation: false,
          component: "flx",
          tenant_id: getToken("tenant_id"),
          tracker_name: document.getElementById(
            "modal_input_hybrid_remote_tracker_flx_name"
          ).value,
          account: getToken("tk_input_hybrid_remote_flx_account"),
          earliest_time: getToken(
            "tk_input_hybrid_remote_tracker_flx_earliest"
          ),
          latest_time: getToken("tk_input_hybrid_remote_tracker_flx_latest"),
          cron_schedule: getToken("tk_input_hybrid_remote_tracker_flx_cron"),
          search_constraint: tk_hybrid_root_constraint,
        };

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while starting some Splunky searches!",
          "30"
        );

        // Retrieve entity info from REST and set actions
        $.ajax({
          url: "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/admin/flx_tracker_simulation",
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // search results
            simulation_results = returneddata["results"];

            setToken(
              "tk_hybrid_remote_tracker_simulation_search",
              returneddata["tracker_simulation_search"]
            );

            // free the search
            setToken("start_simulation_hybrid_remote_flx_tracker", "true");

            // start the search explicitely
            searchHybridRemoteTrackerFlxTest.startSearch();

            // show the view
            $("#divHybridRemoteTrackerFlxTest").css("display", "inherit");

            //
          },
          error: function (xhr, textStatus, error) {
            $("#cssloader").remove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            notify("error", "bottom", message, "30");
          },
        });
      });

    // burn test peformance benchmark
    $("#btn_modal_input_hybrid_remote_flx_add_burn_test")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = document.getElementById(
          "modal_input_hybrid_remote_tracker_flx_name"
        ).value;

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_flx"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_flx_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_flx_latest"
        );
        var tk_hybrid_cron_schedule = getToken(
          "tk_input_hybrid_remote_tracker_flx_cron"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_flx_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_flx_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/admin/flx_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "flx",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          root_constraint: tk_hybrid_root_constraint,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          cron_schedule: tk_hybrid_cron_schedule,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
        };

        // set divs
        parentDiv = "divParentCreateFlxHybridBurnTest";
        spinnerDiv = "divCreateFlxHybridBurnTestLoader";
        childDiv = "divCreateFlxHybridBurnTest";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while running the Hybrid tracker burn test performance benchmark, once the job is terminated, review the run time performance, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "success",
              "bottom",
              "Burn benchmark is now terminated, review the run time performance results.",
              "5"
            );
            // show
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
          error: function (xhr, textStatus, error) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "error",
              "bottom",
              "Failed to run the burn test performance benchmark.",
              "5"
            );
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
        });
      });

    // Create the new hybrid tracker
    $("#btn_modal_input_hybrid_remote_flx_add_new")
      .unbind()
      .click(function () {
        // show modal
        $("#modal_confirm_hybrid_tracker_flx").modal();
      });

    // Create the new hybrid remote tracker
    $("#btn_modal_input_hybrid_remote_flx_add_new_confirm")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = document.getElementById(
          "modal_input_hybrid_remote_tracker_flx_name"
        ).value;

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_flx"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_flx_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_flx_latest"
        );
        var tk_hybrid_cron_schedule = getToken(
          "tk_input_hybrid_remote_tracker_flx_cron"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_flx_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_flx_creation_comment");

        // spinner
        cssloader("Please wait while creating the hybrid tracker...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/admin/flx_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "flx",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          root_constraint: tk_hybrid_root_constraint,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          cron_schedule: tk_hybrid_cron_schedule,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // get tracker from response
            var tk_tracker_name = returneddata.tracker_report;
            // set token for later usage
            setToken("tk_hybrid_final_report", tk_tracker_name);
            // notify
            var msg =
              "The new tracker " +
              tk_tracker_name +
              " has been created successfully.";
            notify("success", "bottom", msg, "5");
            // set the message to be returned and show modal
            $("#modal_hybrid_tracker_flx_creation_success")
              .find(".modal-success-message p")
              .text(JSON.stringify(returneddata));
            closeModals();
            cssloaderremove();
            $("#modal_hybrid_tracker_flx_creation_success").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add hybrid remote tracker";
            object = tk_hybrid_tracker_name;
            object_category = "hybrid_tracker";
            object_attrs = JSON.stringify(record, null, "\t");
            result = message;
            comment = tk_comment;
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // run hybrid tracker now
    $("#modal_hybrid_tracker_flx_run_tracker")
      .unbind()
      .click(function () {
        // Get the tracker name
        var tk_tracker_name = getToken("tk_hybrid_final_report");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // get earliest and latest, as defined during the creation
        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_flx_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_flx_latest"
        );

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the hybrid tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkFlxMain.startSearch();
                  // refresh tabulator
                  $("#splk-flx-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    //
    // Manage hybrid trackers
    //

    $("#btn_modal_hybrid_remote_tracker_flx_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
        };
        hybridTrackingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/flx_tracker_show",
          "POST",
          record,
          "flx"
        );
      });

    // back
    $("#btn_modal_hybrid_flx_back")
      .unbind()
      .click(function () {
        $("#modify_hybrid_trackers_main_flx").modal();
      });

    // mass delete
    $("#btn_confirm_modal_hybrid_flx_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_hybrid_flx_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/admin/flx_tracker_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_hybrid_flx_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          hybrid_trackers_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete hybrid tracker",
          tk_multi_table_array,
          "hybrid",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Hybrid tracker(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              hybridTrackingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/flx_tracker_show",
                "POST",
                record,
                "flx"
              );
            }
          }
        });
      });

    //
    // Manage hybrid trackers
    //

    $("#btn_modal_hybrid_remote_tracker_wlk_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
        };
        hybridTrackingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_tracker_show",
          "POST",
          record,
          "wlk"
        );
      });

    // back from manage hybrid trackers
    $("#btn_modal_hybrid_wlk_back")
      .unbind()
      .click(function () {
        $("#modify_hybrid_trackers_main_wlk").modal();
      });

    // back from create hybrid trackers
    $("#btn_run_hybrid_tracker_wlk_back")
      .unbind()
      .click(function () {
        $("#modify_hybrid_trackers_main_wlk").modal();
      });

    // mass delete
    $("#btn_confirm_modal_hybrid_wlk_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_hybrid_wlk_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/admin/wlk_tracker_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_hybrid_wlk_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          hybrid_trackers_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete hybrid tracker",
          tk_multi_table_array,
          "hybrid",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Hybrid tracker(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              hybridTrackingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/wlk_tracker_show",
                "POST",
                record,
                "wlk"
              );
            }
          }
        });
      });

    // dhm

    // show main modal
    $(".btn_modify_hybrid_trackers_dhm_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("start_modify_hybrid_trackers", "true");

        // Show input modal
        $("#modify_hybrid_trackers_main_dhm").modal();
      });
    });

    // show add new remote tracker modal
    $("#btn_modal_hybrid_remote_tracker_dhm_add")
      .unbind()
      .click(function () {
        // get the number of active hybrid trackers
        var license_is_valid = licenseCall["license_is_valid"];
        var license_active_hybrid_trackers =
          licenseCall["license_active_splk_dhm_hybrid_trackers"];
        var license_active_hybrid_trackers_total =
          licenseCall["license_active_hybrid_trackers"];
        var license_subscription_class =
          licenseCall["license_subscription_class"];

        // proceed
        if (license_active_hybrid_trackers >= 2 && license_is_valid != 1) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers +
                " splk-dhm active hybrid trackers and this deployment is currently running in Free limited edition mode. The Free limited edition mode is limited to 2 active hybrid trackers per component at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_hybrid_trackers_total >= 6 &&
          license_subscription_class === "free_extended"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers_total +
                " active hybrid trackers in total and this deployment is currently running in Free extended edition mode. The Free extended edition mode is limited to 6 active hybrid trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_hybrid_trackers_total >= 16 &&
          license_subscription_class === "enterprise"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers_total +
                " active hybrid trackers in total and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 16 active hybrid trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid Unlimited license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else {
          // Allow populating search
          setToken("show_configuration_account_dhm", "true");
          // force refresh search
          searchPopulateConfigurationAccountDhm.startSearch();
          // disable creation button
          document.getElementById(
            "btn_modal_input_hybrid_remote_dhm_add_new"
          ).disabled = true;
          // Show input modal
          $("#add_hybrid_remote_tracker_dhm").modal();
        }
      });

    // go back to main from hybrid remote new tracker
    $("#btn_modal_hybrid_remote_tracker_dhm_add_new_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_hybrid_trackers_main_dhm").modal();
      });

    // simulate remote tracker
    $("#btn_modal_input_hybrid_remote_dhm_add_simulate")
      .unbind()
      .click(function () {
        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dhm"
        ).value;

        // if unset, but users continues
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        // set record
        var record = {
          run_simulation: false,
          component: "dhm",
          account: getToken("tk_input_hybrid_remote_dhm_account"),
          search_mode: getToken("tk_input_hybrid_remote_search_dhm_mode"),
          earliest_time: getToken(
            "tk_input_hybrid_remote_tracker_dhm_earliest"
          ),
          latest_time: getToken("tk_input_hybrid_remote_tracker_dhm_latest"),
          cron_schedule: getToken("tk_input_hybrid_remote_tracker_dhm_cron"),
          index_earliest_time: getToken(
            "tk_input_hybrid_remote_tracker_dhm_index_earliest"
          ),
          index_latest_time: getToken(
            "tk_input_hybrid_remote_tracker_dhm_index_latest"
          ),
          search_constraint: tk_hybrid_root_constraint,
          breakby_field: getToken("tk_input_hybrid_remote_dhm_break_by_field"),
        };

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while starting some Splunky searches!",
          "30"
        );

        // Retrieve entity info from REST and set actions
        $.ajax({
          url: "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_simulation",
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // search results
            simulation_results = returneddata["results"];

            setToken(
              "tk_hybrid_remote_tracker_simulation_search",
              returneddata["tracker_simulation_search"]
            );

            // free the search
            setToken("start_simulation_hybrid_remote_dhm_tracker", "true");

            // start the search explicitely
            searchHybridRemoteTrackerDhmTest.startSearch();

            // show the view
            $("#divHybridRemoteTrackerDhmTest").css("display", "inherit");

            //
          },
          error: function (xhr, textStatus, error) {
            $("#cssloader").remove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            notify("error", "bottom", message, "30");
          },
        });
      });

    // burn test peformance benchmark show
    $("#btn_modal_input_hybrid_remote_dhm_add_burn_test_show")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_dhm"
        );
        var tk_hybrid_search_mode = getToken(
          "tk_input_hybrid_remote_search_dhm_mode"
        );

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dhm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_dhm_break_by_field"
        );

        // only for tstats but has no effects on raw
        var tk_hybrid_dhm_tstats_root_span = getToken(
          "tk_hybrid_dhm_tstats_root_span"
        );
        var tk_hybrid_dhm_include_splunk_server = getToken(
          "tk_hybrid_dhm_include_splunk_server"
        );

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_latest"
        );

        var tk_hybrid_index_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_index_earliest"
        );
        var tk_hybrid_index_latest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_index_latest"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_dhm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_dhm_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dhm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          dhm_tstats_root_time_span: tk_hybrid_dhm_tstats_root_span,
          dhm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dhm_include_splunk_server,
          dhm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dhm_include_splunk_server,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          index_earliest_time: tk_hybrid_index_earliest,
          index_latest_time: tk_hybrid_index_latest,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
          burn_test_runsearch: "False",
        };

        // set divs
        parentDiv = "divParentCreateDhmHybridBurnTestShow";
        spinnerDiv = "divCreateDhmHybridBurnTestShowLoader";
        childDiv = "divCreateDhmHybridBurnTestShow";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while retrieving the burn test benchmark search, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "success",
              "bottom",
              "Review the burn benchmark search, the root constraint macro has been expanded and replaced automatically, click on Burn test benchmark to execute the search effectively.",
              "5"
            );
            // show
            // creation via template
            $("#" + childDiv).html("<pre>" + returneddata["search"] + "</pre>");
            $("#" + childDiv).css("display", "inherit");
          },
          error: function (xhr, textStatus, error) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "error",
              "bottom",
              "Failed to run the burn test performance benchmark.",
              "5"
            );
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
        });
      });

    // burn test peformance benchmark
    // Splunk Cloud tends to gen time out here due to the Web proxy, we use a search instead for splk-feeds which remain simple enough
    $("#btn_modal_input_hybrid_remote_dhm_add_burn_test")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_dhm"
        );
        var tk_hybrid_search_mode = getToken(
          "tk_input_hybrid_remote_search_dhm_mode"
        );

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dhm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_dhm_break_by_field"
        );

        // only for tstats but has no effects on raw
        var tk_hybrid_dhm_tstats_root_span = getToken(
          "tk_hybrid_dhm_tstats_root_span"
        );
        var tk_hybrid_dhm_include_splunk_server = getToken(
          "tk_hybrid_dhm_include_splunk_server"
        );

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_latest"
        );

        var tk_hybrid_index_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_index_earliest"
        );
        var tk_hybrid_index_latest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_index_latest"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_dhm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_dhm_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dhm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          dhm_tstats_root_time_span: tk_hybrid_dhm_tstats_root_span,
          dhm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dhm_include_splunk_server,
          dhm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dhm_include_splunk_server,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          index_earliest_time: tk_hybrid_index_earliest,
          index_latest_time: tk_hybrid_index_latest,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
        };

        // Define the query
        var searchQuery =
          '| trackme url="/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create" mode="post" body="' +
          JSON.stringify(record).replace(/"/g, '\\"') +
          '"| table _raw';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // set divs
        parentDiv = "divParentCreateDhmHybridBurnTest";
        spinnerDiv = "divCreateDhmHybridBurnTestLoader";
        childDiv = "divCreateDhmHybridBurnTest";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while running the Hybrid tracker burn test performance benchmark, once the job is terminated, review the run time performance, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        // Run a oneshot search that returns the job's results
        service.search(searchQuery, searchParams, function (err, job) {
          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            // notify error
            message =
              "ERROR: hum, something went quite wrong there! Splunk returned an error while while attempting to run the search: " +
              errorStr;
            notify("error", "bottom", message, "30");
            console.error("Review the Splunk search query: " + searchQuery);
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Get the results
                  job.results({}, function (err, results, job) {
                    var fields = results.fields;
                    var rows = results.rows;
                    var jobResult;
                    for (var i = 0; i < rows.length; i++) {
                      var values = rows[i];
                      for (var j = 0; j < values.length; j++) {
                        var field = fields[j];
                        var value = values[j];
                        // get the _raw
                        if (field === "_raw") {
                          jobResult = value;
                        }
                      }

                      // hide
                      $("#" + spinnerDiv).css("display", "none");
                      // notify
                      notify(
                        "success",
                        "bottom",
                        "Burn benchmark is now terminated, review the run time performance results.",
                        "5"
                      );
                      // show
                      // creation via template
                      $("#" + childDiv).html(
                        '<pre class="create-cim-json-rules-preview">' +
                          syntaxHighlight(
                            JSON.stringify(JSON.parse(jobResult), null, 2)
                          ) +
                          "</pre>"
                      );
                      $("#" + childDiv).css("display", "inherit");
                    }

                    // no results were found or we have no _raw
                    if (
                      jobResult == "" ||
                      typeof jobResult === "undefined" ||
                      jobResult == "null"
                    ) {
                      // hide
                      $("#" + spinnerDiv).css("display", "none");
                      // notify
                      notify(
                        "error",
                        "bottom",
                        "Failed to run the burn test performance benchmark.",
                        "5"
                      );
                      // creation via template
                      $("#" + childDiv).html(
                        '<pre class="create-cim-json-rules-preview">' +
                          syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                          "</pre>"
                      );
                      $("#" + childDiv).css("display", "inherit");
                    }
                  });
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }

                  // hide
                  $("#" + spinnerDiv).css("display", "none");
                  // notify
                  notify(
                    "error",
                    "bottom",
                    "Failed to run the burn test performance benchmark.",
                    "5"
                  );
                  // creation via template
                  $("#" + childDiv).html("<pre>" + err + "</pre>");
                  $("#" + childDiv).css("display", "inherit");
                },
                error: function (err) {
                  done(err);

                  // hide
                  $("#" + spinnerDiv).css("display", "none");
                  // notify
                  notify(
                    "error",
                    "bottom",
                    "Failed to run the burn test performance benchmark.",
                    "5"
                  );
                  // creation via template
                  $("#" + childDiv).html("<pre>" + err + "</pre>");
                  $("#" + childDiv).css("display", "inherit");
                },
              }
            );
          }
        });
      });

    // Create the new hybrid tracker
    $("#btn_modal_input_hybrid_remote_dhm_add_new")
      .unbind()
      .click(function () {
        // show modal
        $("#modal_confirm_hybrid_tracker_dhm").modal();
      });

    // Create the new hybrid remote tracker
    $("#btn_modal_input_hybrid_remote_dhm_add_new_confirm")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_dhm"
        );
        var tk_hybrid_search_mode = getToken(
          "tk_input_hybrid_remote_search_dhm_mode"
        );

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_dhm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_dhm_break_by_field"
        );

        // only for tstats but has no effects on raw
        var tk_hybrid_dhm_tstats_root_span = getToken(
          "tk_hybrid_dhm_tstats_root_span"
        );
        var tk_hybrid_dhm_include_splunk_server = getToken(
          "tk_hybrid_dhm_include_splunk_server"
        );

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_latest"
        );

        var tk_hybrid_index_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_index_earliest"
        );
        var tk_hybrid_index_latest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_index_latest"
        );

        var tk_hybrid_cron_schedule = getToken(
          "tk_input_hybrid_remote_tracker_dhm_cron"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_dhm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_dhm_creation_comment");

        // spinner
        cssloader("Please wait while creating the hybrid tracker...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dhm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          dhm_tstats_root_time_span: tk_hybrid_dhm_tstats_root_span,
          dhm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dhm_include_splunk_server,
          dhm_tstats_root_breakby_include_splunk_server:
            tk_hybrid_dhm_include_splunk_server,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          index_earliest_time: tk_hybrid_index_earliest,
          index_latest_time: tk_hybrid_index_latest,
          cron_schedule: tk_hybrid_cron_schedule,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // get tracker from response
            var tk_tracker_name = returneddata.tracker_report;
            // set token for later usage
            setToken("tk_hybrid_final_report", tk_tracker_name);
            // notify
            var msg =
              "The new tracker " +
              tk_tracker_name +
              " has been created successfully.";
            notify("success", "bottom", msg, "5");
            // set the message to be returned and show modal
            $("#modal_hybrid_tracker_dhm_creation_success")
              .find(".modal-success-message p")
              .text(JSON.stringify(returneddata));
            closeModals();
            cssloaderremove();
            $("#modal_hybrid_tracker_dhm_creation_success").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add hybrid remote tracker";
            object = tk_hybrid_tracker_name;
            object_category = "hybrid_tracker";
            object_attrs = JSON.stringify(record, null, "\t");
            result = message;
            comment = tk_comment;
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // run hybrid tracker now
    $("#modal_hybrid_tracker_dhm_run_tracker")
      .unbind()
      .click(function () {
        // Get the tracker name
        var tk_tracker_name = getToken("tk_hybrid_final_report");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // get earliest and latest, as defined during the creation
        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_dhm_latest"
        );

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the hybrid tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dhm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    //
    // Manage hybrid trackers
    //

    $("#btn_modal_hybrid_remote_tracker_dhm_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
        };
        hybridTrackingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/hybrid_tracker_show",
          "POST",
          record,
          "dhm"
        );
      });

    // back
    $("#btn_modal_hybrid_dhm_back")
      .unbind()
      .click(function () {
        $("#modify_hybrid_trackers_main_dhm").modal();
      });

    // mass delete
    $("#btn_confirm_modal_hybrid_dhm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_hybrid_dhm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_hybrid_dhm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "dhm",
          hybrid_trackers_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete hybrid tracker",
          tk_multi_table_array,
          "hybrid",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Hybrid tracker(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              hybridTrackingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/hybrid_tracker_show",
                "POST",
                record,
                "dhm"
              );
            }
          }
        });
      });

    // mhm

    // show main modal
    $(".btn_modify_hybrid_trackers_mhm_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("start_modify_hybrid_trackers", "true");

        // Show input modal
        $("#modify_hybrid_trackers_main_mhm").modal();
      });
    });

    // show add new remote tracker modal
    $("#btn_modal_hybrid_remote_tracker_mhm_add")
      .unbind()
      .click(function () {
        // get the number of active hybrid trackers
        var license_is_valid = licenseCall["license_is_valid"];
        var license_active_hybrid_trackers =
          licenseCall["license_active_splk_mhm_hybrid_trackers"];
        var license_active_hybrid_trackers_total =
          licenseCall["license_active_hybrid_trackers"];
        var license_subscription_class =
          licenseCall["license_subscription_class"];

        // proceed
        if (license_active_hybrid_trackers >= 2 && license_is_valid != 1) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers +
                " splk-mhm active hybrid trackers and this deployment is currently running in Free limited edition mode. The Free limited edition mode is limited to 2 active hybrid trackers per component at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_hybrid_trackers_total >= 6 &&
          license_subscription_class === "free_extended"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers_total +
                " active hybrid trackers in total and this deployment is currently running in Free extended edition mode. The Free extended edition mode is limited to 6 active hybrid trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else if (
          license_active_hybrid_trackers_total >= 16 &&
          license_subscription_class === "enterprise"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_hybrid_trackers_total +
                " active hybrid trackers in total and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 16 active hybrid trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid Unlimited license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else {
          // Allow populating search
          setToken("show_configuration_account_mhm", "true");
          // force refresh search
          searchPopulateConfigurationAccountMhm.startSearch();
          // Show input modal
          $("#add_hybrid_remote_tracker_mhm").modal();
          // disable creation button
          document.getElementById(
            "btn_modal_input_hybrid_remote_mhm_add_new"
          ).disabled = true;
        }
      });

    // go back to main from hybrid remote new tracker
    $("#btn_modal_hybrid_remote_tracker_mhm_add_new_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_hybrid_trackers_main_mhm").modal();
      });

    // simulate remote tracker
    $("#btn_modal_input_hybrid_remote_mhm_add_simulate")
      .unbind()
      .click(function () {
        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_mhm"
        ).value;

        // if unset, but users continues
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        // set record
        var record = {
          run_simulation: false,
          component: "mhm",
          account: getToken("tk_input_hybrid_remote_mhm_account"),
          search_mode: "mstats",
          earliest_time: getToken(
            "tk_input_hybrid_remote_tracker_mhm_earliest"
          ),
          latest_time: getToken("tk_input_hybrid_remote_tracker_mhm_latest"),
          cron_schedule: getToken("tk_input_hybrid_remote_tracker_mhm_cron"),
          search_constraint: tk_hybrid_root_constraint,
          breakby_field: getToken("tk_input_hybrid_remote_mhm_break_by_field"),
        };

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while starting some Splunky searches!",
          "30"
        );

        // Retrieve entity info from REST and set actions
        $.ajax({
          url: "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_simulation",
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // search results
            simulation_results = returneddata["results"];

            setToken(
              "tk_hybrid_remote_tracker_simulation_search",
              returneddata["tracker_simulation_search"]
            );

            // free the search
            setToken("start_simulation_hybrid_remote_mhm_tracker", "true");

            // start the search explicitely
            searchHybridRemoteTrackerMhmTest.startSearch();

            // show the view
            $("#divHybridRemoteTrackerMhmTest").css("display", "inherit");

            //
          },
          error: function (xhr, textStatus, error) {
            $("#cssloader").remove();
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            notify("error", "bottom", message, "30");
          },
        });
      });

    // burn test peformance benchmark
    $("#btn_modal_input_hybrid_remote_mhm_add_burn_test_show")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_mhm"
        );

        // mhm is always mstats
        var tk_hybrid_search_mode = "mstats";

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_mhm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_mhm_break_by_field"
        );

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_latest"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_mhm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_mhm_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "mhm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
          burn_test_runsearch: "False",
        };

        // set divs
        parentDiv = "divParentCreateMhmHybridBurnTestShow";
        spinnerDiv = "divCreateMhmHybridBurnTestShowLoader";
        childDiv = "divCreateMhmHybridBurnTestShow";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while retrieving the burn test benchmark search, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "success",
              "bottom",
              "Review the burn benchmark search, the root constraint macro has been expanded and replaced automatically, click on Burn test benchmark to execute the search effectively.",
              "5"
            );
            // show
            // creation via template
            $("#" + childDiv).html("<pre>" + returneddata["search"] + "</pre>");
            $("#" + childDiv).css("display", "inherit");
          },
          error: function (xhr, textStatus, error) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "error",
              "bottom",
              "Failed to run the burn test performance benchmark.",
              "5"
            );
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
        });
      });

    // burn test peformance benchmark
    // Splunk Cloud tends to gen time out here due to the Web proxy, we use a search instead for splk-feeds which remain simple enough
    $("#btn_modal_input_hybrid_remote_mhm_add_burn_test")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_mhm"
        );

        // mhm is always mstats
        var tk_hybrid_search_mode = "mstats";

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_mhm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_mhm_break_by_field"
        );

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_latest"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_mhm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_mhm_creation_comment");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "mhm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
          burn_test: "True",
        };

        // Define the query
        var searchQuery =
          '| trackme url="/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create" mode="post" body="' +
          JSON.stringify(record).replace(/"/g, '\\"') +
          '"| table _raw';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // set divs
        parentDiv = "divParentCreateMhmHybridBurnTest";
        spinnerDiv = "divCreateMhmHybridBurnTestLoader";
        childDiv = "divCreateMhmHybridBurnTest";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while running the Hybrid tracker burn test performance benchmark, once the job is terminated, review the run time performance, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        // Run a oneshot search that returns the job's results
        service.search(searchQuery, searchParams, function (err, job) {
          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            // notify error
            message =
              "ERROR: hum, something went quite wrong there! Splunk returned an error while while attempting to run the search: " +
              errorStr;
            notify("error", "bottom", message, "30");
            console.error("Review the Splunk search query: " + searchQuery);
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Get the results
                  job.results({}, function (err, results, job) {
                    var fields = results.fields;
                    var rows = results.rows;
                    var jobResult;
                    for (var i = 0; i < rows.length; i++) {
                      var values = rows[i];
                      for (var j = 0; j < values.length; j++) {
                        var field = fields[j];
                        var value = values[j];
                        // get the _raw
                        if (field === "_raw") {
                          jobResult = value;
                        }
                      }

                      // hide
                      $("#" + spinnerDiv).css("display", "none");
                      // notify
                      notify(
                        "success",
                        "bottom",
                        "Burn benchmark is now terminated, review the run time performance results.",
                        "5"
                      );
                      // show
                      // creation via template
                      $("#" + childDiv).html(
                        '<pre class="create-cim-json-rules-preview">' +
                          syntaxHighlight(
                            JSON.stringify(JSON.parse(jobResult), null, 2)
                          ) +
                          "</pre>"
                      );
                      $("#" + childDiv).css("display", "inherit");
                    }

                    // no results were found or we have no _raw
                    if (
                      jobResult == "" ||
                      typeof jobResult === "undefined" ||
                      jobResult == "null"
                    ) {
                      // hide
                      $("#" + spinnerDiv).css("display", "none");
                      // notify
                      notify(
                        "error",
                        "bottom",
                        "Failed to run the burn test performance benchmark.",
                        "5"
                      );
                      // creation via template
                      $("#" + childDiv).html(
                        '<pre class="create-cim-json-rules-preview">' +
                          syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                          "</pre>"
                      );
                      $("#" + childDiv).css("display", "inherit");
                    }
                  });
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }

                  // hide
                  $("#" + spinnerDiv).css("display", "none");
                  // notify
                  notify(
                    "error",
                    "bottom",
                    "Failed to run the burn test performance benchmark.",
                    "5"
                  );
                  // creation via template
                  $("#" + childDiv).html("<pre>" + err + "</pre>");
                  $("#" + childDiv).css("display", "inherit");
                },
                error: function (err) {
                  done(err);

                  // hide
                  $("#" + spinnerDiv).css("display", "none");
                  // notify
                  notify(
                    "error",
                    "bottom",
                    "Failed to run the burn test performance benchmark.",
                    "5"
                  );
                  // creation via template
                  $("#" + childDiv).html("<pre>" + err + "</pre>");
                  $("#" + childDiv).css("display", "inherit");
                },
              }
            );
          }
        });
      });

    // Create the new hybrid tracker
    $("#btn_modal_input_hybrid_remote_mhm_add_new")
      .unbind()
      .click(function () {
        // show modal
        $("#modal_confirm_hybrid_tracker_mhm").modal();
      });

    // Create the new hybrid remote tracker
    $("#btn_modal_input_hybrid_remote_mhm_add_new_confirm")
      .unbind()
      .click(function () {
        // get the component owner
        var tk_tenant_owner = getToken("tk_tenant_owner");

        // get tracker infos
        var tk_hybrid_tracker_name = getToken(
          "tk_input_hybrid_remote_tracker_name_mhm"
        );

        // mhm is always mstats
        var tk_hybrid_search_mode = "mstats";

        // This is not a Splunk form
        var tk_hybrid_root_constraint = document.getElementById(
          "modal_input_hybrid_remote_root_constraint_mhm"
        ).value;

        // if unset
        if (
          tk_hybrid_root_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          tk_hybrid_root_constraint = "index=*";
        }

        var tk_hybrid_break_by_field = getToken(
          "tk_input_hybrid_remote_mhm_break_by_field"
        );

        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_latest"
        );

        var tk_hybrid_cron_schedule = getToken(
          "tk_input_hybrid_remote_tracker_mhm_cron"
        );

        // get the account
        var tk_hybrid_account = getToken("tk_input_hybrid_remote_mhm_account");

        // the type of tracker
        var tk_hybrid_tracker_type;
        if (tk_hybrid_account === "local") {
          tk_hybrid_tracker_type = "local";
        } else {
          tk_hybrid_tracker_type = "remote";
        }

        // Retrieve update comment if any
        var tk_comment = getComment("hybrid_tracker_mhm_creation_comment");

        // spinner
        cssloader("Please wait while creating the hybrid tracker...");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_create";

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "mhm",
          tracker_name: tk_hybrid_tracker_name,
          tracker_type: tk_hybrid_tracker_type,
          account: tk_hybrid_account,
          search_mode: tk_hybrid_search_mode,
          root_constraint: tk_hybrid_root_constraint,
          breakby_field: tk_hybrid_break_by_field,
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
          cron_schedule: tk_hybrid_cron_schedule,
          update_comment: tk_comment,
          owner: tk_tenant_owner,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // get tracker from response
            var tk_tracker_name = returneddata.tracker_report;
            // set token for later usage
            setToken("tk_hybrid_final_report", tk_tracker_name);
            // notify
            var msg =
              "The new tracker " +
              tk_tracker_name +
              " has been created successfully.";
            notify("success", "bottom", msg, "5");
            // set the message to be returned and show modal
            $("#modal_hybrid_tracker_mhm_creation_success")
              .find(".modal-success-message p")
              .text(JSON.stringify(returneddata));
            closeModals();
            cssloaderremove();
            $("#modal_hybrid_tracker_mhm_creation_success").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // Audit
            action = "failure";
            change_type = "add hybrid remote tracker";
            object = tk_hybrid_tracker_name;
            object_category = "hybrid_tracker";
            object_attrs = JSON.stringify(record, null, "\t");
            result = message;
            comment = tk_comment;
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
            closeModals();
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // run hybrid tracker now
    $("#modal_hybrid_tracker_mhm_run_tracker")
      .unbind()
      .click(function () {
        // Get the tracker name
        var tk_tracker_name = getToken("tk_hybrid_final_report");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // get earliest and latest, as defined during the creation
        var tk_hybrid_earliest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_earliest"
        );
        var tk_hybrid_latest = getToken(
          "tk_input_hybrid_remote_tracker_mhm_latest"
        );

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: tk_hybrid_earliest,
          latest_time: tk_hybrid_latest,
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the hybrid tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkMhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-mhm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    //
    // Manage hybrid trackers
    //

    $("#btn_modal_hybrid_remote_tracker_mhm_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "mhm",
        };
        hybridTrackingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/hybrid_tracker_show",
          "POST",
          record,
          "mhm"
        );
      });

    // back
    $("#btn_modal_hybrid_mhm_back")
      .unbind()
      .click(function () {
        $("#modify_hybrid_trackers_main_mhm").modal();
      });

    // mass delete
    $("#btn_confirm_modal_hybrid_mhm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_hybrid_mhm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_hybrid_mhm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "mhm",
          hybrid_trackers_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete hybrid tracker",
          tk_multi_table_array,
          "hybrid",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Hybrid tracker(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              hybridTrackingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/hybrid_tracker_show",
                "POST",
                record,
                "mhm"
              );
            }
          }
        });
      });

    //
    // splk-dsm data sampling state
    //

    // splk-dsm data sampling state handler
    function splkDsmSamplingHandlerTable(
      ajaxUrl,
      ajaxType,
      ajaxData,
      component
    ) {
      // Run the ajax promise
      var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
        resultCall
      ) {
        // Get the status of the feature, and handle possible actions accordingly
        data_sampling_feature = resultCall[0]["data_sample_feature"];

        // We expect the value to be enabled or pending, anything else is either disabled, either an anomaly
        if (
          data_sampling_feature == "enabled" ||
          data_sampling_feature == "pending"
        ) {
          // enable button
          document.getElementById("btn_data_sampling_enable").disabled = true;
          $("#btn_data_sampling_enable").css("display", "none");
          // disable button
          document.getElementById("btn_data_sampling_disable").disabled = false;
          $("#btn_data_sampling_disable").css("display", "inherit");
          // clear state and run button
          if (data_sampling_feature == "enabled") {
            document.getElementById(
              "btn_data_sampling_clear_now"
            ).disabled = false;
          } else {
            document.getElementById(
              "btn_data_sampling_clear_now"
            ).disabled = true;
          }
          // change number of sample records
          document.getElementById(
            "btn_data_sampling_edit_records_nr"
          ).disabled = false;
          // run sampling
          document.getElementById("btn_run_data_sampling").disabled = false;
          // show last sample
          if (data_sampling_feature == "enabled") {
            $("#div_btn_data_sampling_latest_sample").css("display", "inherit");
          } else {
            $("#div_btn_data_sampling_latest_sample").css("display", "none");
          }
        } else {
          // enable button
          document.getElementById("btn_data_sampling_enable").disabled = false;
          $("#btn_data_sampling_enable").css("display", "inherit");
          // disable button
          document.getElementById("btn_data_sampling_disable").disabled = true;
          $("#btn_data_sampling_disable").css("display", "none");
          // clear state and run button
          document.getElementById(
            "btn_data_sampling_clear_now"
          ).disabled = true;
          // change number of sample records
          document.getElementById(
            "btn_data_sampling_edit_records_nr"
          ).disabled = true;
          // run sampling
          document.getElementById("btn_run_data_sampling").disabled = true;
          // show last sample
          $("#div_btn_data_sampling_latest_sample").css("display", "none");
        }

        // the element
        var tabulatorElement = "#splk-dsm-sampling-table";

        // json formatter
        function jsonFormatter(cell, formatterParams, onRendered) {
          cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
          return JSON.stringify(JSON.parse(cell.getValue()), null, 4).replace(
            /\\/g,
            ""
          ); //return JSON formatted cell
        }

        // the table
        var table = new TabulatorFull(tabulatorElement, {
          data: resultCall,
          index: "object",
          layout: "fitDataStretch", //fit columns to width of table
          addRowPos: "top", //when adding a new row, add it to the top of the table
          history: true, //allow undo and redo actions on the table
          maxHeight: "230px", //do not let table get bigger than the height of its parent element
          pagination: "local", //paginate the data
          paginationSize: 1, //allow 7 rows per page of data
          paginationCounter: "rows", //display count of paginated rows in footer
          movableColumns: true, //allow column order to be changed
          resizableRows: true, //allow row order to be changed
          initialSort: [
            //set the initial sort order of the data
            { column: "object", dir: "asc" },
          ],

          columns: [
            //define the table columns
            {
              title: "object",
              field: "object",
              visible: false,
            },
            {
              title: "Feature",
              field: "feature",
              hozAlign: "center",
              editor: false,
              headerFilter: false,
            },
            {
              title: "Current detected format",
              field: "current_detected_format",
              formatter: jsonFormatter,
              editor: false,
              headerFilter: false,
            },
            {
              title: "",
              field: "direction",
              hozAlign: "center",
              editor: false,
              headerFilter: false,
            },
            {
              title: "Previous detected format",
              field: "previous_detected_format",
              formatter: jsonFormatter,
              editor: false,
              headerFilter: false,
            },
            {
              title: "Number of samples",
              field: "data_sampling_nr",
              editor: false,
              headerFilter: false,
            },
            {
              title: "State",
              field: "data_sample_status_message",
              editor: false,
              formatter: jsonFormatter,
              variableHeight: true,
              headerFilter: false,
            },
          ],
        });

        // Open modal
        table.on("tableBuilt", function () {
          $("#data_sampling_manage").modal();
        });
      });
    }

    //
    // Elastic sources
    //

    $(".btn_modify_elastic_sources_main").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("start_modify_elastic_sources", "true");
        setToken("start_modify_elastic_sources_dedicated", "true");
        // Show input modal
        $("#modify_elastic_sources_main").modal();
      });
    });

    $("#btn_modal_elastic_sources_shared_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "elasticshared",
          elastic_type: "shared",
        };
        elasticSharedHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/elastic_show",
          "POST",
          record,
          "elasticshared"
        );
      });

    $("#btn_modal_elastic_sources_dedicated_manage")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "elasticdedicated",
          elastic_type: "dedicated",
        };
        elasticDedicatedHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/elastic_show",
          "POST",
          record,
          "elasticdedicated"
        );
      });

    $("#btn_modal_elastic_sources_add")
      .unbind()
      .click(function () {
        // Default disable button add state
        document.getElementById(
          "btn_modal_elastic_source_add_new"
        ).disabled = true;
        document.getElementById(
          "btn_modal_elastic_source_dedicated_add_new"
        ).disabled = true;
        // hide the table view
        $("#divElasticSourcesTest").css("display", "none");
        // Show input modal
        $("#add_elastic_sources").modal();
        // populate account
        setToken("show_configuration_account_elastic", "true");
      });

    // Back
    $("#btn_modal_elastic_sources_add_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_elastic_sources_main").modal();
      });

    $("#btn_modal_elastic_sources_dedicated_add_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_elastic_sources_main").modal();
      });

    $("#btn_modal_elastic_sources_add_new_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_elastic_sources_main").modal();
      });

    $("#btn_modal_generic_search_error_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#add_elastic_sources").modal();
      });

    function elastic_sources_check_unique(object, status) {
      // Get tenant
      var tk_tenant_id = getToken("tenant_id");

      // Define the query
      var searchQuery =
        '| makeresults | eval object="' +
        object +
        '" | lookup trackme_dsm_elastic_shared_tenant_' +
        tk_tenant_id +
        ' object OUTPUTNEW _key as found | eval is_unique=if(isnull(found), "true", "false") | fields - _time | fields is_unique';

      // Set the search parameters--specify a time range
      var searchParams = {
        earliest_time: "-5m",
        latest_time: "now",
      };

      // Run a oneshot search that returns the job's results
      service.oneshotSearch(searchQuery, searchParams, function (err, results) {
        // Display the results
        var fields = results.fields;
        var rows = results.rows;
        var is_unique;

        for (var i = 0; i < rows.length; i++) {
          var values = rows[i];

          for (var j = 0; j < values.length; j++) {
            var field = fields[j];

            if (fields[j] == "is_unique") {
              is_unique = values[j];
            }
          }
        }

        if (!is_unique) {
          var start_simulation_elastic_sources = "false";
          document.getElementById(
            "btn_modal_elastic_source_add_new"
          ).disabled = true;
          document.getElementById(
            "btn_modal_elastic_source_dedicated_add_new"
          ).disabled = true;
          setToken("start_simulation_elastic_sources", "false");
        }

        if (is_unique == "true" && status == "true") {
          var start_simulation_elastic_sources = "true";
          document.getElementById(
            "btn_modal_elastic_source_add_new"
          ).disabled = false;
          document.getElementById(
            "btn_modal_elastic_dedicated_ource_add_new"
          ).disabled = false;
          setToken("start_simulation_elastic_sources", "true");
        } else if (is_unique == "false") {
          var start_simulation_elastic_sources = "false";
          document.getElementById(
            "btn_modal_elastic_source_add_new"
          ).disabled = true;
          document.getElementById(
            "btn_modal_elastic_source_dedicated_add_new"
          ).disabled = true;
          setToken("start_simulation_elastic_sources", "false");
        }
      });

      return false;
    }

    // Run simulation
    $("#btn_modal_elastic_source_add_simulate")
      .unbind()
      .click(function (event) {
        // disabled if enabled
        document.getElementById(
          "btn_modal_elastic_source_add_new"
        ).disabled = true;
        document.getElementById(
          "btn_modal_elastic_source_dedicated_add_new"
        ).disabled = true;

        // Get tokens
        var tk_input_elastic_source_search_type = getToken(
          "tk_input_elastic_source_search_type"
        );
        var tk_input_elastic_source_object = getToken(
          "tk_input_elastic_source_object"
        );
        var tk_input_elastic_source_elastic_data_index = getToken(
          "tk_input_elastic_source_elastic_data_index"
        );
        var tk_input_elastic_source_elastic_splk_dsmtype = getToken(
          "tk_input_elastic_source_elastic_splk_dsmtype"
        );
        var tk_input_elastic_source_earliest = getToken(
          "tk_input_elastic_source_earliest"
        );
        var tk_input_elastic_source_latest = getToken(
          "tk_input_elastic_source_latest"
        );

        // This is not a Splunk form
        var tk_input_elastic_source_search_constraint = document.getElementById(
          "modal_input_elastic_source_search_constraint"
        ).value;

        // Get the account value, and the type of search
        var tk_elastic_source_type_deployment = getToken(
          "tk_elastic_source_type_deployment"
        );
        var tk_input_elastic_dsm_account = getToken(
          "tk_input_elastic_dsm_account"
        );

        // the token used by the search needs to have escaped double quotes, but not the value to be stored in the KV
        var tk_raw_input_elastic_source_search_constraint =
          document.getElementById(
            "modal_input_elastic_source_search_constraint"
          ).value;

        // if the account != local, combine the account and the search constraint
        if (tk_elastic_source_type_deployment != "local") {
          tk_input_elastic_source_search_constraint =
            'account="' +
            tk_input_elastic_dsm_account +
            '" | ' +
            tk_raw_input_elastic_source_search_constraint;
          tk_raw_input_elastic_source_search_constraint =
            'account="' +
            tk_input_elastic_dsm_account +
            '" | ' +
            tk_raw_input_elastic_source_search_constraint;
        }

        // escape
        tk_input_elastic_source_search_constraint = escapeDoubleQuotes(
          tk_input_elastic_source_search_constraint
        );

        setToken(
          "tk_input_elastic_source_search_constraint",
          tk_input_elastic_source_search_constraint
        );

        // Start the search if all tokens are defined
        if (
          tk_input_elastic_source_search_type &&
          tk_input_elastic_source_object &&
          tk_input_elastic_source_elastic_data_index &&
          tk_input_elastic_source_elastic_splk_dsmtype &&
          tk_input_elastic_source_search_constraint &&
          tk_input_elastic_source_search_constraint !==
            "Enter the Splunk search constraint chain according to the type of search selected"
        ) {
          // notify
          notify(
            "info",
            "bottom",
            "Elastic source simulation started for object: " +
              tk_input_elastic_source_object +
              ", if the simulation is successful, click on save new elastic source to include this new source in the collection.",
            "5"
          );

          // Free the beast
          var start_simulation_elastic_sources = "true";
          var success_simulation_elastic_sources = "false";
          setToken("start_simulation_elastic_sources", "true");

          // Get the translated search
          // Set the search parameters--specify a time range
          var searchParams = {
            earliest_time: "-5m",
            latest_time: "now",
          };

          var searchQuery =
            '| makeresults | eval object="' +
            tk_input_elastic_source_object +
            '", search_mode="' +
            tk_input_elastic_source_search_type +
            '", search_constraint="' +
            tk_input_elastic_source_search_constraint +
            '", elastic_index="' +
            tk_input_elastic_source_elastic_data_index +
            '", elastic_sourcetype="' +
            tk_input_elastic_source_elastic_splk_dsmtype +
            '" | `trackme_elastic_sources_simulate_genspl("' +
            tk_input_elastic_source_object +
            '", "' +
            tk_input_elastic_source_earliest +
            '", "' +
            tk_input_elastic_source_latest +
            '")`';

          // Run a normal search that immediately returns the job's SID
          service.search(searchQuery, searchParams, function (err, job) {
            // Shall the search fail before we can get properties
            if (job == null) {
              let errorStr = "Unknown Error!";
              if (
                err &&
                err.data &&
                err.data.messages &&
                err.data.messages[0]["text"]
              ) {
                errorStr = err.data.messages[0]["text"];
              } else if (err && err.data && err.data.messages) {
                errorStr = JSON.stringify(err.data.messages);
              }
              // notify
              notify("error", "bottom", errorStr, "5");
            } else {
              // Poll the status of the search job
              job.track(
                {
                  period: 200,
                },
                {
                  done: function (job) {
                    // do something

                    // Get the results and display them
                    job.results({}, function (err, results) {
                      var fields = results.fields;
                      var rows = results.rows;
                      for (var i = 0; i < rows.length; i++) {
                        var values = rows[i];
                        for (var j = 0; j < values.length; j++) {
                          var field = fields[j];
                          var value = values[j];

                          if (field == "spl") {
                            // Set the token required for the simulation search
                            setToken(
                              "tk_elastic_source_simulation_search",
                              value
                            );

                            // free the table view
                            $("#divElasticSourcesTest").css(
                              "display",
                              "inherit"
                            );
                            searchElasticSourcesTest.startSearch();

                            //
                            // check the search status
                            //

                            searchElasticSourcesTest.on(
                              "search:error",
                              function (properties) {
                                var start_simulation_elastic_sources = "false";
                                var success_simulation_elastic_sources =
                                  "false";
                                setToken(
                                  "start_simulation_elastic_sources",
                                  "false"
                                );
                                document.getElementById(
                                  "btn_modal_elastic_source_add_new"
                                ).disabled = true;
                                document.getElementById(
                                  "btn_modal_elastic_source_dedicated_add_new"
                                ).disabled = true;

                                // notify
                                notify(
                                  "error",
                                  "bottom",
                                  "The search has failed, verify the syntax and try again.",
                                  "5"
                                );
                              }
                            );

                            searchElasticSourcesTest.on(
                              "search:failed",
                              function (properties) {
                                var start_simulation_elastic_sources = "false";
                                var success_simulation_elastic_sources =
                                  "false";
                                setToken(
                                  "start_simulation_elastic_sources",
                                  "false"
                                );
                                document.getElementById(
                                  "btn_modal_elastic_source_add_new"
                                ).disabled = true;
                                document.getElementById(
                                  "btn_modal_elastic_source_dedicated_add_new"
                                ).disabled = true;

                                // notify
                                notify(
                                  "error",
                                  "bottom",
                                  "The search has failed, verify the syntax and try again.",
                                  "5"
                                );
                              }
                            );

                            // If the search is processed successfully
                            searchElasticSourcesTest.on(
                              "search:done",
                              function (properties) {
                                var start_simulation_elastic_sources = "true";
                                document.getElementById(
                                  "btn_modal_elastic_source_add_new"
                                ).disabled = false;
                                document.getElementById(
                                  "btn_modal_elastic_source_dedicated_add_new"
                                ).disabled = false;
                                setToken(
                                  "start_simulation_elastic_sources",
                                  "true"
                                );
                              }
                            );

                            //
                          }
                        }
                        //
                        //
                      }
                    });

                    //
                    // Run the rest of the logic there
                    //

                    // end job

                    //
                  },
                  failed: function (properties) {
                    let errorStr = "Unknown Error!";
                    if (
                      properties &&
                      properties._properties &&
                      properties._properties.messages &&
                      properties._properties.messages[0]["text"]
                    ) {
                      errorStr = properties._properties.messages[0]["text"];
                    } else if (
                      properties &&
                      properties._properties &&
                      properties._properties.messages
                    ) {
                      errorStr = JSON.stringify(
                        properties._properties.messages
                      );
                    }

                    // notify
                    notify("error", "bottom", errorStr, "5");
                  },
                  error: function (err) {
                    done(err);
                    // notify
                    notify("error", "bottom", err, "5");
                  },
                }
              );
            }
          });
        }

        $("#btn_modal_elastic_source_add_new")
          .unbind()
          .click(function (event) {
            // Get tenant
            var tk_tenant_id = getToken("tenant_id");

            // Get status
            var success_simulation_elastic_sources = getToken(
              "start_simulation_elastic_sources"
            );

            // Get tokens
            var tk_input_elastic_source_search_type = getToken(
              "tk_input_elastic_source_search_type"
            );
            var tk_input_elastic_source_object = getToken(
              "tk_input_elastic_source_object"
            );
            var tk_input_elastic_source_elastic_data_index = getToken(
              "tk_input_elastic_source_elastic_data_index"
            );
            var tk_input_elastic_source_elastic_splk_dsmtype = getToken(
              "tk_input_elastic_source_elastic_splk_dsmtype"
            );
            var tk_input_elastic_source_earliest = getToken(
              "tk_input_elastic_source_earliest"
            );
            var tk_input_elastic_source_latest = getToken(
              "tk_input_elastic_source_latest"
            );

            // This is not a Splunk form
            var tk_input_elastic_source_search_constraint =
              document.getElementById(
                "modal_input_elastic_source_search_constraint"
              ).value;

            // the token used by the search needs to have escaped double quotes, but not the value to be stored in the KV
            var tk_raw_input_elastic_source_search_constraint =
              document.getElementById(
                "modal_input_elastic_source_search_constraint"
              ).value;

            // Get the account value, and the type of search
            var tk_elastic_source_type_deployment = getToken(
              "tk_elastic_source_type_deployment"
            );
            var tk_input_elastic_dsm_account = getToken(
              "tk_input_elastic_dsm_account"
            );

            // if the account != local, combine the account and the search constraint
            if (tk_elastic_source_type_deployment != "local") {
              tk_input_elastic_source_search_constraint =
                'account="' +
                tk_input_elastic_dsm_account +
                '" | ' +
                tk_raw_input_elastic_source_search_constraint;
              tk_raw_input_elastic_source_search_constraint =
                'account="' +
                tk_input_elastic_dsm_account +
                '" | ' +
                tk_raw_input_elastic_source_search_constraint;
            }

            // escape
            //tk_input_elastic_source_search_constraint = escapeDoubleQuotes(
            //  tk_input_elastic_source_search_constraint
            //);

            // set token
            setToken(
              "tk_input_elastic_source_search_constraint",
              tk_input_elastic_source_search_constraint
            );

            // disable the buttons once clicked
            document.getElementById(
              "btn_modal_elastic_source_add_new"
            ).disabled = true;
            document.getElementById(
              "btn_modal_elastic_source_dedicated_add_new"
            ).disabled = true;

            if (
              start_simulation_elastic_sources &&
              start_simulation_elastic_sources == "true"
            ) {
              // no comment
              tk_comment = "N/A";

              // Create the endpoint URL
              var myendpoint_URl =
                "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/admin/elastic_shared_add";

              // set the record
              var record = {
                tenant_id: tk_tenant_id,
                object: tk_input_elastic_source_object,
                search_constraint: tk_input_elastic_source_search_constraint,
                search_mode: tk_input_elastic_source_search_type,
                elastic_index: tk_input_elastic_source_elastic_data_index,
                elastic_sourcetype:
                  tk_input_elastic_source_elastic_splk_dsmtype,
                earliest_time: tk_input_elastic_source_earliest,
                latest_time: tk_input_elastic_source_latest,
              };

              // spinner
              cssloader("Requested action is in progress, please wait...");

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                dataType: "json",
                data: JSON.stringify(record),
                contentType: "application/json",
                success: function (returneddata) {
                  // spinner
                  cssloaderremove();
                  // notify
                  var msg =
                    "The new Elastic Shared source has been created successfully";
                  notify("success", "bottom", msg, "5");
                  // add the response and show the modal
                  $("#add_elastic_source_processed")
                    .find(".modal-success-message p")
                    .text(JSON.stringify(returneddata, null, 2));
                  closeModals();
                  $("#add_elastic_source_processed").modal();
                },
                error: function (xhr, textStatus, error) {
                  // spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "add elastic source tracker";
                  object = tk_input_elastic_source_object;
                  object_category = "elastic_sources_tracker";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = "N/A";
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            } else {
              // notify
              notify(
                "error",
                "bottom",
                "ERROR: Please successfully run the simulation first.",
                "5"
              );
            }
          });

        $("#btn_modal_elastic_source_dedicated_add_new")
          .unbind()
          .click(function (event) {
            // spinner
            cssloader(
              "Creating the new Elastic dedicated source, please wait..."
            );

            // Get tenant
            var tk_tenant_id = getToken("tenant_id");

            // Get status
            var success_simulation_elastic_sources = getToken(
              "start_simulation_elastic_sources"
            );

            // Get tokens
            var tk_input_elastic_source_search_type = getToken(
              "tk_input_elastic_source_search_type"
            );
            var tk_input_elastic_source_object = getToken(
              "tk_input_elastic_source_object"
            );
            var tk_input_elastic_source_elastic_data_index = getToken(
              "tk_input_elastic_source_elastic_data_index"
            );
            var tk_input_elastic_source_elastic_splk_dsmtype = getToken(
              "tk_input_elastic_source_elastic_splk_dsmtype"
            );
            var tk_input_elastic_source_earliest = getToken(
              "tk_input_elastic_source_earliest"
            );
            var tk_input_elastic_source_latest = getToken(
              "tk_input_elastic_source_latest"
            );

            // This is not a Splunk form
            var tk_input_elastic_source_search_constraint =
              document.getElementById(
                "modal_input_elastic_source_search_constraint"
              ).value;

            // the token used by the search needs to have escaped double quotes, but not the value to be stored in the KV
            var tk_raw_input_elastic_source_search_constraint =
              document.getElementById(
                "modal_input_elastic_source_search_constraint"
              ).value;

            // Get the account value, and the type of search
            var tk_elastic_source_type_deployment = getToken(
              "tk_elastic_source_type_deployment"
            );
            var tk_input_elastic_dsm_account = getToken(
              "tk_input_elastic_dsm_account"
            );

            // if the account != local, combine the account and the search constraint
            if (tk_elastic_source_type_deployment != "local") {
              tk_input_elastic_source_search_constraint =
                'account="' +
                tk_input_elastic_dsm_account +
                '" | ' +
                tk_raw_input_elastic_source_search_constraint;
              tk_raw_input_elastic_source_search_constraint =
                'account="' +
                tk_input_elastic_dsm_account +
                '" | ' +
                tk_raw_input_elastic_source_search_constraint;
            }

            // set token
            setToken(
              "tk_input_elastic_source_search_constraint",
              tk_input_elastic_source_search_constraint
            );

            // disable the buttons once clicked
            document.getElementById(
              "btn_modal_elastic_source_add_new"
            ).disabled = true;
            document.getElementById(
              "btn_modal_elastic_source_dedicated_add_new"
            ).disabled = true;

            if (
              start_simulation_elastic_sources &&
              start_simulation_elastic_sources == "true"
            ) {
              // no comment
              tk_comment = "N/A";

              // Create the endpoint URL
              var myendpoint_URl =
                "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/admin/elastic_dedicated_add";

              // set the record
              var record = {
                tenant_id: tk_tenant_id,
                object: tk_input_elastic_source_object,
                search_constraint: tk_input_elastic_source_search_constraint,
                search_mode: tk_input_elastic_source_search_type,
                elastic_index: tk_input_elastic_source_elastic_data_index,
                elastic_sourcetype:
                  tk_input_elastic_source_elastic_splk_dsmtype,
                earliest_time: tk_input_elastic_source_earliest,
                latest_time: tk_input_elastic_source_latest,
              };

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                dataType: "json",
                data: JSON.stringify(record),
                contentType: "application/json",
                success: function (returneddata) {
                  // remove spinner
                  cssloaderremove();
                  // get tracker from response
                  var tk_tracker_name = returneddata.elastic_report;
                  // set as a token for later usage
                  setToken("tk_tracker_name", tk_tracker_name);
                  // notify
                  var msg =
                    "The new tracker " +
                    tk_tracker_name +
                    " has been created successfully.";
                  notify("success", "bottom", msg, "5");
                  // add the response and show the modal
                  $("#modal_elastic_source_alert_creation_success")
                    .find(".modal-success-message p")
                    .text(JSON.stringify(returneddata, null, 2));
                  closeModals();
                  $("#modal_elastic_source_alert_creation_success").modal();
                },
                error: function (xhr, textStatus, error) {
                  // remove spinner
                  cssloaderremove();
                  message =
                    "server response: " +
                    xhr.responseText +
                    "\n - http response: " +
                    error;

                  // Audit
                  action = "failure";
                  change_type = "add elastic source tracker";
                  object = tk_input_elastic_source_object;
                  object_category = "elastic_sources_tracker";
                  object_attrs = JSON.stringify(record, null, "\t");
                  result = message;
                  comment = "N/A";
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(message);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
              });
            } else {
              // notify
              notify(
                "error",
                "bottom",
                "ERROR: Please successfully run the simulation first.",
                "5"
              );
            }
          });
      });

    // run elastic shared tracker now
    $("#add_elastic_source_processed_run_tracker")
      .unbind()
      .click(function () {
        $("#add_elastic_source_processed").modal("hide");

        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="trackme_dsm_shared_elastic_tracker_tenant_' +
          tk_tenant_id +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-4h",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          // run loader
          cssloader("Running the Elastic Shared Tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // run elastic shared tracker now
    $("#modal_elastic_source_alert_creation_success_run_tracker").click(
      function () {
        $("#modal_elastic_source_alert_creation_success").modal("hide");

        // Get the tracker name
        var tk_tracker_name = getToken("tk_tracker_name");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-4h",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the dedicated elastic tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      }
    );

    // shared Elastic Source mass delete
    $("#btn_confirm_modal_elasticshared_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_elasticshared_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/admin/elastic_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_elasticdedicated_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "splk-dsm",
          elastic_type: "shared",
          elastic_entities_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete Elastic Source",
          tk_multi_table_array,
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Elastic Source(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              elasticSharedHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/elastic_show",
                "POST",
                record,
                "elasticshared"
              );
              // refresh searches
              searchSplkDsmMain.startSearch();
              // refresh tabulator
              $("#splk-dsm-table-refresh-hidden").click();
            }
          }
        });
      });

    // dedicated Elastic Source mass delete
    $("#btn_confirm_modal_elasticdedicated_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_elasticdedicated_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/admin/elastic_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_elasticdedicated_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "splk-dsm",
          elastic_type: "dedicated",
          elastic_entities_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete Elastic Source",
          tk_multi_table_array,
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Elastic Source(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              elasticDedicatedHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_elastic_sources/elastic_show",
                "POST",
                record,
                "elasticdedicated"
              );
              // refresh searches
              searchSplkDsmMain.startSearch();
              // refresh tabulator
              $("#splk-dsm-table-refresh-hidden").click();
            }
          }
        });
      });

    //
    // Custom lagging classes
    //

    $(".btn_modify_custom_lagging").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Get table
        laggingClassesHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
          "POST",
          { tenant_id: tk_tenant_id, lagging_class_type: "events" },
          "dsmdhm"
        );
      });
    });

    // Return to bootstrap modal when clicking on cancel
    $("#btn_delete_custom_lagging_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modify_custom_lagging").modal();
      });

    //
    // Metrics SLA policies in-modal editor
    //

    $(".btn_modify_metric_sla_policies").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Get table
        laggingClassesMetricsHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_lagging_classes/lagging_classes_show",
          "POST",
          { tenant_id: tk_tenant_id, lagging_class_type: "metrics" },
          "mhm"
        );

        // Show input modal
        $("#modal_metric_sla_policies").modal();
      });
    });

    // Return to bootstrap modal when clicking on cancel
    $("#btn_delete_metric_sla_policy_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_metric_sla_policies").modal();
      });

    //
    // DSM dataset
    //

    $("#btn_modify_dsm_dataset_handler")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
        };

        dataSetHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
          "POST",
          record,
          "dsm"
        );
      });

    // Return to bootstrap modal
    $("#btn_cancel_modal_dataset_dsm_confirm_delete")
      .unbind()
      .click(function () {
        $("#modal_dsm_dataset_handler").modal();
      });

    // Return to bootstrap modal
    $("#btn_cancel_modal_dataset_dsm_confirm_save")
      .unbind()
      .click(function () {
        $("#modal_dsm_dataset_handler").modal();
      });

    //
    // DHM dataset
    //

    $("#btn_modify_dhm_dataset_handler")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
        };

        dataSetHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
          "POST",
          record,
          "dhm"
        );
      });

    // Return to bootstrap modal
    $("#btn_cancel_modal_dataset_dhm_confirm_delete")
      .unbind()
      .click(function () {
        $("#modal_dhm_dataset_handler").modal();
      });

    // Return to bootstrap modal
    $("#btn_cancel_modal_dataset_dhm_confirm_save")
      .unbind()
      .click(function () {
        $("#modal_dhm_dataset_handler").modal();
      });

    //
    // MHM dataset
    //

    $("#btn_modify_mhm_dataset_handler")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "mhm",
        };

        dataSetHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dataset/dataset_show",
          "POST",
          record,
          "mhm"
        );
      });

    // Return to bootstrap modal
    $("#btn_cancel_modal_dataset_mhm_confirm_delete")
      .unbind()
      .click(function () {
        $("#modal_mhm_dataset_handler").modal();
      });

    // Return to bootstrap modal
    $("#btn_cancel_modal_dataset_mhm_confirm_save")
      .unbind()
      .click(function () {
        $("#modal_mhm_dataset_handler").modal();
      });

    //
    // splk-flx
    //

    // Show modal
    $("#btn_search_splk_flx_reports")
      .unbind()
      .click(function () {
        // Show input modal
        $("#objects_search_and_reports_splk_flx").modal();
      });

    // back button
    $("#btn_splk_flx_search_and_report_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_flx").modal();
      });

    //
    // Metrics hosts Search & Report
    //

    // Show modal
    $("#btn_search_metric_reports")
      .unbind()
      .click(function () {
        // Show input modal
        $("#objects_search_and_reports").modal();
      });

    // back button
    $("#btn_splk_mhm_search_and_report_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_mhm").modal();
      });

    // Ops: Indexer queues
    $(".btn_ops_index_queue").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("tk_start_indexers_queues_searches", "true");

        // Show input modal
        $("#modal_queues").modal();
      });
    });

    // Unset token when bootstrap modal is closed properly
    $("#btn_ops_index_queue_close")
      .unbind()
      .click(function () {
        unsetToken("tk_start_indexers_queues_searches");
      });

    // Ops: Parsing issues

    $(".btn_ops_parsing_issues").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        setToken("tk_start_parsing_issues_searches", "true");
        var tk_hosts = getToken("inputHostParsing");

        // Show input modal
        $("#modal_parsing_issues").modal();
      });
    });

    $("#btn_search_parsing_issues_linebreaking")
      .unbind()
      .click(function () {
        setToken("tk_start_parsing_issues_searches", "true");
        var tk_earliest = getToken("inputLinkParsingIssuesTime.earliest");
        var tk_latest = getToken("inputLinkParsingIssuesTime.latest");
        var tk_hosts = getToken("inputHostParsing");

        // Define the history search
        var search_parsing_issues_linebreaking =
          "search" +
          "?q=search%20" +
          encodeURI(
            "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=LineBreakingProcessor "
          ) +
          encodeURI(tk_hosts) +
          "&earliest=" +
          encodeURI(tk_earliest) +
          "&latest=" +
          encodeURI(tk_latest);

        // Open
        window.open(search_parsing_issues_linebreaking, "_blank");
      });

    $("#btn_search_parsing_issues_aggregator")
      .unbind()
      .click(function () {
        setToken("tk_start_parsing_issues_searches", "true");
        var tk_earliest = getToken("inputLinkParsingIssuesTime.earliest");
        var tk_latest = getToken("inputLinkParsingIssuesTime.latest");
        var tk_hosts = getToken("inputHostParsing");

        // Define the history search
        var search_parsing_issues_aggregator =
          "search" +
          "?q=search%20" +
          encodeURI(
            "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=AggregatorMiningProcessor "
          ) +
          encodeURI(tk_hosts) +
          "&earliest=" +
          encodeURI(tk_earliest) +
          "&latest=" +
          encodeURI(tk_latest);

        // Open
        window.open(search_parsing_issues_aggregator, "_blank");
      });

    $("#btn_search_parsing_issues_dateparser")
      .unbind()
      .click(function () {
        setToken("tk_start_parsing_issues_searches", "true");
        var tk_earliest = getToken("inputLinkParsingIssuesTime.earliest");
        var tk_latest = getToken("inputLinkParsingIssuesTime.latest");
        var tk_hosts = getToken("inputHostParsing");

        // Define the history search
        var search_parsing_issues_dateparser =
          "search" +
          "?q=search%20" +
          encodeURI(
            "index=_internal sourcetype=splunkd error OR warn `trackme_idx_filter` component=DateParserVerbose "
          ) +
          encodeURI(tk_hosts) +
          encodeURI(" | `trackme_rex_dateparserverbose`") +
          "&earliest=" +
          encodeURI(tk_earliest) +
          "&latest=" +
          encodeURI(tk_latest);

        // Open
        window.open(search_parsing_issues_dateparser, "_blank");
      });

    // Unset token when bootstrap modal is closed properly
    $("#btn_ops_parsing_issues_close")
      .unbind()
      .click(function () {
        unsetToken("tk_start_parsing_issues_searches");
      });

    //
    // RUN TRACKERS
    //

    // dsm

    $("#btn_run_tracker_dsm")
      .unbind()
      .click(function () {
        // Run an Ajax call to verify the configuration for this tenant
        var tk_tenant_id = getToken("tenant_id");
        var record = {
          tenant_id: tk_tenant_id,
        };
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/vtenants/show_tenant";

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "json",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Show input modal
            $("#modal_run_splk_dsm_trackers").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // dhm

    $("#btn_run_tracker_dhm")
      .unbind()
      .click(function () {
        // Run an Ajax call to verify the configuration for this tenant
        var tk_tenant_id = getToken("tenant_id");
        var record = {
          tenant_id: tk_tenant_id,
        };
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/vtenants/show_tenant";

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "json",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Show input modal
            $("#modal_run_splk_dhm_trackers").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // mhm

    $("#btn_run_tracker_mhm")
      .unbind()
      .click(function () {
        // Run an Ajax call to verify the configuration for this tenant
        var tk_tenant_id = getToken("tenant_id");
        var record = {
          tenant_id: tk_tenant_id,
        };
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/vtenants/show_tenant";

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "json",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Show input modal
            $("#modal_run_splk_mhm_trackers").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // flx

    $("#btn_run_tracker_flx")
      .unbind()
      .click(function () {
        // Run an Ajax call to verify the configuration for this tenant
        var tk_tenant_id = getToken("tenant_id");
        var record = {
          tenant_id: tk_tenant_id,
        };
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/vtenants/show_tenant";

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "json",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Show input modal
            $("#modal_run_splk_flx_trackers").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // wlk

    $("#btn_run_tracker_wlk")
      .unbind()
      .click(function () {
        // Run an Ajax call to verify the configuration for this tenant
        var tk_tenant_id = getToken("tenant_id");
        var record = {
          tenant_id: tk_tenant_id,
        };
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/vtenants/show_tenant";

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "json",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Show input modal
            $("#modal_run_splk_wlk_trackers").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(message);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // hybrid trackers
    //

    // dsm

    $("#btn_run_tracker_hybrid_dsm")
      .unbind()
      .click(function () {
        // free populating search
        setToken("start_search_input_hybrid_tracker_dsm_dropdown", "true");
        // run
        searchPopulateHybridTrackerDsm.startSearch();
        // Show input modal
        $("#modal_run_hybrid_trackers_dsm").modal();
      });

    // back
    $("#btn_run_hybrid_tracker_dsm_back")
      .unbind()
      .click(function () {
        $("#modal_run_splk_dsm_trackers").modal();
      });

    // dhm

    $("#btn_run_tracker_hybrid_dhm")
      .unbind()
      .click(function () {
        // free populating search
        setToken("start_search_input_hybrid_tracker_dhm_dropdown", "true");
        // run
        searchPopulateHybridTrackerDhm.startSearch();
        // Show input modal
        $("#modal_run_hybrid_trackers_dhm").modal();
      });

    // back
    $("#btn_run_hybrid_tracker_dhm_back")
      .unbind()
      .click(function () {
        $("#modal_run_splk_dhm_trackers").modal();
      });

    // mhm

    $("#btn_run_tracker_hybrid_mhm")
      .unbind()
      .click(function () {
        // free populating search
        setToken("start_search_input_hybrid_tracker_mhm_dropdown", "true");
        // run
        searchPopulateHybridTrackerMhm.startSearch();
        // Show input modal
        $("#modal_run_hybrid_trackers_mhm").modal();
      });

    // back
    $("#btn_run_hybrid_tracker_mhm_back")
      .unbind()
      .click(function () {
        $("#modal_run_splk_mhm_trackers").modal();
      });

    // flx

    $("#btn_run_tracker_hybrid_flx")
      .unbind()
      .click(function () {
        // free populating search
        setToken("start_search_input_hybrid_tracker_flx_dropdown", "true");
        // run
        searchPopulateHybridTrackerFlx.startSearch();
        // Show input modal
        $("#modal_run_hybrid_trackers_flx").modal();
      });

    // back
    $("#btn_run_hybrid_tracker_flx_back")
      .unbind()
      .click(function () {
        $("#modal_run_splk_flx_trackers").modal();
      });

    // wlk

    $("#btn_run_tracker_hybrid_wlk")
      .unbind()
      .click(function () {
        // free populating search
        setToken("start_search_input_hybrid_tracker_wlk_dropdown", "true");
        // run
        searchPopulateHybridTrackerWlk.startSearch();
        // Show input modal
        $("#modal_run_hybrid_trackers_wlk").modal();
      });

    $("#btn_run_tracker_elastic")
      .unbind()
      .click(function () {
        // free populating search
        setToken("start_search_input_elastic_tracker_dropdown", "true");
        // run
        searchPopulateElasticTracker.startSearch();
        // Show input modal
        $("#modal_run_elastic_trackers").modal();
      });

    // back
    $("#btn_run_elastic_tracker_back")
      .unbind()
      .click(function () {
        $("#modal_run_splk_dsm_trackers").modal();
      });

    //
    // UPDATE COLLECTION
    //

    // Call this function when the Update collection button is clicked

    $("#btn_run_tracker_dhm_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="trackme_dhm_tracker_tenant_' +
          tk_tenant_id +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-4h",
          latest_time: "+4h",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running the splk-dhm tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDhmMain.startSearch();

                  // refresh tabulator
                  $("#splk-dhm-table-refresh-hidden").click();

                  cssloaderremove();
                  $("#modal_run_splk_dhm_trackers").modal();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // Elastic shared tracker

    $("#btn_run_tracker_shared_elastic")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="trackme_dsm_shared_elastic_tracker_tenant_' +
          tk_tenant_id +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-4h",
          latest_time: "+4h",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader(
            "Please wait while running the Elastic Sources shared tracker"
          );

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                  cssloaderremove();
                  $("#modal_run_splk_dsm_trackers").modal();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // Data Sampling tracker

    $("#btn_run_tracker_data_sampling")
      .unbind()
      .click(function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="trackme_dsm_data_sampling_tracker_tenant_' +
          tk_tenant_id +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-24h",
          latest_time: "+4h",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader(
            "Please wait while running the data sampling engine tracker..."
          );

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                  cssloaderremove();
                  $("#modal_run_splk_dsm_trackers").modal();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    //
    // hybrid trackers
    //

    // dsm

    $("#btn_run_tracker_hybrid_dsm_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // get report
        var tk_report = getToken("tk_input_hybrid_tracker_dsm_dropdown");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_report +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running hybrid tracker: " + tk_report);

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // dhm

    $("#btn_run_tracker_hybrid_dhm_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // get report
        var tk_report = getToken("tk_input_hybrid_tracker_dhm_dropdown");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_report +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running hybrid tracker: " + tk_report);

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dhm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // flx

    $("#btn_run_tracker_hybrid_flx_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // get report
        var tk_report = getToken("tk_input_hybrid_tracker_flx_dropdown");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_report +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running hybrid tracker: " + tk_report);

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkFlxMain.startSearch();
                  // refresh tabulator
                  $("#splk-flx-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // wlk

    $("#btn_run_tracker_hybrid_wlk_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // get report
        var tk_report = getToken("tk_input_hybrid_tracker_wlk_dropdown");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_report +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running hybrid tracker: " + tk_report);

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkWlkMain.startSearch();
                  // refresh tabulator
                  $("#splk-wlk-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // mhm

    $("#btn_run_tracker_hybrid_mhm_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // get report
        var tk_report = getToken("tk_input_hybrid_tracker_mhm_dropdown");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_report +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running hybrid tracker: " + tk_report);

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkMhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-mhm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // elastic tracker
    $("#btn_run_tracker_elastic_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // get report
        var tk_report = getToken("tk_input_elastic_tracker_dropdown");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_report +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running elastic tracker: " + tk_report);

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkDsmMain.startSearch();
                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // metric host

    $("#btn_run_tracker_mhm_exec")
      .unbind()
      .click(function () {
        // get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="trackme_mhm_tracker_tenant_' +
          tk_tenant_id +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Please wait while running the splk-mhm tracker...");
          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkMhmMain.startSearch();
                  // refresh tabulator
                  $("#splk-mhm-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    //
    // MODIFY BUTTON
    //

    // data source monitoring

    $("#btn_modify_splk_dsm")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage").modal("hide");

        // Show input modal
        $("#modal_modify_splk_dsm_unified").modal();
      });

    // cancel button: returns to selected
    $("#btn_close_splk_dsm_unified")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_dsm").modal();
      });

    $("#btn_modal_modify_wdays")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_wdays").modal();
      });

    $("#btn_modal_modify_monitoring_wdays_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_wdays";

        var tk_data_monitoring_wdays = getToken("tk_input_wdays");

        if (!tk_data_monitoring_wdays || !tk_data_monitoring_wdays.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_object,
            data_monitoring_wdays: tk_data_monitoring_wdays,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();

              // call update data source
              updateSplkDsm(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "data_source";
              object_attrs =
                "data_monitoring_wdays changed to:" + tk_data_monitoring_wdays;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // priority
    $("#btn_modal_modify_priority_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");
        var tk_priority = getToken("tk_priority");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_priority";

        var tk_origin_priority = tk_priority;
        var tk_new_priority = getToken("tk_input_priority");

        if (!tk_new_priority || !tk_new_priority.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_category: "splk-dsm",
            object_list: tk_object,
            priority: tk_new_priority,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();

              // Run the search again to update the table
              searchSplkDsmMain.startSearch();

              // call update data source
              updateSplkDsm(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Priority updated successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();

              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify priority";
              object = tk_object;
              object_category = "data_source";
              object_attrs =
                "priority changed from:" +
                tk_origin_priority +
                " to:" +
                tk_new_priority;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    $("#btn_modal_modify_wdays_no")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_wdays_no").modal();
      });

    // hours ranges

    $("#btn_modal_modify_monitoring_hours_ranges_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_hours_ranges";

        // get ranges
        var tk_data_monitoring_hours_ranges = getToken("tk_input_hours_ranges");

        if (
          !tk_data_monitoring_hours_ranges ||
          !tk_data_monitoring_hours_ranges.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_object,
            data_monitoring_hours_ranges: tk_data_monitoring_hours_ranges,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();

              // call update data source
              updateSplkDsm(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_object;
              object_category = "data_source";
              object_attrs =
                "data_monitoring_hours_ranges changed to: " +
                tk_data_monitoring_hours_ranges;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    $("#btn_modal_modify_hours_ranges_no")
      .unbind()
      .click(function () {
        // free the populating search
        setToken("show_hours_ranges", "true");
        // Show input modal
        $("#modal_modify_monitoring_hours_ranges_no").modal();
      });

    $("#btn_modal_modify_monitoring_hours_ranges_no_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_hours_ranges";

        // get ranges
        var tk_data_monitoring_hours_ranges_no = getToken(
          "tk_input_hours_ranges_no"
        );

        if (
          !tk_data_monitoring_hours_ranges_no ||
          !tk_data_monitoring_hours_ranges_no.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_object,
            data_monitoring_hours_ranges: tk_data_monitoring_hours_ranges_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();

              $("#modal_modify_splk_dsm_unified").modal();

              // call update data source
              updateSplkDsm(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // pre-fill the form
              setToken(
                "form.tk_input_hours_ranges",
                tk_data_monitoring_hours_ranges_no
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_object;
              object_category = "data_source";
              object_attrs =
                "data_monitoring_hours_ranges changed to: " +
                tk_data_monitoring_hours_ranges_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_hours_ranges_no_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_splk_dsm_unified").modal();
      });

    // hours ranges for data hosts

    $("#btn_modal_modify_monitoring_splk_dhm_hours_ranges_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_hours_ranges";

        // get ranges
        var tk_data_monitoring_hours_ranges = getToken(
          "tk_input_splk_dhm_hours_ranges"
        );

        if (
          !tk_data_monitoring_hours_ranges ||
          !tk_data_monitoring_hours_ranges.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            data_monitoring_hours_ranges: tk_data_monitoring_hours_ranges,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();

              // Run the search again to update the table
              searchSplkDhmMain.startSearch();

              // call update data source
              updateSplkDhm(tk_splk_dhm);

              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_dhm;
              object_category = "object";
              object_attrs =
                "data_monitoring_hours_ranges changed to:" +
                tk_data_monitoring_hours_ranges;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    $("#btn_modal_modify_splk_dhm_hours_ranges_no")
      .unbind()
      .click(function () {
        // free the populating search
        setToken("show_hours_ranges", "true");
        // Show input modal
        $("#modal_modify_monitoring_splk_dhm_hours_ranges_no").modal();
      });

    $("#btn_modal_modify_monitoring_splk_dhm_hours_ranges_no_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_hours_ranges";

        // get ranges
        var tk_data_monitoring_hours_ranges_no = getToken(
          "tk_input_splk_dhm_hours_ranges_no"
        );

        if (
          !tk_data_monitoring_hours_ranges_no ||
          !tk_data_monitoring_hours_ranges_no.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            data_monitoring_hours_ranges: tk_data_monitoring_hours_ranges_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();

              $("#modal_modify_splk_dhm_unified").modal();

              // call update data source
              updateSplkDhm(tk_splk_dhm);

              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // pre-fill the form
              setToken(
                "form.tk_input_splk_dhm_hours_ranges",
                tk_data_monitoring_hours_ranges_no
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_dhm;
              object_category = "object";
              object_attrs =
                "data_monitoring_hours_ranges changed to:" +
                tk_data_monitoring_hours_ranges_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_splk_dhm_hours_ranges_no_cancel").click(
      function () {
        // Show input modal
        $("#modal_modify_splk_dhm_unified").modal();
      }
    );

    // hours ranges for splk-flx

    $("#btn_modal_modify_monitoring_splk_flx_hours_ranges_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_flx = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_update_hours_ranges";

        // get ranges
        var tk_monitoring_hours_ranges = getToken(
          "tk_input_splk_flx_hours_ranges"
        );

        if (!tk_monitoring_hours_ranges || !tk_monitoring_hours_ranges.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_hours_ranges: tk_monitoring_hours_ranges,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();

              // call update data source
              updateSplkFlx(tk_splk_flx);

              // refresh tabulator
              $("#splk-flx-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_flx;
              object_category = "object";
              object_attrs =
                "monitoring_hours_ranges changed to:" +
                tk_monitoring_hours_ranges;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    $("#btn_modal_modify_splk_flx_hours_ranges_no")
      .unbind()
      .click(function () {
        // free the populating search
        setToken("show_hours_ranges", "true");
        // Show input modal
        $("#modal_modify_monitoring_splk_flx_hours_ranges_no").modal();
      });

    $("#btn_modal_modify_monitoring_splk_flx_hours_ranges_no_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_flx = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_update_hours_ranges";

        // get ranges
        var tk_data_monitoring_hours_ranges_no = getToken(
          "tk_input_splk_flx_hours_ranges_no"
        );

        if (
          !tk_data_monitoring_hours_ranges_no ||
          !tk_data_monitoring_hours_ranges_no.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_hours_ranges: tk_data_monitoring_hours_ranges_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();

              $("#modal_modify_splk_flx_unified").modal();

              // call update data source
              updateSplkFlx(tk_splk_flx);

              // refresh tabulator
              $("#splk-flx-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // pre-fill the form
              setToken(
                "form.tk_input_splk_flx_hours_ranges",
                tk_data_monitoring_hours_ranges_no
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_flx;
              object_category = "object";
              object_attrs =
                "data_monitoring_hours_ranges changed to:" +
                tk_data_monitoring_hours_ranges_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_splk_flx_hours_ranges_no_cancel").click(
      function () {
        // Show input modal
        $("#modal_modify_splk_flx_unified").modal();
      }
    );

    // hours ranges for splk-cim

    $("#btn_modal_modify_monitoring_splk_cim_hours_ranges_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_cim = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/write/cim_update_hours_ranges";

        // get ranges
        var tk_monitoring_hours_ranges = getToken(
          "tk_input_splk_cim_hours_ranges"
        );

        if (!tk_monitoring_hours_ranges || !tk_monitoring_hours_ranges.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_hours_ranges: tk_monitoring_hours_ranges,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkCimMain.startSearch();

              // call update data source
              updateSplkCim("*", tk_keyid, "false");

              // refresh tabulator
              $("#splk-cim-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_cim;
              object_category = "object";
              object_attrs =
                "monitoring_hours_ranges changed to:" +
                tk_monitoring_hours_ranges;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    $("#btn_modal_modify_splk_cim_hours_ranges_no")
      .unbind()
      .click(function () {
        // free the populating search
        setToken("show_hours_ranges", "true");
        // Show input modal
        $("#modal_modify_monitoring_splk_cim_hours_ranges_no").modal();
      });

    $("#btn_modal_modify_monitoring_splk_cim_hours_ranges_no_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_cim = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/write/cim_update_hours_ranges";

        // get ranges
        var tk_data_monitoring_hours_ranges_no = getToken(
          "tk_input_splk_cim_hours_ranges_no"
        );

        if (
          !tk_data_monitoring_hours_ranges_no ||
          !tk_data_monitoring_hours_ranges_no.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_hours_ranges: tk_data_monitoring_hours_ranges_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkCimMain.startSearch();

              $("#modal_modify_splk_cim_unified").modal();

              // call update data source
              updateSplkCim("*", tk_keyid, "false");

              // refresh tabulator
              $("#splk-cim-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // pre-fill the form
              setToken(
                "form.tk_input_splk_cim_hours_ranges",
                tk_data_monitoring_hours_ranges_no
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_cim;
              object_category = "object";
              object_attrs =
                "data_monitoring_hours_ranges changed to:" +
                tk_data_monitoring_hours_ranges_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_splk_cim_hours_ranges_no_cancel").click(
      function () {
        // Show input modal
        $("#modal_modify_splk_cim_unified").modal();
      }
    );

    // flx priority
    $("#btn_modal_modify_priority_splk_flx_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");
        var tk_priority = getToken("tk_priority");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_update_priority";

        var tk_origin_priority = tk_priority;
        var tk_new_priority = getToken("tk_input_splk_flx_priority");

        if (!tk_new_priority || !tk_new_priority.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            priority: tk_new_priority,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();

              // call update data source
              updateSplkFlx(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Priority updated successfully.",
                "5"
              );

              // refresh tabulator
              $("#splk-flx-table-refresh-hidden").click();

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify priority";
              object = tk_object;
              object_category = "object";
              object_attrs =
                "priority changed from:" +
                tk_origin_priority +
                " to:" +
                tk_new_priority;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // wdays splk-flx

    $("#btn_modal_modify_splk_flx_wdays")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_wdays").modal();
      });

    $("#btn_modal_modify_monitoring_splk_flx_wdays_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_update_wdays";

        var tk_monitoring_wdays = getToken("tk_input_wdays_flx");

        if (!tk_monitoring_wdays || !tk_monitoring_wdays.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_wdays: tk_monitoring_wdays,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();

              // call update data source
              updateSplkFlx(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "splk-flx";
              object_attrs =
                "monitoring_wdays changed to:" + tk_monitoring_wdays;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // manual wdays
    $("#btn_modal_modify_splk_flx_wdays_no")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_splk_flx_wdays_no").modal();
      });

    // wdays manual
    $("#btn_modal_modify_monitoring_splk_flx_wdays_no_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_flx/write/flx_update_wdays";

        var tk_monitoring_wdays_no = getToken("tk_input_splk_flx_wdays_no");

        if (!tk_monitoring_wdays_no || !tk_monitoring_wdays_no.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_wdays: tk_monitoring_wdays_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkFlxMain.startSearch();

              $("#modal_modify_splk_flx_unified").modal();

              // call update data source
              updateSplkFlx(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // pre-fill current wdays input
              setToken("form.tk_input_wdays", tk_monitoring_wdays_no);

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "splk-flx";
              object_attrs =
                "monitoring_wdays changed to:" + tk_monitoring_wdays_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_splk_flx_wdays_no_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_splk_flx_unified").modal();
      });

    // wdays splk-cim

    $("#btn_modal_modify_splk_cim_wdays")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_wdays").modal();
      });

    $("#btn_modal_modify_monitoring_splk_cim_wdays_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/write/cim_update_wdays";

        var tk_monitoring_wdays = getToken("tk_input_wdays_cim");

        if (!tk_monitoring_wdays || !tk_monitoring_wdays.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_wdays: tk_monitoring_wdays,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkCimMain.startSearch();

              // call update data source
              updateSplkCim("*", tk_keyid, "false");

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "splk-cim";
              object_attrs =
                "monitoring_wdays changed to:" + tk_monitoring_wdays;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // manual wdays
    $("#btn_modal_modify_splk_cim_wdays_no")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_splk_cim_wdays_no").modal();
      });

    // wdays manual
    $("#btn_modal_modify_monitoring_splk_cim_wdays_no_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/write/cim_update_wdays";

        var tk_monitoring_wdays_no = getToken("tk_input_splk_cim_wdays_no");

        if (!tk_monitoring_wdays_no || !tk_monitoring_wdays_no.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_wdays: tk_monitoring_wdays_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkCimMain.startSearch();

              $("#modal_modify_splk_cim_unified").modal();

              // call update data source
              updateSplkCim("*", tk_keyid, "false");

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // pre-fill current wdays input
              setToken("form.tk_input_wdays", tk_monitoring_wdays_no);

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "splk-cim";
              object_attrs =
                "monitoring_wdays changed to:" + tk_monitoring_wdays_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_splk_cim_wdays_no_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_splk_cim_unified").modal();
      });

    // hours ranges for splk-wlk

    $("#btn_modal_modify_monitoring_splk_wlk_hours_ranges_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_wlk = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_update_hours_ranges";

        // get ranges
        var tk_monitoring_hours_ranges = getToken(
          "tk_input_splk_wlk_hours_ranges"
        );

        if (!tk_monitoring_hours_ranges || !tk_monitoring_hours_ranges.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_hours_ranges: tk_monitoring_hours_ranges,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();

              // call update data source
              updateSplkWlk(tk_splk_wlk);

              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_wlk;
              object_category = "object";
              object_attrs =
                "monitoring_hours_ranges changed to:" +
                tk_monitoring_hours_ranges;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    $("#btn_modal_modify_splk_wlk_hours_ranges_no")
      .unbind()
      .click(function () {
        // free the populating search
        setToken("show_hours_ranges", "true");
        // Show input modal
        $("#modal_modify_monitoring_splk_wlk_hours_ranges_no").modal();
      });

    $("#btn_modal_modify_monitoring_splk_wlk_hours_ranges_no_confirm").click(
      function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_wlk = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_update_hours_ranges";

        // get ranges
        var tk_data_monitoring_hours_ranges_no = getToken(
          "tk_input_splk_wlk_hours_ranges_no"
        );

        if (
          !tk_data_monitoring_hours_ranges_no ||
          !tk_data_monitoring_hours_ranges_no.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_hours_ranges: tk_data_monitoring_hours_ranges_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();

              $("#modal_modify_splk_wlk_unified").modal();

              // call update data source
              updateSplkWlk(tk_splk_wlk);

              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring hours ranges applied successfully.",
                "5"
              );

              // pre-fill the form
              setToken(
                "form.tk_input_splk_wlk_hours_ranges",
                tk_data_monitoring_hours_ranges_no
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify hours ranges monitoring";
              object = tk_splk_wlk;
              object_category = "object";
              object_attrs =
                "data_monitoring_hours_ranges changed to:" +
                tk_data_monitoring_hours_ranges_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      }
    );

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_splk_wlk_hours_ranges_no_cancel").click(
      function () {
        // Show input modal
        $("#modal_modify_splk_wlk_unified").modal();
      }
    );

    // wlk priority
    $("#btn_modal_modify_priority_splk_wlk_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");
        var tk_priority = getToken("tk_priority");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_update_priority";

        var tk_origin_priority = tk_priority;
        var tk_new_priority = getToken("tk_input_splk_wlk_priority");

        if (!tk_new_priority || !tk_new_priority.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            priority: tk_new_priority,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();

              // call update data source
              updateSplkWlk(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Priority updated successfully.",
                "5"
              );

              // refresh tabulator
              $("#splk-wlk-table-refresh-hidden").click();

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify priority";
              object = tk_object;
              object_category = "object";
              object_attrs =
                "priority changed from:" +
                tk_origin_priority +
                " to:" +
                tk_new_priority;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // wdays splk-wlk

    $("#btn_modal_modify_splk_wlk_wdays")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_wdays").modal();
      });

    $("#btn_modal_modify_monitoring_splk_wlk_wdays_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_update_wdays";

        var tk_monitoring_wdays = getToken("tk_input_wdays_wlk");

        if (!tk_monitoring_wdays || !tk_monitoring_wdays.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_wdays: tk_monitoring_wdays,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();

              // call update data source
              updateSplkWlk(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;

              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "splk-wlk";
              object_attrs =
                "monitoring_wdays changed to:" + tk_monitoring_wdays;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // manual wdays
    $("#btn_modal_modify_splk_wlk_wdays_no")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_splk_wlk_wdays_no").modal();
      });

    // wdays manual
    $("#btn_modal_modify_monitoring_splk_wlk_wdays_no_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_wlk/write/wlk_update_wdays";

        var tk_monitoring_wdays_no = getToken("tk_input_splk_wlk_wdays_no");

        if (!tk_monitoring_wdays_no || !tk_monitoring_wdays_no.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            monitoring_wdays: tk_monitoring_wdays_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkWlkMain.startSearch();

              $("#modal_modify_splk_wlk_unified").modal();

              // call update data source
              updateSplkWlk(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // pre-fill current wdays input
              setToken("form.tk_input_wdays", tk_monitoring_wdays_no);

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "splk-wlk";
              object_attrs =
                "monitoring_wdays changed to:" + tk_monitoring_wdays_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_splk_wlk_wdays_no_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_splk_wlk_unified").modal();
      });

    //
    // splk-dsm
    //

    // wdays manual
    $("#btn_modal_modify_monitoring_wdays_no_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_wdays";

        var tk_data_monitoring_wdays_no = getToken("tk_input_wdays_no");

        if (
          !tk_data_monitoring_wdays_no ||
          !tk_data_monitoring_wdays_no.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_object,
            data_monitoring_wdays: tk_data_monitoring_wdays_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();

              $("#modal_modify_splk_dsm_unified").modal();

              // call update data source
              updateSplkDsm(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // pre-fill current wdays input
              setToken("form.tk_input_wdays", tk_data_monitoring_wdays_no);

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "data_source";
              object_attrs =
                "data_monitoring_wdays changed to:" +
                tk_data_monitoring_wdays_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_wdays_no_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_splk_dsm_unified").modal();
      });

    //
    // dcount host
    //

    $("#btn_modal_modify_dcount_host_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");
        var tk_min_dcount_host = getToken("tk_min_dcount_host");
        var tk_min_dcount_field = getToken("tk_min_dcount_field");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_min_dcount_host";

        var tk_input_splk_dsm_dcount_host = getToken(
          "tk_input_splk_dsm_dcount_host"
        );
        var tk_input_splk_dsm_dcount_field = getToken(
          "tk_input_splk_dsm_dcount_field"
        );
        var tk_origin_dcount_host = getToken("tk_min_dcount_host");

        if (
          !tk_input_splk_dsm_dcount_host ||
          !tk_input_splk_dsm_dcount_host.length
        ) {
          // notify
          notify(
            "error",
            "bottom",
            'ERROR: the minimal distinct host count value needs to be a positive integer, or the string "any" to define any value.',
            "5"
          );
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_object,
            min_dcount_host: tk_input_splk_dsm_dcount_host,
            min_dcount_field: tk_input_splk_dsm_dcount_field,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();

              // call update data source
              updateSplkDsm(tk_keyid);

              // notify
              notify(
                "success",
                "bottom",
                "Min dcount hosts updated successfully.",
                "5"
              );

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify minimal hosts distinct count number";
              object = tk_object;
              object_category = "data_source";
              object_attrs =
                "min_dcount_host changed from:" +
                tk_origin_dcount_host +
                " to:" +
                tk_input_splk_dsm_dcount_host;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    //
    // Modify lag
    //

    $("#btn_modal_modify_lag")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_lag").modal();
      });

    function splkDsmSetAutoLag(tenant_id, object_value, delay, latency) {
      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_lag_policy";

      // Create a dictionary to store the field names and values
      var record = {
        tenant_id: tenant_id,
        object_list: object_value,
        data_max_lag_allowed: latency,
        data_max_delay_allowed: delay,
      };

      // spinner
      cssloader("Requested action is in progress, please wait...");

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "text",
        beforeSend: function (xhr) {
          xhr.overrideMimeType("text/plain; charset=x-user-defined");
        },
        data: JSON.stringify(record),
        success: function (returneddata) {
          // spinner
          cssloaderremove();
          // Run the search again to update the table
          searchSplkDsmMain.startSearch();
          // call update data source
          updateSplkDsm(getToken("tk_keyid"));
          // notify
          notify(
            "success",
            "bottom",
            "Delay and ingest latency thresholds were applied successfully.",
            "5"
          );

          // refresh text inputs
          setToken("form.tk_input_lag", latency);
          setToken("form.tk_input_delay", delay);

          return;
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });
    }

    // open modal for treshold simulation
    $("#btn_modal_modify_lag_simulate")
      .unbind()
      .click(function () {
        $("#modal_splk_dsm_simulate_threshold").modal();
      });

    // run
    $("#btn_splk_dsm_simulate_thresholds")
      .unbind()
      .click(function () {
        // notify
        notify(
          "info",
          "bottom",
          "Running simulation against historical events and looking for latency and delay breached events...",
          "15"
        );
        searchSplkDsmSimulateThresholds.startSearch();
        searchSplkDsmSimulateThresholdsEvents.startSearch();
      });

    // apply
    $("#btn_splk_dsm_thresholds_apply")
      .unbind()
      .click(function () {
        setToken(
          "form.tk_input_lag",
          getToken("tk_input_splk_dsm_simulate_latency")
        );
        setToken(
          "form.tk_input_delay",
          getToken("tk_input_splk_dsm_simulate_delay")
        );
        $("#modal_modify_splk_dsm_unified").modal();
      });

    // back
    $("#btn_splk_dsm_simulate_thresholds_back")
      .unbind()
      .click(function () {
        $("#modal_modify_splk_dsm_unified").modal();
      });

    $("#btn_modal_modify_lag_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_lag_policy";

        // max lag allowed
        var tk_data_max_lag_allowed = getToken("tk_input_lag");

        // max delay allowed
        var tk_data_max_delay_allowed = getToken("tk_input_delay");

        // future_tolerance
        var tk_input_future_tolerance = getToken("tk_input_future_tolerance");

        // alert over kpis
        var tk_data_lag_alert_kpis = getToken("tk_input_data_lag_alert_kpis");

        // lagging class override
        var tk_data_override_lagging_class = getToken(
          "modal_input_lag_override_class"
        );

        // allow adaptive delay
        var tk_allow_adaptive_delay = getToken(
          "modal_input_allow_adaptive_delay"
        );

        if (
          !tk_data_max_lag_allowed ||
          !tk_data_max_lag_allowed.length ||
          !isNumeric(
            tk_data_max_lag_allowed ||
              !tk_data_max_delay_allowed ||
              !tk_data_max_delay_allowed.length ||
              !isNumeric(tk_data_max_delay_allowed)
          )
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_object,
            data_max_lag_allowed: tk_data_max_lag_allowed,
            data_max_delay_allowed: tk_data_max_delay_allowed,
            data_lag_alert_kpis: tk_data_lag_alert_kpis,
            data_override_lagging_class: tk_data_override_lagging_class,
            future_tolerance: tk_input_future_tolerance,
            allow_adaptive_delay: tk_allow_adaptive_delay,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDsmMain.startSearch();
              // call update data source
              updateSplkDsm(tk_keyid);
              // notify
              notify(
                "success",
                "bottom",
                "Max lag policies were updated successfully.",
                "5"
              );
              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify monitoring lag policy";
              object = tk_object;
              object_category = "data_source";
              object_attrs = {
                data_max_lag_allowed: tk_data_max_lag_allowed,
                data_max_delay_allowed: tk_data_max_delay_allowed,
                data_lag_alert_kpis: tk_data_lag_alert_kpis,
              };
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // Show main modal
    $("#btn_modal_modify_lag_auto_main")
      .unbind()
      .click(function () {
        // Free the searches
        setToken("show_splk_dsm_autolagging", "true");

        // Show modal
        $("#modal_modify_splk_dsm_autolag").modal();
      });

    // Show main modal back
    $("#btn_close_splk_dsm_unified_autolag")
      .unbind()
      .click(function () {
        $("#modal_modify_splk_dsm_unified").modal();
      });

    // auto lag perc95 7d
    $("#btn_dsm_modal_modify_lag_auto_perc95")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_7d_metrics"));
        splkDsmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["perc95_delay"],
          metrics["perc95_latency"]
        );
      });

    // auto lag avg 7d
    $("#btn_modal_dsm_modify_lag_auto_average")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_7d_metrics"));
        splkDsmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["avg_delay"],
          metrics["avg_latency"]
        );
      });

    // auto lag perc95 30d
    $("#btn_dsm_modal_modify_lag_auto_perc95_30d")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_30d_metrics"));
        splkDsmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["perc95_delay"],
          metrics["perc95_latency"]
        );
      });

    // auto lag avg 30d
    $("#btn_dsm_modal_modify_lag_auto_average_30d")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_30d_metrics"));
        splkDsmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["avg_delay"],
          metrics["avg_latency"]
        );
      });

    // splk-wlk

    $("#btn_modify_splk_wlk")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_splk_wlk").modal("hide");

        // Show input modal
        $("#modal_modify_splk_wlk_unified").modal();
      });

    // splk-flx monitoring

    $("#btn_modify_splk_flx")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_splk_flx").modal("hide");

        // Show input modal
        $("#modal_modify_splk_flx_unified").modal();
      });

    // metric host monitoring

    $("#btn_modify_splk_mhm")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_metrichost").modal("hide");

        // Show input modal
        $("#modal_modify_splk_mhm_unified").modal();
      });

    // data host monitoring

    $("#btn_modify_splk_dhm")
      .unbind()
      .click(function () {
        // Hide main modal
        $("#modal_manage_splk_dhm").modal("hide");

        // Show input modal
        $("#modal_modify_splk_dhm_unified").modal();
      });

    // cancel button: returns to selected
    $("#btn_close_splk_dhm_unified")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_dhm").modal();
      });

    //
    // Modify monitoring wdays
    //

    $("#btn_modal_modify_wdays_host")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_wdays_host").modal();
      });

    $("#btn_modal_modify_monitoring_wdays_host_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_splk_dhm");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_wdays";

        var tk_data_monitoring_wdays = getToken("tk_input_wdays_host");

        if (!tk_data_monitoring_wdays || !tk_data_monitoring_wdays.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            data_monitoring_wdays: tk_data_monitoring_wdays,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // call update data source
              updateSplkDhm(tk_splk_dhm);

              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_splk_dhm;
              object_category = "object";
              object_attrs =
                "data_monitoring_wdays changed to:" + tk_data_monitoring_wdays;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // host priority
    $("#btn_modal_modify_priority_host_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_splk_dhm");
        var tk_priority = getToken("tk_priority");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_priority";

        var tk_origin_priority = tk_priority;
        var tk_new_priority = getToken("tk_input_host_priority");

        if (!tk_new_priority || !tk_new_priority.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_splk_dhm,
            priority: tk_new_priority,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();

              // notify
              notify(
                "success",
                "bottom",
                "Priority updated successfully.",
                "5"
              );

              // call update data source
              updateSplkDhm(tk_splk_dhm);

              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify priority";
              object = tk_splk_dhm;
              object_category = "object";
              object_attrs =
                "priority changed from:" +
                tk_origin_priority +
                " to:" +
                tk_new_priority;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    $("#btn_modal_modify_wdays_host_no")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_monitoring_wdays_host_no").modal();
      });

    // Week days

    $("#btn_modal_modify_monitoring_wdays_host_no_confirm")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_wdays";

        var tk_data_monitoring_wdays_no = getToken("tk_input_wdays_no");

        if (
          !tk_data_monitoring_wdays_no ||
          !tk_data_monitoring_wdays_no.length
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            keys_list: tk_keyid,
            data_monitoring_wdays: tk_data_monitoring_wdays_no,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();

              $("#modal_modify_splk_dhm_unified").modal();

              // call update data source
              updateSplkDhm(tk_object);

              // notify
              notify(
                "success",
                "bottom",
                "Monitoring wdays applied successfully.",
                "5"
              );

              // pre-fill current wdays input
              setToken("form.tk_input_wdays_host", tk_data_monitoring_wdays_no);

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify week days monitoring";
              object = tk_object;
              object_category = "object";
              object_attrs =
                "data_monitoring_wdays changed to:" +
                tk_data_monitoring_wdays_no;
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // cancel: returns to unified modal
    $("#btn_modal_modify_monitoring_wdays_host_no_cancel")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_splk_dhm_unified").modal();
      });

    //
    // data source id
    //

    //
    // Modify lag
    //

    $("#btn_modal_modify_lag_host")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_modify_lag_host").modal();
      });

    function splkDhmSetAutoLag(tenant_id, object_value, delay, latency) {
      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_lag_policy";

      // Create a dictionary to store the field names and values
      var record = {
        tenant_id: tenant_id,
        object_list: object_value,
        data_max_lag_allowed: delay,
        data_max_delay_allowed: latency,
      };

      // spinner
      cssloader("Requested action is in progress, please wait...");

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "text",
        beforeSend: function (xhr) {
          xhr.overrideMimeType("text/plain; charset=x-user-defined");
        },
        data: JSON.stringify(record),
        success: function (returneddata) {
          // spinner
          cssloaderremove();
          // Run the search again to update the table
          searchSplkDhmMain.startSearch();

          // notify
          notify(
            "success",
            "bottom",
            "Delay and ingest latency thresholds were applied successfully.",
            "5"
          );

          // call update data source
          updateSplkDhm(getToken("tk_keyid"));

          // refresh tabulator
          $("#splk-dhm-table-refresh-hidden").click();

          // refresh text inputs
          setToken("form.tk_input_lag_host", delay);
          setToken("form.tk_input_delay_host", latency);

          return;
        },
        error: function (xhr, textStatus, error) {
          // spinner
          cssloaderremove();
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });
    }

    $("#btn_modal_modify_lag_confirm_host")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_splk_dhm = getToken("tk_splk_dhm");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dhm/write/dh_update_lag_policy";

        // max lag allowed
        var tk_data_max_lag_allowed = getToken("tk_input_lag_host");

        // max delay allowed
        var tk_data_max_delay_allowed = getToken("tk_input_delay_host");

        // alert over kpis
        var tk_data_lag_alert_kpis = getToken(
          "tk_input_data_lag_alert_kpis_host"
        );

        // alerting policy
        var tk_splk_dhm_alerting_policy = getToken(
          "tk_input_host_alerting_policy"
        );

        // lagging class override
        var tk_data_override_lagging_class = getToken(
          "modal_input_lag_override_class_host"
        );

        // lagging class override
        var tk_allow_adaptive_delay = getToken(
          "modal_input_allow_adaptive_delay_host"
        );

        // future tolerance
        var tk_future_tolerance = getToken("tk_input_future_tolerance_host");

        if (
          !tk_data_max_lag_allowed ||
          !tk_data_max_lag_allowed.length ||
          !isNumeric(tk_data_max_lag_allowed)
        ) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object_list: tk_splk_dhm,
            splk_dhm_alerting_policy: tk_splk_dhm_alerting_policy,
            data_max_lag_allowed: tk_data_max_lag_allowed,
            data_max_delay_allowed: tk_data_max_delay_allowed,
            data_lag_alert_kpis: tk_data_lag_alert_kpis,
            data_override_lagging_class: tk_data_override_lagging_class,
            future_tolerance: tk_future_tolerance,
            allow_adaptive_delay: tk_allow_adaptive_delay,
            update_comment: "N/A",
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // Run the search again to update the table
              searchSplkDhmMain.startSearch();

              // notify
              notify(
                "success",
                "bottom",
                "Max lag policies were updated successfully.",
                "5"
              );

              // call update data source
              updateSplkDhm(tk_splk_dhm);

              // refresh tabulator
              $("#splk-dhm-table-refresh-hidden").click();

              // house cleaning
              myendpoint_URl = undefined;
              delete myendpoint_URl;
              tk_keyid = undefined;
              delete tk_keyid;
              return;
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // Audit
              action = "failure";
              change_type = "modify monitoring lag policy";
              object = tk_splk_dhm;
              object_category = "object";
              object_attrs =
                '{"data_max_lag_allowed": "' +
                tk_data_max_lag_allowed +
                '", "data_max_delay_allowed": "' +
                tk_data_max_delay_allowed +
                '", "data_override_lagging_class": "' +
                tk_data_override_lagging_class +
                '", "data_lag_alert_kpis": ' +
                tk_data_lag_alert_kpis +
                '", "future_tolerance": ' +
                tk_future_tolerance +
                '"}';
              result = message;
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // Show main modal
    $("#btn_modal_modify_lag_auto_main_host")
      .unbind()
      .click(function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Free the searches
        setToken("show_splk_dhm_autolagging", "true");

        // Show modal
        $("#modal_modify_splk_dhm_autolag").modal();
      });

    // Show main modal back
    $("#btn_close_splk_dhm_unified_autolag")
      .unbind()
      .click(function () {
        $("#modal_modify_splk_dhm_unified").modal();
      });

    // auto lag perc95 7d
    $("#btn_dhm_modal_modify_lag_auto_perc95")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_7d_metrics"));
        splkDhmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["perc95_delay"],
          metrics["perc95_latency"]
        );
      });

    // auto lag avg 7d
    $("#btn_dhm_modal_modify_lag_auto_average")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_7d_metrics"));
        splkDhmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["avg_delay"],
          metrics["avg_latency"]
        );
      });

    // auto lag perc95 30d
    $("#btn_dhm_modal_modify_lag_auto_perc95_30d")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_30d_metrics"));
        splkDhmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["perc95_delay"],
          metrics["perc95_latency"]
        );
      });

    // auto lag avg 30d
    $("#btn_dhm_modal_modify_lag_auto_average_30d")
      .unbind()
      .click(function () {
        metrics = JSON.parse(getToken("tk_30d_metrics"));
        splkDhmSetAutoLag(
          getToken("tenant_id"),
          getToken("tk_object"),
          metrics["avg_delay"],
          metrics["avg_latency"]
        );
      });

    // Smart Status

    // Smart Status data source
    $("#btn_smart_status_splk_dsm")
      .unbind()
      .click(function () {
        // get token
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Show input modal
        $("#smart_status_splk_dsm").modal();

        // set the search
        setToken(
          "tk_splk_dsm_smart_status_search",
          "| trackme url=/services/trackme/v2/splk_smart_status/ds_smart_status mode=post body=\"{'tenant_id': '" +
            tk_tenant_id +
            "', 'object': '" +
            tk_object +
            "'}\" | `trackme_smart_status_emoji` | spath"
        );

        // Define the search button target
        var search_splk_dsm_smart_status =
          "search" +
          "?q=search" +
          encodeURI(
            " `trackme_idx(" +
              tk_tenant_id +
              ')` source="ds_smart_status"' +
              ' sourcetype=trackme:smart_status object="' +
              tk_object +
              '"'
          ) +
          "&earliest=-7d&latest=now";
        document.getElementById("btn_smart_status_splk_dsm_history").href =
          search_splk_dsm_smart_status;

        // Force search run every time the button is clicked
        searchSmartStatusSplkDsm.startSearch();
      });

    // back
    $("#btn_smart_status_splk_dsm_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_dsm").modal();
      });

    // Smart Status data host
    $("#btn_smart_status_splk_dhm")
      .unbind()
      .click(function () {
        // get token
        var tk_tenant_id = getToken("tenant_id");
        var tk_splk_dhm = getToken("tk_splk_dhm");

        // Show input modal
        $("#smart_status_splk_dhm").modal();

        // set the search
        setToken(
          "tk_splk_dhm_smart_status_search",
          "| trackme url=/services/trackme/v2/splk_smart_status/dh_smart_status mode=post body=\"{'tenant_id': '" +
            tk_tenant_id +
            "', 'object': '" +
            tk_splk_dhm +
            "'}\" | `trackme_smart_status_emoji` | spath"
        );

        // Force search run every time the button is clicked
        searchSmartStatusSplkDhm.startSearch();

        // Define the search button target
        var search_splk_dhm_smart_status =
          "search" +
          "?q=search" +
          encodeURI(
            " `trackme_idx(" +
              tk_tenant_id +
              ")` sourcetype=trackme:smart_status " +
              ' source=dh_smart_status object="' +
              tk_splk_dhm +
              '"'
          ) +
          "&earliest=-7d&latest=now";
        document.getElementById("btn_smart_status_splk_dhm_history").href =
          search_splk_dhm_smart_status;
      });

    // back
    $("#btn_smart_status_splk_dhm_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_dhm").modal();
      });

    // Smart Status metric host
    $("#btn_smart_status_splk_mhm")
      .unbind()
      .click(function () {
        // get token
        var tk_tenant_id = getToken("tenant_id");
        var tk_splk_mhm = getToken("tk_splk_mhm");

        // Show input modal
        $("#smart_status_splk_mhm").modal();

        // set the search
        setToken(
          "tk_splk_dhm_smart_status_search",
          "| trackme url=/services/trackme/v2/splk_smart_status/mh_smart_status mode=post body=\"{'tenant_id': '" +
            tk_tenant_id +
            "', 'object': '" +
            tk_splk_mhm +
            "'}\" | `trackme_smart_status_emoji` | spath"
        );

        // Force search run every time the button is clicked
        searchSmartStatusSplkMhm.startSearch();

        // Define the search button target
        var search_splk_mhm_smart_status =
          "search" +
          "?q=search" +
          encodeURI(
            " `trackme_idx(" +
              tk_tenant_id +
              ')` sourcetype=trackme:smart_status source="mh_smart_status"' +
              ' object="' +
              tk_splk_mhm +
              '"'
          ) +
          "&earliest=-7d&latest=now";
        document.getElementById("btn_smart_status_splk_mhm_history").href =
          search_splk_mhm_smart_status;
      });

    // back
    $("#btn_smart_status_splk_mhm_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_mhm").modal();
      });

    // Smart Status data source
    $("#btn_smart_status_splk_wlk")
      .unbind()
      .click(function () {
        // get token
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Show input modal
        $("#smart_status_splk_wlk").modal();

        // set the search
        setToken(
          "tk_splk_wlk_smart_status_search",
          "| trackme url=/services/trackme/v2/splk_smart_status/wlk_smart_status mode=post body=\"{'tenant_id': '" +
            tk_tenant_id +
            "', 'object': '" +
            tk_object +
            "'}\" | `trackme_smart_status_emoji` | spath"
        );

        // Define the search button target
        var search_splk_wlk_smart_status =
          "search" +
          "?q=search" +
          encodeURI(
            " `trackme_idx(" +
              tk_tenant_id +
              ')` source="wlk_smart_status"' +
              ' sourcetype=trackme:smart_status object="' +
              tk_object +
              '"'
          ) +
          "&earliest=-7d&latest=now";
        document.getElementById("btn_smart_status_splk_wlk_history").href =
          search_splk_wlk_smart_status;

        // Force search run every time the button is clicked
        searchSmartStatusSplkWlk.startSearch();
      });

    // back
    $("#btn_smart_status_splk_wlk_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_wlk").modal();
      });

    //
    // manage permanently deleted entities
    //

    // open screen
    $(".btn_manage_perm_deleted").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        var record = {
          tenant_id: getToken("tenant_id"),
          component: getToken("tk_component"),
        };

        permDeletedEntitiesHandlerTable(
          "/en-US/splunkd/__raw//services/trackme/v2/splk_deleted_entities/get_perm_deleted_entities",
          "POST",
          record
        );
      });
    });

    //
    // delete
    //

    $("#btn_confirm_modal_perm_deleted_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_perm_deleted");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Get component
        var tk_component = getToken("tk_component");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_deleted_entities/write/remove_perm_deleted_entities";

        // retrieve comment, if any
        comment = getComment("comment_modal_perm_deleted_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: tk_component,
          keys_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "remove permanently deleted entities",
          tk_multi_table_array,
          tk_component,
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Permanently deleted records successfully removed.",
                "5"
              );
              // refresh the tabulator
              permDeletedEntitiesHandlerTable(
                "/en-US/splunkd/__raw//services/trackme/v2/splk_deleted_entities/get_perm_deleted_entities",
                "POST",
                record
              );
            }
          }
        });
      });

    // tags

    // tags policies main
    $(".btn_modify_tags_policies").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        var record = {
          tenant_id: getToken("tenant_id"),
        };

        tagsPoliciesHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_tag_policies/tag_policies_show",
          "POST",
          record
        );
      });
    });

    $("#btn_modal_tags_policies_simulate")
      .unbind()
      .click(function () {
        // Retrieve the policy id
        var tk_tags_policies_policy_id = getToken("tk_tags_policies_policy_id");

        // Retrieve the regex rule
        var tk_tags_policies_regex = document.getElementById(
          "modal_input_tags_policies_regex"
        ).value;

        // Retrieve the tags list
        var tk_tags_policies_tags = document.getElementById(
          "modal_input_tags_policies_values"
        ).value;

        // if is not defined, give it a value and override text box content
        if (
          !tk_tags_policies_policy_id ||
          !tk_tags_policies_policy_id.length ||
          tk_tags_policies_regex ==
            "Enter a valid regular expression to match data source names." ||
          !tk_tags_policies_regex ||
          !tk_tags_policies_regex.length ||
          tk_tags_policies_tags ==
            'Enter a list of tags to applied separeted by commas to specify multiple tags and click on "Run policy simulation".' ||
          !tk_tags_policies_tags ||
          !tk_tags_policies_tags.length
        ) {
          // notify
          notify(
            "error",
            "bottom",
            "ERROR: Entries are either incorrect or incomplete, please correct and try again.",
            "5"
          );

          // Disable the add button
          document.getElementById(
            "btn_modal_tags_policies_add"
          ).disabled = true;
        } else {
          // notify
          notify("info", "bottom", "Starting tags policy simulation...", "5");

          // Set the tokens
          setToken("tk_tags_policies_regex", tk_tags_policies_regex);
          setToken("tk_tags_policies_tags", tk_tags_policies_tags);

          // Unset the token and set to free the search
          unsetToken("start_simulation_tags_policies");
          setToken("start_simulation_tags_policies", "true");

          // Disable the add button
          document.getElementById(
            "btn_modal_tags_policies_add"
          ).disabled = false;
        }
      });

    // add policy
    $("#btn_tags_policies_create")
      .unbind()
      .click(function () {
        // Show input modal
        $("#tags_policies_create_policy").modal();
      });

    // back button
    $("#btn_modal_tags_policies_add_back")
      .unbind()
      .click(function () {
        // Show input modal
        $("#manage_tags_policies").modal();
      });

    // add button
    $("#btn_modal_tags_policies_add")
      .unbind()
      .click(function () {
        // hide
        $("#tags_policies_create_policy").modal("hide");
        // Show input modal
        $("#tags_policies_create_policy_confirm").modal();
      });

    // add policy
    $("#btn_modal_add_tags_policy_confirm")
      .unbind()
      .click(function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Retrieve the policy id
        var tk_tags_policies_policy_id = getToken("tk_tags_policies_policy_id");

        // Retrieve the regex rule
        var tk_tags_policies_regex = document.getElementById(
          "modal_input_tags_policies_regex"
        ).value;

        // Retrieve the tags list
        var tk_tags_policies_tags = document.getElementById(
          "modal_input_tags_policies_values"
        ).value;

        // if is not defined, give it a value and override text box content - We should never reach this for the add function
        if (
          !tk_tags_policies_policy_id ||
          !tk_tags_policies_policy_id.length ||
          tk_tags_policies_regex ==
            "Enter a valid regular expression to match data source names." ||
          !tk_tags_policies_regex ||
          !tk_tags_policies_regex.length ||
          tk_tags_policies_tags ==
            'Enter a list of tags to applied separeted by commas to specify multiple tags and click on "Run policy simulation".' ||
          !tk_tags_policies_tags ||
          !tk_tags_policies_tags.length
        ) {
          // Show an error notification

          // notify
          notify(
            "error",
            "bottom",
            "ERROR: Entries are either incorrect or incomplete, please correct and try again.",
            "5"
          );

          // Disable the add button
          document.getElementById(
            "btn_modal_tags_policies_add"
          ).disabled = true;
        } else {
          // Retrieve update comment if any
          var tk_comment = getComment("input_add_tags_policy_sampling_comment");

          // Set the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_tag_policies/write/tag_policies_add";

          // set data for the POST call
          var record = {
            tenant_id: tk_tenant_id,
            tags_policy_id: tk_tags_policies_policy_id,
            tags_policy_value: tk_tags_policies_tags,
            tags_policy_regex: tk_tags_policies_regex,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            dataType: "json",
            data: JSON.stringify(record),
            contentType: "application/json",
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // notify
              notify(
                "success",
                "bottom",
                "Tags policy successfully added.",
                "5"
              );
              tagsPoliciesHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_tag_policies/tag_policies_show",
                "POST",
                { tenant_id: tk_tenant_id }
              );
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              // Audit
              action = "failure";
              change_type = "add tags policy";
              object = tk_tags_policies_policy_id;
              object_category = "all";
              object_attrs = JSON.stringify(record);
              result = "N/A";
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );
              closeModals();
              cssloaderremove();
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    //
    // Tags policies update
    //

    $("#btn_confirm_modal_tagspolicies_dsm_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_tagspolicies_dsm_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_tag_policies/write/tag_policies_update";

        // retrieve comment, if any
        comment = getComment("comment_modal_tagspolicies_dsm_confirm_save");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          records_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update tags policies",
          tk_multi_table_array,
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Tags policie(s) successfully updated.",
                "5"
              );
              // refresh the tabulator
              tagsPoliciesHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_tag_policies/tag_policies_show",
                "POST",
                record
              );
            }
          }
        });
      });

    //
    // Lagging classes delete
    //

    $("#btn_confirm_modal_tagspolicies_dsm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_tagspolicies_dsm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_tag_policies/write/tag_policies_del";

        // retrieve comment, if any
        comment = getComment("comment_modal_tagspolicies_dsm_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          tags_policy_id_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete tags policy",
          tk_multi_table_array,
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Tags policie(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              tagsPoliciesHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_tag_policies/tag_policies_show",
                "POST",
                record
              );
            }
          }
        });
      });

    // tags

    // back button
    $("#btn_back_manage_tags")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_dsm").modal();
      });

    // back button
    $("#btn_back_manage_tags")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_dsm").modal();
      });

    // back button
    $("#btn_back_update_tags")
      .unbind()
      .click(function () {
        // Show input modal
        $("#manage_tags").modal();
      });

    // update button
    $("#btn_modify_manage_tags")
      .unbind()
      .click(function () {
        // Refresh the multiselect
        unsetToken("form.modal_input_tags_update");
        unsetToken("modal_input_tags_update");

        // Refresh the main search
        searchShowTags.startSearch();

        // Show input modal
        $("#update_tags").modal();
      });

    // add button
    $("#btn_modal_tags_add")
      .unbind()
      .click(function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Retrieve input values
        var tk_tags_new = getToken("modal_input_tags_new");
        var tk_tags = getToken("tk_tags");
        var tk_tags_csv;

        // Combine current and new tag if relevant
        if (
          tk_tags !==
            "No tags defined, click on Update tags to define one or more tags to be associated with this data source." &&
          tk_tags !== "null" &&
          tk_tags != undefined
        ) {
          // form a csv tags list
          tk_tags_csv = tk_tags.replace(/ \/ /g, ",");
          tk_tags_new = tk_tags_csv + "," + tk_tags_new;
        }

        // Get tk mains
        var tk_object = getToken("tk_object");
        var tk_keyid = getToken("tk_keyid");

        // Define the query
        var searchQuery =
          "| inputlookup trackme_dsm_tenant_" +
          tk_tenant_id +
          ' where _key="' +
          tk_keyid +
          '" | eval keyid=_key, tags_manual="' +
          tk_tags_new +
          '" | outputlookup trackme_dsm_tenant_' +
          tk_tenant_id +
          " append=t key_field=keyid";

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a blocking search and get back a job
        service.search(searchQuery, searchParams, function (err, job) {
          function audit_failure() {
            // Audit
            action = "failure";
            change_type = "add tags";
            object = tk_object;
            object_category = "data_source";
            object_attrs = tk_tags_new;
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
          }

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            audit_failure();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "New tag(s) successfully added.",
                    "5"
                  );

                  // Update the tags token
                  tk_tags_audit = tk_tags_new;
                  tk_tags_new = tk_tags_new.replace(/,/g, " / ");
                  setToken("tk_tags", tk_tags_new);

                  // keep div up to date
                  $("#child-data-source-tag-content").html(
                    '<h2 style="font-weight: bold; color: darkslategray;">' +
                      tk_tags_new +
                      "</h2>"
                  );

                  // Refresh the multiselect
                  unsetToken("form.modal_input_tags_update");
                  unsetToken("modal_input_tags_update");

                  // Refresh the main search
                  searchShowTags.startSearch();
                  searchSplkDsmMain.startSearch();

                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();

                  var deps = ["splunkjs/ready!"];
                  require(deps, function (mvc) {
                    var idSelectTags = mvc.Components.get(
                      "modal_input_tags_update"
                    );
                    allValues = [];
                    uniqueNames = [];

                    var idSearchSelectTags =
                      mvc.Components.get("searchShowTags");
                    var idSearchSelectTags_results =
                      idSearchSelectTags.data("preview");
                    idSearchSelectTags_results.on("data", function () {
                      $.each(
                        idSearchSelectTags_results.data().rows,
                        function (index, value) {
                          allValues.push(value[0]);
                        }
                      );
                      $.each(allValues, function (i, el) {
                        if ($.inArray(el, uniqueNames) === -1)
                          uniqueNames.push(el);
                      });
                      idSelectTags.settings.set("default", uniqueNames);
                    });
                  });

                  // Make sure the link exposes Show tags
                  setToken("tk_tags_link_main", "Show tags");

                  // Audit
                  action = "success";
                  change_type = "add tags";
                  object = tk_object;
                  object_category = "data_source";
                  object_attrs = tk_tags_audit;
                  result = "N/A";
                  comment = "N/A";
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  audit_failure();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  audit_failure();
                  closeModals();
                  $("#modal_update_collection_failure_flush").modal();
                },
              }
            );
          }
        });
      });

    // modify button
    $("#btn_modal_tags_save")
      .unbind()
      .click(function () {
        // Get tenant_id
        var tk_tenant_id = getToken("tenant_id");

        // Retrieve input values
        var tk_tags_list = getToken("modal_input_tags_update");
        var tk_object = getToken("tk_object");
        var tk_keyid = getToken("tk_keyid");

        // Define the query
        var searchQuery =
          "| inputlookup trackme_dsm_tenant_" +
          tk_tenant_id +
          ' where _key="' +
          tk_keyid +
          '" | eval keyid=_key, tags_manual="' +
          tk_tags_list +
          '" | outputlookup trackme_dsm_tenant_' +
          tk_tenant_id +
          " append=t key_field=keyid";

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a blocking search and get back a job
        service.search(searchQuery, searchParams, function (err, job) {
          function audit_failure() {
            // Audit
            action = "failure";
            change_type = "update tags";
            object = tk_object;
            object_category = "data_source";
            object_attrs = tk_tags_list;
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
          }

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            audit_failure();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Tags list was updated successfully.",
                    "5"
                  );

                  // Audit
                  action = "success";
                  change_type = "update tags";
                  object = tk_object;
                  object_category = "data_source";
                  object_attrs = tk_tags_list;
                  result = "N/A";
                  comment = "N/A";
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );

                  // Update the tags token
                  tk_tags_list = tk_tags_list.replace(/,/g, " / ");
                  setToken("tk_tags", tk_tags_list);

                  // keep div up to date
                  $("#child-data-source-tag-content").html(
                    '<h2 style="font-weight: bold; color: darkslategray;">' +
                      tk_tags_list +
                      "</h2>"
                  );

                  // Refresh the main search
                  searchShowTags.startSearch();
                  searchSplkDsmMain.startSearch();

                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();

                  var deps = ["splunkjs/ready!"];
                  require(deps, function (mvc) {
                    var idSelectTags = mvc.Components.get(
                      "modal_input_tags_update"
                    );
                    allValues = [];
                    uniqueNames = [];

                    var idSearchSelectTags =
                      mvc.Components.get("searchShowTags");
                    var idSearchSelectTags_results =
                      idSearchSelectTags.data("preview");
                    idSearchSelectTags_results.on("data", function () {
                      $.each(
                        idSearchSelectTags_results.data().rows,
                        function (index, value) {
                          allValues.push(value[0]);
                        }
                      );
                      $.each(allValues, function (i, el) {
                        if ($.inArray(el, uniqueNames) === -1)
                          uniqueNames.push(el);
                      });
                      idSelectTags.settings.set("default", uniqueNames);
                    });
                  });

                  // Make sure the link exposes Show tags
                  setToken("tk_tags_link_main", "Show tags");
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  audit_failure();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  audit_failure();
                  closeModals();
                  $("#modal_update_collection_failure_flush").modal();
                },
              }
            );
          }
        });
      });

    // clear button
    $("#btn_modal_tags_clear")
      .unbind()
      .click(function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Retrieve input values
        var tk_tags_list = getToken("modal_input_tags_update");
        var tk_object = getToken("tk_object");
        var tk_keyid = getToken("tk_keyid");

        // Define the query
        var searchQuery =
          '| inputlookup trackme_dsm_tenant_$tenant_id$ where _key="' +
          tk_keyid +
          '" | eval keyid=_key | fields - tags_manual | outputlookup trackme_dsm_tenant_' +
          tk_tenant_id +
          " append=t key_field=keyid";

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a blocking search and get back a job
        service.search(searchQuery, searchParams, function (err, job) {
          function audit_failure() {
            // Audit
            action = "failure";
            change_type = "clear tags";
            object = tk_object;
            object_category = "data_source";
            object_attrs = tk_tags_list;
            result = "N/A";
            comment = "N/A";
            auditRecord(
              action,
              change_type,
              object,
              object_category,
              object_attrs,
              result,
              comment
            );
          }

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            audit_failure();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Tags list was cleared successfully.",
                    "5"
                  );

                  // Update the tags token
                  setToken(
                    "tk_tags",
                    "No tags defined, click on Update tags to define one or more tags to be associated with this data source."
                  );

                  // keep div up to date
                  $("#child-data-source-tag-content").html(
                    '<h2 style="font-weight: bold; color: darkslategray;">No tags defined, click on Update tags to define one or more tags to be associated with this data source.</h2>'
                  );

                  // Refresh the multiselect
                  unsetToken("form.modal_input_tags_update");
                  unsetToken("modal_input_tags_update");
                  unsetToken("form.modal_input_tags_new");

                  // Refresh the main search
                  searchShowTags.startSearch();
                  searchSplkDsmMain.startSearch();

                  // refresh tabulator
                  $("#splk-dsm-table-refresh-hidden").click();

                  // Make sure the link exposes "Click here to define tags"
                  setToken("tk_tags_link_main", "Click here to define tags");

                  // Audit
                  action = "success";
                  change_type = "clear tags";
                  object = tk_object;
                  object_category = "data_source";
                  object_attrs = tk_tags_list;
                  result = "N/A";
                  comment = "N/A";
                  auditRecord(
                    action,
                    change_type,
                    object,
                    object_category,
                    object_attrs,
                    result,
                    comment
                  );
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  audit_failure();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  audit_failure();
                  closeModals();
                  $("#modal_update_collection_failure_flush").modal();
                },
              }
            );
          }
        });
      });

    // data source identity documentation

    // back button
    $("#btn_back_manage_identity_card")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_dsm").modal();
      });

    $("#btn_close_define_identity_card")
      .unbind()
      .click(function () {
        // Show input modal
        $("#modal_manage_splk_dsm").modal();
      });

    // update button
    $("#btn_modify_manage_identity_card")
      .unbind()
      .click(function () {
        // Show input modal
        $("#define_identity_card").modal();
      });

    // delete button
    $("#btn_delete_manage_identity_card")
      .unbind()
      .click(function () {
        // Show deletion modal
        $("#delete_identity_card").modal();
      });

    // identity card

    $(".btn_define_identity_card").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        // spinner
        cssloader("Please wait performing the identity card creation...");

        //
        //
        //

        // Retrieve input values
        var input_doc_note = document.getElementById("input_doc_note").value;
        // replace chars that would lead the operation to fail
        var input_doc_note = input_doc_note.replace(/\"/g, '\\"');
        var input_doc_link = document.getElementById("input_doc_link").value;

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_identity_cards/write/identity_cards_add_card";

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          action: "associate",
          doc_note: input_doc_note,
          doc_link: input_doc_link,
          object_list: getToken("tk_object"),
          update_comment: getComment(
            "comment_modal_datasamplingmodels_dsm_confirm_delete"
          ),
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "create and associate identity card",
          getToken("tk_object"),
          "dsm",
          getComment("comment_modal_datasamplingmodels_dsm_confirm_delete")
        ).then(function (resultCall) {
          // spinner
          cssloaderremove();
          // notify
          notify(
            "success",
            "bottom",
            "A new idenfity card was successfully created and associated.",
            "5"
          );
          // Run the search again to update the table
          searchSplkDsmMain.startSearch();
          // refresh tabulator
          $("#splk-dsm-table-refresh-hidden").click();
          // return modal
          $("#update_achieved_identity_card").modal();
        });

        //
        //
        //
      });
    });

    // back
    $("#btn_define_identity_card_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#modal_manage_splk_dsm").modal();
      });

    // delete button
    $("#btn_delete_identity_card_confirm")
      .unbind()
      .click(function () {
        //
        //
        //

        // spinner
        cssloader("Please wait removing the identity card association...");

        //
        //
        //

        // Retrieve input values
        var input_doc_note = document.getElementById("input_doc_note").value;
        // replace chars that would lead the operation to fail
        var input_doc_note = input_doc_note.replace(/\"/g, '\\"');
        var input_doc_link = document.getElementById("input_doc_link").value;

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_identity_cards/write/identity_cards_manage_association";

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          action: "unassociate",
          doc_note: input_doc_note,
          doc_link: input_doc_link,
          object_list: getToken("tk_object"),
          update_comment: getComment(
            "comment_modal_datasamplingmodels_dsm_confirm_delete"
          ),
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "unassociate identity card",
          getToken("tk_object"),
          "dsm",
          getComment("comment_modal_datasamplingmodels_dsm_confirm_delete")
        ).then(function (resultCall) {
          // spinner
          cssloaderremove();
          // notify
          notify(
            "success",
            "bottom",
            "The identity card association was removed successfully.",
            "5"
          );
          // Run the search again to update the table
          searchSplkDsmMain.startSearch();
          // refresh tabulator
          $("#splk-dsm-table-refresh-hidden").click();
          // return modal
          $("#delete_achieved_identity_card").modal();
        });
        //
      });

    // back button
    $("#btn_delete_identity_card_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#define_identity_card").modal();
      });

    // associate identity card button
    $(".btn_associate_identity_card").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        // if the token exists already, restart the search, otherwise allow the search to start
        var tk_start_associate_identity_card = getToken(
          "tk_start_associate_identity_card"
        );

        if (
          tk_start_associate_identity_card &&
          tk_start_associate_identity_card.length
        ) {
          searchIdentityCardTable.startSearch();
        } else {
          setToken("tk_start_associate_identity_card", "true");
        }

        // Show modal
        $("#associate_identity_card").modal();
      });
    });

    // confirm button
    $("#btn_associate_identity_card_confirm_valid")
      .unbind()
      .click(function () {
        // spinner
        cssloader("Please wait performing the identity card association...");

        //
        //
        //

        // Retrieve input values
        var input_doc_note = document.getElementById("input_doc_note").value;
        // replace chars that would lead the operation to fail
        var input_doc_note = input_doc_note.replace(/\"/g, '\\"');
        var input_doc_link = document.getElementById("input_doc_link").value;

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_identity_cards/write/identity_cards_manage_association";

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          action: "associate",
          doc_link: getToken("tk_input_doc_link"),
          object_list: getToken("tk_object"),
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "associate identity card",
          getToken("tk_object"),
          "dsm",
          "N/A"
        ).then(function (resultCall) {
          // spinner
          cssloaderremove();
          // notify
          notify(
            "success",
            "bottom",
            "The identity card association was performed successfully.",
            "5"
          );
          // Run the search again to update the table
          searchSplkDsmMain.startSearch();
          // refresh tabulator
          $("#splk-dsm-table-refresh-hidden").click();
          // return modal
          $("#associate_achieved_identity_card").modal();
        });
        //
      });

    // back button
    $("#btn_associate_identity_card_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#define_identity_card").modal();
      });

    // back button
    $("#btn_associate_identity_card_confirm_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#associate_identity_card").modal();
      });

    // Acknowledgment

    $(".btn_ack").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        // The Ack duration is populated through a Splunk search, allow its start
        setToken("tk_start_ack_get", "true");

        // Get Ack record, if any.
        record = {
          tenant_id: getToken("tenant_id"),
          object_category: getToken("tk_object_category"),
          object_list: getToken("tk_object"),
        };

        ackHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/ack/get_ack_for_object",
          "POST",
          record,
          "true"
        );
      });
    });

    // Logical group

    // show modal
    $(".btn_logical_group").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);
        // Free the search
        setToken("tk_start_logical_member_get", "true");
        // Start the search
        searchLogicalGroupTable.startSearch();
        // set the logical group target token
        setToken("tk_logical_group_target", getToken("tk_object"));
        // make sure back actions are visible (would be hidden by bulk if hit)
        $("#btn_associate_logical_group_add_group_back").show();
        $("#btn_associate_logical_group_add_member_back").show();
        $("#btn_associate_logical_group_back").show();
        // show modal
        $("#logical_group").modal();
      });
    });

    // back
    $("#btn_associate_logical_group_back")
      .unbind()
      .click(function () {
        // retrieve token
        var tk_object_category = getToken("tk_object_category");
        // conditional modal target
        if (tk_object_category === "splk-dsm") {
          $("#modal_manage_splk_dsm").modal();
        } else if (tk_object_category === "splk-dhm") {
          $("#modal_manage_splk_dhm").modal();
        } else if (tk_object_category === "splk-mhm") {
          $("#modal_manage_splk_mhm").modal();
        }
      });

    // back delete
    $("#confirm_remove_from_logical_group")
      .unbind()
      .click(function () {
        $("#logical_group").modal();
      });

    // Remove from logical group
    $("#btn_remove_from_logical_group_confirm_valid")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_logical_group_target");
        var tk_object_category = getToken("tk_object_category");
        var tk_object_group_name = getToken("tk_object_group_name");

        if (tk_object && tk_object.length) {
          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_logical_groups/write/logical_groups_associate_group";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            action: "unassociate",
            object_group_name: tk_object_group_name,
            object_list: tk_object,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // notify
              msg =
                "Unassociation successfully proceeded, logical group " +
                tk_object_group_name;
              notify("success", "bottom", msg, "5");

              if (tk_object_category === "splk-dsm") {
                searchSplkDsmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-dsm-table-refresh-hidden").click();
              } else if (tk_object_category === "splk-dhm") {
                searchSplkDhmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-dhm-table-refresh-hidden").click();
              } else if (tk_object_category === "splk-mhm") {
                searchSplkMhmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-mhm-table-refresh-hidden").click();
              }
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });

          // house cleaning
          myendpoint_URl = undefined;
          delete myendpoint_URl;
          return;
        } else {
          invalidEntry();
          return;
        }
      });

    // Add logical group member
    $("#btn_add_logical_group_member")
      .unbind()
      .click(function () {
        // if the token exists already, restart the search, otherwise allow the search to start
        var tk_start_logical_member_add = getToken(
          "tk_start_logical_member_add"
        );

        if (tk_start_logical_member_add && tk_start_logical_member_add.length) {
          searchLogicalGroupTableAddMember.startSearch();
        } else {
          setToken("tk_start_logical_member_add", "true");
        }

        $("#logical_group_add_member").modal();
      });

    // Add logical group member
    $("#btn_add_logical_group_member_confirm_valid")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_logical_group_target");
        var tk_object_category = getToken("tk_object_category");

        // from click
        var tk_object_group_name = getToken("tk_object_group_name");

        if (tk_object && tk_object.length) {
          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_logical_groups/write/logical_groups_associate_group";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            action: "associate",
            object_group_name: tk_object_group_name,
            object_list: tk_object,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // notify
              msg =
                "Association successfully proceeded, logical group " +
                tk_object_group_name;
              notify("success", "bottom", msg, "5");

              // refresh searches
              if (tk_object_category === "splk-dsm") {
                searchSplkDsmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-dsm-table-refresh-hidden").click();
              } else if (tk_object_category === "splk-dhm") {
                searchSplkDhmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-dhm-table-refresh-hidden").click();
              } else if (tk_object_category === "splk-mhm") {
                searchSplkMhmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-mhm-table-refresh-hidden").click();
              }

              // return to modal
              $("#logical_group").modal();
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });

          // house cleaning
          myendpoint_URl = undefined;
          delete myendpoint_URl;
          return;
        } else {
          invalidEntry();
          return;
        }
      });

    // Add logical group member
    $("#btn_add_logical_group_new")
      .unbind()
      .click(function () {
        $("#logical_group_add_group").modal();
      });

    // back
    $("#btn_associate_logical_group_add_member_back")
      .unbind()
      .click(function () {
        $("#logical_group").modal();
      });

    // back
    $("#btn_associate_logical_group_add_group_back")
      .unbind()
      .click(function () {
        $("#logical_group").modal();
      });

    // back
    $("#btn_add_logical_group_member_confirm_back")
      .unbind()
      .click(function () {
        $("#logical_group").modal();
      });

    // Add logical group
    $("#btn_associate_logical_group_add_group")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_logical_group_target");
        var tk_object_category = getToken("tk_object_category");

        // from input
        var tk_object_group_name = getToken("InputLogicalGroupName");
        var tk_object_group_green_percent = getToken(
          "InputLogicalGroupNamePercent"
        );

        if (tk_object_group_name && tk_object_group_name.length) {
          // Create the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_logical_groups/write/logical_groups_associate_group";

          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            action: "associate",
            object_group_name: tk_object_group_name,
            object_list: tk_object,
            object_group_min_green_percent: tk_object_group_green_percent,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // notify
              msg =
                "The new logical group " +
                tk_object_group_name +
                " was successfully created";
              notify("success", "bottom", msg, "5");

              if (tk_object_category === "splk-dsm") {
                searchSplkDsmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-dsm-table-refresh-hidden").click();
              } else if (tk_object_category === "splk-dhm") {
                searchSplkDhmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-dhm-table-refresh-hidden").click();
              } else if (tk_object_category === "splk-mhm") {
                searchSplkMhmMain.startSearch();
                searchLogicalGroupTable.startSearch();
                // refresh tabulator
                $("#splk-mhm-table-refresh-hidden").click();
              }

              // return to modal
              $("#logical_group").modal();
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });

          // house cleaning
          myendpoint_URl = undefined;
          delete myendpoint_URl;
          return;
        } else {
          invalidEntry();
          return;
        }
      });

    //
    // flipping
    //

    $("#btn_refresh_flip")
      .unbind()
      .click(function () {
        searchMainAuditFlipPopulate.startSearch();
        searchMainAuditFlip.startSearch();
      });

    //
    // audit
    //

    $("#btn_refresh_audit")
      .unbind()
      .click(function () {
        searchMainAuditChangesPopulate.startSearch();
        searchMainAuditChanges.startSearch();
      });

    //
    // splk-dsm
    //

    $("#btn_refresh_dsm")
      .unbind()
      .click(function () {
        searchSplkDsmMain.startSearch();
        // refresh tabulator
        $("#splk-dsm-table-refresh-hidden").click();
      });

    //
    // splk-dhm
    //

    $("#btn_refresh_dhm")
      .unbind()
      .click(function () {
        searchSplkDhmMain.startSearch();
        // refresh tabulator
        $("#splk-dhm-table-refresh-hidden").click();
      });

    //
    // splk-mhm
    //

    $("#btn_refresh_mhm")
      .unbind()
      .click(function () {
        searchSplkMhmMain.startSearch();
        // refresh tabulator
        $("#splk-mhm-table-refresh-hidden").click();
      });

    //
    // splk-flx
    //

    $("#btn_refresh_flx")
      .unbind()
      .click(function () {
        searchSplkFlxMain.startSearch();
        // refresh tabulator
        $("#splk-flx-table-refresh-hidden").click();
      });

    //
    // splk-wlk
    //

    $("#btn_refresh_wlk")
      .unbind()
      .click(function () {
        searchSplkWlkMain.startSearch();
        // refresh tabulator
        $("#splk-wlk-table-refresh-hidden").click();
      });

    //
    // splk-cim
    //

    $("#btn_refresh_cim")
      .unbind()
      .click(function () {
        searchSplkCimMain.startSearch();
        // refresh tabulator
        $("#splk-cim-table-refresh-hidden").click();
      });

    // main modal for new cim tracker creation
    $("#btn_create_cim_tracker")
      .unbind()
      .click(function () {
        $("#modify_cim_trackers_main").modal();
      });

    $("#btn_manage_cim_trackers")
      .unbind()
      .click(function () {
        $("#modify_cim_trackers_main").modal();
      });

    $("#btn_add_cim_tracker")
      .unbind()
      .click(function () {
        // get the number of active hybrid trackers
        var license_is_valid = licenseCall["license_is_valid"];
        var license_active_cim_trackers =
          licenseCall["license_active_cim_trackers"];
        var license_subscription_class =
          licenseCall["license_subscription_class"];

        // proceed
        if (
          license_active_cim_trackers >= 16 &&
          license_subscription_class === "enterprise"
        ) {
          $("#modal_licensing_max_trackers")
            .find(".modal-info-message")
            .text(
              "There are " +
                license_active_cim_trackers +
                " active CIM trackers in total and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 16 active CIM trackers globally at a time." +
                " To create a new tracker, you can disable or delete an existing tracker, register a valid Unlimited license or start a Trial period."
            );
          $("#modal_licensing_max_trackers").modal();
        } else {
          // free some searches
          setToken("show_configuration_account_cim_tracker", "true");
          // force refresh the cim entity dropdown for cloning
          searchSplkCimPopulateClone.startSearch();
          // disable all actions by default
          // actions array
          var listId = [
            "btn_input_cim_tracker_upload_rules_submit",
            "btn_input_cim_tracker_clone_rules_submit",
            "btn_modal_input_cim_add",
            "btn_modal_input_cim_add_startover_rules",
            "btn_modal_input_cim_field_preview_json",
            "btn_modal_input_cim_tracker_simulate_clear",
            "btn_modal_input_cim_tracker_simulate_run",
            "btn_modal_input_cim_tracker_simulate",
            "btn_modal_input_cim_tracker_simulate_clearall",
            "btn_modal_input_cim_promote_live",
          ];
          // disable all actions
          for (var i = 0, l = listId.length; i < l; i++) {
            document.getElementById(listId[i]).disabled = true;
          }
          // show modal
          $("#modal_add_cim_tracker").modal();
        }
      });

    $("#btn_manager_cim_tracker")
      .unbind()
      .click(function () {
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "splk-cim",
        };
        cimTrackingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/cim_tracker_show",
          "POST",
          record,
          "cim"
        );
      });

    // multi deletion
    $("#btn_modal_cim_tracker_manage_delete")
      .unbind()
      .click(function () {
        $("#modal_cim_trackers_multi_delete").modal();
      });

    // back from create
    $("#btn_modal_cim_tracker_add_new_back")
      .unbind()
      .click(function () {
        $("#modify_cim_trackers_main").modal();
      });

    // back from delete
    $("#btn_modal_cim_tracker_manage_back")
      .unbind()
      .click(function () {
        $("#modify_cim_trackers_main").modal();
      });

    // run cim tracker now
    $("#modal_cim_tracker_run_tracker")
      .unbind()
      .click(function () {
        // Get the tracker name
        var tk_tracker_name = getToken("tk_cim_final_report");

        // Define the query
        var searchQuery =
          "| trackmeoneshotexecutor tenant_id=" +
          getToken("tenant_id") +
          ' report="' +
          tk_tracker_name +
          '"';

        // Set the search parameters--specify a time range
        var searchParams = {
          earliest_time: "-5m",
          latest_time: "now",
        };

        // Run a normal search that immediately returns the job's SID
        service.search(searchQuery, searchParams, function (err, job) {
          cssloader("Running the cim tracker...");

          // Shall the search fail before we can get properties
          if (job == null) {
            let errorStr = "Unknown Error!";
            if (
              err &&
              err.data &&
              err.data.messages &&
              err.data.messages[0]["text"]
            ) {
              errorStr = err.data.messages[0]["text"];
            } else if (err && err.data && err.data.messages) {
              errorStr = JSON.stringify(err.data.messages);
            }
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(errorStr);
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          } else {
            // Poll the status of the search job
            job.track(
              {
                period: 200,
              },
              {
                done: function (job) {
                  // Once the job is done, update all searches
                  searchSplkCimMain.startSearch();
                  // refresh tabulator
                  $("#splk-cim-table-refresh-hidden").click();
                  cssloaderremove();
                },
                failed: function (properties) {
                  let errorStr = "Unknown Error!";
                  if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages &&
                    properties._properties.messages[0]["text"]
                  ) {
                    errorStr = properties._properties.messages[0]["text"];
                  } else if (
                    properties &&
                    properties._properties &&
                    properties._properties.messages
                  ) {
                    errorStr = JSON.stringify(properties._properties.messages);
                  }
                  cssloaderremove();
                  $("#modal_update_collection_failure_return")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  closeModals();
                  $("#modal_update_collection_failure_return").modal();
                },
                error: function (err) {
                  done(err);
                  cssloaderremove();
                  closeModals();
                  $("#modal_update_collection_failure").modal();
                },
              }
            );
          }
        });
      });

    // object tags

    // return to unified modify when clicking on back
    $("#btn_back_splk_dhm_tags")
      .unbind()
      .click(function () {
        $("#modal_manage_splk_dhm").modal();
      });

    // return to unified modify when clicking on back
    $("#btn_back_splk_mhm_tags")
      .unbind()
      .click(function () {
        $("#modal_manage_splk_mhm").modal();
      });

    //
    // Outliers Anomaly Settings
    //

    //
    // splk-dsm
    //

    // Train ML models now

    function splk_dsm_train_models() {
      // Built the search URI
      var tk_tenant_id = getToken("tenant_id");
      var tk_object = getToken("tk_object");

      // Define the query
      var searchQuery =
        '| trackmesplkoutlierstrain tenant_id="' +
        tk_tenant_id +
        '" component="dsm" object="' +
        tk_object +
        '"';

      // Set the search parameters--specify a time range
      var searchParams = {
        earliest_time: "-5m",
        latest_time: "now",
      };

      // Run a normal search that immediately returns the job's SID
      service.search(searchQuery, searchParams, function (err, job) {
        // spinner
        cssloader("Running Machine Learning Models training now...");

        // Shall the search fail before we can get properties
        if (job == null) {
          let errorStr = "Unknown Error!";
          if (
            err &&
            err.data &&
            err.data.messages &&
            err.data.messages[0]["text"]
          ) {
            errorStr = err.data.messages[0]["text"];
          } else if (err && err.data && err.data.messages) {
            errorStr = JSON.stringify(err.data.messages);
          }
          cssloaderremove();
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(errorStr);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        } else {
          // Poll the status of the search job
          job.track(
            {
              period: 200,
            },
            {
              done: function (job) {
                // Run Ajax call
                OutliersAnomalySplkDsmHandlerTable(
                  "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                  "POST",
                  {
                    tenant_id: tk_tenant_id,
                    component: "dsm",
                    object: tk_object,
                  },
                  "outlier_config_splk_dsm"
                );
                cssloaderremove();
                $("#splk_dsm_outliers_manage").modal();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Machine Learning models were trained successfully for this entity.",
                  "5"
                );
                // ML is ready
                // refresh tabulator
                $("#splk-dsm-table-refresh-hidden").click();
                // Outliers render
                $("#divDsmOutliersInfo").css("display", "none");
                $("#divDsmOutliersRender").css("display", "inherit");
                setToken("tk_outliers_readiness", "True");
                // Outliers settings
                $("#divDsmOutliersSimulationInfo").css("display", "none");
                $("#divDsmOutliersSimulationRender").css("display", "inherit");
                $("#btn_outlier_config_splk_dsm_simulate").prop(
                  "disabled",
                  false
                );
                $("#btn_outlier_config_splk_dsm_save").prop("disabled", false);
              },
              failed: function (properties) {
                let errorStr = "Unknown Error!";
                if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages &&
                  properties._properties.messages[0]["text"]
                ) {
                  errorStr = properties._properties.messages[0]["text"];
                } else if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages
                ) {
                  errorStr = JSON.stringify(properties._properties.messages);
                }
                cssloaderremove();
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(errorStr);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
              error: function (err) {
                done(err);
                cssloaderremove();
                closeModals();
                $("#modal_update_collection_failure").modal();
              },
            }
          );
        }
      });
    }

    $("#btn_outlier_config_splk_dsm_train")
      .unbind()
      .click(function () {
        // call
        splk_dsm_train_models();
      });

    // Outliers anomaly detection configuration
    $("#btn_splk_dsm_manage_outliers")
      .unbind()
      .click(function () {
        setToken("show_splk_dsm_outlier_configuration", "true");

        // Get Tabulator
        OutliersAnomalySplkDsmHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "dsm",
            object: getToken("tk_object"),
          },
          "outlier_config_splk_dsm"
        );

        // Set the search target for get rules btn
        document.getElementById("btn_outlier_config_splk_dsm_getrules").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetrules tenant_id="' +
              getToken("tenant_id") +
              '" component="dsm" object="' +
              getToken("tk_object") +
              '"'
          );

        // Set the search target for get data btn
        document.getElementById("btn_outlier_config_splk_dsm_getdata").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetdata tenant_id="' +
              getToken("tenant_id") +
              '" component="dsm" object="' +
              getToken("tk_object") +
              '"'
          );

        // Open moal
        $("#splk_dsm_outliers_manage").modal();
      });

    // Go back
    $("#splk_dsm_outliers_manage_back")
      .unbind()
      .click(function () {
        $("#modal_manage_splk_dsm").modal();
        unsetToken("show_splk_dsm_outlier_configuration");
      });

    // Outliers anomaly detection periods exclusions
    $("#btn_outlier_config_splk_dsm_period_exclusions")
      .unbind()
      .click(function () {
        // Get Tabulator
        // spinner
        cssloader("Requested action is in progress, please wait...");
        OutliersAnomalyPeriodsExclusionSplkDsmHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "dsm",
            object: getToken("tk_object"),
            action: "show",
            model_id: getToken(
              "tk_input_splk_dsm_outliers_model_id_settings_dropdown"
            ),
          },
          "outlier_periods_exclusions_splk_dsm"
        );
      });

    // Go back
    $("#splk_dsm_outliers_periods_exclusions_back")
      .unbind()
      .click(function () {
        $("#splk_dsm_outliers_manage").modal();
      });

    // Run ML monitor
    $("#btn_outliers_dsm_run_monitor")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_mlmonitor_models";
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
          object: getToken("tk_object"),
        };

        // spinner
        cssloader(
          "Please wait while running ML monitor update for this entity, this can take some time..."
        );

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // notify
            notify(
              "success",
              "bottom",
              "ML monitor update terminated successfully.",
              "5"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // splk-flx
    //

    // Train ML models now

    function splk_flx_train_models() {
      // Built the search URI
      var tk_tenant_id = getToken("tenant_id");
      var tk_object = getToken("tk_object");

      // Define the query
      var searchQuery =
        '| trackmesplkoutlierstrain tenant_id="' +
        tk_tenant_id +
        '" component="flx" object="' +
        tk_object +
        '"';

      // Set the search parameters--specify a time range
      var searchParams = {
        earliest_time: "-5m",
        latest_time: "now",
      };

      // Run a normal search that immediately returns the job's SID
      service.search(searchQuery, searchParams, function (err, job) {
        // spinner
        cssloader("Running Machine Learning Models training now...");

        // Shall the search fail before we can get properties
        if (job == null) {
          let errorStr = "Unknown Error!";
          if (
            err &&
            err.data &&
            err.data.messages &&
            err.data.messages[0]["text"]
          ) {
            errorStr = err.data.messages[0]["text"];
          } else if (err && err.data && err.data.messages) {
            errorStr = JSON.stringify(err.data.messages);
          }
          cssloaderremove();
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(errorStr);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        } else {
          // Poll the status of the search job
          job.track(
            {
              period: 200,
            },
            {
              done: function (job) {
                // Run Ajax call
                OutliersAnomalySplkFlxHandlerTable(
                  "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                  "POST",
                  {
                    tenant_id: tk_tenant_id,
                    component: "flx",
                    object: tk_object,
                  },
                  "outlier_config_splk_flx"
                );
                cssloaderremove();
                $("#splk_flx_outliers_manage").modal();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Machine Learning models were trained successfully for this entity.",
                  "5"
                );
                // ML is ready
                // refresh tabulator
                $("#splk-flx-table-refresh-hidden").click();
                // Outliers render
                $("#divFlxOutliersInfo").css("display", "none");
                $("#divFlxOutliersRender").css("display", "inherit");
                setToken("tk_outliers_readiness", "True");
                // Outliers settings
                $("#divFlxOutliersSimulationInfo").css("display", "none");
                $("#divFlxOutliersSimulationRender").css("display", "inherit");
                $("#btn_outlier_config_splk_flx_simulate").prop(
                  "disabled",
                  false
                );
                $("#btn_outlier_config_splk_flx_save").prop("disabled", false);
              },
              failed: function (properties) {
                let errorStr = "Unknown Error!";
                if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages &&
                  properties._properties.messages[0]["text"]
                ) {
                  errorStr = properties._properties.messages[0]["text"];
                } else if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages
                ) {
                  errorStr = JSON.stringify(properties._properties.messages);
                }
                cssloaderremove();
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(errorStr);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
              error: function (err) {
                done(err);
                cssloaderremove();
                closeModals();
                $("#modal_update_collection_failure").modal();
              },
            }
          );
        }
      });
    }

    $("#btn_outlier_config_splk_flx_train")
      .unbind()
      .click(function () {
        // call
        splk_flx_train_models();
      });

    // Outliers anomaly detection configuration
    $("#btn_splk_flx_manage_outliers")
      .unbind()
      .click(function () {
        setToken("show_splk_flx_outlier_configuration", "true");

        // Get Tabulator
        OutliersAnomalySplkFlxHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "flx",
            object: getToken("tk_object"),
          },
          "outlier_config_splk_flx"
        );

        // Set the search target for get rules btn
        document.getElementById("btn_outlier_config_splk_flx_getrules").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetrules tenant_id="' +
              getToken("tenant_id") +
              '" component="flx" object="' +
              getToken("tk_object") +
              '"'
          );

        // Set the search target for get data btn
        document.getElementById("btn_outlier_config_splk_flx_getdata").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetdata tenant_id="' +
              getToken("tenant_id") +
              '" component="flx" object="' +
              getToken("tk_object") +
              '"'
          );

        // Open moal
        $("#splk_flx_outliers_manage").modal();
      });

    // Go back
    $("#splk_flx_outliers_manage_back")
      .unbind()
      .click(function () {
        $("#modal_manage_splk_flx").modal();
        unsetToken("show_splk_flx_outlier_configuration");
      });

    // Outliers anomaly detection periods exclusions
    $("#btn_outlier_config_splk_flx_period_exclusions")
      .unbind()
      .click(function () {
        // Get Tabulator
        // spinner
        cssloader("Requested action is in progress, please wait...");
        OutliersAnomalyPeriodsExclusionSplkFlxHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "flx",
            object: getToken("tk_object"),
            action: "show",
            model_id: getToken(
              "tk_input_splk_flx_outliers_model_id_settings_dropdown"
            ),
          },
          "outlier_periods_exclusions_splk_flx"
        );
      });

    // Go back
    $("#splk_flx_outliers_periods_exclusions_back")
      .unbind()
      .click(function () {
        $("#splk_flx_outliers_manage").modal();
      });

    // Run ML monitor
    $("#btn_outliers_flx_run_monitor")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_mlmonitor_models";
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
          object: getToken("tk_object"),
        };

        // spinner
        cssloader(
          "Please wait while running ML monitor update for this entity, this can take some time..."
        );

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // notify
            notify(
              "success",
              "bottom",
              "ML monitor update terminated successfully.",
              "5"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // splk-wlk
    //

    // Train ML models now

    function splk_wlk_train_models() {
      // Built the search URI
      var tk_tenant_id = getToken("tenant_id");
      var tk_object = getToken("tk_object");

      // Define the query
      var searchQuery =
        '| trackmesplkoutlierstrain tenant_id="' +
        tk_tenant_id +
        '" component="wlk" object="' +
        tk_object +
        '"';

      // Set the search parameters--specify a time range
      var searchParams = {
        earliest_time: "-5m",
        latest_time: "now",
      };

      // Run a normal search that immediately returns the job's SID
      service.search(searchQuery, searchParams, function (err, job) {
        // spinner
        cssloader("Running Machine Learning Models training now...");

        // Shall the search fail before we can get properties
        if (job == null) {
          let errorStr = "Unknown Error!";
          if (
            err &&
            err.data &&
            err.data.messages &&
            err.data.messages[0]["text"]
          ) {
            errorStr = err.data.messages[0]["text"];
          } else if (err && err.data && err.data.messages) {
            errorStr = JSON.stringify(err.data.messages);
          }
          cssloaderremove();
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(errorStr);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        } else {
          // Poll the status of the search job
          job.track(
            {
              period: 200,
            },
            {
              done: function (job) {
                // Run Ajax call
                OutliersAnomalySplkWlkHandlerTable(
                  "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                  "POST",
                  {
                    tenant_id: tk_tenant_id,
                    component: "wlk",
                    object: tk_object,
                  },
                  "outlier_config_splk_wlk"
                );
                cssloaderremove();
                $("#splk_wlk_outliers_manage").modal();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Machine Learning models were trained successfully for this entity.",
                  "5"
                );
                // ML is ready
                // refresh tabulator
                $("#splk-wlk-table-refresh-hidden").click();
                // Outliers render
                $("#divWlkOutliersInfo").css("display", "none");
                $("#divWlkOutliersRender").css("display", "inherit");
                setToken("tk_outliers_readiness", "True");
                // Outliers settings
                $("#divWlkOutliersSimulationInfo").css("display", "none");
                $("#divWlkOutliersSimulationRender").css("display", "inherit");
                $("#btn_outlier_config_splk_wlk_simulate").prop(
                  "disabled",
                  false
                );
                $("#btn_outlier_config_splk_wlk_save").prop("disabled", false);
              },
              failed: function (properties) {
                let errorStr = "Unknown Error!";
                if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages &&
                  properties._properties.messages[0]["text"]
                ) {
                  errorStr = properties._properties.messages[0]["text"];
                } else if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages
                ) {
                  errorStr = JSON.stringify(properties._properties.messages);
                }
                cssloaderremove();
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(errorStr);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
              error: function (err) {
                done(err);
                cssloaderremove();
                closeModals();
                $("#modal_update_collection_failure").modal();
              },
            }
          );
        }
      });
    }

    $("#btn_outlier_config_splk_wlk_train")
      .unbind()
      .click(function () {
        // call
        splk_wlk_train_models();
      });

    // Outliers anomaly detection configuration
    $("#btn_splk_wlk_manage_outliers")
      .unbind()
      .click(function () {
        setToken("show_splk_wlk_outlier_configuration", "true");

        // Get Tabulator
        OutliersAnomalySplkWlkHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "wlk",
            object: getToken("tk_object"),
          },
          "outlier_config_splk_wlk"
        );

        // Set the search target for get rules btn
        document.getElementById("btn_outlier_config_splk_wlk_getrules").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetrules tenant_id="' +
              getToken("tenant_id") +
              '" component="wlk" object="' +
              getToken("tk_object") +
              '"'
          );

        // Set the search target for get data btn
        document.getElementById("btn_outlier_config_splk_wlk_getdata").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetdata tenant_id="' +
              getToken("tenant_id") +
              '" component="wlk" object="' +
              getToken("tk_object") +
              '"'
          );

        // Open moal
        $("#splk_wlk_outliers_manage").modal();
      });

    // Go back
    $("#splk_wlk_outliers_manage_back")
      .unbind()
      .click(function () {
        $("#modal_manage_splk_wlk").modal();
        unsetToken("show_splk_wlk_outlier_configuration");
      });

    // Outliers anomaly detection periods exclusions
    $("#btn_outlier_config_splk_wlk_period_exclusions")
      .unbind()
      .click(function () {
        // Get Tabulator
        // spinner
        cssloader("Requested action is in progress, please wait...");
        OutliersAnomalyPeriodsExclusionSplkWlkHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "wlk",
            object: getToken("tk_object"),
            action: "show",
            model_id: getToken(
              "tk_input_splk_wlk_outliers_model_id_settings_dropdown"
            ),
          },
          "outlier_periods_exclusions_splk_wlk"
        );
      });

    // Go back
    $("#splk_wlk_outliers_periods_exclusions_back")
      .unbind()
      .click(function () {
        $("#splk_wlk_outliers_manage").modal();
      });

    // Run ML monitor
    $("#btn_outliers_wlk_run_monitor")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_mlmonitor_models";
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
          object: getToken("tk_object"),
        };

        // spinner
        cssloader(
          "Please wait while running ML monitor update for this entity, this can take some time..."
        );

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // notify
            notify(
              "success",
              "bottom",
              "ML monitor update terminated successfully.",
              "5"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // splk-cim
    //

    // Train ML models now

    function splk_cim_train_models() {
      // Built the search URI
      var tk_tenant_id = getToken("tenant_id");
      var tk_object = getToken("tk_object");

      // Define the query
      var searchQuery =
        '| trackmesplkoutlierscimtrain tenant_id="' +
        tk_tenant_id +
        '" component="cim" object="' +
        tk_object +
        '" cim_field=*';

      // Set the search parameters--specify a time range
      var searchParams = {
        earliest_time: "-5m",
        latest_time: "now",
      };

      // Run a normal search that immediately returns the job's SID
      service.search(searchQuery, searchParams, function (err, job) {
        // spinner
        cssloader("Running Machine Learning Models training now...");

        // Shall the search fail before we can get properties
        if (job == null) {
          let errorStr = "Unknown Error!";
          if (
            err &&
            err.data &&
            err.data.messages &&
            err.data.messages[0]["text"]
          ) {
            errorStr = err.data.messages[0]["text"];
          } else if (err && err.data && err.data.messages) {
            errorStr = JSON.stringify(err.data.messages);
          }
          cssloaderremove();
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(errorStr);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        } else {
          // Poll the status of the search job
          job.track(
            {
              period: 200,
            },
            {
              done: function (job) {
                // Run Ajax call
                OutliersAnomalySplkCimHandlerTable(
                  "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_cim_get_rules",
                  "POST",
                  {
                    tenant_id: tk_tenant_id,
                    object: tk_object,
                    entity: "*",
                    cim_field: "*",
                  },
                  "outlier_config_splk_cim"
                );
                cssloaderremove();
                $("#splk_cim_outliers_manage").modal();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Machine Learning models were trained successfully for this entity.",
                  "5"
                );
                // ML is ready
                // refresh tabulator
                $("#splk-cim-table-refresh-hidden").click();
                // Outliers render
                $("#divCimOutliersInfo").css("display", "none");
                $("#divCimOutliersRender").css("display", "inherit");
                setToken("tk_outliers_readiness", "True");
                // Outliers settings
                $("#divCimOutliersSimulationInfo").css("display", "none");
                $("#divCimOutliersSimulationRender").css("display", "inherit");
                $("#btn_outlier_config_splk_cim_simulate").prop(
                  "disabled",
                  false
                );
                $("#btn_outlier_config_splk_cim_save").prop("disabled", false);
              },
              failed: function (properties) {
                let errorStr = "Unknown Error!";
                if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages &&
                  properties._properties.messages[0]["text"]
                ) {
                  errorStr = properties._properties.messages[0]["text"];
                } else if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages
                ) {
                  errorStr = JSON.stringify(properties._properties.messages);
                }
                cssloaderremove();
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(errorStr);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
              error: function (err) {
                done(err);
                cssloaderremove();
                closeModals();
                $("#modal_update_collection_failure").modal();
              },
            }
          );
        }
      });
    }

    $("#btn_outlier_config_splk_cim_train")
      .unbind()
      .click(function () {
        // call
        splk_cim_train_models();
      });

    // Outliers anomaly detection configuration
    $("#btn_splk_cim_manage_outliers")
      .unbind()
      .click(function () {
        setToken("show_splk_cim_outlier_configuration", "true");

        // Get Tabulator
        OutliersAnomalySplkCimHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_cim_get_rules",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            object: getToken("tk_object"),
            entity: "*",
            cim_field: "*",
          },
          "outlier_config_splk_cim"
        );

        // Set the search target for get rules btn
        document.getElementById("btn_outlier_config_splk_cim_getrules").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutlierscimgetrules tenant_id="' +
              getToken("tenant_id") +
              '" component="cim" object="' +
              getToken("tk_object") +
              '" entity=* cim_field=*'
          );

        // Set the search target for get data btn
        document.getElementById("btn_outlier_config_splk_cim_getdata").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetdata tenant_id="' +
              getToken("tenant_id") +
              '" component="cim" object="' +
              getToken("tk_object") +
              '"'
          );

        // Open moal
        $("#splk_cim_outliers_manage").modal();
      });

    // Outliers anomaly detection periods exclusions
    $("#btn_outlier_config_splk_cim_period_exclusions")
      .unbind()
      .click(function () {
        // Get Tabulator
        // spinner
        cssloader("Requested action is in progress, please wait...");
        OutliersAnomalyPeriodsExclusionSplkCimHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "cim",
            object: getToken("tk_object"),
            cim_field: getToken("input_splk_cim_outliers_add_model_cim_field"),
            action: "show",
            model_id: getToken(
              "tk_input_splk_cim_outliers_model_id_settings_dropdown"
            ),
          },
          "outlier_periods_exclusions_splk_cim"
        );
      });

    // Go back
    $("#splk_cim_outliers_periods_exclusions_back")
      .unbind()
      .click(function () {
        $("#splk_cim_outliers_manage").modal();
      });

    // Go back
    $("#splk_cim_outliers_manage_back")
      .unbind()
      .click(function () {
        $("#modal_manage_cim").modal();
        unsetToken("show_splk_cim_outlier_configuration");
      });

    // Run ML monitor
    $("#btn_outliers_cim_run_monitor")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_cim_mlmonitor_models";
        var record = {
          tenant_id: getToken("tenant_id"),
          object: getToken("tk_object"),
        };

        // spinner
        cssloader(
          "Please wait while running ML monitor update for this entity, this can take some time..."
        );

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // notify
            notify(
              "success",
              "bottom",
              "ML monitor update terminated successfully.",
              "5"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    //
    // splk-dhm
    //

    // Train ML models now

    function splk_dhm_train_models() {
      // Built the search URI
      var tk_tenant_id = getToken("tenant_id");
      var tk_object = getToken("tk_object");

      // Define the query
      var searchQuery =
        '| trackmesplkoutlierstrain tenant_id="' +
        tk_tenant_id +
        '" component="dhm" object="' +
        tk_object +
        '"';

      // Set the search parameters--specify a time range
      var searchParams = {
        earliest_time: "-5m",
        latest_time: "now",
      };

      // Run a normal search that immediately returns the job's SID
      service.search(searchQuery, searchParams, function (err, job) {
        // spinner
        cssloader("Running Machine Learning Models training now...");

        // Shall the search fail before we can get properties
        if (job == null) {
          let errorStr = "Unknown Error!";
          if (
            err &&
            err.data &&
            err.data.messages &&
            err.data.messages[0]["text"]
          ) {
            errorStr = err.data.messages[0]["text"];
          } else if (err && err.data && err.data.messages) {
            errorStr = JSON.stringify(err.data.messages);
          }
          cssloaderremove();
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(errorStr);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        } else {
          // Poll the status of the search job
          job.track(
            {
              period: 200,
            },
            {
              done: function (job) {
                // Run Ajax call
                OutliersAnomalySplkDhmHandlerTable(
                  "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                  "POST",
                  {
                    tenant_id: tk_tenant_id,
                    component: "dhm",
                    object: tk_object,
                  },
                  "outlier_config_splk_dhm"
                );
                cssloaderremove();
                $("#splk_dhm_outliers_manage").modal();
                // notify
                notify(
                  "success",
                  "bottom",
                  "Machine Learning models were trained successfully for this entity.",
                  "5"
                );
                // ML is ready
                // refresh tabulator
                $("#splk-dhm-table-refresh-hidden").click();
                // Outliers render
                $("#divDhmOutliersInfo").css("display", "none");
                $("#divDhmOutliersRender").css("display", "inherit");
                setToken("tk_outliers_readiness", "True");
                // Outliers settings
                $("#divDhmOutliersSimulationInfo").css("display", "none");
                $("#divDhmOutliersSimulationRender").css("display", "inherit");
                $("#btn_outlier_config_splk_dhm_simulate").prop(
                  "disabled",
                  false
                );
                $("#btn_outlier_config_splk_dhm_save").prop("disabled", false);
              },
              failed: function (properties) {
                let errorStr = "Unknown Error!";
                if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages &&
                  properties._properties.messages[0]["text"]
                ) {
                  errorStr = properties._properties.messages[0]["text"];
                } else if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages
                ) {
                  errorStr = JSON.stringify(properties._properties.messages);
                }
                cssloaderremove();
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(errorStr);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
              error: function (err) {
                done(err);
                cssloaderremove();
                closeModals();
                $("#modal_update_collection_failure").modal();
              },
            }
          );
        }
      });
    }

    $("#btn_outlier_config_splk_dhm_train")
      .unbind()
      .click(function () {
        // call
        splk_dhm_train_models();
      });

    // Outliers anomaly detection configuration
    $("#btn_splk_dhm_manage_outliers")
      .unbind()
      .click(function () {
        setToken("show_splk_dhm_outlier_configuration", "true");

        // Get Tabulator
        OutliersAnomalySplkDhmHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "dhm",
            object: getToken("tk_object"),
          },
          "outlier_config_splk_dhm"
        );

        // Set the search target for get rules btn
        document.getElementById("btn_outlier_config_splk_dhm_getrules").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetrules tenant_id="' +
              getToken("tenant_id") +
              '" component="dhm" object="' +
              getToken("tk_object") +
              '"'
          );

        // Set the search target for get data btn
        document.getElementById("btn_outlier_config_splk_dhm_getdata").href =
          "search" +
          "?q=" +
          encodeURI(
            '| trackmesplkoutliersgetdata tenant_id="' +
              getToken("tenant_id") +
              '" component="dhm" object="' +
              getToken("tk_object") +
              '"'
          );

        // Open moal
        $("#splk_dhm_outliers_manage").modal();
      });

    // Go back
    $("#splk_dhm_outliers_manage_back")
      .unbind()
      .click(function () {
        $("#modal_manage_splk_dhm").modal();
        unsetToken("show_splk_dhm_outlier_configuration");
      });

    // Outliers anomaly detection periods exclusions
    $("#btn_outlier_config_splk_dhm_period_exclusions")
      .unbind()
      .click(function () {
        // Get Tabulator
        // spinner
        cssloader("Requested action is in progress, please wait...");
        OutliersAnomalyPeriodsExclusionSplkDhmHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
          "POST",
          {
            tenant_id: getToken("tenant_id"),
            component: "dhm",
            object: getToken("tk_object"),
            action: "show",
            model_id: getToken(
              "tk_input_splk_dhm_outliers_model_id_settings_dropdown"
            ),
          },
          "outlier_periods_exclusions_splk_dhm"
        );
      });

    // Go back
    $("#splk_dhm_outliers_periods_exclusions_back")
      .unbind()
      .click(function () {
        $("#splk_dhm_outliers_manage").modal();
      });

    // Run ML monitor
    $("#btn_outliers_dhm_run_monitor")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_mlmonitor_models";
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
          object: getToken("tk_object"),
        };

        // spinner
        cssloader(
          "Please wait while running ML monitor update for this entity, this can take some time..."
        );

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // notify
            notify(
              "success",
              "bottom",
              "ML monitor update terminated successfully.",
              "5"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // Data sampling
    $(".btn_data_sampling_manage").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        // Get vars
        var tk_tenant_id = getToken("tenant_id");
        var tk_keyid = getToken("tk_keyid");
        var tk_object = getToken("tk_object");

        // Run Ajax call
        splkDsmSamplingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_dsm_sampling",
          "POST",
          { tenant_id: tk_tenant_id, object: getToken("tk_object") },
          "splk-dsm"
        );

        // Built the search URI
        var search_latest_sample =
          "search" +
          "?q=" +
          encodeURI(
            "| inputlookup trackme_dsm_data_sampling_tenant_" +
              tk_tenant_id +
              ' where object="' +
              tk_object +
              '" | fields raw_sample | mvexpand raw_sample | eval ' +
              " [ | inputlookup trackme_dsm_tenant_" +
              tk_tenant_id +
              ' where object="' +
              tk_object +
              '" | fields data_sourcetype | return data_sourcetype ]' +
              " | `trackme_data_sampling_abstract_detect_events_format(" +
              tk_tenant_id +
              ")` | lookup trackme_dsm_data_sampling_custom_models_tenant_" +
              tk_tenant_id +
              ' model_name as current_detected_format output model_type | eval model_type=if(isnull(model_type) AND isnotnull(current_detected_format), "inclusive", model_type)'
          );

        // Verify the current data sampling obfuscation mode, if enabled we change the search target
        var splk_dsm_obfuscation_mode = getToken("splk_dsm_obfuscation_mode");

        if (!splk_dsm_obfuscation_mode) {
          // Define the URL target
          document.getElementById("btn_data_sampling_latest_sample").href =
            search_latest_sample;
          return;
        }

        // Dynamically manage buttons states
        if (splk_dsm_obfuscation_mode == "enabled") {
          search_latest_sample =
            "search" +
            "?q=" +
            encodeURI(
              "| inputlookup trackme_dsm_data_sampling_tenant_" +
                tk_tenant_id +
                ' where object="' +
                tk_object +
                '" | fields raw_sample'
            );
          // Define the URL target
          document.getElementById("btn_data_sampling_latest_sample").href =
            search_latest_sample;
        } else if (splk_dsm_obfuscation_mode == "disabled") {
          // Define the URL target
          document.getElementById("btn_data_sampling_latest_sample").href =
            search_latest_sample;
        } else {
          // Define the URL target
          document.getElementById("btn_data_sampling_latest_sample").href =
            search_latest_sample;
        }

        // Run engine should not be granted when an anomaly was found at first discovery
        var data_sample_anomaly_reason = getToken(
          "tk_data_sample_anomaly_reason"
        );
        if (data_sample_anomaly_reason == "multiformat_at_discovery") {
          document.getElementById("btn_run_data_sampling").disabled = true;
        } else {
          document.getElementById("btn_run_data_sampling").disabled = false;
        }
      });
    });

    // Back button
    $(".btn_data_sampling_back").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);
        $("#modal_manage_splk_dsm").modal();
      });
    });

    // Show builtin rules
    $(".btn_data_sampling_builtin_rules").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);
        $("#data_sampling_show_builtin_rules").modal();
      });
    });

    // Back button
    $(".btn_data_sampling_builtin_rules_back").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);
        $("#data_sampling_manage").modal();
      });
    });

    // Show custom rules from data source
    $("#btn_data_sampling_custom_rules_view")
      .unbind("click")
      .click(function () {
        // Hide the back button
        var btn_back = document.getElementById(
          "btn_data_sampling_custom_rules_back"
        );
        btn_back.style.display = "inline-block";
        // load tabulator
        dataSamplingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/data_sampling_rules_show",
          "POST",
          { tenant_id: getToken("tenant_id") }
        );
      });

    // Show custom rules from main
    $("#btn_modify_data_sampling_rules")
      .unbind("click")
      .click(function () {
        // Hide the back button
        var btn_back = document.getElementById(
          "btn_data_sampling_custom_rules_back"
        );
        btn_back.style.display = "none";

        var record = {
          tenant_id: getToken("tenant_id"),
        };

        dataSamplingHandlerTable(
          "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/data_sampling_rules_show",
          "POST",
          record
        );
      });

    // Back button
    $(".btn_data_sampling_custom_rules_back").each(function () {
      var $btn_group = $(this);
      $btn_group.find("button").on("click", function () {
        var $btn = $(this);

        // target
        $("#data_sampling_manage").modal();
      });
    });

    //
    // data samplig custom rules delete
    //

    $("#btn_confirm_modal_datasamplingmodels_dsm_confirm_delete").click(
      function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_datasamplingmodels_dsm_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/write/data_sampling_models_del";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_datasamplingmodels_dsm_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "splk-dsm",
          models_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete data sampling model",
          tk_multi_table_array,
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Data sampling custom model(s) successfully deleted.",
                "5"
              );
              // refresh the tabulator
              dataSamplingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/data_sampling_rules_show",
                "POST",
                record
              );
            }
          }
        });
      }
    );

    //
    // Data sampling custom models update
    //

    $("#btn_confirm_modal_datasamplingmodels_dsm_confirm_save").click(
      function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_datasamplingmodels_dsm_update");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/write/data_sampling_models_update";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_datasamplingmodels_dsm_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "splk-dsm",
          records_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update data sampling policies",
          tk_multi_table_array,
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "Data sampling model(s) successfully updated.",
                "5"
              );
              // refresh the tabulator
              dataSamplingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/data_sampling_rules_show",
                "POST",
                record
              );
            }
          }
        });
      }
    );

    // Run data sampling engine
    $("#btn_run_data_sampling")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_manage_data_sampling";
        var record = {
          tenant_id: getToken("tenant_id"),
          object_list: getToken("tk_object"),
          action: "run",
        };

        //
        // Call TrackMe API endpoint
        //

        // spinner
        cssloader("Running the data sampling and format recognition engine...");

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Refresh
            splkDsmSamplingHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_dsm_sampling",
              "POST",
              {
                tenant_id: getToken("tenant_id"),
                object: getToken("tk_object"),
              },
              "splk-dsm"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // Disable action
    $("#btn_data_sampling_disable")
      .unbind()
      .click(function () {
        $("#modal_disable_data_sampling").modal();
      });

    // Proceed
    $("#btn_modal_data_sampling_disable_confirm")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_manage_data_sampling";
        var record = {
          tenant_id: getToken("tenant_id"),
          object_list: getToken("tk_object"),
          action: "disable",
          update_comment: getComment("input_disable_data_sampling_comment"),
        };

        //
        // Call TrackMe API endpoint
        //

        // spinner
        cssloader("Disabling Data Sampling for this entity...");

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Refresh
            splkDsmSamplingHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_dsm_sampling",
              "POST",
              {
                tenant_id: getToken("tenant_id"),
                object: getToken("tk_object"),
              },
              "splk-dsm"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // Enable action
    $("#btn_data_sampling_enable")
      .unbind()
      .click(function () {
        $("#modal_enable_data_sampling").modal();
      });

    // Proceed
    $("#btn_modal_data_sampling_enable_confirm")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_manage_data_sampling";
        var record = {
          tenant_id: getToken("tenant_id"),
          object_list: getToken("tk_object"),
          action: "enable",
          update_comment: getComment("input_enable_data_sampling_comment"),
        };

        //
        // Call TrackMe API endpoint
        //

        // spinner
        cssloader("Enabling Data Sampling for this entity...");

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Refresh
            splkDsmSamplingHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_dsm_sampling",
              "POST",
              {
                tenant_id: getToken("tenant_id"),
                object: getToken("tk_object"),
              },
              "splk-dsm"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // Update number of records per sample
    $("#btn_data_sampling_edit_records_nr")
      .unbind()
      .click(function () {
        $("#modal_update_records_nr_data_sampling").modal();
      });

    // Proceed
    $("#btn_update_records_nr_confirm")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_update_data_sampling_records_nr";
        var record = {
          tenant_id: getToken("tenant_id"),
          object_list: getToken("tk_object"),
          data_sampling_nr: getToken("tk_input_data_sampling_records_nr"),
          update_comment: getComment(
            "input_update_records_nr_data_sampling_comment"
          ),
        };

        //
        // Call TrackMe API endpoint
        //

        // spinner
        cssloader("Updating Data Sampling configuration for this entity...");

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Refresh
            splkDsmSamplingHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_dsm_sampling",
              "POST",
              {
                tenant_id: getToken("tenant_id"),
                object: getToken("tk_object"),
              },
              "splk-dsm"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    $("#btn_update_records_nr_confirm_back")
      .unbind()
      .click(function () {
        // Return to modal
        $("#data_sampling_manage").modal();
      });

    // Clear state action
    $("#btn_data_sampling_clear_now")
      .unbind()
      .click(function () {
        $("#modal_clear_state_data_sampling").modal();
      });

    // Back button
    $("#btn_modal_clear_state_confirm_back")
      .unbind()
      .click(function () {
        // Return to modal
        $("#data_sampling_manage").modal();
      });

    // Clear state action button is confirmed
    $("#btn_modal_clear_state_confirm")
      .unbind()
      .click(function () {
        // Endpoint URI
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/write/ds_manage_data_sampling";
        var record = {
          tenant_id: getToken("tenant_id"),
          object_list: getToken("tk_object"),
          action: "reset",
          update_comment: getComment("input_clear_state_data_sampling_comment"),
        };

        //
        // Call TrackMe API endpoint
        //

        // spinner
        cssloader(
          "Clearing the data source state and running the data sampling and format recognition engine..."
        );

        // API call
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // Refresh
            splkDsmSamplingHandlerTable(
              "/en-US/splunkd/__raw/services/trackme/v2/splk_dsm/ds_get_dsm_sampling",
              "POST",
              {
                tenant_id: getToken("tenant_id"),
                object: getToken("tk_object"),
              },
              "splk-dsm"
            );
            // Remove spinner
            cssloaderremove();
          },
          error: function (xhr, textStatus, error) {
            cssloaderremove();
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(xhr));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          },
        });
      });

    // Back button
    $("#btn_modal_data_sampling_disable_confirm_back")
      .unbind()
      .click(function () {
        // Return to modal
        $("#data_sampling_manage").modal();
      });

    // Back button
    $("#btn_modal_data_sampling_enable_confirm_back")
      .unbind()
      .click(function () {
        // Return to modal
        $("#data_sampling_manage").modal();
      });

    // Data sampling custom rules
    $("#btn_data_sampling_custom_rules")
      .unbind()
      .click(function () {
        // Get the current data source
        var tk_object = getToken("tk_object");
        var tk_splk_dsmtype = getToken("tk_splk_dsmtype");

        // Apply to the form inputs
        setToken("form.tk_input_data_sampling_dropdown", tk_object);
        setToken("form.tk_data_sampling_custom_st_value", tk_splk_dsmtype);

        // Unset action tokens
        unsetToken("start_simulation_data_sampling_custom_rule_show_events");
        unsetToken("start_simulation_data_sampling_custom_rule");

        // Disable the button results
        document.getElementById(
          "btn_modal_data_sampling_custom_rule_simulate_show_details"
        ).disabled = true;
        document.getElementById(
          "btn_data_sampling_custom_rule_add"
        ).disabled = true;

        // Free the dropdown populating search
        setToken("start_search_input_data_sampling_dropdown", "true");

        // force re-run the search each time the button is clicked
        searchPopulateDataSampling.startSearch();

        // Open modal
        $("#data_sampling_create_custom_rules").modal();
      });

    // Back button
    $("#btn_modal_data_sampling_custom_rule_add_new_back")
      .unbind()
      .click(function () {
        // Show modal
        $("#data_sampling_show_custom_rules").modal();
      });

    // Data sampling custom rule simulation
    $("#btn_modal_data_sampling_custom_rule_show_sample")
      .unbind()
      .click(function () {
        // show the sample table
        $("#divTableDataSamplingSample").css("display", "inherit");

        // Unset the token and set to free the search
        unsetToken("start_simulation_data_sampling_custom_rule_show_events");
        setToken(
          "start_simulation_data_sampling_custom_rule_show_events",
          "true"
        );
      });

    // Data sampling custom rule simulation
    $("#btn_modal_data_sampling_custom_rule_simulate")
      .unbind()
      .click(function () {
        // show the simulation div
        $("#divTableDataSamplingSimulate").css("display", "inherit");

        // Retrieve the regex rule
        var tk_data_sampling_custom_rule_regex = document.getElementById(
          "modal_input_data_sampling_custom_rule_regex"
        ).value;

        // Retrieve the rule name
        var tk_data_sampling_custom_rule_name = getToken(
          "tk_data_sampling_custom_rule_name"
        );

        // Retrieve the key id
        var tk_keyid = getToken("tk_keyid");

        // if is not defined, give it a value and override text box content
        if (
          tk_data_sampling_custom_rule_regex ==
            'Enter a valid regular expression and click on the button "Run model simulation".' ||
          !tk_data_sampling_custom_rule_name ||
          !tk_data_sampling_custom_rule_name.length
        ) {
          // notify
          notify(
            "error",
            "bottom",
            "ERROR: Entries are either incorrect or incomplete, please correct and try again.",
            "5"
          );

          // Disable the add button
          document.getElementById(
            "btn_data_sampling_custom_rule_add"
          ).disabled = true;
        } else {
          // replace the textarea for modification requests

          // notify
          notify("info", "bottom", "Running new data sampling model...", "5");

          unsetToken("tk_data_sampling_custom_rule_regex");
          setToken(
            "tk_data_sampling_custom_rule_regex",
            tk_data_sampling_custom_rule_regex
          );
          // Free the simulation search
          setToken("start_simulation_data_sampling_custom_rule", "true");

          // Define the URL target
          document.getElementById(
            "btn_modal_data_sampling_custom_rule_simulate_show_details"
          ).disabled = false;

          // Enable the button results
          document.getElementById(
            "btn_modal_data_sampling_custom_rule_simulate_show_details"
          ).disabled = false;

          // Enable the add button
          document.getElementById(
            "btn_data_sampling_custom_rule_add"
          ).disabled = false;

          // show the sample table (agin if previously showned)
          //$("#divTableDataSamplingSample").css("display", "inherit");
        }
      });

    // Data sampling add custom rule
    $("#btn_data_sampling_custom_rule_add")
      .unbind()
      .click(function () {
        $("#data_sampling_create_custom_rules").modal("hide");
        $("#modal_add_custom_rule_data_sampling").modal();
      });

    // Data sampling add custom rule
    $("#btn_modal_add_custom_rule_confirm")
      .unbind()
      .click(function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Retrieve the regex rule
        var tk_data_sampling_custom_rule_regex = document.getElementById(
          "modal_input_data_sampling_custom_rule_regex"
        ).value;

        // Retrieve the rule name
        var tk_data_sampling_custom_rule_name = getToken(
          "tk_data_sampling_custom_rule_name"
        );

        // Retrieve the rule type
        var tk_data_sampling_custom_rule_type = getToken(
          "tk_data_sampling_custom_rule_type"
        );

        // Retrieve the sourcetype scope
        var tk_data_sampling_custom_sourcetype_scope = getToken(
          "tk_data_sampling_custom_sourcetype_scope"
        );

        // if is not defined, give it a value and override text box content - We should never reach this for the add function
        if (
          tk_data_sampling_custom_rule_regex ==
            'Enter a valid regular expression and click on the button "Run model simulation".' ||
          !tk_data_sampling_custom_rule_name ||
          !tk_data_sampling_custom_rule_name.length
        ) {
          // notify
          notify(
            "error",
            "bottom",
            "ERROR: Entries are either incorrect or incomplete, please correct and try again.",
            "5"
          );

          // Disable the add button
          document.getElementById(
            "btn_data_sampling_custom_rule_add"
          ).disabled = true;
        } else {
          // Retrieve update comment if any
          var tk_comment = getComment(
            "input_add_custom_rule_data_sampling_comment"
          );

          // Set the endpoint URL
          var myendpoint_URl =
            "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/write/data_sampling_models_add";

          // set data for the POST call
          var record = {
            tenant_id: tk_tenant_id,
            model_name: tk_data_sampling_custom_rule_name,
            model_type: tk_data_sampling_custom_rule_type,
            model_regex: tk_data_sampling_custom_rule_regex,
            sourcetype_scope: tk_data_sampling_custom_sourcetype_scope,
            update_comment: tk_comment,
          };

          // spinner
          cssloader("Requested action is in progress, please wait...");

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            dataType: "json",
            data: JSON.stringify(record),
            contentType: "application/json",
            success: function (returneddata) {
              // spinner
              cssloaderremove();
              // notify
              notify(
                "success",
                "bottom",
                "Data sampling model successfully added.",
                "5"
              );
              dataSamplingHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_data_sampling/data_sampling_rules_show",
                "POST",
                { tenant_id: tk_tenant_id }
              );
            },
            error: function (xhr, textStatus, error) {
              // spinner
              cssloaderremove();
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;
              // Audit
              action = "failure";
              change_type = "add data sampling model";
              object = tk_data_sampling_custom_rule_name;
              object_category = "all";
              object_attrs = JSON.stringify(record);
              result = "N/A";
              comment = "N/A";
              auditRecord(
                action,
                change_type,
                object,
                object_category,
                object_attrs,
                result,
                comment
              );
              closeModals();
              cssloaderremove();
              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    $("#btn_modal_data_sampling_custom_rule_simulate_show_details").click(
      function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");

        // Get object
        var tk_object = getToken("tk_input_data_sampling_dropdown");

        // Retrieve the regex rule
        var tk_data_sampling_custom_rule_regex = document.getElementById(
          "modal_input_data_sampling_custom_rule_regex"
        ).value;

        // Retrieve the rule name
        var tk_data_sampling_custom_rule_name = getToken(
          "tk_data_sampling_custom_rule_name"
        );

        // Retrieve the sourcetype scope
        var tk_data_sampling_custom_sourcetype_scope = getToken(
          "tk_data_sampling_custom_sourcetype_scope"
        );

        // Retrieve the key id
        var tk_keyid = getToken("tk_keyid");

        // Retrieve the key id
        var tk_splk_dsmtype = getToken("tk_splk_dsmtype");

        // If we are coming from the main UI, we have no keyid / sourcetype
        var tk_selected_splk_dsmtype = getToken(
          "tk_input_data_sampling_dropdown"
        );
        var tk_data_sampling_custom_st_value = getToken(
          "tk_data_sampling_custom_st_value"
        );

        // earliest and latest
        var tk_earliest = getToken("timerange_sampling_simulation.earliest");
        var tk_latest = getToken("timerange_sampling_simulation.latest");

        // if tk_keyid is unset
        if (tk_keyid == null) {
          tk_keyid = tk_selected_splk_dsmtype;
        }

        // if sourcetype is unset
        if (tk_splk_dsmtype == null) {
          tk_splk_dsmtype = tk_data_sampling_custom_st_value;
        }

        // Built the search URI
        var similation_events_detail =
          "search" +
          "?q=" +
          encodeURIComponent(
            '| trackmesamplingexecutor tenant_id="' +
              tk_tenant_id +
              '" object="' +
              tk_object +
              '" mode="get_samples" get_samples_max_count="10000" earliest="' +
              tk_earliest +
              '" latest="' +
              tk_latest +
              '" | table _raw data_sourcetype' +
              '| eval sourcetype_scope="' +
              tk_data_sampling_custom_sourcetype_scope +
              '" | eval detected_format = case((sourcetype_scope=="*"), case(match(_raw, "' +
              tk_data_sampling_custom_rule_regex +
              '"), "' +
              tk_data_sampling_custom_rule_name +
              '"), in(sourcetype, `trackme_data_sampling_custom_models_simulate_genlist("' +
              tk_data_sampling_custom_sourcetype_scope +
              '")`), case(match(_raw, "' +
              tk_data_sampling_custom_rule_regex +
              '"), "' +
              tk_data_sampling_custom_rule_name +
              '")) | eval detected_format_id=md5(detected_format)'
          );

        // Open
        window.open(similation_events_detail, "_blank");
      }
    );

    //
    // manage cim entity
    //

    function object_manage(action, entity, attr, commentInput, returnModal) {
      // Get tenant
      var tk_tenant_id = getToken("tenant_id");

      // Set
      var ajaxurl;
      var ajaxType;
      var ajaxdata;
      var changeType;
      var changeItem;
      var changeCat;
      var comment;

      // entity
      changeItem = entity;

      // cat
      changeCat = "cim";

      // retrieve comment, if any
      comment = getComment(commentInput);

      if (action === "delete") {
        ajaxurl = "/services/trackme/v2/splk_cim/admin/cim_tracker_delete";
        ajaxType = "POST";
        notifyMsg =
          "The CIM tracker " +
          changeItem +
          " and its associated objects were successfully deleted.";
        ajaxData = {
          tenant_id: tk_tenant_id,
          object_list: changeItem,
          update_comment: comment,
        };
        changeType = "delete cim tracker";
      } else if (action === "enable") {
        ajaxurl = "/services/trackme/v2/splk_cim/admin/cim_tracker_enablement";
        ajaxType = "POST";
        notifyMsg =
          "The CIM tracker " +
          changeItem +
          " and its associated objects were successfully enabled.";
        ajaxData = {
          tenant_id: tk_tenant_id,
          action: "enable",
          object_list: changeItem,
          update_comment: comment,
        };
        changeType = "enable cim tracker";
      } else if (action === "disable") {
        ajaxurl = "/services/trackme/v2/splk_cim/admin/cim_tracker_enablement";
        ajaxType = "POST";
        notifyMsg =
          "The CIM tracker " +
          changeItem +
          " and its associated objects were successfully disabled.";
        ajaxData = {
          tenant_id: tk_tenant_id,
          action: "disable",
          object_list: changeItem,
          update_comment: comment,
        };
        changeType = "disable cim tracker";
      } else if (action === "update_priority") {
        ajaxurl =
          "/services/trackme/v2/splk_cim/write/cim_tracker_update_priority";
        ajaxType = "POST";
        notifyMsg =
          "The CIM tracker " +
          changeItem +
          " and its associated objects were successfully updated.";
        ajaxData = {
          tenant_id: tk_tenant_id,
          object_list: changeItem,
          priority: attr,
          update_comment: comment,
        };
        changeType = "update priority";
      } else if (action === "update_rules") {
        ajaxurl =
          "/services/trackme/v2/splk_cim/write/cim_tracker_update_rules";
        ajaxType = "POST";
        notifyMsg =
          "The CIM tracker " +
          changeItem +
          " and its associated objects were successfully updated.";
        ajaxData = {
          tenant_id: tk_tenant_id,
          object: changeItem,
          cim_tracking_rules: attr,
          update_comment: comment,
        };
        changeType = "update tracking rules";
      }

      // Set the endpoint URL
      ajaxurl = "/en-US/splunkd/__raw/" + ajaxurl;

      // Run the ajax promise
      asyncCallApi(
        ajaxurl,
        ajaxType,
        ajaxData,
        changeType,
        changeItem,
        changeCat,
        comment
      ).then(function (resultCall) {
        if (typeof resultCall != "undefined") {
          action_result = resultCall.action;
          if (action_result == "success") {
            // notify
            notify("success", "bottom", JSON.stringify(resultCall), "5");
            // Run the search again to update the table
            searchSplkCimMain.startSearch();
            // refresh tabulator
            $("#splk-cim-table-refresh-hidden").click();
            // refresh entity
            updateSplkCim(changeItem, "*", "false");
            // return modal
            closeModals();
            if (action != "delete") {
              $("#" + returnModal).modal();
            }
          } else {
            $("#modal_update_collection_failure_return")
              .find(".modal-error-message p")
              .text(JSON.stringify(resultCall));
            closeModals();
            $("#modal_update_collection_failure_return").modal();
          }
        }
      });
    }

    $("#btn_delete_cim")
      .unbind()
      .click(function () {
        // close modals
        closeModals();
        var tk_object = getToken("tk_object");
        if (tk_object && tk_object.length) {
          $("#modal_entry_modification").modal();
          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              object_manage(
                "delete",
                tk_object,
                "none",
                "input_update_comment",
                "modal_manage_cim"
              );
            });
        }
      });

    $("#btn_enable_cim")
      .unbind()
      .click(function () {
        // close modals
        closeModals();
        var tk_object = getToken("tk_object");
        if (tk_object && tk_object.length) {
          $("#modal_entry_modification").modal();
          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              object_manage(
                "enable",
                tk_object,
                "none",
                "input_update_comment",
                "modal_manage_cim"
              );
            });
        }
      });

    $("#btn_disable_cim")
      .unbind()
      .click(function () {
        // close modals
        closeModals();
        var tk_object = getToken("tk_object");
        if (tk_object && tk_object.length) {
          $("#modal_entry_modification").modal();
          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              object_manage(
                "disable",
                tk_object,
                "none",
                "input_update_comment",
                "modal_manage_cim"
              );
            });
        }
      });

    // mass delete
    $("#btn_confirm_modal_cim_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken("tk_cim_delete");

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker_delete";

        // retrieve comment, if any
        comment = getComment("comment_modal_cim_confirm_delete");

        // set data for the POST call
        var record = {
          tenant_id: tk_tenant_id,
          component: "splk-cim",
          object_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete cim tracker",
          tk_multi_table_array,
          "cim",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "CIM tracker(s) successfully deleted.",
                "5"
              );
              // refresh searches
              searchSplkCimMain.startSearch();
              // refresh tabulator
              $("#splk-cim-table-refresh-hidden").click();
              // return modal
              $("#modal_cim_handler").modal();
            }
          }
        });
      });

    // function to refresh searches and UI elements for splk-cim
    function refreshSplCimElements() {
      var tk_keyid = getToken("tk_keyid");
      // refresh the entity panel and other dynamic UI elements
      updateSplkCim("*", tk_keyid, "true");
      // refresh searches for this entity
      searchHostTableMSplkCim.startSearch();
      searchSplkCimNotables.startSearch();
      searchSplkCimMetricsOverTime.startSearch();
      searchOutlierDetectionChartCim.startSearch();
      searchSplkCimMainAuditChanges.startSearch();
      searchAuditCimAuditChangesOverTime.startSearch();
      searchSplkCimTimeline.startSearch();
      searchSplkCimMainAuditFlip.startSearch();
      searchSingleSLASplkCimpct.startSearch();
      // add new models populate
      searchPopulateSplkCimOutliersAddCimEntities.startSearch();
      searchPopulateSplkCimOutliersAddCimFields.startSearch();
      // refresh tabulator
      $("#splk-cim-table-refresh-hidden").click();
    }

    // function to run the cim tracker
    function runSplkCimTracker() {
      var tk_tracker_name = getToken("tk_tracker_name");
      var tk_object = getToken("tk_object");
      var tk_keyid = getToken("tk_keyid");

      // spinner
      cssloader("Please wait while running the splk-cim tracker...");

      // set the query
      var searchQuery =
        "| trackmeoneshotexecutor tenant_id=" +
        getToken("tenant_id") +
        ' report="' +
        tk_tracker_name +
        '"';

      // Set the search parameters--specify a time range
      var searchParams = {
        earliest_time: "-5m",
        latest_time: "now",
      };

      // Run a blocking search and get back a job
      service.search(searchQuery, searchParams, function (err, job) {
        // Shall the search fail before we can get properties
        if (job == null) {
          let errorStr = "Unknown Error!";
          if (
            err &&
            err.data &&
            err.data.messages &&
            err.data.messages[0]["text"]
          ) {
            errorStr = err.data.messages[0]["text"];
          } else if (err && err.data && err.data.messages) {
            errorStr = JSON.stringify(err.data.messages);
          }
          cssloaderremove();
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(errorStr);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        } else {
          // Poll the status of the search job
          job.track(
            {
              period: 200,
            },
            {
              done: function (job) {
                // refresh searches and UI elements
                refreshSplCimElements();
                // Remove the spinner
                cssloaderremove();
              },
              failed: function (properties) {
                let errorStr = "Unknown Error!";
                if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages &&
                  properties._properties.messages[0]["text"]
                ) {
                  errorStr = properties._properties.messages[0]["text"];
                } else if (
                  properties &&
                  properties._properties &&
                  properties._properties.messages
                ) {
                  errorStr = JSON.stringify(properties._properties.messages);
                }
                cssloaderremove();
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(errorStr);
                closeModals();
                $("#modal_update_collection_failure_return").modal();
              },
              error: function (err) {
                done(err);
                cssloaderremove();
                closeModals();
                $("#modal_update_collection_failure_flush").modal();
              },
            }
          );
        }
      });
    }

    // Run the CIM tracker now
    $("#btn_run_object")
      .unbind()
      .click(function () {
        runSplkCimTracker();
      });

    // Refresh only
    $("#btn_run_object_refresh")
      .unbind()
      .click(function () {
        // refresh searches and UI elements
        refreshSplCimElements();
      });

    // CIM create JSON preview

    // syntax highlighting for JSON
    function syntaxHighlight(json) {
      json = json
        .replace(/&/g, "&amp;")
        .replace(/</g, "&lt;")
        .replace(/>/g, "&gt;");
      return json.replace(
        /("(\\u[a-zA-Z0-9]{4}|\\[^u]|[^\\"])*"(\s*:)?|\b(true|false|null)\b|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?)/g,
        function (match) {
          var cls = "json-preview-number";
          if (/^"/.test(match)) {
            if (/:$/.test(match)) {
              cls = "json-preview-key";
            } else {
              cls = "json-preview-string";
            }
          } else if (/true|false/.test(match)) {
            cls = "json-preview-boolean";
          } else if (/null/.test(match)) {
            cls = "json-preview-null";
          }
          return '<span class="' + cls + '">' + match + "</span>";
        }
      );
    }

    // psuedo syntax highlighting for Splunk
    function syntaxHighlightSpl(str) {
      return str.replace(/(\w+)/g, function (match) {
        if (/^\s*(search|tstats|datamodel|from|stats)/.test(match)) {
          var cls = "spl-search-preview-blue";
        } else if (/\|\s{0,1}(search|tstats|datamodel|from)/.test(match)) {
          var cls = "spl-search-preview-blue";
        } else if (/(from|where|AND|by)/.test(match)) {
          var cls = "spl-search-preview-orange";
        } else if (/(summariesonly|datamodel)\=/.test(match)) {
          var cls = "spl-search-preview-green";
        }
        return '<span class="' + cls + '">' + match + "</span>";
      });
    }

    // preset the regex validation expression
    function presetCimRegex() {
      // Get field
      var tk_cim_field = getToken("input_cim_tracker_add_field_name");

      // Perform a target search to update key values
      var searchQuery =
        '| makeresults | eval field="' +
        tk_cim_field +
        '" | lookup local=t trackme_cim_regex field | fields - _time | eval validation_regex=if(isnull(validation_regex) OR validation_regex="", ".*", validation_regex)';

      // Set the search parameters
      var searchParams = {
        exec_mode: "normal",
        earliest_time: "-5m",
      };

      service.search(searchQuery, searchParams, function (err, job) {
        // Poll the status of the search job
        job.track(
          {
            period: 200,
          },
          {
            done: function (job) {
              // Get the results and print them
              job.results({}, function (err, results, job) {
                var fields = results.fields;
                var rows = results.rows;
                for (var i = 0; i < rows.length; i++) {
                  var values = rows[i];
                  for (var j = 0; j < values.length; j++) {
                    var field = fields[j];
                    var value = values[j];

                    // preset the regex validator value
                    setToken("form.input_cim_tracker_add_field_regex", value);
                  }
                }
              });
            },
            failed: function (job) {},
            error: function (err) {
              done(err);
            },
          }
        );
      });
    }

    // check the remote account connectivity
    function checkCimRemoteAccount(account) {
      // notify
      notify(
        "info",
        "bottom",
        "Please wait while we verify the connectivity and authentication to the remote Splunk deployment, this can take a few minutes if the target cannot be reached, hold on...",
        "150"
      );
      // Show the parent
      $("#divParentCreateCimValidateRemoteConnectivity").css(
        "display",
        "inherit"
      );
      // Show the spinner
      $("#divCreateCimValidateRemoteConnectivityLoader").css(
        "display",
        "inherit"
      );
      // hide the result viewer
      $("#divCreateCimValidateRemoteConnectivity").css("display", "none");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/configuration/test_remote_account";

      // Create a dictionary to store the field names and values
      var record = {
        account: account,
      };

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "json",
        data: JSON.stringify(record),
        success: function (returneddata) {
          // hide
          $("#divCreateCimValidateRemoteConnectivityLoader").css(
            "display",
            "none"
          );
          // notify
          notify(
            "success",
            "bottom",
            "Successfully passed the connectivity check to the remote Splunk deployment.",
            "5"
          );
          // show
          // creation via template
          $("#divCreateCimValidateRemoteConnectivity").html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
              "</pre>"
          );
          $("#divCreateCimValidateRemoteConnectivity").css(
            "display",
            "inherit"
          );
        },
        error: function (xhr, textStatus, error) {
          // hide
          $("#divCreateCimValidateRemoteConnectivityLoader").css(
            "display",
            "none"
          );
          // notify
          notify(
            "error",
            "bottom",
            "Failed to verify the connectivity to the Splunk remote deployment.",
            "5"
          );
          // creation via template
          $("#divCreateCimValidateRemoteConnectivity").html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(JSON.stringify(xhr, null, 2)) +
              "</pre>"
          );
          $("#divCreateCimValidateRemoteConnectivity").css(
            "display",
            "inherit"
          );
        },
      });
    }

    // preview the CIM search
    function previewCimSplunkSearch() {
      var splSearch;
      // get token
      var preview_cim_tracker_datamodel_name = getToken(
        "input_cim_tracker_datamodel_name"
      );
      var preview_cim_tracker_datamodel_nodename = getToken(
        "input_cim_tracker_datamodel_nodename"
      );
      var preview_cim_tracker_datamodel_constraint = document.getElementById(
        "modal_input_cim_root_constraint"
      ).value;
      var preview_cim_tracker_drop_dm_object_name = getToken(
        "input_cim_tracker_add_field_drop_dm_object_name"
      );

      // if either preview_cim_tracker_datamodel_name or preview_cim_tracker_datamodel_nodename is not defined
      if (
        preview_cim_tracker_datamodel_name == null ||
        preview_cim_tracker_datamodel_nodename == null ||
        preview_cim_tracker_datamodel_name == "null" ||
        preview_cim_tracker_datamodel_nodename == "null" ||
        preview_cim_tracker_datamodel_name == "" ||
        preview_cim_tracker_datamodel_nodename == ""
      ) {
        // empty the preview
        $("#divCreateCimSplSearchPreview").html(
          '<h2 style="color: dodgerblue; font-style: italic;">Splunk search preview: (datamodel and tstats variations)</h2>\n' +
            '<pre class="create-cim-json-rules-preview" style="font-style: italic;">Pending for datamodel name and/or node name...</pre>'
        );
        // set visibility
        $("#divCreateCimSplSearchPreview").css("display", "inherit");
      } else {
        if (
          preview_cim_tracker_datamodel_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          splSearch =
            '| datamodel "' +
            preview_cim_tracker_datamodel_name +
            '" "' +
            preview_cim_tracker_datamodel_nodename +
            '"' +
            ' search | `drop_dm_object_name("' +
            preview_cim_tracker_drop_dm_object_name +
            '")`' +
            "\n\n" +
            '| tstats count from datamodel="' +
            preview_cim_tracker_datamodel_name +
            '" where (nodename = ' +
            preview_cim_tracker_datamodel_nodename +
            ")" +
            ' | `drop_dm_object_name("' +
            preview_cim_tracker_drop_dm_object_name +
            '")`';
          splSearch = syntaxHighlightSpl(splSearch);

          $("#divCreateCimSplSearchPreview").html(
            '<h2 style="color: dodgerblue; font-style: italic;">Splunk search preview:</h2>\n' +
              '<pre class="create-cim-json-rules-preview">' +
              splSearch +
              "</pre>"
          );
        } else {
          splSearch =
            '| datamodel "' +
            preview_cim_tracker_datamodel_name +
            '" "' +
            preview_cim_tracker_datamodel_nodename +
            '"' +
            " search | search " +
            preview_cim_tracker_datamodel_constraint +
            "\n\n" +
            '| tstats count from datamodel="' +
            preview_cim_tracker_datamodel_name +
            '" where (nodename = ' +
            preview_cim_tracker_datamodel_nodename +
            ")" +
            " AND ( " +
            preview_cim_tracker_datamodel_constraint +
            " )" +
            ' | `drop_dm_object_name("' +
            preview_cim_tracker_drop_dm_object_name +
            '")`';
          splSearch = syntaxHighlightSpl(splSearch);
          $("#divCreateCimSplSearchPreview").html(
            '<h2 style="color: dodgerblue; font-style: italic;">Splunk search preview:</h2>\n' +
              '<pre class="create-cim-json-rules-preview">' +
              splSearch +
              "</pre>"
          );
        }
        // set visibility
        $("#divCreateCimSplSearchPreview").css("display", "inherit");
      }
    }

    // monitor the area input
    $(function () {
      $("#modal_input_cim_root_constraint").change(function () {
        if ($(this).val() != "") {
          previewCimSplunkSearch();
        }
      });
    });

    function previewCimJsonRules() {
      // empty the preview
      $("#divChildCreateCimJsonPreview").html(
        '<pre class="create-cim-json-rules-preview">' + "</pre>"
      );

      // get vars
      var preview_cim_tracker_datamodel_name = getToken(
        "input_cim_tracker_datamodel_name"
      );
      var preview_cim_tracker_datamodel_nodename = getToken(
        "input_cim_tracker_datamodel_nodename"
      );
      var preview_cim_tracker_cim_fields = getToken("tk_create_cim_fields");
      var preview_cim_tracker_cim_tracking_rules = getToken(
        "tk_create_cim_fields_array"
      );
      var preview_cim_tracker_drop_dm_object_name = getToken(
        "input_cim_tracker_add_field_drop_dm_object_name"
      );
      var preview_cim_tracker_breakby_prefix = getToken(
        "input_cim_tracker_breakby_prefix"
      );
      var preview_cim_tracker_breakby = getToken("input_cim_tracker_breakby");
      var preview_cim_tracker_datamodel_constraint = document
        .getElementById("modal_input_cim_root_constraint")
        .value.replace(/\"/g, '\\"');

      if (
        preview_cim_tracker_datamodel_constraint ===
        "Enter the Splunk root search constraint"
      ) {
        preview_cim_tracker_datamodel_constraint = "";
      }
      var preview_json_rules;

      // build the JSON rules preview
      preview_json_rules =
        "{" +
        '"cim_datamodel_name": "' +
        preview_cim_tracker_datamodel_name +
        '",' +
        '"cim_datamodel_nodename": "' +
        preview_cim_tracker_datamodel_nodename +
        '",' +
        '"cim_drop_dm_object_name": "' +
        preview_cim_tracker_drop_dm_object_name +
        '",' +
        '"cim_breakby_prefix": "' +
        preview_cim_tracker_breakby_prefix +
        '",' +
        '"cim_breakby": "' +
        preview_cim_tracker_breakby +
        '",' +
        '"cim_fields": "' +
        preview_cim_tracker_cim_fields +
        '",' +
        '"cim_root_constraint": "' +
        preview_cim_tracker_datamodel_constraint +
        '",' +
        preview_cim_tracker_cim_tracking_rules +
        "}";

      jsonObj = JSON.parse(preview_json_rules);
      jsonStr = JSON.stringify(jsonObj, null, 2);

      // store the raw json object
      setToken("tk_cim_json_rules", preview_json_rules);

      $("#divChildCreateCimJsonPreview").html(
        '<pre class="create-cim-json-rules-preview">' +
          syntaxHighlight(jsonStr) +
          "</pre>"
      );

      $("#divCreateCimJsonPreview").css("display", "inherit");
    }

    $("#btn_modal_input_cim_add")
      .unbind()
      .click(function () {
        // in manual mode, hide other options
        $("#divSplkCimUpload").css("display", "none");
        $("#divSplkCimClone").css("display", "none");

        // gets vars
        var tk_create_cim_fields = getToken("tk_create_cim_fields");
        var tk_create_cim_fields_array = getToken("tk_create_cim_fields_array");

        var tk_input_cim_tracker_add_field_name = getToken(
          "input_cim_tracker_add_field_name"
        );
        var tk_input_cim_tracker_add_field_datamodel_fieldname = getToken(
          "input_cim_tracker_add_field_datamodel_fieldname"
        );
        var tk_input_cim_tracker_add_field_max_unknown_pct = getToken(
          "input_cim_tracker_add_field_max_unknown_pct"
        );
        var tk_input_cim_tracker_add_field_regex = getToken(
          "input_cim_tracker_add_field_regex"
        ).replace(/\\/g, "\\\\");
        var tk_input_cim_tracker_add_field_min_compliant_pct = getToken(
          "input_cim_tracker_add_field_min_compliant_pct"
        );

        // proceed only if all inputs are provided
        if (
          tk_input_cim_tracker_add_field_name == null ||
          tk_input_cim_tracker_add_field_name === "null" ||
          tk_input_cim_tracker_add_field_datamodel_fieldname === null ||
          tk_input_cim_tracker_add_field_datamodel_fieldname === "null" ||
          tk_input_cim_tracker_add_field_max_unknown_pct === null ||
          tk_input_cim_tracker_add_field_max_unknown_pct === "null" ||
          tk_input_cim_tracker_add_field_regex === null ||
          tk_input_cim_tracker_add_field_regex === "null" ||
          tk_input_cim_tracker_add_field_min_compliant_pct === null ||
          tk_input_cim_tracker_add_field_min_compliant_pct === "null"
        ) {
          msg =
            "Fields inputs are incomplete, verify your inputs settings and try again.";
          notify("error", "bottom", msg, "5");
        } else {
          // if this is the first addition
          if (tk_create_cim_fields == "null" || tk_create_cim_fields == null) {
            setToken(
              "tk_create_cim_fields",
              tk_input_cim_tracker_add_field_name
            );
            setToken(
              "tk_create_cim_fields_array",
              '"' +
                tk_input_cim_tracker_add_field_name +
                '": [{"datamodel_fieldname": "' +
                tk_input_cim_tracker_add_field_datamodel_fieldname +
                '"},{"min_compliant_coverage_percentage": ' +
                tk_input_cim_tracker_add_field_min_compliant_pct +
                '},{"max_unknown_coverage_percentage": ' +
                tk_input_cim_tracker_add_field_max_unknown_pct +
                '},{"regex_validator_rule": "' +
                tk_input_cim_tracker_add_field_regex +
                '"}]'
            );
            msg =
              "The field: " +
              tk_input_cim_tracker_add_field_name +
              " was added successfully";
            notify("success", "bottom", msg, "5");
          }
          // otherwise, complete the existing definition
          else {
            // verify that this same field was not added yet
            var fieldsList = tk_create_cim_fields.split(",");
            if (fieldsList.includes(tk_input_cim_tracker_add_field_name)) {
              msg =
                "The field: " +
                tk_input_cim_tracker_add_field_name +
                " is already part of the CIM fields tracked";
              notify("error", "bottom", msg, "5");
            } else {
              // fields to be monitored
              tk_create_cim_fields =
                tk_create_cim_fields +
                "," +
                tk_input_cim_tracker_add_field_name;
              setToken("tk_create_cim_fields", tk_create_cim_fields);

              // json rules
              tk_create_cim_fields_array =
                tk_create_cim_fields_array +
                "," +
                '"' +
                tk_input_cim_tracker_add_field_name +
                '": [{"datamodel_fieldname": "' +
                tk_input_cim_tracker_add_field_datamodel_fieldname +
                '"},{"min_compliant_coverage_percentage": ' +
                tk_input_cim_tracker_add_field_min_compliant_pct +
                '},{"max_unknown_coverage_percentage": ' +
                tk_input_cim_tracker_add_field_max_unknown_pct +
                '},{"regex_validator_rule": "' +
                tk_input_cim_tracker_add_field_regex +
                '"}]';
              setToken(
                "tk_create_cim_fields_array",
                tk_create_cim_fields_array
              );
              msg =
                "The field: " +
                tk_input_cim_tracker_add_field_name +
                " was added successfully";
              notify("success", "bottom", msg, "5");
            }
          }

          // preview json rules
          previewCimJsonRules();
        }
      });

    $("#btn_modal_input_cim_field_preview_json")
      .unbind()
      .click(function () {
        // preview json rules
        previewCimJsonRules();
      });

    // simulation
    $("#btn_modal_input_cim_tracker_simulate")
      .unbind()
      .click(function () {
        // get the main tokens
        var tk_tenant_id = getToken("tenant_id");
        var simulate_object_name = getToken("input_object_name_formated");
        var simulate_cim_tracker_account = getToken(
          "input_cim_tracker_account"
        );
        var simulate_cim_tracker_datamodel_name = getToken(
          "input_cim_tracker_datamodel_name"
        );
        var simulate_cim_tracker_datamodel_nodename = getToken(
          "input_cim_tracker_datamodel_nodename"
        );
        var simulate_cim_tracker_cim_fields = getToken("tk_create_cim_fields");
        var simulate_cim_tracker_cim_tracking_rules = getToken(
          "tk_create_cim_fields_array"
        );
        var simulate_cim_tracker_drop_dm_object_name = getToken(
          "input_cim_tracker_add_field_drop_dm_object_name"
        );
        var simulate_cim_tracker_datamodel_constraint = document
          .getElementById("modal_input_cim_root_constraint")
          .value.replace(/\"/g, '\\"');

        if (
          simulate_cim_tracker_datamodel_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          simulate_cim_tracker_datamodel_constraint = "";
        }

        // get the json rules previously defined
        var simulate_cim_json_rules = getToken("tk_cim_json_rules");

        // get earliest and latest time quantifiers (from live)
        var simulate_earliest = getToken("input_cim_tracker_promote_earliest");
        var simulate_latest = getToken("input_cim_tracker_promote_latest");

        // get summariesonly argument
        var simulate_summariesonly = getToken(
          "input_cim_tracker_summariesonly"
        );

        // get cron_schedule (from live)
        var simulate_cron_schedule = getToken("input_cim_tracker_promote_cron");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker";

        // Create a dictionary to store the field names and values
        var record = {
          tenant_id: tk_tenant_id,
          context: "simulation",
          object: simulate_object_name,
          account: simulate_cim_tracker_account,
          root_constraint: simulate_cim_tracker_datamodel_constraint,
          cim_tracking_rules: simulate_cim_json_rules,
          earliest: simulate_earliest,
          latest: simulate_latest,
          summariesonly: simulate_summariesonly,
          cron_schedule: simulate_cron_schedule,
          update_comment: "simulation",
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "json",
          data: JSON.stringify(record),
          success: function (returneddata) {
            // notify
            notify(
              "success",
              "bottom",
              "Simulation was successfully performed.",
              "5"
            );

            // show the JSON response from the entity creation
            jsonStr = JSON.stringify(returneddata, null, 2);

            $("#divChildCreateCimJsonSimulation").html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(jsonStr) +
                "</pre>"
            );
            $("#divCreateCimJsonSimulation").css("display", "inherit");

            // enable next step
            document.getElementById(
              "btn_modal_input_cim_tracker_simulate_run"
            ).disabled = false;

            // inject tracking rules for modification purposes
            cim_simulation_inject_tracking_rules(
              tenant_id,
              simulate_object_name
            );
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // notify
            notify("error", "bottom", message, "5");
            returneddata = {
              responseText: xhr.responseText,
              status: xhr.status,
              statusText: xhr.statusText,
            };
            jsonStr = JSON.stringify(returneddata, null, 2);
            $("#divChildCreateCimJsonSimulation").html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(jsonStr) +
                "</pre>"
            );
            $("#divCreateCimJsonSimulation").css("display", "inherit");
            // disable next step
            document.getElementById(
              "btn_modal_input_cim_tracker_simulate_run"
            ).disabled = true;
          },
        });
      });

    // Simulation: inject cim tracking rules
    function cim_simulation_inject_tracking_rules(
      tenant_id,
      simulate_object_name
    ) {
      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/cim_tracker_rules";

      var record = {
        tenant_id: tenant_id,
        object: simulate_object_name,
        context: "simulation",
      };

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "text",
        beforeSend: function (xhr) {
          xhr.overrideMimeType("text/plain; charset=x-user-defined");
        },
        data: JSON.stringify(record),
        success: function (returneddata) {
          jsonStr = returneddata;
          document.getElementById(
            "modal_input_cim_tracker_simulation_tracking_rules"
          ).value = jsonStr;
          document
            .getElementById("btn_simulation_download_cim_json_template")
            .addEventListener(
              "click",
              function () {
                var text = jsonStr;
                var filename = "cim_tracking_rules_template.json";
                download(filename, text);
              },
              false
            );
          // show element
          $("#divCreateCimJsonSimulationChanges").css("display", "inherit");
        },
        error: function (xhr, textStatus, error) {
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;

          // notify
          notify("error", "bottom", message, "5");

          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });
    }

    function cim_simulation_update_tracking_rules(
      tenant_id,
      simulate_object_name
    ) {
      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/write/cim_tracker_update_rules";

      var record = {
        tenant_id: tenant_id,
        object: simulate_object_name,
        cim_tracking_rules: document.getElementById(
          "modal_input_cim_tracker_simulation_tracking_rules"
        ).value,
        context: "simulation",
      };

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "text",
        beforeSend: function (xhr) {
          xhr.overrideMimeType("text/plain; charset=x-user-defined");
        },
        data: JSON.stringify(record),
        success: function (returneddata) {
          // notify
          notify(
            "info",
            "bottom",
            "Update was successful, run the simulation execution again",
            "5"
          );
          // Update preview
          $("#divChildCreateCimJsonSimulation").html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(
                document.getElementById(
                  "modal_input_cim_tracker_simulation_tracking_rules"
                ).value
              ) +
              "</pre>"
          );
        },
        error: function (xhr, textStatus, error) {
          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          // notify
          notify("error", "bottom", message, "5");
          $("#modal_update_collection_failure_return")
            .find(".modal-error-message p")
            .text(message);
          closeModals();
          $("#modal_update_collection_failure_return").modal();
        },
      });
    }

    // run on demand
    $("#btn_simulation_modify_tracking_rules_submit")
      .unbind()
      .click(function () {
        cim_simulation_update_tracking_rules(
          getToken("tenant_id"),
          getToken("input_object_name_formated")
        );
      });

    $("#btn_modal_input_cim_tracker_simulate_run")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var simulate_object_name = getToken("input_object_name_formated");
        var simulate_cim_tracker_account = getToken(
          "input_cim_tracker_account"
        );

        // get earliest and latest time quantifiers
        var simulate_earliest = getToken(
          "input_cim_tracker_simulation_earliest"
        );
        var simulate_latest = getToken("input_cim_tracker_simulation_latest");

        // get summariesonly
        var simulate_summariesonly = getToken(
          "input_cim_tracker_summariesonly"
        );

        // Set the Splunk search
        var tk_create_cim_json_simulation_search =
          '| trackmecimtrackerexecutor context="simulation" ' +
          'tenant_id="' +
          tk_tenant_id +
          '" object="' +
          simulate_object_name +
          '" account="' +
          simulate_cim_tracker_account +
          '" component="splk-cim" summariesonly="true" earliest="' +
          simulate_earliest +
          '" latest="' +
          simulate_latest +
          '" summariesonly="' +
          simulate_summariesonly +
          '" | spath';

        setToken(
          "tk_create_cim_json_simulation_search",
          tk_create_cim_json_simulation_search
        );

        // free the search
        setToken("start_create_cim_json_simulation_exec", "true");
        // explicitely start the search
        searchCreateCimJsonSimulationExec.startSearch();
        // Show the Splunk table view
        $("#divCreateCimJsonSimulationExec").css("display", "inherit");
        // enable the promote to live action, at this stage the user is responsible for it
        document.getElementById(
          "btn_modal_input_cim_promote_live"
        ).disabled = false;
      });

    // function to clear the simulation, called for clear and promote to Live
    function SplkCimClearSimulation(cimEntity, showNotify, clearAll) {
      // spinner
      cssloader("Cleaning out the simulation, please wait...");

      // Get tenant
      var tk_tenant_id = getToken("tenant_id");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker_delete";

      // Create a dictionary to store the field names and values
      var record = {
        tenant_id: tk_tenant_id,
        context: "simulation",
        object_list: cimEntity,
        update_comment: "simulation",
      };

      $.ajax({
        url: myendpoint_URl,
        type: "POST",
        async: true,
        contentType: "application/json",
        dataType: "text",
        beforeSend: function (xhr) {
          xhr.overrideMimeType("text/plain; charset=x-user-defined");
        },
        data: JSON.stringify(record),
        success: function (returneddata) {
          // remove loader
          cssloaderremove();

          // notify
          if (showNotify === "true") {
            notify(
              "success",
              "bottom",
              "The simulation was successfully cleared out.",
              "5"
            );
          }

          // clear this div in all cases
          $("#divCreateCimJsonSimulation").css("display", "none");

          if (clearAll === "true") {
            // clear these divs
            $("#divCreateCimJsonPreview").css("display", "none");
            $("#divCreateCimJsonSimulationExec").css("display", "none");

            // unset various tokens
            unsetToken("tk_create_cim_fields");
            unsetToken("form.input_object_name");
            unsetToken("form.input_cim_tracker_datamodel_name");
            unsetToken("form.input_cim_tracker_datamodel_nodename");
            unsetToken("form.input_cim_tracker_add_field_drop_dm_object_name");
            unsetToken("form.input_cim_tracker_add_field_name");
            unsetToken("form.input_cim_tracker_add_field_datamodel_fieldname");
            document.getElementById("modal_input_cim_root_constraint").value =
              "Enter the Splunk root search constraint";
          }
        },
        error: function (xhr, textStatus, error) {
          // remove loader
          cssloaderremove();

          message =
            "server response: " +
            xhr.responseText +
            "\n - http response: " +
            error;
          // notify
          if (showNotify === "true") {
            notify("error", "bottom", message, "5");
          }
          returneddata = {
            responseText: xhr.responseText,
            status: xhr.status,
            statusText: xhr.statusText,
          };

          jsonStr = JSON.stringify(returneddata, null, 2);
          $("#divChildCreateCimJsonSimulation").html(
            '<pre class="create-cim-json-rules-preview">' +
              syntaxHighlight(jsonStr) +
              "</pre>"
          );
          // don't do anything further, this is not expected
        },
      });
    }

    // Start over cim tracking rules
    $("#btn_modal_input_cim_add_startover_rules")
      .unbind()
      .click(function () {
        // unset various tokens
        unsetToken("tk_create_cim_fields");
        unsetToken("form.input_cim_tracker_add_field_name");
        unsetToken("form.input_cim_tracker_add_field_datamodel_fieldname");
        // clear these divs
        $("#divCreateCimJsonPreview").css("display", "none");
        // show divs
        $("#divSplkCimUpload").css("display", "inherit");
        $("#divSplkCimClone").css("display", "inherit");
        $("#divSplkCimDefineManually").css("display", "inherit");
        $("#divSplkCimDefineManuallyRefreshBtn").css("display", "inherit");
      });

    // Clear simulation creation
    $("#btn_modal_input_cim_tracker_simulate_clear")
      .unbind()
      .click(function () {
        // remove the simulation record
        var cimEntity = getToken("input_object_name_formated");
        SplkCimClearSimulation(cimEntity, "true", "false");
      });

    // Clear all steps
    $("#btn_modal_input_cim_tracker_simulate_clearall")
      .unbind()
      .click(function () {
        // remove the simulation record
        var cimEntity = getToken("input_object_name_formated");
        SplkCimClearSimulation(cimEntity, "true", "true");
        $("#divSplkCimUpload").css("display", "inherit");
        $("#divSplkCimClone").css("display", "inherit");
        $("#divSplkCimDefineManually").css("display", "inherit");
        $("#divSplkCimDefineManuallyRefreshBtn").css("display", "inherit");
      });

    // burn test peformance benchmark
    $("#btn_modal_input_hybrid_remote_cim_add_burn_test")
      .unbind()
      .click(function () {
        // get the main tokens
        var tk_tenant_id = getToken("tenant_id");
        var live_object_name = getToken("input_object_name_formated");
        var live_cim_tracker_account = getToken("input_cim_tracker_account");
        var live_cim_tracker_datamodel_name = getToken(
          "input_cim_tracker_datamodel_name"
        );
        var live_cim_tracker_datamodel_nodename = getToken(
          "input_cim_tracker_datamodel_nodename"
        );
        var live_cim_tracker_cim_fields = getToken("tk_create_cim_fields");
        var live_cim_tracker_cim_tracking_rules = getToken(
          "tk_create_cim_fields_array"
        );
        var live_cim_tracker_drop_dm_object_name = getToken(
          "input_cim_tracker_add_field_drop_dm_object_name"
        );
        var live_cim_tracker_datamodel_constraint = document
          .getElementById("modal_input_cim_root_constraint")
          .value.replace(/\"/g, '\\"');

        if (
          live_cim_tracker_datamodel_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          live_cim_tracker_datamodel_constraint = "";
        }

        // get earliest and latest time quantifiers
        var live_earliest = getToken("input_cim_tracker_promote_earliest");
        var live_latest = getToken("input_cim_tracker_promote_latest");

        // get summariesonly
        var live_summariesonly = getToken("input_cim_tracker_summariesonly");

        // get cron_schedule
        var live_cron_schedule = getToken("input_cim_tracker_promote_cron");

        // get the json rules previously defined
        var live_cim_json_rules = getToken("tk_cim_json_rules");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker";

        // get the comment
        var tk_comment = getComment("cim_tracker_creation_comment");

        // Create a dictionary to store the field names and values
        var record = {
          tenant_id: tk_tenant_id,
          context: "simulation",
          object: live_object_name,
          account: live_cim_tracker_account,
          root_constraint: live_cim_tracker_datamodel_constraint,
          cim_tracking_rules: live_cim_json_rules,
          earliest: live_earliest,
          latest: live_latest,
          summariesonly: live_summariesonly,
          cron_schedule: live_cron_schedule,
          burn_test: "True",
          update_comment: tk_comment,
        };

        // set divs
        parentDiv = "divParentCreateCimHybridBurnTest";
        spinnerDiv = "divCreateCimHybridBurnTestLoader";
        childDiv = "divCreateCimHybridBurnTest";

        // notify
        notify(
          "info",
          "bottom",
          "Please wait while running the Hybrid tracker burn test performance benchmark, once the job is terminated, review the run time performance, hold on...",
          "600"
        );
        // Show the parent
        $("#" + parentDiv).css("display", "inherit");
        // Show the spinner
        $("#" + spinnerDiv).css("display", "inherit");
        // hide the result viewer
        $("#" + childDiv).css("display", "none");

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          dataType: "json",
          data: JSON.stringify(record),
          contentType: "application/json",
          success: function (returneddata) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "success",
              "bottom",
              "Burn benchmark is now terminated, review the run time performance results.",
              "5"
            );
            // show
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
          error: function (xhr, textStatus, error) {
            // hide
            $("#" + spinnerDiv).css("display", "none");
            // notify
            notify(
              "error",
              "bottom",
              "Failed to run the burn test performance benchmark.",
              "5"
            );
            // creation via template
            $("#" + childDiv).html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                "</pre>"
            );
            $("#" + childDiv).css("display", "inherit");
          },
        });
      });

    // promote to Live
    $("#btn_modal_input_cim_promote_live")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        // remove the simulation record
        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker_delete";

        // remove the simulation record
        var cimEntity = getToken("input_object_name_formated");
        SplkCimClearSimulation(cimEntity, "false", "true");

        //open confirmation modal
        $("#modal_confirm_cim_tracker").modal();
      });

    $("#btn_modal_input_cim_tracker_add_new_confirm")
      .unbind()
      .click(function () {
        // spinner
        cssloader("Get ready, creating the new CIM Tracker, please wait...");

        // get the main tokens
        var tk_tenant_id = getToken("tenant_id");
        var live_object_name = getToken("input_object_name_formated");
        var live_cim_tracker_account = getToken("input_cim_tracker_account");
        var live_cim_tracker_datamodel_name = getToken(
          "input_cim_tracker_datamodel_name"
        );
        var live_cim_tracker_datamodel_nodename = getToken(
          "input_cim_tracker_datamodel_nodename"
        );
        var live_cim_tracker_cim_fields = getToken("tk_create_cim_fields");
        var live_cim_tracker_cim_tracking_rules = getToken(
          "tk_create_cim_fields_array"
        );
        var live_cim_tracker_drop_dm_object_name = getToken(
          "input_cim_tracker_add_field_drop_dm_object_name"
        );
        var live_cim_tracker_datamodel_constraint = document
          .getElementById("modal_input_cim_root_constraint")
          .value.replace(/\"/g, '\\"');

        if (
          live_cim_tracker_datamodel_constraint ===
          "Enter the Splunk root search constraint"
        ) {
          live_cim_tracker_datamodel_constraint = "";
        }

        // get earliest and latest time quantifiers
        var live_earliest = getToken("input_cim_tracker_promote_earliest");
        var live_latest = getToken("input_cim_tracker_promote_latest");

        // get summariesonly
        var live_summariesonly = getToken("input_cim_tracker_summariesonly");

        // get cron_schedule
        var live_cron_schedule = getToken("input_cim_tracker_promote_cron");

        // get the json rules previously defined
        var live_cim_json_rules = getToken("tk_cim_json_rules");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker";

        // get the comment
        var tk_comment = getComment("cim_tracker_creation_comment");

        // Create a dictionary to store the field names and values
        var record = {
          tenant_id: tk_tenant_id,
          context: "live",
          object: live_object_name,
          account: live_cim_tracker_account,
          root_constraint: live_cim_tracker_datamodel_constraint,
          cim_tracking_rules: live_cim_json_rules,
          earliest: live_earliest,
          latest: live_latest,
          summariesonly: live_summariesonly,
          cron_schedule: live_cron_schedule,
          update_comment: tk_comment,
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "text",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            returneddata = JSON.parse(returneddata);
            var tk_tracker_name = returneddata.tracker_name;
            setToken("tk_cim_final_report", tk_tracker_name);
            // remove spinner
            cssloaderremove();
            // notify
            msg =
              "The creation of the new CIM entity: " +
              live_object_name +
              " was successful.";
            notify("success", "bottom", msg, "5");
            // set the message to be returned and show modal
            $("#modal_cim_tracker_creation_success")
              .find(".modal-success-message p")
              .text(JSON.stringify(returneddata));
            closeModals();
            cssloaderremove();
            $("#modal_cim_tracker_creation_success").modal();
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // remove spinner
            cssloaderremove();
            // notify
            notify("error", "bottom", message, "5");
            returneddata = {
              responseText: xhr.responseText,
              status: xhr.status,
              statusText: xhr.statusText,
            };
          },
        });
      });

    // functiom to check if the cim entity is already defined
    function checkSplkCimExists(cimEntity) {
      // Get tenant
      var tk_tenant_id = getToken("tenant_id");

      // Create the endpoint URL
      var myendpoint_URl =
        "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/cim_tracker_rules";

      if (!cimEntity || !cimEntity.length) {
        // Show an error message
        invalidEntry();
        return;
      } else {
        // Create a dictionary to store the field names and values
        var record = {
          tenant_id: tk_tenant_id,
          object: cimEntity,
        };

        // actions array
        var listId = [
          "btn_input_cim_tracker_upload_rules_submit",
          "btn_input_cim_tracker_clone_rules_submit",
          "btn_modal_input_cim_add",
          "btn_modal_input_cim_add_startover_rules",
          "btn_modal_input_cim_field_preview_json",
          "btn_modal_input_cim_tracker_simulate_clear",
          "btn_modal_input_cim_tracker_simulate_run",
          "btn_modal_input_cim_tracker_simulate",
          "btn_modal_input_cim_tracker_simulate_clearall",
          "btn_modal_input_cim_promote_live",
        ];

        // call the endpoint, success is a failure, failure is a success
        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "text",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            if (returneddata.length > 2) {
              message =
                "The cim entity: " +
                cimEntity +
                " is already defined, choose a different identifier to continue.";
              // notify
              notify("error", "bottom", message, "5");
              // disable all actions
              for (var i = 0, l = listId.length; i < l; i++) {
                document.getElementById(listId[i]).disabled = true;
              }
            } else {
              message =
                "The cim entity idenfitier is available, you can continue.";
              // notify
              notify("success", "bottom", message, "5");
              // enable all actions
              for (var i = 0, l = listId.length; i < l; i++) {
                document.getElementById(listId[i]).disabled = false;
              }
            }
          },
          error: function (xhr, textStatus, error) {
            message = "Oops! An error was encountered: " + error;
            // notify
            notify("error", "bottom", message, "5");
            // enable all actions
            for (var i = 0, l = listId.length; i < l; i++) {
              document.getElementById(listId[i]).disabled = false;
            }
          },
        });
      }
    }

    // btn_modify_cim
    $("#btn_modify_cim")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/cim_tracker_rules";

        if (!tk_object || !tk_object.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object: tk_object,
          };

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              jsonStr = returneddata;
              document.getElementById(
                "modal_input_cim_tracker_live_tracking_rules"
              ).value = jsonStr;
              $("#modal_modify_object").modal();
              // download json function
              document
                .getElementById("btn_modal_download_cim_json_template")
                .addEventListener(
                  "click",
                  function () {
                    var text = jsonStr;
                    var filename = "cim_tracking_rules_template.json";
                    download(filename, text);
                  },
                  false
                );
            },
            error: function (xhr, textStatus, error) {
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // notify
              notify("error", "bottom", message, "5");

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    function previewFile(id, context) {
      var [file] = document.getElementById(id).files;
      var reader = new FileReader();
      var jsonStr;

      reader.addEventListener(
        "load",
        () => {
          // return the file content and update the textarea
          var jsonStr = reader.result;
          // handle
          if (context === "creation") {
            // creation via template
            $("#divChildCreateCimJsonPreview").html(
              '<pre class="create-cim-json-rules-preview">' +
                syntaxHighlight(jsonStr) +
                "</pre>"
            );
            $("#divCreateCimJsonPreview").css("display", "inherit");
            // set the expected token
            setToken("tk_cim_json_rules", jsonStr);
          } else if (context === "update") {
            // update existing rules
            $("#div_input_cim_tracker_live_tracking_rules").html(
              '"<textarea id = "modal_input_cim_tracker_live_tracking_rules" rows = "10" cols = "80" style="width: 1100px;">' +
                JSON.stringify(JSON.parse(jsonStr), null, 4) +
                "</textarea>"
            );
          }
        },
        false
      );

      if (file) {
        reader.readAsText(file);
      }
    }

    // Upload JSON file feature

    $("#btn_input_cim_tracker_upload_rules_submit")
      .unbind()
      .click(function () {
        var myFile = document.getElementById(
          "btn_input_cim_tracker_upload_rules"
        );

        // Get the files from the form input
        var files = myFile.files;

        // Select only the first file from the input array
        var file = files[0];

        if (!file.type.endsWith("json")) {
          // notify
          notify("error", "bottom", "The file must be a valid JSON file.", "5");
        } else {
          // call
          previewFile("btn_input_cim_tracker_upload_rules", "creation");
          // notify
          notify(
            "success",
            "bottom",
            "JSON file uploaded successfully, you can now simulate the rules before promoting to Live.",
            "5"
          );
          // hide the manual option div
          $("#divSplkCimClone").css("display", "none");
          $("#divSplkCimDefineManually").css("display", "none");
          $("#divSplkCimDefineManuallyRefreshBtn").css("display", "none");
        }
      });

    $("#btn_modal_modify_tracking_rules_upload_submit")
      .unbind()
      .click(function () {
        var myFile = document.getElementById(
          "btn_modal_modify_tracking_rules_upload"
        );

        // Get the files from the form input
        var files = myFile.files;

        // Select only the first file from the input array
        var file = files[0];

        if (!file.type.endsWith("json")) {
          // notify
          notify("error", "bottom", "The file must be a valid JSON file.", "5");
        } else {
          // call
          previewFile("btn_modal_modify_tracking_rules_upload", "update");
          // notify
          notify(
            "success",
            "bottom",
            "JSON file uploaded successfully, you can now simulate the rules before promoting to Live.",
            "5"
          );
        }
      });

    // clone JSON rules from another entity
    $("#btn_input_cim_tracker_clone_rules_submit")
      .unbind()
      .click(function () {
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("inputCimCloneSelector");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/cim_tracker_rules";

        if (!tk_object || !tk_object.length) {
          // Show an error message
          invalidEntry();
          return;
        } else {
          // Create a dictionary to store the field names and values
          var record = {
            tenant_id: tk_tenant_id,
            object: tk_object,
          };

          $.ajax({
            url: myendpoint_URl,
            type: "POST",
            async: true,
            contentType: "application/json",
            dataType: "text",
            beforeSend: function (xhr) {
              xhr.overrideMimeType("text/plain; charset=x-user-defined");
            },
            data: JSON.stringify(record),
            success: function (returneddata) {
              jsonStr = returneddata;

              // creation via template
              $("#divChildCreateCimJsonPreview").html(
                '<pre class="create-cim-json-rules-preview">' +
                  syntaxHighlight(jsonStr) +
                  "</pre>"
              );
              $("#divCreateCimJsonPreview").css("display", "inherit");

              // set the expected token
              setToken("tk_cim_json_rules", jsonStr);

              // hide the manual option div
              $("#divSplkCimUpload").css("display", "none");
              $("#divSplkCimDefineManually").css("display", "none");
              $("#divSplkCimDefineManuallyRefreshBtn").css("display", "none");

              // notify
              message =
                "CIM tracking JSON rules have been successfully cloned fron the entity: " +
                message;
              notify("success", "bottom", message, "5");
            },
            error: function (xhr, textStatus, error) {
              message =
                "server response: " +
                xhr.responseText +
                "\n - http response: " +
                error;

              // notify
              notify("error", "bottom", message, "5");

              $("#modal_update_collection_failure_return")
                .find(".modal-error-message p")
                .text(message);
              closeModals();
              $("#modal_update_collection_failure_return").modal();
            },
          });
        }
      });

    // Simulate changes before promote to Live
    $("#btn_modal_modify_tracking_rules_simulate")
      .unbind()
      .click(function () {
        // Get tenant
        var tk_tenant_id = getToken("tenant_id");
        // Get the new rules
        jsonStr = document.getElementById(
          "modal_input_cim_tracker_live_tracking_rules"
        ).value;

        // Get a few tokens, everything else comes from the JSOn rules
        var tk_object = getToken("tk_object");
        var tk_account = getToken("tk_account");

        // Create the endpoint URL
        var myendpoint_URl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_cim/admin/cim_tracker";

        // Create a dictionary to store the field names and values

        root_constraint = ".*";

        var record = {
          tenant_id: tk_tenant_id,
          context: "simulation",
          object: tk_object,
          account: tk_account,
          cim_tracking_rules: jsonStr,
          root_constraint: root_constraint,
          update_comment: "simulation",
        };

        $.ajax({
          url: myendpoint_URl,
          type: "POST",
          async: true,
          contentType: "application/json",
          dataType: "text",
          beforeSend: function (xhr) {
            xhr.overrideMimeType("text/plain; charset=x-user-defined");
          },
          data: JSON.stringify(record),
          success: function (returneddata) {
            // notify
            notify(
              "success",
              "bottom",
              "Simulation was successfully performed.",
              "5"
            );
            // remove the simulation record
            SplkCimClearSimulation(tk_object, "false", "false");
          },
          error: function (xhr, textStatus, error) {
            message =
              "server response: " +
              xhr.responseText +
              "\n - http response: " +
              error;
            // notify
            notify("error", "bottom", message, "5");
            returneddata = {
              responseText: xhr.responseText,
              status: xhr.status,
              statusText: xhr.statusText,
            };
            // remove the simulation record
            SplkCimClearSimulation(tk_object, "false", "false");
          },
        });
      });

    // cim tracking rules update
    $("#btn_modal_modify_tracking_rules_submit")
      .unbind()
      .click(function () {
        // close modals
        closeModals();
        var tk_object = getToken("tk_object");
        var jsonStr = document.getElementById(
          "modal_input_cim_tracker_live_tracking_rules"
        ).value;
        if (tk_object && tk_object.length) {
          $("#modal_entry_modification").modal();
          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler
              object_manage(
                "update_rules",
                tk_object,
                jsonStr,
                "input_update_comment",
                "modal_modify_object"
              );
            });
        }
      });

    // cim priority update
    $("#btn_modal_modify_priority_splk_cim_confirm")
      .unbind()
      .click(function () {
        // close modals
        closeModals();
        var tk_object = getToken("tk_object");
        var tk_priority = getToken("tk_input_splk_cim_priority");
        if (tk_object && tk_object.length) {
          $("#modal_entry_modification").modal();
          $("#btn_modal_entry_modification")
            .unbind()
            .click(function () {
              var that = $(this);
              that.off("click"); // remove handler
              object_manage(
                "update_priority",
                tk_object,
                tk_priority,
                "input_update_comment",
                "modal_modify_object"
              );
            });
        }
      });

    // back from modify screen
    $("#btn_close_object_modify")
      .unbind()
      .click(function () {
        $("#modal_manage_cim").modal();
      });

    //
    // Anomaly outliers
    //

    // splk-dsm

    //
    // ML models delete
    //

    $("#btn_confirm_modal_outlier_config_splk_dsm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_dsm_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_delete_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_dsm_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
          object: getToken("tk_object"),
          models_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "dsmdhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully deleted.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkDsmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dsm",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_dsm"
              );
              // refresh dropdowns
              searchPopulateSplkDsmOutliersModelsSettings.startSearch();
              searchPopulateSplkDsmOutliersModels.startSearch();
              // return modal
              $("#splk_dsm_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models update
    //

    $("#btn_confirm_modal_outlier_config_splk_dsm_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_dsm_update"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_update_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_dsm_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
          object: getToken("tk_object"),
          outliers_rules: JSON.parse(tk_multi_table_array),
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update ML models",
          JSON.parse(tk_multi_table_array),
          "splk-dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully updated.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkDsmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dsm",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_dsm"
              );
              // refresh dropdowns
              searchPopulateSplkDsmOutliersModelsSettings.startSearch();
              searchPopulateSplkDsmOutliersModels.startSearch();
              // return modal
              $("#splk_dsm_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models reset
    //

    $("#btn_confirm_modal_outlier_config_splk_dsm_confirm_reset")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_reset_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_dsm_confirm_reset"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
          object: getToken("tk_object"),
          update_comment: comment,
        };

        // spinner
        cssloader(
          "Reset and training Machine Learning Models now, please wait..."
        );

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "reset ML models",
          "none",
          "splk-dsm",
          comment
        ).then(function (resultCall) {
          // remove spinner
          cssloaderremove();
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify("success", "bottom", "ML models successfully reset.", "5");
              // refresh dropdowns
              searchPopulateSplkDsmOutliersModelsSettings.startSearch();
              searchPopulateSplkDsmOutliersModels.startSearch();
              // Call models training
              splk_dsm_train_models();
            }
          }
        });
      });

    //
    // ML models addition
    //

    // Open add modal

    $("#btn_outlier_config_splk_dsm_add")
      .unbind()
      .click(function () {
        // free some populating searches
        setToken("show_splk_dsm_outliers_add_model", "true");
        // Open modal
        closeModals();
        $("#add_model_splk_dsm_outliers").modal();
      });

    // Back button

    $("#btn_modal_input_splk_dsm_outliers_add_model_back")
      .unbind()
      .click(function () {
        // Open modal
        closeModals();
        $("#splk_dsm_outliers_manage").modal();
      });

    // Populating searches
    var searchOutlierDetectionPopulateSimulationAddModelDsm = new SearchManager(
      {
        id: "searchOutlierDetectionPopulateSimulationAddModelDsm",
        sample_ratio: 1,
        search:
          '| makeresults | eval kpi_metrics="splk.feeds.avg_dcount_host_5m|splk.feeds.avg_eventcount_5m|splk.feeds.avg_latency_5m|splk.feeds.eventcount_4h|splk.feeds.hostcount_4h|splk.feeds.lag_event_sec|splk.feeds.lag_ingestion_sec|splk.feeds.latest_dcount_host_5m|splk.feeds.latest_eventcount_5m|splk.feeds.latest_latency_5m|splk.feeds.perc95_dcount_host_5m|splk.feeds.perc95_eventcount_5m|splk.feeds.perc95_latency_5m|splk.feeds.stdev_dcount_host_5m|splk.feeds.stdev_eventcount_5m|splk.feeds.stdev_latency_5m" | makemv kpi_metrics delim="|" | fields kpi_metrics | fields - _time | mvexpand kpi_metrics',
        status_buckets: 0,
        earliest_time: "-5m",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
          depends: "$show_splk_dsm_outlier$",
        },
        autostart: true,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // dropdowns
    var modal_input_splk_dsm_outliers_add_model_kpi_metric = new DropdownInput(
      {
        id: "modal_input_splk_dsm_outliers_add_model_kpi_metric",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "kpi_metrics",
        selectFirstChoice: true,
        width: 300,
        valueField: "kpi_metrics",
        value: "$form.input_splk_dsm_outliers_add_model_kpi_metric$",
        managerid: "searchOutlierDetectionPopulateSimulationAddModelDsm",
        el: $("#modal_input_splk_dsm_outliers_add_model_kpi_metric"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dsm_outliers_add_model_kpi_metric.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_kpi_metric
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_kpi_span = new DropdownInput(
      {
        id: "modal_input_splk_dsm_outliers_add_model_kpi_span",
        choices: [
          {
            label: "5m",
            value: "5m",
          },
          {
            label: "10m",
            value: "10m",
          },
          {
            label: "15m",
            value: "15m",
          },
          {
            label: "30m",
            value: "30m",
          },
          {
            label: "1h",
            value: "1h",
          },
        ],
        searchWhenChanged: true,
        default: "10m",
        showClearButton: true,
        initialValue: "10m",
        selectFirstChoice: false,
        value: "$form.input_splk_dsm_outliers_add_model_kpi_span$",
        el: $("#modal_input_splk_dsm_outliers_add_model_kpi_span"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dsm_outliers_add_model_kpi_span.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_kpi_span
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_calculation_method =
      new DropdownInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_calculation_method",
          choices: [
            {
              label: "stdev",
              value: "stdev",
            },
            {
              label: "avg",
              value: "avg",
            },
            {
              label: "perc95",
              value: "perc95",
            },
            {
              label: "latest",
              value: "latest",
            },
          ],
          searchWhenChanged: true,
          default: "avg",
          showClearButton: true,
          initialValue: "avg",
          selectFirstChoice: false,
          value: "$form.input_splk_dsm_outliers_add_model_calculation_method$",
          el: $("#modal_input_splk_dsm_outliers_add_model_calculation_method"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_calculation_method.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_calculation_method
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_density_lowerthreshold =
      new TextInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_density_lowerthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_dsm_outliers_add_model_density_lowerthreshold$",
          el: $(
            "#modal_input_splk_dsm_outliers_add_model_density_lowerthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_density_lowerthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_density_lowerthreshold
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_density_upperthreshold =
      new TextInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_density_upperthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_dsm_outliers_add_model_density_upperthreshold$",
          el: $(
            "#modal_input_splk_dsm_outliers_add_model_density_upperthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_density_upperthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_density_upperthreshold
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_alert_lower_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_alert_lower_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_dsm_outliers_add_model_alert_lower_breached$",
          el: $(
            "#modal_input_splk_dsm_outliers_add_model_alert_lower_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_alert_lower_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_alert_lower_breached
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_alert_upper_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_alert_upper_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_dsm_outliers_add_model_alert_upper_breached$",
          el: $(
            "#modal_input_splk_dsm_outliers_add_model_alert_upper_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_alert_upper_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_alert_upper_breached
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_period_calculation =
      new DropdownInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_period_calculation",
          choices: [
            {
              label: "-7d",
              value: "-7d",
            },
            {
              label: "-30d",
              value: "-30d",
            },
            {
              label: "-60d",
              value: "-60d",
            },
            {
              label: "-90d",
              value: "-90d",
            },
          ],
          searchWhenChanged: true,
          default: "-30d",
          showClearButton: true,
          initialValue: "-30d",
          selectFirstChoice: false,
          value: "$form.input_splk_dsm_outliers_add_model_period_calculation$",
          el: $("#modal_input_splk_dsm_outliers_add_model_period_calculation"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_period_calculation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_period_calculation
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_time_factor = new DropdownInput(
      {
        id: "modal_input_splk_dsm_outliers_add_model_time_factor",
        choices: [
          {
            label: "%H",
            value: "%H",
          },
          {
            label: "%H%M",
            value: "%H%M",
          },
          {
            label: "%w%H",
            value: "%w%H",
          },
          {
            label: "%w%H%M",
            value: "%w%H%M",
          },
          {
            label: "No time factor",
            value: "none",
          },
        ],
        searchWhenChanged: true,
        default: "%H",
        showClearButton: true,
        initialValue: "%H",
        selectFirstChoice: false,
        value: "$form.input_splk_dsm_outliers_add_model_time_factor$",
        el: $("#modal_input_splk_dsm_outliers_add_model_time_factor"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dsm_outliers_add_model_time_factor.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_time_factor
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_auto_correct =
      new DropdownInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_auto_correct",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value: "$form.input_splk_dsm_outliers_add_model_auto_correct$",
          el: $("#modal_input_splk_dsm_outliers_add_model_auto_correct"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_auto_correct.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_auto_correct
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation$",
          el: $(
            "#modal_input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation
        );
      }
    );

    var modal_input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation$",
          el: $(
            "#modal_input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation
        );
      }
    );

    //
    // Rendering elements
    //

    var searchOutlierDetectionChartSimulationAddModelDsm = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationAddModelDsm",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="dsm" object="$tk_object$" mode="simulation" model_json_def="$tk_splk_dsm_simulation_add_model_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkDsmTimeAddModel.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkDsmTimeAddModel.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_dsm_tracker$",
          depends: "$show_splk_dsm_outlier$",
          depends: "$show_splk_dsm_outliers_add_model$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationAddModelDsm.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkDsmNoResultsAddModel").css("display", "none");
        // show at start
        $("#elementOutlierLoaderAddModelDsm").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelDsm.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelDsm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDsmNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelDsm.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelDsm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDsmNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelDsm.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderAddModelDsm").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierAddModelSimulationDsm").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationDsm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDsmTimeAddModel").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkDsmNoResultsAddModel").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderAddModelDsm").css("display", "none");
          // show chart and results link
          $("#elementOutlierAddModelSimulationDsm").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationDsm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDsmTimeAddModel").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkDsmNoResultsAddModel").css("display", "none");
        }
      }
    );

    var elementOutlierAddModelSimulationDsm = new OutliersViz(
      {
        id: "elementOutlierAddModelSimulationDsm",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationAddModelDsm",
        el: $("#elementOutlierAddModelSimulationDsm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierAddModelSimulationDsm = new ResultsLinkView({
      id: "resultsLinkelementOutlierAddModelSimulationDsm",
      managerid: "searchOutlierDetectionChartSimulationAddModelDsm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierAddModelSimulationDsm"),
    });

    resultsLinkelementOutlierAddModelSimulationDsm
      .render()
      .$el.appendTo($("resultsLinkelementOutlierAddModelSimulationDsm"));

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkDsmTimeAddModel = new LinkListInput(
      {
        id: "inputOutliersSplkDsmTimeAddModel",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkDsmTimeAddModel$",
        el: $("#inputOutliersSplkDsmTimeAddModel"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkDsmTimeAddModel.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkDsmTimeAddModel);
    });

    inputOutliersSplkDsmTimeAddModel.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDsmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      }
    });

    // Simulate

    $("#modal_input_splk_dsm_outliers_add_simulate")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_dsm_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_dsm_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_dsm_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_dsm_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_dsm_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_dsm_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_dsm_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_dsm_outliers_add_model_period_calculation"
          ),
          time_factor: getToken(
            "input_splk_dsm_outliers_add_model_time_factor"
          ),
          auto_correct: getToken(
            "input_splk_dsm_outliers_add_model_auto_correct"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // Set token
        setToken("start_outliers_simulation_add_model_splk_dsm", "true");
        setToken(
          "tk_splk_dsm_simulation_add_model_model_def",
          JSON.stringify(model_json_value).replace(/\"/g, '\\"')
        );

        // Explicitly start the search
        searchOutlierDetectionChartSimulationAddModelDsm.startSearch();
      });

    // Confirm addition

    $("#modal_input_splk_dsm_outliers_add_confirm")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_add_model";

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_dsm_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_dsm_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_dsm_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_dsm_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_dsm_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_dsm_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_dsm_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_dsm_outliers_add_model_period_calculation"
          ),
          time_factor: encodeURI(
            getToken("input_splk_dsm_outliers_add_model_time_factor")
          ),
          auto_correct: getToken(
            "input_splk_dsm_outliers_add_model_auto_correct"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_dsm_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_dsm_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
          object: getToken("tk_object"),
          model_json: JSON.stringify(model_json_value),
          update_comment: "N/A",
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML model",
          "none",
          "splk-dsm",
          "N/A"
        ).then(function (resultCall) {
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // refresh dropdowns
              searchPopulateSplkDsmOutliersModelsSettings.startSearch();
              searchPopulateSplkDsmOutliersModels.startSearch();
              // Call models training
              splk_dsm_train_models();
              // Open modal
              $("#splk_dsm_outliers_manage").modal();
              // notify
              notify(
                "success",
                "bottom",
                "ML model was successfully added and trained.",
                "5"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion add
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_dsm_confirm_add")
      .unbind()
      .click(function () {
        // Retrieve start date
        var inputStart = document.getElementById(
          "splk_dsm_period_exclusion_earliest"
        ).value;

        // Retrieve end date
        var inputEnd = document.getElementById(
          "splk_dsm_period_exclusion_latest"
        ).value;

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_dsm_confirm_add"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
          action: "add",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_dsm_outliers_model_id_settings_dropdown"
          ),
          earliest: inputStart,
          latest: inputEnd,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML exclusion period",
          getToken("tk_input_splk_dsm_outliers_model_id_settings_dropdown"),
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully added.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkDsmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dsm",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_dsm_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_dsm"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion delete
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_dsm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_periods_exclusions_splk_dsm_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_dsm_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dsm",
          action: "delete",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_dsm_outliers_model_id_settings_dropdown"
          ),
          period_exclusion_id: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete ML exclusion period",
          tk_multi_table_array,
          "dsm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully deleted.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkDsmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dsm",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_dsm_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_dsm"
              );
            }
          }
        });
      });

    // splk-flx

    //
    // ML models delete
    //

    $("#btn_confirm_modal_outlier_config_splk_flx_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_flx_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_delete_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_flx_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
          object: getToken("tk_object"),
          models_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "flxdhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully deleted.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkFlxHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "flx",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_flx"
              );
              // refresh dropdowns
              searchPopulateSplkFlxOutliersModelsSettings.startSearch();
              searchPopulateSplkFlxOutliersModels.startSearch();
              // return modal
              $("#splk_flx_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models update
    //

    $("#btn_confirm_modal_outlier_config_splk_flx_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_flx_update"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_update_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_flx_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
          object: getToken("tk_object"),
          outliers_rules: JSON.parse(tk_multi_table_array),
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update ML models",
          JSON.parse(tk_multi_table_array),
          "splk-flx",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully updated.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkFlxHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "flx",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_flx"
              );
              // refresh dropdowns
              searchPopulateSplkFlxOutliersModelsSettings.startSearch();
              searchPopulateSplkFlxOutliersModels.startSearch();
              // return modal
              $("#splk_flx_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models reset
    //

    $("#btn_confirm_modal_outlier_config_splk_flx_confirm_reset")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_reset_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_flx_confirm_reset"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
          object: getToken("tk_object"),
          update_comment: comment,
        };

        // spinner
        cssloader(
          "Reset and training Machine Learning Models now, please wait..."
        );

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "reset ML models",
          "none",
          "splk-flx",
          comment
        ).then(function (resultCall) {
          // remove spinner
          cssloaderremove();
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify("success", "bottom", "ML models successfully reset.", "5");
              // refresh dropdowns
              searchPopulateSplkFlxOutliersModelsSettings.startSearch();
              searchPopulateSplkFlxOutliersModels.startSearch();
              // Call models training
              splk_flx_train_models();
            }
          }
        });
      });

    //
    // ML models addition
    //

    // Open add modal

    $("#btn_outlier_config_splk_flx_add")
      .unbind()
      .click(function () {
        // free some populating searches
        setToken("show_splk_flx_outliers_add_model", "true");
        // Open modal
        closeModals();
        $("#add_model_splk_flx_outliers").modal();
      });

    // Back button

    $("#btn_modal_input_splk_flx_outliers_add_model_back")
      .unbind()
      .click(function () {
        // Open modal
        closeModals();
        $("#splk_flx_outliers_manage").modal();
      });

    // Populating searches
    var searchOutlierDetectionPopulateSimulationAddModelFlx = new SearchManager(
      {
        id: "searchOutlierDetectionPopulateSimulationAddModelFlx",
        sample_ratio: 1,
        search:
          '$splk_flx_metrics_populate_search$ | rex field=metric_name "^trackme.(?<kpi_metrics>.*)"',
        status_buckets: 0,
        earliest_time: "-5m",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
          depends: "$show_splk_flx_outlier$",
        },
        autostart: true,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // dropdowns
    var modal_input_splk_flx_outliers_add_model_kpi_metric = new DropdownInput(
      {
        id: "modal_input_splk_flx_outliers_add_model_kpi_metric",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "kpi_metrics",
        selectFirstChoice: true,
        width: 300,
        valueField: "kpi_metrics",
        value: "$form.input_splk_flx_outliers_add_model_kpi_metric$",
        managerid: "searchOutlierDetectionPopulateSimulationAddModelFlx",
        el: $("#modal_input_splk_flx_outliers_add_model_kpi_metric"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_outliers_add_model_kpi_metric.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_kpi_metric
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_kpi_span = new DropdownInput(
      {
        id: "modal_input_splk_flx_outliers_add_model_kpi_span",
        choices: [
          {
            label: "5m",
            value: "5m",
          },
          {
            label: "10m",
            value: "10m",
          },
          {
            label: "15m",
            value: "15m",
          },
          {
            label: "30m",
            value: "30m",
          },
          {
            label: "1h",
            value: "1h",
          },
        ],
        searchWhenChanged: true,
        default: "10m",
        showClearButton: true,
        initialValue: "10m",
        selectFirstChoice: false,
        value: "$form.input_splk_flx_outliers_add_model_kpi_span$",
        el: $("#modal_input_splk_flx_outliers_add_model_kpi_span"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_outliers_add_model_kpi_span.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_kpi_span
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_calculation_method =
      new DropdownInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_calculation_method",
          choices: [
            {
              label: "stdev",
              value: "stdev",
            },
            {
              label: "avg",
              value: "avg",
            },
            {
              label: "perc95",
              value: "perc95",
            },
            {
              label: "latest",
              value: "latest",
            },
          ],
          searchWhenChanged: true,
          default: "avg",
          showClearButton: true,
          initialValue: "avg",
          selectFirstChoice: false,
          value: "$form.input_splk_flx_outliers_add_model_calculation_method$",
          el: $("#modal_input_splk_flx_outliers_add_model_calculation_method"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_calculation_method.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_calculation_method
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_density_lowerthreshold =
      new TextInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_density_lowerthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_flx_outliers_add_model_density_lowerthreshold$",
          el: $(
            "#modal_input_splk_flx_outliers_add_model_density_lowerthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_density_lowerthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_density_lowerthreshold
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_density_upperthreshold =
      new TextInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_density_upperthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_flx_outliers_add_model_density_upperthreshold$",
          el: $(
            "#modal_input_splk_flx_outliers_add_model_density_upperthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_density_upperthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_density_upperthreshold
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_alert_lower_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_alert_lower_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_flx_outliers_add_model_alert_lower_breached$",
          el: $(
            "#modal_input_splk_flx_outliers_add_model_alert_lower_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_alert_lower_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_alert_lower_breached
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_alert_upper_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_alert_upper_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_flx_outliers_add_model_alert_upper_breached$",
          el: $(
            "#modal_input_splk_flx_outliers_add_model_alert_upper_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_alert_upper_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_alert_upper_breached
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_period_calculation =
      new DropdownInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_period_calculation",
          choices: [
            {
              label: "-7d",
              value: "-7d",
            },
            {
              label: "-30d",
              value: "-30d",
            },
            {
              label: "-60d",
              value: "-60d",
            },
            {
              label: "-90d",
              value: "-90d",
            },
          ],
          searchWhenChanged: true,
          default: "-30d",
          showClearButton: true,
          initialValue: "-30d",
          selectFirstChoice: false,
          value: "$form.input_splk_flx_outliers_add_model_period_calculation$",
          el: $("#modal_input_splk_flx_outliers_add_model_period_calculation"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_period_calculation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_period_calculation
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_time_factor = new DropdownInput(
      {
        id: "modal_input_splk_flx_outliers_add_model_time_factor",
        choices: [
          {
            label: "%H",
            value: "%H",
          },
          {
            label: "%H%M",
            value: "%H%M",
          },
          {
            label: "%w%H",
            value: "%w%H",
          },
          {
            label: "%w%H%M",
            value: "%w%H%M",
          },
          {
            label: "No time factor",
            value: "none",
          },
        ],
        searchWhenChanged: true,
        default: "%H",
        showClearButton: true,
        initialValue: "%H",
        selectFirstChoice: false,
        value: "$form.input_splk_flx_outliers_add_model_time_factor$",
        el: $("#modal_input_splk_flx_outliers_add_model_time_factor"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_flx_outliers_add_model_time_factor.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_time_factor
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation$",
          el: $(
            "#modal_input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation
        );
      }
    );

    var modal_input_splk_flx_outliers_add_model_perc_min_upperbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_flx_outliers_add_model_perc_min_upperbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_flx_outliers_add_model_perc_min_upperbound_deviation$",
          el: $(
            "#modal_input_splk_flx_outliers_add_model_perc_min_upperbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_flx_outliers_add_model_perc_min_upperbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_flx_outliers_add_model_perc_min_upperbound_deviation
        );
      }
    );

    //
    // Rendering elements
    //

    var searchOutlierDetectionChartSimulationAddModelFlx = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationAddModelFlx",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="flx" object="$tk_object$" mode="simulation" model_json_def="$tk_splk_flx_simulation_add_model_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkFlxTimeAddModel.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkFlxTimeAddModel.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_flx_tracker$",
          depends: "$show_splk_flx_outlier$",
          depends: "$show_splk_flx_outliers_add_model$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationAddModelFlx.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkFlxNoResultsAddModel").css("display", "none");
        // show at start
        $("#elementOutlierLoaderAddModelFlx").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelFlx.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelFlx").css("display", "none");
        // show no results
        $("#elementOutliersSplkFlxNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelFlx.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelFlx").css("display", "none");
        // show no results
        $("#elementOutliersSplkFlxNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelFlx.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderAddModelFlx").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierAddModelSimulationFlx").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationFlx").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkFlxTimeAddModel").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkFlxNoResultsAddModel").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderAddModelFlx").css("display", "none");
          // show chart and results link
          $("#elementOutlierAddModelSimulationFlx").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationFlx").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkFlxTimeAddModel").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkFlxNoResultsAddModel").css("display", "none");
        }
      }
    );

    var elementOutlierAddModelSimulationFlx = new OutliersViz(
      {
        id: "elementOutlierAddModelSimulationFlx",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationAddModelFlx",
        el: $("#elementOutlierAddModelSimulationFlx"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierAddModelSimulationFlx = new ResultsLinkView({
      id: "resultsLinkelementOutlierAddModelSimulationFlx",
      managerid: "searchOutlierDetectionChartSimulationAddModelFlx",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierAddModelSimulationFlx"),
    });

    resultsLinkelementOutlierAddModelSimulationFlx
      .render()
      .$el.appendTo($("resultsLinkelementOutlierAddModelSimulationFlx"));

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkFlxTimeAddModel = new LinkListInput(
      {
        id: "inputOutliersSplkFlxTimeAddModel",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkFlxTimeAddModel$",
        el: $("#inputOutliersSplkFlxTimeAddModel"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkFlxTimeAddModel.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkFlxTimeAddModel);
    });

    inputOutliersSplkFlxTimeAddModel.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkFlxTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      }
    });

    // Simulate

    $("#modal_input_splk_flx_outliers_add_simulate")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_flx_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_flx_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_flx_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_flx_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_flx_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_flx_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_flx_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_flx_outliers_add_model_period_calculation"
          ),
          time_factor: getToken(
            "input_splk_flx_outliers_add_model_time_factor"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_flx_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // Set token
        setToken("start_outliers_simulation_add_model_splk_flx", "true");
        setToken(
          "tk_splk_flx_simulation_add_model_model_def",
          JSON.stringify(model_json_value).replace(/\"/g, '\\"')
        );

        // Explicitly start the search
        searchOutlierDetectionChartSimulationAddModelFlx.startSearch();
      });

    // Confirm addition

    $("#modal_input_splk_flx_outliers_add_confirm")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_add_model";

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_flx_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_flx_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_flx_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_flx_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_flx_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_flx_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_flx_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_flx_outliers_add_model_period_calculation"
          ),
          time_factor: encodeURI(
            getToken("input_splk_flx_outliers_add_model_time_factor")
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_flx_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_flx_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
          object: getToken("tk_object"),
          model_json: JSON.stringify(model_json_value),
          update_comment: "N/A",
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML model",
          "none",
          "splk-flx",
          "N/A"
        ).then(function (resultCall) {
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // refresh dropdowns
              searchPopulateSplkFlxOutliersModelsSettings.startSearch();
              searchPopulateSplkFlxOutliersModels.startSearch();
              // Call models training
              splk_flx_train_models();
              // Open modal
              $("#splk_flx_outliers_manage").modal();
              // notify
              notify(
                "success",
                "bottom",
                "ML model was successfully added and trained.",
                "5"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion add
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_flx_confirm_add")
      .unbind()
      .click(function () {
        // Retrieve start date
        var inputStart = document.getElementById(
          "splk_flx_period_exclusion_earliest"
        ).value;

        // Retrieve end date
        var inputEnd = document.getElementById(
          "splk_flx_period_exclusion_latest"
        ).value;

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_flx_confirm_add"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
          action: "add",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_flx_outliers_model_id_settings_dropdown"
          ),
          earliest: inputStart,
          latest: inputEnd,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML exclusion period",
          getToken("tk_input_splk_flx_outliers_model_id_settings_dropdown"),
          "flx",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully added.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkFlxHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "flx",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_flx_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_flx"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion delete
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_flx_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_periods_exclusions_splk_flx_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_flx_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "flx",
          action: "delete",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_flx_outliers_model_id_settings_dropdown"
          ),
          period_exclusion_id: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete ML exclusion period",
          tk_multi_table_array,
          "flx",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully deleted.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkFlxHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "flx",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_flx_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_flx"
              );
            }
          }
        });
      });

    // splk-wlk

    //
    // ML models delete
    //

    $("#btn_confirm_modal_outlier_config_splk_wlk_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_wlk_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_delete_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_wlk_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
          object: getToken("tk_object"),
          models_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "wlkdhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully deleted.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkWlkHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "wlk",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_wlk"
              );
              // refresh dropdowns
              searchPopulateSplkWlkOutliersModelsSettings.startSearch();
              searchPopulateSplkWlkOutliersModels.startSearch();
              // return modal
              $("#splk_wlk_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models update
    //

    $("#btn_confirm_modal_outlier_config_splk_wlk_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_wlk_update"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_update_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_wlk_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
          object: getToken("tk_object"),
          outliers_rules: JSON.parse(tk_multi_table_array),
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update ML models",
          JSON.parse(tk_multi_table_array),
          "splk-wlk",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully updated.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkWlkHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "wlk",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_wlk"
              );
              // refresh dropdowns
              searchPopulateSplkWlkOutliersModelsSettings.startSearch();
              searchPopulateSplkWlkOutliersModels.startSearch();
              // return modal
              $("#splk_wlk_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models reset
    //

    $("#btn_confirm_modal_outlier_config_splk_wlk_confirm_reset")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_reset_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_wlk_confirm_reset"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
          object: getToken("tk_object"),
          update_comment: comment,
        };

        // spinner
        cssloader(
          "Reset and training Machine Learning Models now, please wait..."
        );

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "reset ML models",
          "none",
          "splk-wlk",
          comment
        ).then(function (resultCall) {
          // remove spinner
          cssloaderremove();
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify("success", "bottom", "ML models successfully reset.", "5");
              // refresh dropdowns
              searchPopulateSplkWlkOutliersModelsSettings.startSearch();
              searchPopulateSplkWlkOutliersModels.startSearch();
              // Call models training
              splk_wlk_train_models();
            }
          }
        });
      });

    //
    // ML models addition
    //

    // Open add modal

    $("#btn_outlier_config_splk_wlk_add")
      .unbind()
      .click(function () {
        // free some populating searches
        setToken("show_splk_wlk_outliers_add_model", "true");
        // Open modal
        closeModals();
        $("#add_model_splk_wlk_outliers").modal();
      });

    // Back button

    $("#btn_modal_input_splk_wlk_outliers_add_model_back")
      .unbind()
      .click(function () {
        // Open modal
        closeModals();
        $("#splk_wlk_outliers_manage").modal();
      });

    // Populating searches
    var searchOutlierDetectionPopulateSimulationAddModelWlk = new SearchManager(
      {
        id: "searchOutlierDetectionPopulateSimulationAddModelWlk",
        sample_ratio: 1,
        search:
          '$splk_wlk_metrics_populate_search$ | rex field=metric_name "^trackme.(?<kpi_metrics>.*)"',
        status_buckets: 0,
        earliest_time: "-5m",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
          depends: "$show_splk_wlk_outlier$",
        },
        autostart: true,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // dropdowns
    var modal_input_splk_wlk_outliers_add_model_kpi_metric = new DropdownInput(
      {
        id: "modal_input_splk_wlk_outliers_add_model_kpi_metric",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "kpi_metrics",
        selectFirstChoice: true,
        width: 300,
        valueField: "kpi_metrics",
        value: "$form.input_splk_wlk_outliers_add_model_kpi_metric$",
        managerid: "searchOutlierDetectionPopulateSimulationAddModelWlk",
        el: $("#modal_input_splk_wlk_outliers_add_model_kpi_metric"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_outliers_add_model_kpi_metric.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_kpi_metric
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_kpi_span = new DropdownInput(
      {
        id: "modal_input_splk_wlk_outliers_add_model_kpi_span",
        choices: [
          {
            label: "5m",
            value: "5m",
          },
          {
            label: "10m",
            value: "10m",
          },
          {
            label: "15m",
            value: "15m",
          },
          {
            label: "30m",
            value: "30m",
          },
          {
            label: "1h",
            value: "1h",
          },
        ],
        searchWhenChanged: true,
        default: "10m",
        showClearButton: true,
        initialValue: "10m",
        selectFirstChoice: false,
        value: "$form.input_splk_wlk_outliers_add_model_kpi_span$",
        el: $("#modal_input_splk_wlk_outliers_add_model_kpi_span"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_outliers_add_model_kpi_span.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_kpi_span
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_calculation_method =
      new DropdownInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_calculation_method",
          choices: [
            {
              label: "stdev",
              value: "stdev",
            },
            {
              label: "avg",
              value: "avg",
            },
            {
              label: "perc95",
              value: "perc95",
            },
            {
              label: "latest",
              value: "latest",
            },
          ],
          searchWhenChanged: true,
          default: "avg",
          showClearButton: true,
          initialValue: "avg",
          selectFirstChoice: false,
          value: "$form.input_splk_wlk_outliers_add_model_calculation_method$",
          el: $("#modal_input_splk_wlk_outliers_add_model_calculation_method"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_calculation_method.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_calculation_method
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_density_lowerthreshold =
      new TextInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_density_lowerthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_wlk_outliers_add_model_density_lowerthreshold$",
          el: $(
            "#modal_input_splk_wlk_outliers_add_model_density_lowerthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_density_lowerthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_density_lowerthreshold
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_density_upperthreshold =
      new TextInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_density_upperthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_wlk_outliers_add_model_density_upperthreshold$",
          el: $(
            "#modal_input_splk_wlk_outliers_add_model_density_upperthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_density_upperthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_density_upperthreshold
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_alert_lower_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_alert_lower_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_wlk_outliers_add_model_alert_lower_breached$",
          el: $(
            "#modal_input_splk_wlk_outliers_add_model_alert_lower_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_alert_lower_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_alert_lower_breached
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_alert_upper_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_alert_upper_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_wlk_outliers_add_model_alert_upper_breached$",
          el: $(
            "#modal_input_splk_wlk_outliers_add_model_alert_upper_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_alert_upper_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_alert_upper_breached
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_period_calculation =
      new DropdownInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_period_calculation",
          choices: [
            {
              label: "-7d",
              value: "-7d",
            },
            {
              label: "-30d",
              value: "-30d",
            },
            {
              label: "-60d",
              value: "-60d",
            },
            {
              label: "-90d",
              value: "-90d",
            },
          ],
          searchWhenChanged: true,
          default: "-30d",
          showClearButton: true,
          initialValue: "-30d",
          selectFirstChoice: false,
          value: "$form.input_splk_wlk_outliers_add_model_period_calculation$",
          el: $("#modal_input_splk_wlk_outliers_add_model_period_calculation"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_period_calculation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_period_calculation
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_time_factor = new DropdownInput(
      {
        id: "modal_input_splk_wlk_outliers_add_model_time_factor",
        choices: [
          {
            label: "%H",
            value: "%H",
          },
          {
            label: "%H%M",
            value: "%H%M",
          },
          {
            label: "%w%H",
            value: "%w%H",
          },
          {
            label: "%w%H%M",
            value: "%w%H%M",
          },
          {
            label: "No time factor",
            value: "none",
          },
        ],
        searchWhenChanged: true,
        default: "%H",
        showClearButton: true,
        initialValue: "%H",
        selectFirstChoice: false,
        value: "$form.input_splk_wlk_outliers_add_model_time_factor$",
        el: $("#modal_input_splk_wlk_outliers_add_model_time_factor"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_wlk_outliers_add_model_time_factor.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_time_factor
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation$",
          el: $(
            "#modal_input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation
        );
      }
    );

    var modal_input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation$",
          el: $(
            "#modal_input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation
        );
      }
    );

    //
    // Rendering elements
    //

    var searchOutlierDetectionChartSimulationAddModelWlk = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationAddModelWlk",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="wlk" object="$tk_object$" mode="simulation" model_json_def="$tk_splk_wlk_simulation_add_model_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkWlkTimeAddModel.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkWlkTimeAddModel.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_wlk_tracker$",
          depends: "$show_splk_wlk_outlier$",
          depends: "$show_splk_wlk_outliers_add_model$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationAddModelWlk.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkWlkNoResultsAddModel").css("display", "none");
        // show at start
        $("#elementOutlierLoaderAddModelWlk").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelWlk.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelWlk").css("display", "none");
        // show no results
        $("#elementOutliersSplkWlkNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelWlk.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelWlk").css("display", "none");
        // show no results
        $("#elementOutliersSplkWlkNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelWlk.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderAddModelWlk").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierAddModelSimulationWlk").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationWlk").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkWlkTimeAddModel").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkWlkNoResultsAddModel").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderAddModelWlk").css("display", "none");
          // show chart and results link
          $("#elementOutlierAddModelSimulationWlk").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationWlk").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkWlkTimeAddModel").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkWlkNoResultsAddModel").css("display", "none");
        }
      }
    );

    var elementOutlierAddModelSimulationWlk = new OutliersViz(
      {
        id: "elementOutlierAddModelSimulationWlk",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationAddModelWlk",
        el: $("#elementOutlierAddModelSimulationWlk"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierAddModelSimulationWlk = new ResultsLinkView({
      id: "resultsLinkelementOutlierAddModelSimulationWlk",
      managerid: "searchOutlierDetectionChartSimulationAddModelWlk",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierAddModelSimulationWlk"),
    });

    resultsLinkelementOutlierAddModelSimulationWlk
      .render()
      .$el.appendTo($("resultsLinkelementOutlierAddModelSimulationWlk"));

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkWlkTimeAddModel = new LinkListInput(
      {
        id: "inputOutliersSplkWlkTimeAddModel",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkWlkTimeAddModel$",
        el: $("#inputOutliersSplkWlkTimeAddModel"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkWlkTimeAddModel.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkWlkTimeAddModel);
    });

    inputOutliersSplkWlkTimeAddModel.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkWlkTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      }
    });

    // Simulate

    $("#modal_input_splk_wlk_outliers_add_simulate")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_wlk_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_wlk_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_wlk_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_wlk_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_wlk_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_wlk_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_wlk_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_wlk_outliers_add_model_period_calculation"
          ),
          time_factor: getToken(
            "input_splk_wlk_outliers_add_model_time_factor"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // Set token
        setToken("start_outliers_simulation_add_model_splk_wlk", "true");
        setToken(
          "tk_splk_wlk_simulation_add_model_model_def",
          JSON.stringify(model_json_value).replace(/\"/g, '\\"')
        );

        // Explicitly start the search
        searchOutlierDetectionChartSimulationAddModelWlk.startSearch();
      });

    // Confirm addition

    $("#modal_input_splk_wlk_outliers_add_confirm")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_add_model";

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_wlk_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_wlk_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_wlk_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_wlk_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_wlk_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_wlk_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_wlk_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_wlk_outliers_add_model_period_calculation"
          ),
          time_factor: encodeURI(
            getToken("input_splk_wlk_outliers_add_model_time_factor")
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_wlk_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_wlk_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
          object: getToken("tk_object"),
          model_json: JSON.stringify(model_json_value),
          update_comment: "N/A",
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML model",
          "none",
          "splk-wlk",
          "N/A"
        ).then(function (resultCall) {
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // refresh dropdowns
              searchPopulateSplkWlkOutliersModelsSettings.startSearch();
              searchPopulateSplkWlkOutliersModels.startSearch();
              // Call models training
              splk_wlk_train_models();
              // Open modal
              $("#splk_wlk_outliers_manage").modal();
              // notify
              notify(
                "success",
                "bottom",
                "ML model was successfully added and trained.",
                "5"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion add
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_wlk_confirm_add")
      .unbind()
      .click(function () {
        // Retrieve start date
        var inputStart = document.getElementById(
          "splk_wlk_period_exclusion_earliest"
        ).value;

        // Retrieve end date
        var inputEnd = document.getElementById(
          "splk_wlk_period_exclusion_latest"
        ).value;

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_wlk_confirm_add"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
          action: "add",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_wlk_outliers_model_id_settings_dropdown"
          ),
          earliest: inputStart,
          latest: inputEnd,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML exclusion period",
          getToken("tk_input_splk_wlk_outliers_model_id_settings_dropdown"),
          "wlk",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully added.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkWlkHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "wlk",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_wlk_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_wlk"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion delete
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_wlk_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_periods_exclusions_splk_wlk_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_wlk_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "wlk",
          action: "delete",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_wlk_outliers_model_id_settings_dropdown"
          ),
          period_exclusion_id: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete ML exclusion period",
          tk_multi_table_array,
          "wlk",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully deleted.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkWlkHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "wlk",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_wlk_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_wlk"
              );
            }
          }
        });
      });

    // splk-cim

    //
    // ML models delete
    //

    $("#btn_confirm_modal_outlier_config_splk_cim_confirm_delete")
      .unbind()
      .click(function () {
        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_cim_delete_models";

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          object: getToken("tk_object"),
          json_dict: getToken("tk_outlier_config_splk_cim_delete"),
          update_comment: getComment(
            "comment_modal_outlier_config_splk_cim_confirm_save"
          ),
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete cim outliers model",
          getToken("tk_outlier_config_splk_cim_delete"),
          "cim",
          getComment("comment_modal_outlier_config_splk_cim_confirm_save")
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully deleted.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkCimHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_cim_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  object: getToken("tk_object"),
                  entity: "*",
                  cim_field: "*",
                },
                "outlier_config_splk_cim"
              );
              // refresh dropdowns
              refreshSplkCimMlModelsDropdows();
              // return modal
              $("#splk_cim_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models update
    //

    $("#btn_confirm_modal_outlier_config_splk_cim_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_cim_update"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_cim_update_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_cim_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "cim",
          object: getToken("tk_object"),
          outliers_rules: JSON.parse(tk_multi_table_array),
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update ML models",
          JSON.parse(tk_multi_table_array),
          "splk-cim",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully updated.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkCimHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_cim_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  object: getToken("tk_object"),
                  entity: "*",
                  cim_field: "*",
                },
                "outlier_config_splk_cim"
              );
              // refresh dropdowns
              refreshSplkCimMlModelsDropdows();
              // return modal
              $("#splk_cim_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML: refresh populating searches for ML related dropdowns
    //

    function refreshSplkCimMlModelsDropdows() {
      // main outliers screen
      searchPopulateSplkCimOutliersCimEntities.startSearch();
      searchPopulateSplkCimOutliersCimFields.startSearch();
      searchPopulateSplkCimOutliersModels.startSearch();
      // manage outliers screen
      searchPopulateSplkCimOutliersModelsSettings.startSearch();
      // add model screen
      searchPopulateSplkCimOutliersAddCimEntities.startSearch();
      searchPopulateSplkCimOutliersAddCimFields.startSearch();
    }

    //
    // ML models reset
    //

    $("#btn_confirm_modal_outlier_config_splk_cim_confirm_reset")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_cim_reset_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_cim_confirm_reset"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          object: getToken("tk_object"),
          update_comment: comment,
        };

        // spinner
        cssloader(
          "Reset and train Machine Learning Models now, please wait..."
        );

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "reset ML models",
          "none",
          "splk-cim",
          comment
        ).then(function (resultCall) {
          // remove spinner
          cssloaderremove();
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // refresh some elements
              refreshSplCimElements();
              // notify
              notify(
                "success",
                "bottom",
                "ML models were successfully reset and trained.",
                "5"
              );

              // Get Tabulator
              OutliersAnomalySplkCimHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_cim_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  object: getToken("tk_object"),
                  entity: "*",
                  cim_field: "*",
                },
                "outlier_config_splk_cim"
              );

              // Open moal
              $("#splk_cim_outliers_manage").modal();

              //
            }
          }
        });
      });

    //
    // ML models addition
    //

    // Open add modal

    $("#btn_outlier_config_splk_cim_add")
      .unbind()
      .click(function () {
        // free some populating searches
        setToken("show_splk_cim_outliers_add_model", "true");
        // Open modal
        closeModals();
        $("#add_model_splk_cim_outliers").modal();
      });

    // Back button

    $("#btn_modal_input_splk_cim_outliers_add_model_back")
      .unbind()
      .click(function () {
        // Open modal
        closeModals();
        $("#splk_cim_outliers_manage").modal();
      });

    // dropdowns

    var modal_input_splk_cim_outliers_add_model_entity = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_add_model_entity",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "entity",
        valueField: "entity",
        selectFirstChoice: true,
        value: "$form.input_splk_cim_outliers_add_model_entity$",
        managerid: "searchPopulateSplkCimOutliersAddCimEntities",
        el: $("#modal_input_splk_cim_outliers_add_model_entity"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_add_model_entity.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_entity
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_cim_field = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_add_model_cim_field",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "cim_field",
        valueField: "cim_field",
        selectFirstChoice: true,
        value: "$form.input_splk_cim_outliers_add_model_cim_field$",
        managerid: "searchPopulateSplkCimOutliersAddCimFields",
        el: $("#modal_input_splk_cim_outliers_add_model_cim_field"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_add_model_cim_field.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_cim_field
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_kpi_metric = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_add_model_kpi_metric",
        choices: [
          {
            label: "splk.cim.pct_coverage_compliant",
            value: "splk.cim.pct_coverage_compliant",
          },
          {
            label: "splk.cim.pct_coverage_unknown",
            value: "splk.cim.pct_coverage_unknown",
          },
          {
            label: "splk.cim.count_unknown",
            value: "splk.cim.count_unknown",
          },
          {
            label: "splk.cim.count_not_unknown",
            value: "splk.cim.count_not_unknown",
          },
          {
            label: "splk.cim.total_count",
            value: "splk.cim.total_count",
          },
          {
            label: "splk.cim.status",
            value: "splk.cim.status",
          },
        ],
        default: "splk.cim.pct_coverage_compliant",
        initialValue: "splk.cim.pct_coverage_compliant",
        searchWhenChanged: true,
        showClearButton: true,
        selectFirstChoice: true,
        width: 300,
        value: "$form.input_splk_cim_outliers_add_model_kpi_metric$",
        managerid: "searchOutlierDetectionPopulateSimulationAddModelCim",
        el: $("#modal_input_splk_cim_outliers_add_model_kpi_metric"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_add_model_kpi_metric.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_kpi_metric
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_kpi_span = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_add_model_kpi_span",
        choices: [
          {
            label: "5m",
            value: "5m",
          },
          {
            label: "10m",
            value: "10m",
          },
          {
            label: "15m",
            value: "15m",
          },
          {
            label: "30m",
            value: "30m",
          },
          {
            label: "1h",
            value: "1h",
          },
        ],
        searchWhenChanged: true,
        default: "10m",
        showClearButton: true,
        initialValue: "10m",
        selectFirstChoice: false,
        value: "$form.input_splk_cim_outliers_add_model_kpi_span$",
        el: $("#modal_input_splk_cim_outliers_add_model_kpi_span"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_add_model_kpi_span.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_kpi_span
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_calculation_method =
      new DropdownInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_calculation_method",
          choices: [
            {
              label: "stdev",
              value: "stdev",
            },
            {
              label: "avg",
              value: "avg",
            },
            {
              label: "perc95",
              value: "perc95",
            },
            {
              label: "latest",
              value: "latest",
            },
          ],
          searchWhenChanged: true,
          default: "avg",
          showClearButton: true,
          initialValue: "avg",
          selectFirstChoice: false,
          value: "$form.input_splk_cim_outliers_add_model_calculation_method$",
          el: $("#modal_input_splk_cim_outliers_add_model_calculation_method"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_calculation_method.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_calculation_method
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_density_lowerthreshold =
      new TextInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_density_lowerthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_cim_outliers_add_model_density_lowerthreshold$",
          el: $(
            "#modal_input_splk_cim_outliers_add_model_density_lowerthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_density_lowerthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_density_lowerthreshold
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_density_upperthreshold =
      new TextInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_density_upperthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_cim_outliers_add_model_density_upperthreshold$",
          el: $(
            "#modal_input_splk_cim_outliers_add_model_density_upperthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_density_upperthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_density_upperthreshold
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_alert_lower_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_alert_lower_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_cim_outliers_add_model_alert_lower_breached$",
          el: $(
            "#modal_input_splk_cim_outliers_add_model_alert_lower_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_alert_lower_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_alert_lower_breached
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_alert_upper_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_alert_upper_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_cim_outliers_add_model_alert_upper_breached$",
          el: $(
            "#modal_input_splk_cim_outliers_add_model_alert_upper_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_alert_upper_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_alert_upper_breached
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_period_calculation =
      new DropdownInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_period_calculation",
          choices: [
            {
              label: "-7d",
              value: "-7d",
            },
            {
              label: "-30d",
              value: "-30d",
            },
            {
              label: "-60d",
              value: "-60d",
            },
            {
              label: "-90d",
              value: "-90d",
            },
          ],
          searchWhenChanged: true,
          default: "-30d",
          showClearButton: true,
          initialValue: "-30d",
          selectFirstChoice: false,
          value: "$form.input_splk_cim_outliers_add_model_period_calculation$",
          el: $("#modal_input_splk_cim_outliers_add_model_period_calculation"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_period_calculation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_period_calculation
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_time_factor = new DropdownInput(
      {
        id: "modal_input_splk_cim_outliers_add_model_time_factor",
        choices: [
          {
            label: "%H",
            value: "%H",
          },
          {
            label: "%H%M",
            value: "%H%M",
          },
          {
            label: "%w%H",
            value: "%w%H",
          },
          {
            label: "%w%H%M",
            value: "%w%H%M",
          },
          {
            label: "No time factor",
            value: "none",
          },
        ],
        searchWhenChanged: true,
        default: "%H",
        showClearButton: true,
        initialValue: "%H",
        selectFirstChoice: false,
        value: "$form.input_splk_cim_outliers_add_model_time_factor$",
        el: $("#modal_input_splk_cim_outliers_add_model_time_factor"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_cim_outliers_add_model_time_factor.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_time_factor
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_auto_correct =
      new DropdownInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_auto_correct",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value: "$form.input_splk_cim_outliers_add_model_auto_correct$",
          el: $("#modal_input_splk_cim_outliers_add_model_auto_correct"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_auto_correct.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_auto_correct
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation$",
          el: $(
            "#modal_input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation
        );
      }
    );

    var modal_input_splk_cim_outliers_add_model_perc_min_upperbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_cim_outliers_add_model_perc_min_upperbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_cim_outliers_add_model_perc_min_upperbound_deviation$",
          el: $(
            "#modal_input_splk_cim_outliers_add_model_perc_min_upperbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_cim_outliers_add_model_perc_min_upperbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_cim_outliers_add_model_perc_min_upperbound_deviation
        );
      }
    );

    //
    // Rendering elements
    //

    var searchOutlierDetectionChartSimulationAddModelCim = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationAddModelCim",
        sample_ratio: 1,
        search:
          '| trackmesplkoutlierscimrender tenant_id="$tenant_id$" component="cim" object="$tk_object$" earliest="$OutliersSplkCimTimeAddModel.earliest$" latest="$OutliersSplkCimTimeAddModel.latest$" mode="simulation" entity="$input_splk_cim_outliers_add_model_entity$" cim_field="$input_splk_cim_outliers_add_model_cim_field$" model_json_def="$tk_splk_cim_simulation_add_model_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkCimTimeAddModel.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkCimTimeAddModel.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_cim_tracker$",
          depends: "$show_splk_cim_outlier$",
          depends: "$show_splk_cim_outliers_add_model$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationAddModelCim.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkCimNoResultsAddModel").css("display", "none");
        // show at start
        $("#elementOutlierLoaderAddModelCim").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelCim.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelCim").css("display", "none");
        // show no results
        $("#elementOutliersSplkCimNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutlierscimrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelCim.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelCim").css("display", "none");
        // show no results
        $("#elementOutliersSplkCimNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelCim.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderAddModelCim").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierAddModelSimulationCim").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationCim").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkCimTimeAddModel").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkCimNoResultsAddModel").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderAddModelCim").css("display", "none");
          // show chart and results link
          $("#elementOutlierAddModelSimulationCim").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationCim").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkCimTimeAddModel").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkCimNoResultsAddModel").css("display", "none");
        }
      }
    );

    var elementOutlierAddModelSimulationCim = new OutliersViz(
      {
        id: "elementOutlierAddModelSimulationCim",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationAddModelCim",
        el: $("#elementOutlierAddModelSimulationCim"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierAddModelSimulationCim = new ResultsLinkView({
      id: "resultsLinkelementOutlierAddModelSimulationCim",
      managerid: "searchOutlierDetectionChartSimulationAddModelCim",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierAddModelSimulationCim"),
    });

    resultsLinkelementOutlierAddModelSimulationCim
      .render()
      .$el.appendTo($("resultsLinkelementOutlierAddModelSimulationCim"));

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkCimTimeAddModel = new LinkListInput(
      {
        id: "inputOutliersSplkCimTimeAddModel",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkCimTimeAddModel$",
        el: $("#inputOutliersSplkCimTimeAddModel"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkCimTimeAddModel.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkCimTimeAddModel);
    });

    inputOutliersSplkCimTimeAddModel.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkCimTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      }
    });

    // Simulate

    $("#modal_input_splk_cim_outliers_add_simulate")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Retrieve all required values
        var model_json_value = {
          entity: getToken("input_splk_cim_outliers_add_model_entity"),
          cim_field: getToken("input_splk_cim_outliers_add_model_cim_field"),
          kpi_metric: getToken("input_splk_cim_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_cim_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_cim_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_cim_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_cim_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_cim_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_cim_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_cim_outliers_add_model_period_calculation"
          ),
          time_factor: getToken(
            "input_splk_cim_outliers_add_model_time_factor"
          ),
          auto_correct: getToken(
            "input_splk_cim_outliers_add_model_auto_correct"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_cim_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // Set token
        setToken("start_outliers_simulation_add_model_splk_cim", "true");
        setToken(
          "tk_splk_cim_simulation_add_model_model_def",
          JSON.stringify(model_json_value).replace(/\"/g, '\\"')
        );

        // Explicitly start the search
        searchOutlierDetectionChartSimulationAddModelCim.startSearch();
      });

    // Confirm addition

    $("#modal_input_splk_cim_outliers_add_confirm")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_cim_add_model";

        // Retrieve all required values
        var model_json_value = {
          entity: getToken("input_splk_cim_outliers_add_model_entity"),
          cim_field: getToken("input_splk_cim_outliers_add_model_cim_field"),
          kpi_metric: getToken("input_splk_cim_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_cim_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_cim_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_cim_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_cim_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_cim_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_cim_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_cim_outliers_add_model_period_calculation"
          ),
          time_factor: encodeURI(
            getToken("input_splk_cim_outliers_add_model_time_factor")
          ),
          auto_correct: getToken(
            "input_splk_cim_outliers_add_model_auto_correct"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_cim_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_cim_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          object: getToken("tk_object"),
          entity: getToken("input_splk_cim_outliers_add_model_entity"),
          cim_field: getToken("input_splk_cim_outliers_add_model_cim_field"),
          model_json: JSON.stringify(model_json_value),
          update_comment: "N/A",
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML model",
          "none",
          "splk-cim",
          "N/A"
        ).then(function (resultCall) {
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // refresh dropdowns
              refreshSplkCimMlModelsDropdows();
              // Call models training
              splk_cim_train_models();
              // Open modal
              $("#splk_cim_outliers_manage").modal();
              // notify
              notify(
                "success",
                "bottom",
                "ML model was successfully added and trained.",
                "5"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion add
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_cim_confirm_add")
      .unbind()
      .click(function () {
        // Retrieve start date
        var inputStart = document.getElementById(
          "splk_cim_period_exclusion_earliest"
        ).value;

        // Retrieve end date
        var inputEnd = document.getElementById(
          "splk_cim_period_exclusion_latest"
        ).value;

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_cim_confirm_add"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "cim",
          action: "add",
          object: getToken("tk_object"),
          cim_field: getToken("input_splk_cim_outliers_add_model_cim_field"),
          model_id: getToken(
            "tk_input_splk_cim_outliers_model_id_settings_dropdown"
          ),
          earliest: inputStart,
          latest: inputEnd,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML exclusion period",
          getToken("tk_input_splk_cim_outliers_model_id_settings_dropdown"),
          "cim",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully added.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkCimHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "cim",
                  object: getToken("tk_object"),
                  cim_field: getToken(
                    "input_splk_cim_outliers_add_model_cim_field"
                  ),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_cim_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_cim"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion delete
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_cim_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_periods_exclusions_splk_cim_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_cim_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "cim",
          action: "delete",
          object: getToken("tk_object"),
          cim_field: getToken("input_splk_cim_outliers_add_model_cim_field"),
          model_id: getToken(
            "tk_input_splk_cim_outliers_model_id_settings_dropdown"
          ),
          period_exclusion_id: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete ML exclusion period",
          tk_multi_table_array,
          "cim",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully deleted.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkCimHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "cim",
                  object: getToken("tk_object"),
                  cim_field: getToken(
                    "input_splk_cim_outliers_add_model_cim_field"
                  ),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_cim_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_cim"
              );
            }
          }
        });
      });

    // splk-dhm

    //
    // ML models delete
    //

    $("#btn_confirm_modal_outlier_config_splk_dhm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_dhm_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_delete_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_dhm_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
          object: getToken("tk_object"),
          models_list: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update allowlist index",
          tk_multi_table_array,
          "dhmdhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully deleted.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkDhmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dhm",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_dhm"
              );
              // refresh dropdowns
              searchPopulateSplkDhmOutliersModelsSettings.startSearch();
              searchPopulateSplkDhmOutliersModels.startSearch();
              // return modal
              $("#splk_dhm_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models update
    //

    $("#btn_confirm_modal_outlier_config_splk_dhm_confirm_save")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_config_splk_dhm_update"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_update_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_dhm_confirm_save"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
          object: getToken("tk_object"),
          outliers_rules: JSON.parse(tk_multi_table_array),
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "update ML models",
          JSON.parse(tk_multi_table_array),
          "splk-dhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML models successfully updated.",
                "5"
              );
              // refresh the tabulator
              OutliersAnomalySplkDhmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/outliers_get_rules",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dhm",
                  object: getToken("tk_object"),
                },
                "outlier_config_splk_dhm"
              );
              // refresh dropdowns
              searchPopulateSplkDhmOutliersModelsSettings.startSearch();
              searchPopulateSplkDhmOutliersModels.startSearch();
              // return modal
              $("#splk_dhm_outliers_manage").modal();
            }
          }
        });
      });

    //
    // ML models reset
    //

    $("#btn_confirm_modal_outlier_config_splk_dhm_confirm_reset")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_reset_models";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_config_splk_dhm_confirm_reset"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
          object: getToken("tk_object"),
          update_comment: comment,
        };

        // spinner
        cssloader(
          "Reset and training Machine Learning Models now, please wait..."
        );

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "reset ML models",
          "none",
          "splk-dhm",
          comment
        ).then(function (resultCall) {
          // remove spinner
          cssloaderremove();
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify("success", "bottom", "ML models successfully reset.", "5");
              // refresh dropdowns
              searchPopulateSplkDhmOutliersModelsSettings.startSearch();
              searchPopulateSplkDhmOutliersModels.startSearch();
              // Call models training
              splk_dhm_train_models();
            }
          }
        });
      });

    //
    // ML models addition
    //

    // Open add modal

    $("#btn_outlier_config_splk_dhm_add")
      .unbind()
      .click(function () {
        // free some populating searches
        setToken("show_splk_dhm_outliers_add_model", "true");
        // Open modal
        closeModals();
        $("#add_model_splk_dhm_outliers").modal();
      });

    // Back button

    $("#btn_modal_input_splk_dhm_outliers_add_model_back")
      .unbind()
      .click(function () {
        // Open modal
        closeModals();
        $("#splk_dhm_outliers_manage").modal();
      });

    // Populating searches
    var searchOutlierDetectionPopulateSimulationAddModelDhm = new SearchManager(
      {
        id: "searchOutlierDetectionPopulateSimulationAddModelDhm",
        sample_ratio: 1,
        search:
          '| makeresults | eval kpi_metrics="splk.feeds.avg_eventcount_5m|splk.feeds.latest_eventcount_5m|splk.feeds.perc95_eventcount_5m|splk.feeds.stdev_eventcount_5m|splk.feeds.avg_latency_5m|splk.feeds.latest_latency_5m|splk.feeds.perc95_latency_5m|splk.feeds.stdev_latency_5m" | makemv kpi_metrics delim="|" | fields kpi_metrics | fields - _time | mvexpand kpi_metrics',
        status_buckets: 0,
        earliest_time: "-5m",
        cancelOnUnload: true,
        latest_time: "now",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
          depends: "$show_splk_dhm_outlier$",
        },
        autostart: true,
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // dropdowns
    var modal_input_splk_dhm_outliers_add_model_kpi_metric = new DropdownInput(
      {
        id: "modal_input_splk_dhm_outliers_add_model_kpi_metric",
        searchWhenChanged: true,
        showClearButton: true,
        labelField: "kpi_metrics",
        selectFirstChoice: true,
        width: 300,
        valueField: "kpi_metrics",
        value: "$form.input_splk_dhm_outliers_add_model_kpi_metric$",
        managerid: "searchOutlierDetectionPopulateSimulationAddModelDhm",
        el: $("#modal_input_splk_dhm_outliers_add_model_kpi_metric"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dhm_outliers_add_model_kpi_metric.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_kpi_metric
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_kpi_span = new DropdownInput(
      {
        id: "modal_input_splk_dhm_outliers_add_model_kpi_span",
        choices: [
          {
            label: "5m",
            value: "5m",
          },
          {
            label: "10m",
            value: "10m",
          },
          {
            label: "15m",
            value: "15m",
          },
          {
            label: "30m",
            value: "30m",
          },
          {
            label: "1h",
            value: "1h",
          },
        ],
        searchWhenChanged: true,
        default: "10m",
        showClearButton: true,
        initialValue: "10m",
        selectFirstChoice: false,
        value: "$form.input_splk_dhm_outliers_add_model_kpi_span$",
        el: $("#modal_input_splk_dhm_outliers_add_model_kpi_span"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dhm_outliers_add_model_kpi_span.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_kpi_span
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_calculation_method =
      new DropdownInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_calculation_method",
          choices: [
            {
              label: "stdev",
              value: "stdev",
            },
            {
              label: "avg",
              value: "avg",
            },
            {
              label: "perc95",
              value: "perc95",
            },
            {
              label: "latest",
              value: "latest",
            },
          ],
          searchWhenChanged: true,
          default: "avg",
          showClearButton: true,
          initialValue: "avg",
          selectFirstChoice: false,
          value: "$form.input_splk_dhm_outliers_add_model_calculation_method$",
          el: $("#modal_input_splk_dhm_outliers_add_model_calculation_method"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_calculation_method.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_calculation_method
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_density_lowerthreshold =
      new TextInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_density_lowerthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_dhm_outliers_add_model_density_lowerthreshold$",
          el: $(
            "#modal_input_splk_dhm_outliers_add_model_density_lowerthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_density_lowerthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_density_lowerthreshold
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_density_upperthreshold =
      new TextInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_density_upperthreshold",
          searchWhenChanged: true,
          initialValue: "0.005",
          default: "0.005",
          value:
            "$form.input_splk_dhm_outliers_add_model_density_upperthreshold$",
          el: $(
            "#modal_input_splk_dhm_outliers_add_model_density_upperthreshold"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_density_upperthreshold.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_density_upperthreshold
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_alert_lower_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_alert_lower_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_dhm_outliers_add_model_alert_lower_breached$",
          el: $(
            "#modal_input_splk_dhm_outliers_add_model_alert_lower_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_alert_lower_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_alert_lower_breached
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_alert_upper_breached =
      new DropdownInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_alert_upper_breached",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value:
            "$form.input_splk_dhm_outliers_add_model_alert_upper_breached$",
          el: $(
            "#modal_input_splk_dhm_outliers_add_model_alert_upper_breached"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_alert_upper_breached.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_alert_upper_breached
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_period_calculation =
      new DropdownInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_period_calculation",
          choices: [
            {
              label: "-7d",
              value: "-7d",
            },
            {
              label: "-30d",
              value: "-30d",
            },
            {
              label: "-60d",
              value: "-60d",
            },
            {
              label: "-90d",
              value: "-90d",
            },
          ],
          searchWhenChanged: true,
          default: "-30d",
          showClearButton: true,
          initialValue: "-30d",
          selectFirstChoice: false,
          value: "$form.input_splk_dhm_outliers_add_model_period_calculation$",
          el: $("#modal_input_splk_dhm_outliers_add_model_period_calculation"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_period_calculation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_period_calculation
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_time_factor = new DropdownInput(
      {
        id: "modal_input_splk_dhm_outliers_add_model_time_factor",
        choices: [
          {
            label: "%H",
            value: "%H",
          },
          {
            label: "%H%M",
            value: "%H%M",
          },
          {
            label: "%w%H",
            value: "%w%H",
          },
          {
            label: "%w%H%M",
            value: "%w%H%M",
          },
          {
            label: "No time factor",
            value: "none",
          },
        ],
        searchWhenChanged: true,
        default: "%H",
        showClearButton: true,
        initialValue: "%H",
        selectFirstChoice: false,
        value: "$form.input_splk_dhm_outliers_add_model_time_factor$",
        el: $("#modal_input_splk_dhm_outliers_add_model_time_factor"),
      },
      {
        tokens: true,
      }
    ).render();

    modal_input_splk_dhm_outliers_add_model_time_factor.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_time_factor
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_auto_correct =
      new DropdownInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_auto_correct",
          choices: [
            {
              label: "True",
              value: "1",
            },
            {
              label: "False",
              value: "0",
            },
          ],
          searchWhenChanged: true,
          default: "1",
          showClearButton: true,
          initialValue: "1",
          selectFirstChoice: false,
          value: "$form.input_splk_dhm_outliers_add_model_auto_correct$",
          el: $("#modal_input_splk_dhm_outliers_add_model_auto_correct"),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_auto_correct.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_auto_correct
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation$",
          el: $(
            "#modal_input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation
        );
      }
    );

    var modal_input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation =
      new TextInput(
        {
          id: "modal_input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation",
          searchWhenChanged: true,
          initialValue: "5.0",
          default: "5.0",
          value:
            "$form.input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation$",
          el: $(
            "#modal_input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation"
          ),
        },
        {
          tokens: true,
        }
      ).render();

    modal_input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation.on(
      "change",
      function (newValue) {
        FormUtils.handleValueChange(
          modal_input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation
        );
      }
    );

    //
    // Rendering elements
    //

    var searchOutlierDetectionChartSimulationAddModelDhm = new SearchManager(
      {
        id: "searchOutlierDetectionChartSimulationAddModelDhm",
        sample_ratio: 1,
        search:
          '| trackmesplkoutliersrender tenant_id="$tenant_id$" component="dhm" object="$tk_object$" mode="simulation" model_json_def="$tk_splk_dhm_simulation_add_model_model_def$" | table _time, *, LowerBound, UpperBound',
        status_buckets: 0,
        earliest_time: "$OutliersSplkDhmTimeAddModel.earliest$",
        cancelOnUnload: true,
        latest_time: "$OutliersSplkDhmTimeAddModel.latest$",
        app: utils.getCurrentApp(),
        auto_cancel: 90,
        autostart: false,
        tokenDependencies: {
          depends: "$show_splk_dhm_tracker$",
          depends: "$show_splk_dhm_outlier$",
          depends: "$show_splk_dhm_outliers_add_model$",
        },
        preview: true,
        runWhenTimeIsUndefined: false,
      },
      {
        tokens: true,
      }
    );

    // Handle its life cycle

    searchOutlierDetectionChartSimulationAddModelDhm.on(
      "search:start",
      function (properties) {
        // hide at start
        $("#elementOutliersSplkDhmNoResultsAddModel").css("display", "none");
        // show at start
        $("#elementOutlierLoaderAddModelDhm").css("display", "inherit");
        notify(
          "info",
          "bottom",
          "ML model simulation is being processed, depending on your settings its processing can take some time, please wait",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelDhm.on(
      "search:failed",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelDhm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDhmNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelDhm.on(
      "search:error",
      function (properties) {
        // hide loader
        $("#elementOutlierLoaderAddModelDhm").css("display", "none");
        // show no results
        $("#elementOutliersSplkDhmNoResultsAddModel").css("display", "inherit");
        // notify
        notify(
          "error",
          "bottom",
          "ML model simulation has failed! Review trackmesplkoutliersrender logs: index=_internal sourcetype=trackme:custom_commands:trackmesplkoutliersrender",
          "60"
        );
      }
    );

    searchOutlierDetectionChartSimulationAddModelDhm.on(
      "search:done",
      function (properties) {
        // notify
        notify(
          "success",
          "bottom",
          "ML model simulation finished successfully",
          "5"
        );
        var eventCount = properties.content.eventCount;
        if (eventCount == 0) {
          // show no result message if we have no events returned
          // hide loader
          $("#elementOutlierLoaderAddModelDhm").css("display", "none");
          // try to show chart and results link
          $("#elementOutlierAddModelSimulationDhm").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationDhm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDhmTimeAddModel").css("display", "inherit");
          // show no results
          $("#elementOutliersSplkDhmNoResultsAddModel").css(
            "display",
            "inherit"
          );
        } else {
          // hide loader
          $("#elementOutlierLoaderAddModelDhm").css("display", "none");
          // show chart and results link
          $("#elementOutlierAddModelSimulationDhm").css("display", "inherit");
          $("#resultsLinkelementOutlierAddModelSimulationDhm").css(
            "display",
            "inherit"
          );
          $("#inputOutliersSplkDhmTimeAddModel").css("display", "inherit");
          // hide no results
          $("#elementOutliersSplkDhmNoResultsAddModel").css("display", "none");
        }
      }
    );

    var elementOutlierAddModelSimulationDhm = new OutliersViz(
      {
        id: "elementOutlierAddModelSimulationDhm",
        type: "Splunk_ML_Toolkit.OutliersViz",
        resizable: true,
        "Splunk_ML_Toolkit.OutliersViz.showOutlierCount": "true",
        drilldown: "none",
        "trellis.enabled": "0",
        "trellis.scales.shared": "1",
        "trellis.size": "medium",
        height: "390",
        managerid: "searchOutlierDetectionChartSimulationAddModelDhm",
        el: $("#elementOutlierAddModelSimulationDhm"),
      },
      {
        tokens: true,
      }
    ).render();

    var resultsLinkelementOutlierAddModelSimulationDhm = new ResultsLinkView({
      id: "resultsLinkelementOutlierAddModelSimulationDhm",
      managerid: "searchOutlierDetectionChartSimulationAddModelDhm",
      "link.exportResults.visible": false,
      el: $("#resultsLinkelementOutlierAddModelSimulationDhm"),
    });

    resultsLinkelementOutlierAddModelSimulationDhm
      .render()
      .$el.appendTo($("resultsLinkelementOutlierAddModelSimulationDhm"));

    // time selector for rendering purposes
    // input link selection for modal window
    var inputOutliersSplkDhmTimeAddModel = new LinkListInput(
      {
        id: "inputOutliersSplkDhmTimeAddModel",
        choices: [
          {
            value: "30m",
            label: "30m",
          },
          {
            value: "60m",
            label: "60m",
          },
          {
            value: "2h",
            label: "2h",
          },
          {
            value: "4h",
            label: "4h",
          },
          {
            value: "8h",
            label: "8h",
          },
          {
            value: "12h",
            label: "12h",
          },
          {
            value: "24h",
            label: "24h",
          },
          {
            value: "48h",
            label: "48h",
          },
          {
            value: "7d",
            label: "7d",
          },
          {
            value: "15d",
            label: "15d",
          },
          {
            value: "30d",
            label: "30d",
          },
          {
            value: "60d",
            label: "60d",
          },
          {
            value: "90d",
            label: "90d",
          },
        ],
        default: "24h",
        searchWhenChanged: true,
        selectFirstChoice: false,
        initialValue: "24h",
        value: "$form.OutliersSplkDhmTimeAddModel$",
        el: $("#inputOutliersSplkDhmTimeAddModel"),
      },
      {
        tokens: true,
      }
    ).render();

    inputOutliersSplkDhmTimeAddModel.on("change", function (newValue) {
      FormUtils.handleValueChange(inputOutliersSplkDhmTimeAddModel);
    });

    inputOutliersSplkDhmTimeAddModel.on("valueChange", function (e) {
      if (e.value === "30m") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-30m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60m") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-60m",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "2h") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-2h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "4h") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-4h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "8h") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-8h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "12h") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-12h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "24h") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-24h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "48h") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-48h",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "7d") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-7d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "15d") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-15d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "30d") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-30d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "60d") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-60d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      } else if (e.value === "90d") {
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.earliest",
          "-90d",
          {},
          e.data
        );
        EventHandler.setToken(
          "OutliersSplkDhmTimeAddModel.latest",
          "now",
          {},
          e.data
        );
      }
    });

    // Simulate

    $("#modal_input_splk_dhm_outliers_add_simulate")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");
        var tk_object = getToken("tk_object");

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_dhm_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_dhm_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_dhm_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_dhm_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_dhm_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_dhm_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_dhm_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_dhm_outliers_add_model_period_calculation"
          ),
          time_factor: getToken(
            "input_splk_dhm_outliers_add_model_time_factor"
          ),
          auto_correct: getToken(
            "input_splk_dhm_outliers_add_model_auto_correct"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // Set token
        setToken("start_outliers_simulation_add_model_splk_dhm", "true");
        setToken(
          "tk_splk_dhm_simulation_add_model_model_def",
          JSON.stringify(model_json_value).replace(/\"/g, '\\"')
        );

        // Explicitly start the search
        searchOutlierDetectionChartSimulationAddModelDhm.startSearch();

        // notify
        notify(
          "info",
          "bottom",
          "Starting ML model simulation, please wait...",
          "5"
        );
      });

    // Confirm addition

    $("#modal_input_splk_dhm_outliers_add_confirm")
      .unbind()
      .click(function () {
        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_add_model";

        // Retrieve all required values
        var model_json_value = {
          kpi_metric: getToken("input_splk_dhm_outliers_add_model_kpi_metric"),
          kpi_span: getToken("input_splk_dhm_outliers_add_model_kpi_span"),
          method_calculation: getToken(
            "input_splk_dhm_outliers_add_model_calculation_method"
          ),
          density_lowerthreshold: getToken(
            "input_splk_dhm_outliers_add_model_density_lowerthreshold"
          ),
          density_upperthreshold: getToken(
            "input_splk_dhm_outliers_add_model_density_upperthreshold"
          ),
          alert_lower_breached: getToken(
            "input_splk_dhm_outliers_add_model_alert_lower_breached"
          ),
          alert_upper_breached: getToken(
            "input_splk_dhm_outliers_add_model_alert_upper_breached"
          ),
          period_calculation: getToken(
            "input_splk_dhm_outliers_add_model_period_calculation"
          ),
          time_factor: encodeURI(
            getToken("input_splk_dhm_outliers_add_model_time_factor")
          ),
          auto_correct: getToken(
            "input_splk_dhm_outliers_add_model_auto_correct"
          ),
          perc_min_lowerbound_deviation: getToken(
            "input_splk_dhm_outliers_add_model_perc_min_lowerbound_deviation"
          ),
          perc_min_upperbound_deviation: getToken(
            "input_splk_dhm_outliers_add_model_perc_min_upperbound_deviation"
          ),
        };

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
          object: getToken("tk_object"),
          model_json: JSON.stringify(model_json_value),
          update_comment: "N/A",
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML model",
          "none",
          "splk-dhm",
          "N/A"
        ).then(function (resultCall) {
          // check results
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // refresh dropdowns
              searchPopulateSplkDhmOutliersModelsSettings.startSearch();
              searchPopulateSplkDhmOutliersModels.startSearch();
              // Call models training
              splk_dhm_train_models();
              // Open modal
              $("#splk_dhm_outliers_manage").modal();
              // notify
              notify(
                "success",
                "bottom",
                "ML model was successfully added and trained.",
                "5"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion add
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_dhm_confirm_add")
      .unbind()
      .click(function () {
        // Retrieve start date
        var inputStart = document.getElementById(
          "splk_dhm_period_exclusion_earliest"
        ).value;

        // Retrieve end date
        var inputEnd = document.getElementById(
          "splk_dhm_period_exclusion_latest"
        ).value;

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_dhm_confirm_add"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
          action: "add",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_dhm_outliers_model_id_settings_dropdown"
          ),
          earliest: inputStart,
          latest: inputEnd,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "add ML exclusion period",
          getToken("tk_input_splk_dhm_outliers_model_id_settings_dropdown"),
          "dhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully added.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkDhmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dhm",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_dhm_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_dhm"
              );
            }
          }
        });
      });

    //
    // ML model period exclusion delete
    //

    $("#btn_confirm_modal_outlier_periods_exclusions_splk_dhm_confirm_delete")
      .unbind()
      .click(function () {
        // Get the arrays of keys
        var tk_multi_table_array = getToken(
          "tk_outlier_periods_exclusions_splk_dhm_delete"
        );

        // Get tenant id
        var tk_tenant_id = getToken("tenant_id");

        // Set the endpoint URL
        var endpointUrl =
          "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion";

        // retrieve comment, if any
        comment = getComment(
          "comment_modal_outlier_periods_exclusions_splk_dhm_confirm_delete"
        );

        // set data for the POST call
        var record = {
          tenant_id: getToken("tenant_id"),
          component: "dhm",
          action: "delete",
          object: getToken("tk_object"),
          model_id: getToken(
            "tk_input_splk_dhm_outliers_model_id_settings_dropdown"
          ),
          period_exclusion_id: tk_multi_table_array,
          update_comment: comment,
        };

        // Run the ajax promise
        asyncCallApi(
          endpointUrl,
          "POST",
          record,
          "delete ML exclusion period",
          tk_multi_table_array,
          "dhm",
          comment
        ).then(function (resultCall) {
          if (typeof resultCall != "undefined") {
            failures_count = resultCall.failures_count;
            if (failures_count == 0) {
              unsetToken("tk_multi_table_array");
              // notify
              notify(
                "success",
                "bottom",
                "ML model period exclusion successfully deleted.",
                "5"
              );
              // refresh the tabulator
              // spinner
              cssloader("Requested action is in progress, please wait...");
              OutliersAnomalyPeriodsExclusionSplkDhmHandlerTable(
                "/en-US/splunkd/__raw/services/trackme/v2/splk_outliers_engine/write/outliers_manage_model_period_exclusion",
                "POST",
                {
                  tenant_id: getToken("tenant_id"),
                  component: "dhm",
                  object: getToken("tk_object"),
                  action: "show",
                  model_id: getToken(
                    "tk_input_splk_dhm_outliers_model_id_settings_dropdown"
                  ),
                },
                "outlier_periods_exclusions_splk_dhm"
              );
            }
          }
        });
      });

    //
    // END
    //
  });
});
