const { Callbacks } = require("jquery");

require([
  "jquery",
  "underscore",
  "splunkjs/mvc",
  "splunkjs/mvc/searchcontrolsview",
  "splunkjs/mvc/searchmanager",
  "splunkjs/mvc/postprocessmanager",
  "splunkjs/mvc/savedsearchmanager",
  "splunkjs/mvc/dropdownview",
  "splunkjs/mvc/multidropdownview",
  "splunkjs/mvc/tableview",
  "splunkjs/mvc/textinputview",
  "splunkjs/mvc/singleview",
  "splunkjs/mvc/chartview",
  "splunkjs/mvc/resultslinkview",
  "splunkjs/mvc/simplexml/searcheventhandler",
  "splunkjs/mvc/visualizationregistry",
  "/static/app/trackme/tabulator/js/tabulator.js",
  "/static/app/trackme/momentjs/moment.js",
  "splunkjs/mvc/simplexml/ready!",
  "splunkjs/mvc/simpleform/input/multiselect",
], function (
  $,
  _,
  mvc,
  SearchControlsView,
  SearchManager,
  PostProcessManager,
  SavedSearchManager,
  DropdownView,
  MultiDropdownView,
  TableView,
  TextInputView,
  SingleView,
  ChartView,
  ResultsLinkView,
  SearchEventHandler,
  VisualizationRegistry,
  TabulatorFull,
  moment
) {
  //
  // ajax promise for API calls
  //

  async function asyncAjax(ajaxurl, ajaxType, ajaxdata) {
    var resultCall;
    try {
      resultCall = await $.ajax({
        url: ajaxurl,
        type: ajaxType,
        data: JSON.stringify(ajaxdata),
      });
      return resultCall;
    } catch (error) {
      // notify error
      $("#cssloader").remove();
      $("#badges-tenant-count-loader").remove();

      // if the error contains "insufficient permission to access this resource" as a full sentence
      if (
        error.responseText.includes(
          "insufficient permission to access this resource"
        )
      ) {
        message =
          "Insufficient permissions, to access and use TrackMe, you need to be granted a TrackMe capability which is part of the TrackMe roles. Please contact your Splunk administrator and refer to: https://docs.trackme-solutions.com/latest/admin_guide_rbac.html";
      } else {
        message =
          "ERROR: hum, something went quite wrong while checking for TrackMe dependencies: " +
          JSON.stringify(error);
      }
      $("#modal_generic_error").find(".modal-error-message p").text(message);
      $("#modal_generic_error").modal();
    }
  }

  //
  // Verify TrackMe requirements
  //

  var doAsync = asyncAjax(
    "/en-US/splunkd/__raw/services/trackme/v2/configuration/trackme_check_dependencies",
    "GET"
  ).then(function (resultCall) {
    var depsMet = resultCall["action"];
    var trackme_conf = resultCall["trackme_conf"];

    //
    // if dependencies are not met, avoid executing the page and show a message
    //

    if (depsMet == "failure") {
      $("#cssloader").remove();
      $("#badges-tenant-count-loader").remove();
      message = JSON.stringify(resultCall, null, 2);
      $("#modal_dep_error").find(".modal-error-message").text(message);
      $("#modal_dep_error").modal();
    }
    //
    // If dependencies are met, process
    //
    else if (depsMet == "success") {
      //
      // All dependencies are met, start execution
      //

      var defaultTokenModel = mvc.Components.getInstance("default", {
        create: true,
      });
      var submittedTokenModel = mvc.Components.getInstance("submitted", {
        create: true,
      });

      function setToken(name, value) {
        defaultTokenModel.set(name, value);
        submittedTokenModel.set(name, value);
      }

      function getToken(name) {
        var ret = null;
        if (defaultTokenModel.get(name) != undefined) {
          ret = defaultTokenModel.get(name);
        } else if (submittedTokenModel.get(name) != undefined) {
          ret = submittedTokenModel.get(name);
        }
        return ret;
      }

      function unsetToken(name) {
        defaultTokenModel.unset(name);
        submittedTokenModel.unset(name);
      }

      var doAsync = asyncAjax(
        "/en-US/splunkd/__raw/services/trackme/v2/vtenants/trackmeload",
        "POST",
        { mode: "full" }
      ).then(function (resultCall) {
        // Privileges level
        userLevel = resultCall["user_level"];
        setToken("userLevel", userLevel);
        // hide the tenant creation access button
        if (userLevel === "user" || userLevel === "power") {
          $("#btn_start_create_tenant").prop("disabled", true);
          $("#btn_start_create_tenant").css("display", "none");
          $("#btn_start_create_tenant_replica").prop("disabled", true);
          $("#btn_start_create_tenant_replica").css("display", "none");
        }

        // Tenants count
        var tenantsCount = resultCall["vtenants_count"];

        // Tenants JSON
        var tenantsJson = resultCall["tenants_json"];

        // Position
        var userPositionPrefs = resultCall["position_prefs"];

        // theme preferences
        var icons_state_mode = resultCall["icons_state_mode"];
        var show_tenants_mgmt_header = resultCall["show_tenants_mgmt_header"];
        var flex_width_default = resultCall["flex_width_default"];
        var flex_show_desc = resultCall["flex_show_desc"];
        var flex_show_summary = resultCall["flex_show_summary"];
        var colorTheme = resultCall["colorTheme"];
        var colorThemeAlert = resultCall["colorThemeAlert"];
        var dynTheme = resultCall["dynTheme"];
        var dynThemeCondition = resultCall["dynThemeCondition"];

        var userPrefs = {
          icons_state_mode: icons_state_mode,
          show_tenants_mgmt_header: show_tenants_mgmt_header,
          flex_width_default: flex_width_default,
          flex_show_desc: flex_show_desc,
          flex_show_summary: flex_show_summary,
          colorTheme: colorTheme,
          colorThemeAlert: colorThemeAlert,
          dynTheme: dynTheme,
          dynThemeCondition: dynThemeCondition,
        };

        // close all opened modals
        function closeModals() {
          $(".modal.in").modal("hide");
        }

        //
        // Notify
        //

        function notify(varCss, varPosition, varHtml, vardelay) {
          require([
            "jquery",
            "/static/app/trackme/notifybar/jquery.notifyBar.js",
          ], function ($) {
            //code here
            jQuery(function () {
              jQuery.notifyBar({
                cssClass: varCss,
                position: varPosition,
                html: varHtml,
                delay: vardelay,
              });
            });
          });
        }

        //
        // setStatusIcon
        //

        function setStatusIcon(status, icons_state_mode) {
          if (status == "operational") {
            if (icons_state_mode == "bootstrap") {
              return "<i class='bi bi-check-circle-fill icon-state-green'></i> operational";
            } else if (icons_state_mode == "emoji") {
              return "🟢 operational";
            }
          } else if (status == "degraded") {
            if (icons_state_mode == "bootstrap") {
              return "<i class='bi bi-exclamation-triangle-fill icon-state-red'></i> degraded";
            } else if (icons_state_mode == "emoji") {
              return "❌ degraded";
            }
          } else if (status == "disabled") {
            if (icons_state_mode == "bootstrap") {
              return "<i class='bi bi-exclamation-triangle-fill icon-state-red'></i> disabled";
            } else if (icons_state_mode == "emoji") {
              return "❌ disabled";
            }
          }
        }

        //
        // tenant overview
        //

        var searchTenantTrackerDsm = new SearchManager(
          {
            id: "searchTenantTrackerDsm",
            search:
              '| savedsearch "trackme_dsm_tracker_tenant_$clickedTenantId$"',
            earliest_time: "-4h",
            latest_time: "+4h",
            autostart: false,
          },
          { tokens: true }
        );

        var searchTenantOverviewDsm = new SearchManager(
          {
            id: "searchTenantOverviewDsm",
            search: "| `tenant_get_info($clickedTenantId$, dsm)`",
            earliest_time: "-5m",
            latest_time: "now",
            autostart: false,
          },
          { tokens: true }
        );

        new SearchEventHandler({
          managerid: "searchTenantOverviewDsm",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntities",
                  value: "$result.count$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesStatusGreen",
                  value: "$result.count_green$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesStatusRed",
                  value: "$result.count_red$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesStatusOthers",
                  value: "$result.count_others$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesPriorityLow",
                  value: "$result.count_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesPriorityMedium",
                  value: "$result.count_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesPriorityHigh",
                  value: "$result.count_high_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesRedPriorityLow",
                  value: "$result.count_red_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesRedPriorityMedium",
                  value: "$result.count_red_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDsmEntitiesRedPriorityHigh",
                  value: "$result.count_red_high_priority$",
                },
              ],
            },
          ],
        });

        var searchTenantOverviewCim = new SearchManager(
          {
            id: "searchTenantOverviewCim",
            search: "| `tenant_get_info($clickedTenantId$, cim)`",
            earliest_time: "-5m",
            latest_time: "now",
            autostart: false,
          },
          { tokens: true }
        );

        new SearchEventHandler({
          managerid: "searchTenantOverviewCim",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "clickedTenantIdCimEntities",
                  value: "$result.count$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesStatusGreen",
                  value: "$result.count_green$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesStatusRed",
                  value: "$result.count_red$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesStatusOthers",
                  value: "$result.count_others$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesPriorityLow",
                  value: "$result.count_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesPriorityMedium",
                  value: "$result.count_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesPriorityHigh",
                  value: "$result.count_high_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesRedPriorityLow",
                  value: "$result.count_red_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesRedPriorityMedium",
                  value: "$result.count_red_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdCimEntitiesRedPriorityHigh",
                  value: "$result.count_red_high_priority$",
                },
              ],
            },
          ],
        });

        var searchTenantOverviewFlx = new SearchManager(
          {
            id: "searchTenantOverviewFlx",
            search: "| `tenant_get_info($clickedTenantId$, flx)`",
            earliest_time: "-5m",
            latest_time: "now",
            autostart: false,
          },
          { tokens: true }
        );

        new SearchEventHandler({
          managerid: "searchTenantOverviewFlx",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntities",
                  value: "$result.count$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesStatusGreen",
                  value: "$result.count_green$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesStatusRed",
                  value: "$result.count_red$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesStatusOthers",
                  value: "$result.count_others$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesPriorityLow",
                  value: "$result.count_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesPriorityMedium",
                  value: "$result.count_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesPriorityHigh",
                  value: "$result.count_high_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesRedPriorityLow",
                  value: "$result.count_red_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesRedPriorityMedium",
                  value: "$result.count_red_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdFlxEntitiesRedPriorityHigh",
                  value: "$result.count_red_high_priority$",
                },
              ],
            },
          ],
        });

        var searchTenantOverviewWlk = new SearchManager(
          {
            id: "searchTenantOverviewWlk",
            search: "| `tenant_get_info_wlk($clickedTenantId$, wlk)`",
            earliest_time: "-5m",
            latest_time: "now",
            autostart: false,
          },
          { tokens: true }
        );

        new SearchEventHandler({
          managerid: "searchTenantOverviewWlk",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntities",
                  value: "$result.count$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesStatusGreen",
                  value: "$result.count_green$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesStatusRed",
                  value: "$result.count_red$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesStatusOthers",
                  value: "$result.count_others$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesPriorityLow",
                  value: "$result.count_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesPriorityMedium",
                  value: "$result.count_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesPriorityHigh",
                  value: "$result.count_high_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesRedPriorityLow",
                  value: "$result.count_red_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesRedPriorityMedium",
                  value: "$result.count_red_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdWlkEntitiesRedPriorityHigh",
                  value: "$result.count_red_high_priority$",
                },
              ],
            },
          ],
        });

        var searchTenantOverviewDhm = new SearchManager(
          {
            id: "searchTenantOverviewDhm",
            search: "| `tenant_get_info($clickedTenantId$, dhm)`",
            earliest_time: "-5m",
            latest_time: "now",
            autostart: false,
          },
          { tokens: true }
        );

        new SearchEventHandler({
          managerid: "searchTenantOverviewDhm",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntities",
                  value: "$result.count$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesStatusGreen",
                  value: "$result.count_green$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesStatusRed",
                  value: "$result.count_red$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesStatusOthers",
                  value: "$result.count_others$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesPriorityLow",
                  value: "$result.count_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesPriorityMedium",
                  value: "$result.count_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesPriorityHigh",
                  value: "$result.count_high_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesRedPriorityLow",
                  value: "$result.count_red_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesRedPriorityMedium",
                  value: "$result.count_red_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdDhmEntitiesRedPriorityHigh",
                  value: "$result.count_red_high_priority$",
                },
              ],
            },
          ],
        });

        var searchTenantOverviewMhm = new SearchManager(
          {
            id: "searchTenantOverviewMhm",
            search: "| `tenant_get_info($clickedTenantId$, mhm)`",
            earliest_time: "-5m",
            latest_time: "now",
            autostart: false,
          },
          { tokens: true }
        );

        new SearchEventHandler({
          managerid: "searchTenantOverviewMhm",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntities",
                  value: "$result.count$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesStatusGreen",
                  value: "$result.count_green$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesStatusRed",
                  value: "$result.count_red$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesStatusOthers",
                  value: "$result.count_others$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesPriorityLow",
                  value: "$result.count_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesPriorityMedium",
                  value: "$result.count_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesPriorityHigh",
                  value: "$result.count_high_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesRedPriorityLow",
                  value: "$result.count_red_low_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesRedPriorityMedium",
                  value: "$result.count_red_medium_priority$",
                },
                {
                  type: "set",
                  token: "clickedTenantIdMhmEntitiesRedPriorityHigh",
                  value: "$result.count_red_high_priority$",
                },
              ],
            },
          ],
        });

        //
        // SEARCHES
        //

        // to avoid being tagged with all time searches (such as WLM rules), all searches should have a time range even if not required in theory

        var searchListComponents = new SearchManager({
          id: "searchListComponents",
          search:
            '| makeresults | eval components="splk-dsm|splk-dhm|splk-mhm|splk-cim|splk-flx|splk-wlk" | fields - _time | makemv components delim="|" | mvexpand components',
          earliest_time: "-5m",
          latest_time: "now",
          autostart: false,
        });

        var searchListRoles = new SearchManager({
          id: "searchListRoles",
          search:
            "| rest splunk_server=local count=0 /services/authorization/roles | table title | sort 0 title",
          earliest_time: "-5m",
          latest_time: "now",
          autostart: false,
        });

        var searchListUsers = new SearchManager({
          id: "searchListUsers",
          search:
            '| trackme mode=get url="/services/trackme/v2/configuration/list_local_users" | spath | rename "users{}" as title | mvexpand title | table title | sort 0 title',
          earliest_time: "-5m",
          latest_time: "now",
          autostart: false,
        });

        var searchListIdxSummary = new SearchManager({
          id: "searchListIdxSummary",
          search:
            '| rest splunk_server=local count=0 /services/trackme_settings/index_settings | fields trackme_summary_idx | rename trackme_summary_idx as title | append [ | rest splunk_server=local "/services/data/indexes" count=0 | table title ] | search [ | rest splunk_server=local /services/trackme_settings/index_settings count=0 | table trackme_idx_search_filter | rename trackme_idx_search_filter as title | return title ] | dedup title | sort 0 title',
          earliest_time: "-5m",
          latest_time: "now",
          autostart: false,
        });

        new SearchEventHandler({
          managerid: "searchListIdxSummary",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "tk_default_tenant_idx_summary",
                  value: "$result.title$",
                },
              ],
            },
          ],
        });

        var searchListIdxAudit = new SearchManager({
          id: "searchListIdxAudit",
          search:
            '| rest splunk_server=local count=0 /services/trackme_settings/index_settings | fields trackme_audit_idx | rename trackme_audit_idx as title | append [ | rest splunk_server=local "/services/data/indexes" count=0 | table title ] | search [ | rest splunk_server=local /services/trackme_settings/index_settings count=0 | table trackme_idx_search_filter | rename trackme_idx_search_filter as title | return title ] | dedup title | sort 0 title',
          earliest_time: "-5m",
          latest_time: "now",
          autostart: false,
        });

        new SearchEventHandler({
          managerid: "searchListIdxAudit",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "tk_default_tenant_idx_audit",
                  value: "$result.title$",
                },
              ],
            },
          ],
        });

        var searchListIdxNotable = new SearchManager({
          id: "searchListIdxNotable",
          search:
            '| rest splunk_server=local count=0 /services/trackme_settings/index_settings | fields trackme_notable_idx | rename trackme_notable_idx as title | append [ | rest splunk_server=local "/services/data/indexes" count=0 | table title ] | search [ | rest splunk_server=local /services/trackme_settings/index_settings count=0 | table trackme_idx_search_filter | rename trackme_idx_search_filter as title | return title ] | dedup title | sort 0 title',
          earliest_time: "-5m",
          latest_time: "now",
          autostart: false,
        });

        new SearchEventHandler({
          managerid: "searchListIdxNotable",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "tk_default_tenant_idx_notable",
                  value: "$result.title$",
                },
              ],
            },
          ],
        });

        var searchListIdxMetric = new SearchManager({
          id: "searchListIdxMetric",
          search:
            '| rest splunk_server=local count=0 /services/trackme_settings/index_settings | fields trackme_metric_idx | rename trackme_metric_idx as title | append [ | rest splunk_server=local "/services/data/indexes?datatype=metric" count=0 | table title ] | search [ | rest splunk_server=local /services/trackme_settings/index_settings count=0 | table trackme_idx_search_filter | rename trackme_idx_search_filter as title | return title ] | dedup title | sort 0 title',
          earliest_time: "-5m",
          latest_time: "now",
          autostart: false,
        });

        new SearchEventHandler({
          managerid: "searchListIdxMetric",
          event: "progress",
          conditions: [
            {
              attr: "any",
              value: "*",
              actions: [
                {
                  type: "set",
                  token: "tk_default_tenant_idx_metric",
                  value: "$result.title$",
                },
              ],
            },
          ],
        });

        // Scheduler status

        var searchSchedulerStatus = new SavedSearchManager({
          id: "searchSchedulerStatus",
          searchname: "trackme_scheduler_completness",
          cache: false,
          preview: true,
          "dispatch.earliest_time": "-15m",
          "dispatch.latest_time": "now",
          app: "trackme",
          refreshType: "delay",
          refresh: "5m",
        });

        // set the label visibility
        searchSchedulerStatus.on("change", function (newValue) {
          $("#vizSchedulerStatusLabel").css("display", "inherit");
        });

        // Ops status

        var searchOpsStatus = new SavedSearchManager({
          id: "searchOpsStatus",
          searchname: "trackme_ops_status",
          cache: false,
          preview: true,
          "dispatch.earliest_time": "-5m",
          "dispatch.latest_time": "now",
          app: "trackme",
          refreshType: "delay",
          refresh: "5m",
        });

        // set the label visibility
        searchOpsStatus.on("change", function (newValue) {
          $("#vizOpsStatusLabel").css("display", "inherit");
        });

        // populate Splunk accounts
        // searchPopulateConfigurationAccounts

        var searchPopulateConfigurationAccounts = new SearchManager(
          {
            id: "searchPopulateConfigurationAccounts",
            earliest_time: "-5m",
            cancelOnUnload: true,
            latest_time: "+5m",
            search: "| `trackme_list_accounts`",
            auto_cancel: 90,
            autostart: false,
            preview: true,
            tokenDependencies: {
              //depends: "$show_configuration_account_dsm$",
            },
            runWhenTimeIsUndefined: false,
          },
          {
            tokens: true,
          }
        );

        function get_entities_summary(
          infoMsg,
          context,
          tenantId,
          status,
          priority
        ) {
          // Create the service
          var service = mvc.createService({
            owner: "nobody",
          });

          // Define the query
          var searchQuery =
            "| `get_tenant_entities_summary(" +
            tenantId +
            ", " +
            context +
            ", " +
            status +
            ", " +
            priority +
            ")`";

          // Set the search parameters--specify a time range
          var searchParams = {
            earliest_time: "-5m",
            latest_time: "now",
          };

          // Run a blocking search and get back a job
          service.search(searchQuery, searchParams, function (err, job) {
            // Shall the search fail before we can get properties
            if (job == null) {
              let errorStr = "Unknown Error!";
              if (
                err &&
                err.data &&
                err.data.messages &&
                err.data.messages[0]["text"]
              ) {
                errorStr = err.data.messages[0]["text"];
              } else if (err && err.data && err.data.messages) {
                errorStr = JSON.stringify(err.data.messages);
              }
              // notify error
              message =
                "ERROR: hum, something went quite wrong there! Splunk returned an error while while attempting to run the search: " +
                errorStr;
              notify("error", "bottom", message, "30");
              console.error("Review the Splunk search query: " + searchQuery);
            } else {
              // Poll the status of the search job
              job.track(
                {
                  period: 200,
                },
                {
                  done: function (job) {
                    // Get the results
                    job.results({}, function (err, results, job) {
                      var fields = results.fields;
                      var rows = results.rows;
                      var jobResult;
                      for (var i = 0; i < rows.length; i++) {
                        var values = rows[i];
                        for (var j = 0; j < values.length; j++) {
                          var field = fields[j];
                          var value = values[j];
                          // get the _raw
                          if (field === "_raw") {
                            jobResult = value;
                          }
                        }
                        // notify
                        message =
                          "ℹ️ 10 entities sample " +
                          infoMsg +
                          ": " +
                          JSON.stringify(jobResult, null, 2);
                        notify("info", "bottom", message, "30");
                      }

                      // no results were found or we have no _raw
                      if (
                        jobResult == "" ||
                        typeof jobResult === "undefined" ||
                        jobResult == "null"
                      ) {
                        message =
                          "ERROR: hum, something went quite wrong there! The search was sucessfully executed but we got no results! ";
                        notify("error", "bottom", message, "30");
                      }
                    });
                  },
                  failed: function (properties) {
                    let errorStr = "Unknown Error!";
                    if (
                      properties &&
                      properties._properties &&
                      properties._properties.messages &&
                      properties._properties.messages[0]["text"]
                    ) {
                      errorStr = properties._properties.messages[0]["text"];
                    } else if (
                      properties &&
                      properties._properties &&
                      properties._properties.messages
                    ) {
                      errorStr = JSON.stringify(
                        properties._properties.messages
                      );
                    }
                    message =
                      "ERROR: hum, something went quite wrong there! Splunk returned the following errors: " +
                      errorStr;
                    notify("error", "bottom", message, "30");
                  },
                  error: function (err) {
                    done(err);
                    message =
                      "ERROR: hum, something went quite wrong there! Splunk returned the following errors: " +
                      err;
                    notify("error", "bottom", message, "30");
                  },
                }
              );
            }
          });
        }

        function get_entities_summary_wlk(
          infoMsg,
          context,
          tenantId,
          status,
          priority
        ) {
          // Create the service
          var service = mvc.createService({
            owner: "nobody",
          });

          // Define the query
          var searchQuery =
            "| `get_tenant_entities_summary_wlk(" +
            tenantId +
            ", " +
            context +
            ", " +
            status +
            ", " +
            priority +
            ")`";

          // Set the search parameters--specify a time range
          var searchParams = {
            earliest_time: "-5m",
            latest_time: "now",
          };

          // Run a blocking search and get back a job
          service.search(searchQuery, searchParams, function (err, job) {
            // Shall the search fail before we can get properties
            if (job == null) {
              let errorStr = "Unknown Error!";
              if (
                err &&
                err.data &&
                err.data.messages &&
                err.data.messages[0]["text"]
              ) {
                errorStr = err.data.messages[0]["text"];
              } else if (err && err.data && err.data.messages) {
                errorStr = JSON.stringify(err.data.messages);
              }
              // notify error
              message =
                "ERROR: hum, something went quite wrong there! Splunk returned an error while while attempting to run the search: " +
                errorStr;
              notify("error", "bottom", message, "30");
              console.error("Review the Splunk search query: " + searchQuery);
            } else {
              // Poll the status of the search job
              job.track(
                {
                  period: 200,
                },
                {
                  done: function (job) {
                    // Get the results
                    job.results({}, function (err, results, job) {
                      var fields = results.fields;
                      var rows = results.rows;
                      var jobResult;
                      for (var i = 0; i < rows.length; i++) {
                        var values = rows[i];
                        for (var j = 0; j < values.length; j++) {
                          var field = fields[j];
                          var value = values[j];
                          // get the _raw
                          if (field === "_raw") {
                            jobResult = value;
                          }
                        }
                        // notify
                        message =
                          "ℹ️ 10 entities sample " +
                          infoMsg +
                          ": " +
                          JSON.stringify(jobResult, null, 2);
                        notify("info", "bottom", message, "30");
                      }

                      // no results were found or we have no _raw
                      if (
                        jobResult == "" ||
                        typeof jobResult === "undefined" ||
                        jobResult == "null"
                      ) {
                        message =
                          "ERROR: hum, something went quite wrong there! The search was sucessfully executed but we got no results! ";
                        notify("error", "bottom", message, "30");
                      }
                    });
                  },
                  failed: function (properties) {
                    let errorStr = "Unknown Error!";
                    if (
                      properties &&
                      properties._properties &&
                      properties._properties.messages &&
                      properties._properties.messages[0]["text"]
                    ) {
                      errorStr = properties._properties.messages[0]["text"];
                    } else if (
                      properties &&
                      properties._properties &&
                      properties._properties.messages
                    ) {
                      errorStr = JSON.stringify(
                        properties._properties.messages
                      );
                    }
                    message =
                      "ERROR: hum, something went quite wrong there! Splunk returned the following errors: " +
                      errorStr;
                    notify("error", "bottom", message, "30");
                  },
                  error: function (err) {
                    done(err);
                    message =
                      "ERROR: hum, something went quite wrong there! Splunk returned the following errors: " +
                      err;
                    notify("error", "bottom", message, "30");
                  },
                }
              );
            }
          });
        }

        function removeNotify() {
          $(".jquery-notify-bar").remove();
        }

        function genTenantsElements(
          tenantsDict,
          userPrefs,
          userPositionPrefs,
          showMessage,
          checkCount
        ) {
          // remove loader
          $("#cssloader").remove();
          $("#dyntenants").remove();
          $("#dyntenantsub").remove();
          $("#dyntenants-container").append(
            '<div id="dyntenants" style="min-height: 450px;"></div>'
          );

          var dict = JSON.parse(tenantsDict);
          var tenants = {};
          var tenantsArray = [];

          for (var i = 0, tenant; i < dict.tenants.length; i++) {
            tenant = dict.tenants[i];
            tenants[tenant.tenant_id] = tenant;
            tenantsArray.push(tenant);
          }

          // sort
          tenantsArray = tenantsArray.sort();

          // Theme preferences

          var show_tenants_mgmt_header = userPrefs["show_tenants_mgmt_header"];
          var flex_width_default = userPrefs["flex_width_default"];
          var flex_show_desc = userPrefs["flex_show_desc"];
          var flex_show_summary = userPrefs["flex_show_summary"];
          var colorTheme = userPrefs["colorTheme"];
          var colorThemeAlert = userPrefs["colorThemeAlert"];
          var dynTheme = userPrefs["dynTheme"];
          var dynThemeCondition = userPrefs["dynThemeCondition"];

          // update dropdowns

          //
          // color theme preferences and behaviour
          //

          $("#edit_prefs_color_theme").val(colorTheme);
          $("#edit_prefs_color_theme_alert").val(colorThemeAlert);
          $("#edit_prefs_dynamic_color").val(dynTheme);
          $("#edit_prefs_dynamic_color_condition").val(dynThemeCondition);

          //
          // Flex boxes size and show/hide preferences
          //

          $("#edit_prefs_tenants_status_header").val(show_tenants_mgmt_header);
          $("#edit_prefs_flex_width_default").val(flex_width_default);
          $("#edit_prefs_flex_show_desc").val(flex_show_desc);
          $("#edit_prefs_flex_show_summary").val(flex_show_summary);

          // User positions
          if (userPositionPrefs == "None" && showMessage == "true") {
            if (showMessage == "true") {
              if (getToken("userLevel") != "admin") {
                notify(
                  "info",
                  "bottom",
                  "Welcome! You can drag and drop trackMe tenants to order them up to your preference, then click on save your profile. Double click to access Virtual Tenants!",
                  "60"
                );
              } else {
                notify(
                  "info",
                  "bottom",
                  "Welcome! You can drag and drop trackMe tenants to order them up to your preference, then click on save your profile. Double click on any existing tenant, or create new tenants as needed!",
                  "60"
                );
              }
            }
          } else {
            if (showMessage == "true") {
              // Welcome message
              notify(
                "info",
                "bottom",
                "Welcome! We have loaded your saved user space, remember that you can drag and drop tenants and save your profile. Double click to access Virtual Tenants!",
                "60"
              );
            }
          }

          // If there are Vtenants created yet
          if (tenantsCount == 0 && checkCount === "true") {
            // disable position management
            $("#edit_tenants_position").prop("disabled", true);
            $("#save_tenants_position").prop("disabled", true);
            $("#reset_tenants_position").prop("disabled", true);
            // show modal
            closeModals();
            // ensure the last remaining tenant card was removed
            $("#item1").remove();
            // show welcome modal
            $("#modal_create_tenant_welcome").modal();
            // start related searches
            searchListRoles.startSearch();
            searchListUsers.startSearch();
            searchListIdxSummary.startSearch();
            searchListIdxAudit.startSearch();
            searchListIdxNotable.startSearch();
            searchListIdxMetric.startSearch();
            // remove loader
            $("#cssloader").remove();
            // show message
            notify(
              "info",
              "bottom",
              "Hands up! It looks like it's time for some configuration, follow the guide and get started!",
              "60"
            );
          }

          // user profile dict
          var userProfile = [];
          // array to store divs
          var userProfileTenants = [];
          // user profile tenant order dict
          var userTenantsOrderDict = {};
          // user profile tenant visibility dict
          var userTenantsVisibilityDict = {};

          // detect if we have a profile
          if (
            userPositionPrefs == "" ||
            userPositionPrefs == "None" ||
            typeof userPositionPrefs === "undefined"
          ) {
            // always return 0 as the order, we have no preferences yet
            function getOrder(tenant) {
              return 0;
            }
            function getVisibility(tenant) {
              return "True";
            }
          } else {
            // parse to the dict
            userPositionPrefs = JSON.parse(userPositionPrefs);
            userProfile = JSON.parse(userPositionPrefs["payload"]);

            // loop
            for (var i = 0, divName; i < userProfile.profile.length; i++) {
              // full object (divId, divOrder, divTenant
              divName = userProfile.profile[i];
              userProfileTenants.push(divName.divTenant);

              // Add to the dict and define the function
              userTenantsOrderDict[divName.divTenant] = divName.divOrder;
              function getOrder(tenant) {
                return userTenantsOrderDict[tenant];
              }

              // Add to the dict and define the function
              userTenantsVisibilityDict[divName.divTenant] = divName.isVisible;
              function getVisibility(tenant) {
                return userTenantsVisibilityDict[tenant];
              }
            }
          }

          // show or hide tenant management css translation
          var show_tenants_mgmt_header_css = "grid important;";
          if (show_tenants_mgmt_header == 0) {
            show_tenants_mgmt_header_css = "none !important;";
          } else if (show_tenants_mgmt_header == 1) {
            show_tenants_mgmt_header_css = "grid !important;";
          }

          // show or hide desc css translation
          var flex_show_desc_css = "inherit important;";
          if (flex_show_desc == 0) {
            flex_show_desc_css = "none !important;";
          } else if (flex_show_desc == 1) {
            flex_show_desc_css = "inherit !important;";
          }

          // show or hide summary css translation
          var flex_show_summary_css = "inherit important;";
          if (flex_show_summary == 0) {
            flex_show_summary_css = "none !important;";
          } else if (flex_show_summary == 1) {
            flex_show_summary_css = "inherit !important;";
          }

          // dynamic style element
          $("#dyntenants").append(
            '<style id="dynstyle" type="text/css">' +
              ".parent-vtenant-top-header { display: " +
              show_tenants_mgmt_header_css +
              "px;" +
              "}" +
              "\n" +
              ".flex-items { max-width:" +
              flex_width_default +
              "px;" +
              "}" +
              "\n" +
              ".flex-items-desc { display: " +
              flex_show_desc_css +
              "}" +
              "\n" +
              ".flex-items-list { display: " +
              flex_show_summary_css +
              "}" +
              "\n" +
              ".flex-items-color { background-color:" +
              colorTheme +
              "}" +
              ".flex-items-alertcolor { background-color:" +
              colorThemeAlert +
              "}" +
              "</style>"
          );

          // create the container
          $("#dyntenants").append(
            '<div id="dyntenantsub" class="flex-container"></div>'
          );

          // loop through the array and handle elements
          var counter = 0;
          tenantsArray.forEach(function (item, index) {
            // consider the tenant only if it contains at least one component enabled
            if (
              item.tenant_dsm_enabled == 1 ||
              item.tenant_cim_enabled == 1 ||
              item.tenant_flx_enabled == 1 ||
              item.tenant_wlk_enabled == 1 ||
              item.tenant_dhm_enabled == 1 ||
              item.tenant_mhm_enabled == 1
            ) {
              // divId
              counter += 1;
              itemDivId = "#item" + counter;
              itemDiv = "item" + counter;

              function isNumeric(n) {
                return !isNaN(parseFloat(n)) && isFinite(n);
              }

              function getVar(varName) {
                if (
                  varName == "" ||
                  varName === "null" ||
                  typeof varName === "undefined"
                ) {
                  varName = 0;
                } else if (!isNaN(varName)) {
                  varName = parseFloat(varName);
                }
                return varName;
              }

              function isNumeric(n) {
                return !isNaN(parseFloat(n)) && isFinite(n);
              }

              function formatDateTime(date) {
                const days = ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"];
                const months = [
                  "Jan",
                  "Feb",
                  "Mar",
                  "Apr",
                  "May",
                  "Jun",
                  "Jul",
                  "Aug",
                  "Sep",
                  "Oct",
                  "Nov",
                  "Dec",
                ];
                const day = days[date.getDay()];
                const month = months[date.getMonth()];
                const dateNum = date.getDate().toString().padStart(2, "0");
                const hours = date.getHours().toString().padStart(2, "0");
                const minutes = date.getMinutes().toString().padStart(2, "0");
                const seconds = date.getSeconds().toString().padStart(2, "0");
                const year = date.getFullYear();

                return `${day} ${month} ${dateNum} ${hours}:${minutes}:${seconds} ${year}`;
              }

              function getLastExec(varName) {
                if (varName == "" || typeof varName === "undefined") {
                  varName = "Unknown";
                } else if (isNumeric(varName)) {
                  var date = new Date(parseInt(varName) * 1000);
                  varName = formatDateTime(date);
                }
                return varName;
              }

              function getIcon(varName, icons_state_mode) {
                var varIcon;
                if (varName > 0) {
                  if (icons_state_mode == "emoji") {
                    varIcon = "❌";
                  } else if (icons_state_mode == "bootstrap") {
                    varIcon =
                      "<i class='bi bi-exclamation-triangle-fill icon-state-red'></i>";
                  }
                } else {
                  varIcon = "";
                }
                return varIcon;
              }

              // gen the element
              if (item.tenant_status == "enabled") {
                //
                // get info from the tenant summary
                //
                // total number of entities
                var dsm_entities = getVar(item.dsm_entities);
                var cim_entities = getVar(item.cim_entities);
                var flx_entities = getVar(item.flx_entities);
                var wlk_entities = getVar(item.wlk_entities);
                var dhm_entities = getVar(item.dhm_entities);
                var mhm_entities = getVar(item.mhm_entities);
                var summary_entities;

                // sum all entities
                summary_entities =
                  dsm_entities +
                  cim_entities +
                  dhm_entities +
                  mhm_entities +
                  flx_entities +
                  wlk_entities;

                // dsm priority red entities
                var dsm_low_red_priority = getVar(item.dsm_low_red_priority);
                var dsm_medium_red_priority = getVar(
                  item.dsm_medium_red_priority
                );
                var dsm_high_red_priority = getVar(item.dsm_high_red_priority);

                // cim priority red entities
                var cim_low_red_priority = getVar(item.cim_low_red_priority);
                var cim_medium_red_priority = getVar(
                  item.cim_medium_red_priority
                );
                var cim_high_red_priority = getVar(item.cim_high_red_priority);

                // flx priority red entities
                var flx_low_red_priority = getVar(item.flx_low_red_priority);
                var flx_medium_red_priority = getVar(
                  item.flx_medium_red_priority
                );
                var flx_high_red_priority = getVar(item.flx_high_red_priority);

                // wlk priority red entities
                var wlk_low_red_priority = getVar(item.wlk_low_red_priority);
                var wlk_medium_red_priority = getVar(
                  item.wlk_medium_red_priority
                );
                var wlk_high_red_priority = getVar(item.wlk_high_red_priority);

                // dhm priority red entities
                var dhm_low_red_priority = getVar(item.dsm_low_red_priority);
                var dhm_medium_red_priority = getVar(
                  item.dhm_medium_red_priority
                );
                var dhm_high_red_priority = getVar(item.dhm_high_red_priority);

                // mhm priority red entities
                var mhm_low_red_priority = getVar(item.mhm_low_red_priority);
                var mhm_medium_red_priority = getVar(
                  item.mhm_medium_red_priority
                );
                var mhm_high_red_priority = getVar(item.mhm_high_red_priority);

                // for all
                var low_red_priority =
                  dsm_low_red_priority +
                  cim_low_red_priority +
                  flx_low_red_priority +
                  wlk_low_red_priority +
                  dhm_low_red_priority +
                  mhm_low_red_priority;
                var medium_red_priority =
                  dsm_medium_red_priority +
                  cim_medium_red_priority +
                  flx_medium_red_priority +
                  wlk_medium_red_priority +
                  dhm_medium_red_priority +
                  mhm_medium_red_priority;
                var high_red_priority =
                  dsm_high_red_priority +
                  cim_high_red_priority +
                  flx_high_red_priority +
                  wlk_high_red_priority +
                  dhm_high_red_priority +
                  mhm_high_red_priority;

                // sum all red entities for the tenant
                var summary_red_entities =
                  low_red_priority + medium_red_priority + high_red_priority;

                // sum medium and high priorities entities for the tenant
                var summary_highmedium_red_entities =
                  medium_red_priority + high_red_priority;

                // ascii emoji
                var low_red_priority_icon = getIcon(
                  low_red_priority,
                  icons_state_mode
                );
                var medium_red_priority_icon = getIcon(
                  medium_red_priority,
                  icons_state_mode
                );
                var high_red_priority_icon = getIcon(
                  high_red_priority,
                  icons_state_mode
                );

                // last exec: define if the tenant is operational or degraded
                var dsm_status = item.dsm_status;
                var dhm_status = item.dhm_status;
                var mhm_status = item.mhm_status;
                var cim_status = item.cim_status;
                var flx_status = item.flx_status;
                var wlk_status = item.wlk_status;
                var tenant_status;

                // only affect the status if the component is enabled
                if (item.tenant_dsm_enabled == 0) {
                  dsm_status = 0;
                }
                if (item.tenant_dhm_enabled == 0) {
                  dhm_status = 0;
                }
                if (item.tenant_mhm_enabled == 0) {
                  mhm_status = 0;
                }
                if (item.tenant_cim_enabled == 0) {
                  cim_status = 0;
                }
                if (item.tenant_flx_enabled == 0) {
                  flx_status = 0;
                }
                if (item.tenant_wlk_enabled == 0) {
                  wlk_status = 0;
                }

                // if any of the component has not been refreshed since more than 10 minutes, assume it is degraded
                if (
                  dsm_status > 0 ||
                  dhm_status > 0 ||
                  mhm_status > 0 ||
                  flx_status > 0 ||
                  wlk_status > 0 ||
                  cim_status > 0
                ) {
                  tenant_status = setStatusIcon("degraded", icons_state_mode);
                } else {
                  tenant_status = setStatusIcon(
                    "operational",
                    icons_state_mode
                  );
                }

                // however, shall a component be enabled with no status
                if (
                  typeof dsm_status === "undefined" ||
                  typeof dhm_status === "undefined" ||
                  typeof mhm_status === "undefined" ||
                  typeof flx_status === "undefined" ||
                  typeof wlk_status === "undefined" ||
                  typeof cim_status === "undefined"
                ) {
                  tenant_status = setStatusIcon("degraded", icons_state_mode);
                }

                // last exec human
                var dsm_last_exec_human = getLastExec(item.dsm_last_exec);
                var cim_last_exec_human = getLastExec(item.cim_last_exec);
                var dhm_last_exec_human = getLastExec(item.dhm_last_exec);
                var mhm_last_exec_human = getLastExec(item.mhm_last_exec);
                var flx_last_exec_human = getLastExec(item.flx_last_exec);
                var wlk_last_exec_human = getLastExec(item.wlk_last_exec);

                // getOrder: if the user has saved preferences, otherwise we return 0
                var divOrder = getOrder(item.tenant_id);

                // getVisbility: if the user has saved preferences, otherwise we return visible
                var divVisibility;
                var isVisible = getVisibility(item.tenant_id);

                if (isVisible === "True") {
                  divVisibility = "block";
                } else if (isVisible === "False") {
                  divVisibility = "none";
                } else {
                  divVisibility = "block";
                }

                // dynclass
                var dynclass;
                if (summary_red_entities > 0 && dynTheme == "1") {
                  dynclass = "flex-items-alertcolor";

                  // dynTheme condition
                  if (dynThemeCondition == "any") {
                    dynclass = "flex-items-alertcolor";
                  } else if (
                    dynThemeCondition == "high_priority" &&
                    high_red_priority > 0
                  ) {
                    dynclass = "flex-items-alertcolor";
                  } else if (
                    dynThemeCondition == "medium_priority" &&
                    summary_highmedium_red_entities > 0
                  ) {
                    dynclass = "flex-items-alertcolor";
                  } else {
                    dynclass = "flex-items-color";
                  }
                } else {
                  dynclass = "flex-items-color";
                }

                $("#dyntenantsub").append(
                  '<div id="' +
                    itemDiv +
                    '" data-href="#" style="cursor: pointer; order: ' +
                    divOrder +
                    "; display:" +
                    divVisibility +
                    ';" ' +
                    'data-tenant="' +
                    item.tenant_id +
                    '" data-tenant-desc="' +
                    item.tenant_desc +
                    '" data-tenant-dsm-enabled="' +
                    item.tenant_dsm_enabled +
                    '" data-tenant-cim-enabled="' +
                    item.tenant_cim_enabled +
                    '" data-tenant-flx-enabled="' +
                    item.tenant_flx_enabled +
                    '" data-tenant-wlk-enabled="' +
                    item.tenant_wlk_enabled +
                    '" data-tenant-dhm-enabled="' +
                    item.tenant_dhm_enabled +
                    '" data-tenant-mhm-enabled="' +
                    item.tenant_mhm_enabled +
                    '" data-tenant-owner="' +
                    item.tenant_owner +
                    '" data-tenant-dsm-create-trackers="' +
                    item.tenant_dsm_create_trackers +
                    '" data-tenant-dsm-last-exec="' +
                    dsm_last_exec_human +
                    '" data-tenant-flx-last-exec="' +
                    flx_last_exec_human +
                    '" data-tenant-wlk-last-exec="' +
                    wlk_last_exec_human +
                    '" data-tenant-cim-last-exec="' +
                    cim_last_exec_human +
                    '" data-tenant-dhm-last-exec="' +
                    dhm_last_exec_human +
                    '" data-tenant-mhm-last-exec="' +
                    mhm_last_exec_human +
                    '" data-tenant-dsm-last-status="' +
                    dsm_status +
                    '" data-tenant-flx-last-status="' +
                    flx_status +
                    '" data-tenant-wlk-last-status="' +
                    wlk_status +
                    '" data-tenant-cim-last-status="' +
                    cim_status +
                    '" data-tenant-dhm-last-status="' +
                    dhm_status +
                    '" data-tenant-mhm-last-status="' +
                    mhm_status +
                    '" data-tenant-status="' +
                    item.tenant_status +
                    '" class="flex-items-dragg flex-items ' +
                    dynclass +
                    ' flex-item-containers"><div class="flex-items-container">' +
                    item.tenant_id +
                    ": " +
                    tenant_status +
                    "</div></div>"
                );

                // tenant description
                if (
                  item.tenant_desc !== null &&
                  typeof item.tenant_desc !== "undefined"
                ) {
                  if (item.tenant_desc.length > 0) {
                    $(itemDivId).append(
                      '<div class="flex-items-desc"><h2>' +
                        item.tenant_desc +
                        "</h2></div>"
                    );
                  }
                } else {
                  $(itemDivId).append(
                    '<div class="flex-items-desc"><h2></h2></div>'
                  );
                }

                // add the entities summary
                $(itemDivId).append(
                  '<div style="margin-bottom: 10px;" class="flex-items-list"><h2><lu><li>Number of entities: ' +
                    summary_entities +
                    "</li>" +
                    "<li>Low priority red status: " +
                    low_red_priority_icon +
                    low_red_priority +
                    "</li>" +
                    "<li>Medium priority red status: " +
                    medium_red_priority_icon +
                    medium_red_priority +
                    "</li>" +
                    "<li>High priority red status: " +
                    high_red_priority_icon +
                    high_red_priority +
                    "</li></lu></h2></div>"
                );
              } else if (item.tenant_status == "disabled") {
                // getOrder: if the user has saved preferences, otherwise we return 0
                var divOrder = getOrder(item.tenant_id);

                // getVisbility: if the user has saved preferences, otherwise we return visible
                var divVisibility;
                var isVisible = getVisibility(item.tenant_id);

                if (isVisible === "True") {
                  divVisibility = "block";
                } else if (isVisible === "False") {
                  divVisibility = "none";
                } else {
                  divVisibility = "block";
                }

                $("#dyntenantsub").append(
                  '<div id="' +
                    itemDiv +
                    '" data-href="#" style="cursor: pointer; order: ' +
                    divOrder +
                    "; display: " +
                    divVisibility +
                    ';" ' +
                    'data-tenant="' +
                    item.tenant_id +
                    '" data-tenant-desc="' +
                    item.tenant_desc +
                    '" data-tenant-dsm-enabled="' +
                    item.tenant_dsm_enabled +
                    '" data-tenant-cim-enabled="' +
                    item.tenant_cim_enabled +
                    '" data-tenant-flx-enabled="' +
                    item.tenant_flx_enabled +
                    '" data-tenant-wlk-enabled="' +
                    item.tenant_wlk_enabled +
                    '" data-tenant-dhm-enabled="' +
                    item.tenant_dhm_enabled +
                    '" data-tenant-mhm-enabled="' +
                    item.tenant_mhm_enabled +
                    '" data-tenant-owner="' +
                    item.tenant_owner +
                    '" data-tenant-status="' +
                    item.tenant_status +
                    '" class="flex-items-dragg flex-items flex-items-disabled ' +
                    dynclass +
                    ' flex-item-containers"><div class="flex-items-container">' +
                    item.tenant_id +
                    ": " +
                    setStatusIcon("disabled", icons_state_mode) +
                    "</div></div>"
                );
                if (
                  item.tenant_desc !== null &&
                  typeof item.tenant_desc !== "undefined"
                ) {
                  if (item.tenant_desc.length > 0) {
                    $(itemDivId).append(
                      '<div class="flex-items-desc"><h2>' +
                        item.tenant_desc +
                        "</h2></div>"
                    );
                  }
                } else {
                  $(itemDivId).append(
                    '<div class="flex-items-desc"><h2></h2></div>'
                  );
                }
              }
            }
          });

          // track over events
          $(".flex-items").on("mouseenter", function () {
            var tenant_id = $(this).attr("data-tenant");
            var tenant_dsm_enabled = $(this).attr("data-tenant-dsm-enabled");
            var tenant_cim_enabled = $(this).attr("data-tenant-cim-enabled");
            var tenant_flx_enabled = $(this).attr("data-tenant-flx-enabled");
            var tenant_wlk_enabled = $(this).attr("data-tenant-wlk-enabled");
            var tenant_dhm_enabled = $(this).attr("data-tenant-dhm-enabled");
            var tenant_mhm_enabled = $(this).attr("data-tenant-mhm-enabled");
            var tenant_dsm_last_exec_human = $(this).attr(
              "data-tenant-dsm-last-exec"
            );
            if (
              tenant_dsm_last_exec_human == "undefined" ||
              tenant_dsm_last_exec_human == null ||
              tenant_dsm_last_exec_human == "null"
            ) {
              tenant_dsm_last_exec_human = "Unknown";
            }
            var tenant_dhm_last_exec_human = $(this).attr(
              "data-tenant-dhm-last-exec"
            );
            if (
              tenant_dhm_last_exec_human == "undefined" ||
              tenant_dhm_last_exec_human == null ||
              tenant_dhm_last_exec_human == "null"
            ) {
              tenant_dhm_last_exec_human = "Unknown";
            }
            var tenant_cim_last_exec_human = $(this).attr(
              "data-tenant-cim-last-exec"
            );
            if (
              tenant_cim_last_exec_human == "undefined" ||
              tenant_cim_last_exec_human == null ||
              tenant_cim_last_exec_human == "null"
            ) {
              tenant_cim_last_exec_human = "Unknown";
            }
            var tenant_flx_last_exec_human = $(this).attr(
              "data-tenant-flx-last-exec"
            );
            if (
              tenant_flx_last_exec_human == "undefined" ||
              tenant_flx_last_exec_human == null ||
              tenant_cim_last_exec_human == "null"
            ) {
              tenant_flx_last_exec_human = "Unknown";
            }
            var tenant_wlk_last_exec_human = $(this).attr(
              "data-tenant-wlk-last-exec"
            );
            if (
              tenant_wlk_last_exec_human == "undefined" ||
              tenant_wlk_last_exec_human == null
            ) {
              tenant_wlk_last_exec_human = "Unknown";
            }
            var tenant_mhm_last_exec_human = $(this).attr(
              "data-tenant-mhm-last-exec"
            );
            if (
              tenant_mhm_last_exec_human == "undefined" ||
              tenant_mhm_last_exec_human == null ||
              tenant_mhm_last_exec_human == "null"
            ) {
              tenant_mhm_last_exec_human = "Unknown";
            }
            var tenant_dsm_status = $(this).attr("data-tenant-dsm-last-status");
            var tenant_cim_status = $(this).attr("data-tenant-cim-last-status");
            var tenant_flx_status = $(this).attr("data-tenant-flx-last-status");
            var tenant_wlk_status = $(this).attr("data-tenant-wlk-last-status");
            var tenant_dhm_status = $(this).attr("data-tenant-dhm-last-status");
            var tenant_mhm_last_status = $(this).attr(
              "data-tenant-mhm-last-status"
            );

            var message = "";
            var status;

            function formatStatus(status, icons_state_mode) {
              if (status == 0) {
                if (icons_state_mode == "emoji") {
                  status = "🟢 ";
                } else if (icons_state_mode == "bootstrap") {
                  status =
                    "<i class='bi bi-check-circle-fill icon-state-green'></i> ";
                }
              } else {
                if (icons_state_mode == "emoji") {
                  status = "❌ ";
                } else if (icons_state_mode == "bootstrap") {
                  status =
                    "<i class='bi bi-exclamation-triangle-fill icon-state-red'></i> ";
                }
              }
              return status;
            }

            if (tenant_dsm_enabled == 1) {
              status = formatStatus(tenant_dsm_status, icons_state_mode);
              message =
                message +
                " / DSM last exec: " +
                status +
                tenant_dsm_last_exec_human;
            }
            if (tenant_cim_enabled == 1) {
              status = formatStatus(tenant_cim_status, icons_state_mode);
              message =
                message +
                " / CIM last exec: " +
                status +
                tenant_cim_last_exec_human;
            }
            if (tenant_flx_enabled == 1) {
              status = formatStatus(tenant_flx_status, icons_state_mode);
              message =
                message +
                " / FLX last exec: " +
                status +
                tenant_flx_last_exec_human;
            }
            if (tenant_wlk_enabled == 1) {
              status = formatStatus(tenant_wlk_status, icons_state_mode);
              message =
                message +
                " / WLK last exec: " +
                status +
                tenant_wlk_last_exec_human;
            }
            if (tenant_dhm_enabled == 1) {
              status = formatStatus(tenant_dhm_status, icons_state_mode);
              message =
                message +
                " / DHM last exec: " +
                status +
                tenant_dhm_last_exec_human;
            }
            if (tenant_mhm_enabled == 1) {
              status = formatStatus(tenant_mhm_last_status, icons_state_mode);
              message =
                message +
                " / MHM last exec: " +
                status +
                tenant_mhm_last_exec_human;
            }

            notify(
              "info",
              "bottom",
              "ℹ️ Double-Click to open the tenant: " +
                tenant_id +
                " " +
                message,
              "5"
            );
          });

          // draggable flex boxes
          $(function () {
            $(".flex-items-dragg").draggable({
              // start
              start: function (event, ui) {
                var target = document.getElementById(this.id);
                target.style.zIndex = 100;
                target.style.opacity = "50%";
              },

              // stop
              stop: function (event, ui) {
                var target = document.getElementById(this.id);
                var nowPosition = new Object();
                var newPosition = new Array();
                target.style.opacity = "100%";

                // loop
                for (var i = 1; i < ($(".flex-items-dragg").length += 1); i++) {
                  var positionData = getPosition(i);
                  nowPosition = {
                    name: "item" + i,
                    position: positionData,
                  };

                  newPosition.push(nowPosition);
                }

                // new position
                newPosition.sort(function (a, b) {
                  if (a["position"] > b["position"]) return -1;
                  if (a["position"] < b["position"]) return 1;
                  return 0;
                });

                // Order
                var number = 0;
                for (var i = newPosition.length; i--; ) {
                  var tmpItem = document.getElementById(newPosition[i].name);
                  tmpItem.style.order = number;
                  tmpItem.style.left = 0;
                  tmpItem.style.top = 0;

                  number++;
                }

                // final
                var target = document.getElementById(this.id);
                target.style.zIndex = 0;
              },
            });

            // position
            function getPosition(item) {
              var tmpItem = document.getElementById("item" + item);
              return tmpItem.offsetLeft;
            }
          });

          // show knowledge objects function
          function showTenantKos(ajaxUrl, ajaxType, ajaxData) {
            // notify
            notify(
              "info",
              "bottom",
              "Please wait loading the tenant knowledge objects...",
              "5"
            );
            // Run the ajax promise
            var doAsync = asyncAjax(ajaxUrl, ajaxType, ajaxData).then(function (
              resultCall
            ) {
              tabulatorElement = "#showKosTabulator";

              function jsonFormatter(cell, formatterParams, onRendered) {
                cell.getElement().style.whiteSpace = "pre-wrap"; //allow cell to take up multiple lines of text
                return JSON.stringify(cell.getValue(), null, 4).replace(
                  /\\/g,
                  ""
                ); //return JSON formatted cell
              }

              // count the number of items in the array and update the title
              var no_items = resultCall.length;
              var no_collections = 0;
              var no_lookups = 0;
              var no_savedsearches_scheduled = 0;
              var no_savedsearches_not_scheduled = 0;
              var no_macros = 0;
              var type_ko;
              var ko_properties;
              var re = new RegExp('"(is_scheduled": 1)');
              var re2 = new RegExp('(?!"is_scheduled": 1)');

              for (var i = 0; i < resultCall.length; i++) {
                type_ko = resultCall[i].type;
                ko_properties = resultCall[i].properties;
                if (type_ko === "kvstore_collections") {
                  no_collections++;
                } else if (type_ko === "lookup_definitions") {
                  no_lookups++;
                } else if (
                  type_ko === "savedsearches" &&
                  re.test(ko_properties)
                ) {
                  no_savedsearches_scheduled++;
                } else if (
                  type_ko === "savedsearches" &&
                  re2.test(ko_properties)
                ) {
                  no_savedsearches_not_scheduled++;
                } else if (type_ko === "macros") {
                  no_macros++;
                }
              }

              $("#divTitleKos1").html(
                "<h1>" + ajaxData["tenant_id"] + ":</h1>"
              );

              $("#divTitleKos2").html(
                '<h1><span style="color: #a7c7e7;">' +
                  no_items +
                  " Knowledge Objects / " +
                  no_collections +
                  " KVstores / " +
                  no_lookups +
                  " Lookups / " +
                  no_savedsearches_scheduled +
                  " Scheduled Reports / " +
                  no_savedsearches_not_scheduled +
                  " Non Scheduled Reports / " +
                  no_macros +
                  " Macros" +
                  "</span></h1>"
              );

              var table = new TabulatorFull(tabulatorElement, {
                data: resultCall,
                index: "title",
                layout: "fitDataStretch", //fit columns to width of table
                responsiveLayout: "hide", //hide columns that dont fit on the table
                movableRows: true, // allow rows to be moved
                addRowPos: "top", //when adding a new row, add it to the top of the table
                history: true, //allow undo and redo actions on the table
                pagination: "local", //paginate the data
                paginationSize: 10, //allow 5 rows per page of data
                paginationCounter: "rows", //display count of paginated rows in footer
                movableColumns: true, //allow column order to be changed
                resizableRows: true, //allow row order to be changed
                maxHeight: "600px",
                groupBy: "component",
                initialSort: [
                  //set the initial sort order of the data
                  { column: "type", dir: "asc" },
                ],

                columns: [
                  //define the table columns
                  {
                    title: "Component",
                    field: "component",
                    editor: false,
                    headerFilter: true,
                    sorter: "string",
                  },
                  {
                    title: "Type",
                    field: "type",
                    editor: false,
                    headerFilter: true,
                  },
                  {
                    title: "Title",
                    field: "title",
                    editor: false,
                    headerFilter: true,
                  },
                  {
                    title: "Properties",
                    field: "properties",
                    formatter: jsonFormatter,
                    variableHeight: true,
                    editor: false,
                    headerFilter: true,
                  },
                ],
              });

              table.on("tableBuilt", function () {
                // notify
                notify(
                  "success",
                  "bottom",
                  "Tenant's knowledge objects list successfully loaded!",
                  "5"
                );
              });
            });
          }

          // show knowledge objects button
          $("#show_tenant_kos")
            .unbind()
            .click(function () {
              $(this).blur();
              // set the tenant id
              var clickedTenantId = getToken("clickedTenantId");
              // set the open in search link
              $("#btn_modal_open_kos").attr(
                "href",
                encodeURI(
                  "search?q=| `get_tenants_reports(" + clickedTenantId + ")`"
                )
              );
              // get table
              showTenantKos(
                "/en-US/splunkd/__raw/services/trackme/v2/configuration/get_tenant_knowledge_objects",
                "post",
                { tenant_id: clickedTenantId }
              );
              // open modal
              $("#modal_show_tenant_kos").modal();
            });

          // edit position profile
          function show_profile() {
            // retrieve all div from the class, build a dictionnary of tenants_id / order
            var jsonDict = [];
            var divId;
            var divOrder;
            var isVisible;

            $(".flex-items-dragg").each(function (index, value) {
              divId = `${this.id}`;
              divOrder = $(this).css("order");
              divVisibility = $(this).css("display");
              divTenant = $(this).attr("data-tenant");
              if (divVisibility == "block") {
                isVisible = "True";
              } else {
                isVisible = "False";
              }

              jsonDict.push({
                divTenant: divTenant,
                divOrder: divOrder,
                isVisible: isVisible,
              });

              //
            });

            // loop through the object
            initialJsonDict = [];
            Object.entries(jsonDict).forEach(([k, v]) => {
              initialJsonDict.push({
                divTenant: v["divTenant"],
                isVisible: v["isVisible"],
                divOrder: k,
              });
            });

            // tabulator profile
            function editProfileTable(jsonDict) {
              tabulatorElement = "#editProfileTabulator";
              var table = new TabulatorFull(tabulatorElement, {
                data: jsonDict,
                index: "divTenant",
                layout: "fitColumns", //fit columns to width of table
                responsiveLayout: "hide", //hide columns that dont fit on the table
                movableRows: true, // allow rows to be moved
                addRowPos: "top", //when adding a new row, add it to the top of the table
                history: false, //allow undo and redo actions on the table
                pagination: "local", //paginate the data
                paginationSize: 10, //allow 5 rows per page of data
                paginationCounter: "rows", //display count of paginated rows in footer
                movableColumns: true, //allow column order to be changed
                resizableRows: true, //allow row order to be changed
                //groupValues: [["block", "none"]],
                groupBy: "isVisible",
                initialSort: [
                  //set the initial sort order of the data
                  { column: "divOrder", dir: "asc" },
                ],

                columns: [
                  //define the table columns
                  {
                    rowHandle: true,
                    formatter: "handle",
                    headerSort: false,
                    frozen: true,
                    width: 30,
                    minWidth: 30,
                  },
                  {
                    title: "tenant_id",
                    field: "divTenant",
                    editor: false,
                    headerFilter: true,
                    sorter: "string",
                  },
                  {
                    title: "Position order",
                    field: "divOrder",
                    editor: false,
                    headerFilter: true,
                    sorter: "number",
                  },
                  {
                    title: "Is visible",
                    field: "isVisible",
                    hozAlign: "center",
                    formatter: "tickCross",
                    editor: "list",
                    editorParams: { values: ["True", "False"] },
                    headerFilter: false,
                    headerSort: false,
                  },
                ],
              });

              // detect inline edit
              table.on("cellEdited", function (cell) {
                //e - the click event object
                //row - row component
                $("#btn_modal_edit_profile").prop("disabled", false);
              });

              //listen for row move
              table.on("rowMoved", function (row) {
                // loop through the object
                var newJsonDict = [];
                var selectedData = table.getData("active");
                Object.entries(selectedData).forEach(([k, v]) => {
                  newJsonDict.push({
                    divTenant: v["divTenant"],
                    isVisible: v["isVisible"],
                    divOrder: k,
                  });
                });

                // replace data table
                table.replaceData(JSON.stringify(newJsonDict));

                // enable the button
                $("#btn_modal_edit_profile").prop("disabled", false);
              });

              // update
              $("#btn_modal_edit_profile")
                .unbind("click")
                .click(function () {
                  var selectedData = table.getData("active");

                  // loop through the object
                  var newJsonDict = [];
                  Object.entries(selectedData).forEach(([k, v]) => {
                    newJsonDict.push({
                      divTenant: v["divTenant"],
                      isVisible: v["isVisible"],
                      divOrder: k,
                    });
                  });

                  // Get current user
                  var currentUser = Splunk.util.getConfigValue("USERNAME");

                  var myendpoint_URl =
                    "/en-US/splunkd/__raw/services/trackme/v2/configuration/update_vtenants_user_prefs";

                  var postJsonData = {
                    target_user: currentUser,
                    target_prefs: "position",
                    json_data: newJsonDict,
                  };

                  $.ajax({
                    url: myendpoint_URl,
                    type: "POST",
                    async: true,
                    data: JSON.stringify(postJsonData),
                    contentType: "application/json",
                    success: function (returneddata) {
                      returneddata = JSON.parse(returneddata);
                      payload = JSON.parse(returneddata["payload"]);
                      profile = payload["profile"];

                      // replace data table
                      table.replaceData(JSON.stringify(profile));
                      // refresh flex boxes
                      getTenantsList("false", "true");
                      // notify
                      notify(
                        "success",
                        "bottom",
                        "OK! your user profile has been updated successfully",
                        "5"
                      );
                    },
                    error: function (xhr, textStatus, error) {
                      msg =
                        "Oops! Looks like something wrong happened: " + error;
                      notify("error", "bottom", msg, "5");
                    },
                  });
                });
            }

            editProfileTable(initialJsonDict);
          }

          // edit profile button
          $("#edit_tenants_position")
            .unbind()
            .click(function () {
              $(this).blur();
              // get current
              show_profile();
              $("#modal_edit_profile").modal();
            });

          // hide a tenant (and save profile)

          function hide_tenant(successMsg, tenant_id) {
            // Create the service
            var service = mvc.createService({
              owner: "nobody",
            });

            // Get current user
            var currentUser = Splunk.util.getConfigValue("USERNAME");

            // retrieve all div from the class, build a dictionnary of tenants_id / order
            var jsonDict = [];
            var divId;
            var divOrder;
            var isVisible;

            $(".flex-items-dragg").each(function (index, value) {
              divId = `${this.id}`;
              divOrder = $(this).css("order");
              divTenant = $(this).attr("data-tenant");

              // if target
              if (divTenant == tenant_id) {
                $("#" + divId).css("display", "none");
                divVisibility = "none";
                isVisible = "False";
              } else {
                divVisibility = $(this).css("display");
                isVisible = "True";
              }

              jsonDict.push({
                divTenant: divTenant,
                isVisible: isVisible,
                divOrder: divOrder,
              });

              //
            });

            // Get current user
            var currentUser = Splunk.util.getConfigValue("USERNAME");

            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/configuration/update_vtenants_user_prefs";

            var postJsonData = {
              target_user: currentUser,
              target_prefs: "position",
              json_data: jsonDict,
            };

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              data: JSON.stringify(postJsonData),
              contentType: "application/json",
              success: function (returneddata) {
                // notify
                notify("success", "bottom", successMsg, "5");
              },
              error: function (xhr, textStatus, error) {
                msg = "Oops! Looks like something wrong happened: " + error;
                notify("error", "bottom", msg, "5");
              },
            });

            //
          }

          // save position profile

          function save_profile(successMsg) {
            // Get current user
            var currentUser = Splunk.util.getConfigValue("USERNAME");

            // retrieve all div from the class, build a dictionnary of tenants_id / order
            var jsonDict = [];
            var divId;
            var divOrder;
            var isVisible;

            $(".flex-items-dragg").each(function (index, value) {
              divId = `${this.id}`;
              divOrder = $(this).css("order");
              divVisibility = $(this).css("display");
              if (divVisibility === "block") {
                isVisible = "True";
              } else {
                isVisible = "False";
              }
              divTenant = $(this).attr("data-tenant");

              jsonDict.push({
                divTenant: divTenant,
                divVisibility: divVisibility,
                isVisible: isVisible,
                divOrder: divOrder,
              });

              //
            });

            // Get current user
            var currentUser = Splunk.util.getConfigValue("USERNAME");

            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/configuration/update_vtenants_user_prefs";

            var postJsonData = {
              target_user: currentUser,
              target_prefs: "position",
              json_data: jsonDict,
            };

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              data: JSON.stringify(postJsonData),
              contentType: "application/json",
              success: function (returneddata) {
                // refresh
                getTenantsList("false", "true");
                // notify
                notify(
                  "success",
                  "bottom",
                  "OK! your user profile has been updated successfully",
                  "5"
                );
              },
              error: function (xhr, textStatus, error) {
                msg = "Oops! Looks like something wrong happened: " + error;
                notify("error", "bottom", msg, "5");
              },
            });

            //
          }

          // save profile button
          $("#save_tenants_position")
            .unbind()
            .click(function () {
              $(this).blur();
              $("#modal_save_profile").modal();
            });

          $("#btn_modal_save_profile")
            .unbind()
            .click(function () {
              $(this).blur();
              // call the function
              save_profile("OK! Your preferences have been saved successfully");
            });

          // reset position profile
          $("#reset_tenants_position")
            .unbind()
            .click(function () {
              $(this).blur();
              $("#modal_reset_profile").modal();
            });

          $("#btn_modal_reset_profile")
            .unbind()
            .click(function () {
              $(this).blur();

              var dataJson = {
                vtenant_position_userpref: "True",
                vtenant_theme_userpref: "True",
              };

              // function
              function deletePreferences(urlTarget) {
                $.ajax({
                  url: urlTarget,
                  type: "POST",
                  async: true,
                  contentType: "application/json",
                  dataType: "text",
                  data: JSON.stringify(dataJson),
                  success: function () {
                    // Refresh
                    getTenantsList("false", "true");
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "OK! We've erased your user profiles, tenants cards position and visibility, as well as color theme and behaviour preferences were reverted to default",
                      "5"
                    );
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon or an exception was encountered! " +
                        message,
                      "600"
                    );
                  },
                });
              }

              var myendpoint_URl =
                "/en-US/splunkd/__raw/services/trackme/v2/configuration/reset_vtenants_prefs";

              // Call the API endpoint
              deletePreferences(myendpoint_URl);
              //
            });

          $("#btn_modal_reset_profile_position_only")
            .unbind()
            .click(function () {
              $(this).blur();

              var dataJson = {
                vtenant_position_userpref: "True",
                vtenant_theme_userpref: "False",
              };

              // function
              function deletePreferences(urlTarget) {
                $.ajax({
                  url: urlTarget,
                  type: "POST",
                  async: true,
                  contentType: "application/json",
                  dataType: "text",
                  data: JSON.stringify(dataJson),
                  success: function () {
                    // Refresh
                    getTenantsList("false", "true");
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "OK! Tenants flex boses position and visibility preferences were reverted to default",
                      "5"
                    );
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon or an exception was encountered! " +
                        message,
                      "600"
                    );
                  },
                });
              }

              var myendpoint_URl =
                "/en-US/splunkd/__raw/services/trackme/v2/configuration/reset_vtenants_prefs";

              // Call the API endpoint
              deletePreferences(myendpoint_URl);
              //
            });

          $("#btn_modal_reset_profile_theme_only")
            .unbind()
            .click(function () {
              $(this).blur();

              var dataJson = {
                vtenant_position_userpref: "False",
                vtenant_theme_userpref: "True",
              };

              // function
              function deletePreferences(urlTarget) {
                $.ajax({
                  url: urlTarget,
                  type: "POST",
                  async: true,
                  contentType: "application/json",
                  dataType: "text",
                  data: JSON.stringify(dataJson),
                  success: function () {
                    // Refresh
                    getTenantsList("true", "true");
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "OK! Color theme and behaviour preferences were reverted to default",
                      "5"
                    );
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon or an exception was encountered! " +
                        message,
                      "600"
                    );
                  },
                });
              }

              var myendpoint_URl =
                "/en-US/splunkd/__raw/services/trackme/v2/configuration/reset_vtenants_prefs";

              // Call the API endpoint
              deletePreferences(myendpoint_URl);
              //
            });

          // hide tenant from profile button
          $("#hide_tenant_confirmed")
            .unbind()
            .click(function () {
              $(this).blur();
              var tenant_id = defaultTokenModel.get("clickedTenantId");
              // call function
              hide_tenant(
                "OK! The tenant has been hiden successfully. This configuration is stored in your user profile, you can reset your user profile if you wish to revert this.",
                tenant_id
              );
            });

          // track click events
          $(".flex-items").dblclick(function () {
            window.location = $(this).attr("data-href");
            var item = $(this).attr("data-tenant");

            // set the open tenant link
            $("#open_tenant").attr(
              "href",
              encodeURI("trackMe_home?tenant_id=" + item)
            );

            // set the open SLA link
            $("#open_sla").attr(
              "href",
              encodeURI("trackMe_sla?form.tk_tenant_id=" + item)
            );

            // set tokens
            defaultTokenModel.unset("clickedTenantId");
            defaultTokenModel.unset("clickedTenantIdDsmEntities");
            defaultTokenModel.unset("clickedTenantIdCimEntities");
            defaultTokenModel.unset("clickedTenantIdFlxEntities");
            defaultTokenModel.unset("clickedTenantIdWlkEntities");
            defaultTokenModel.unset("clickedTenantIdDhmEntities");
            defaultTokenModel.unset("clickedTenantIdMhmEntities");
            defaultTokenModel.set("clickedTenantId", item);

            // for badges
            var clickedTenantDsmEnabled = $(this).attr(
              "data-tenant-dsm-enabled"
            );
            defaultTokenModel.set(
              "clickedTenantDsmEnabled",
              clickedTenantDsmEnabled
            );
            var clickedTenantCimEnabled = $(this).attr(
              "data-tenant-cim-enabled"
            );
            defaultTokenModel.set(
              "clickedTenantCimEnabled",
              clickedTenantCimEnabled
            );
            var clickedTenantFlxEnabled = $(this).attr(
              "data-tenant-flx-enabled"
            );
            defaultTokenModel.set(
              "clickedTenantFlxEnabled",
              clickedTenantFlxEnabled
            );
            var clickedTenantWlkEnabled = $(this).attr(
              "data-tenant-wlk-enabled"
            );
            defaultTokenModel.set(
              "clickedTenantWlkEnabled",
              clickedTenantWlkEnabled
            );
            var clickedTenantDhmEnabled = $(this).attr(
              "data-tenant-dhm-enabled"
            );
            defaultTokenModel.set(
              "clickedTenantDhmEnabled",
              clickedTenantDhmEnabled
            );
            var clickedTenantMhmEnabled = $(this).attr(
              "data-tenant-mhm-enabled"
            );
            defaultTokenModel.set(
              "clickedTenantMhmEnabled",
              clickedTenantMhmEnabled
            );

            // for RBAC update prefill
            var clickedTenantOwner = $(this).attr("data-tenant-owner");
            defaultTokenModel.set("clickedTenantOwner", clickedTenantOwner);

            // prefill dropdown input for RBAC updates (multiselect cannot be prefilled)
            defaultTokenModel.set("tk_update_tenant_owner", clickedTenantOwner);

            // set var
            var clickedTenantId = $(this).attr("data-tenant");
            var clickedTenantDescription = $(this).attr("data-tenant-desc");
            var tenantStatus = $(this).attr("data-tenant-status");

            // compose the object name conditionally
            var clickedObject;
            var notifyMsg;

            if (
              clickedTenantDescription == null ||
              typeof clickedTenantDescription == "undefined" ||
              clickedTenantDescription == "undefined"
            ) {
              clickedObject = clickedTenantId;
              notifyMsg =
                "ℹ️ Overview of the tenant id: " +
                clickedTenantId +
                " - Get tenant activity insights and manage its life cycle from this screen";
            } else {
              if (clickedTenantDescription.length > 1) {
                clickedObject =
                  clickedTenantId + " / " + clickedTenantDescription;
                notifyMsg =
                  "ℹ️ Overview of the tenant id: " +
                  clickedTenantId +
                  ", description: " +
                  clickedTenantDescription +
                  " - Get tenant activity insights and manage its life cycle from this screen";
              } else {
                clickedObject = clickedTenantId;
                notifyMsg =
                  "ℹ️ Overview of the tenant id: " +
                  clickedTenantId +
                  " - Get tenant activity insights and manage its life cycle from this screen";
              }
            }

            // Show message
            notify("info", "bottom", notifyMsg, "10");

            // create element for tenant overview
            $("#dynmodal").remove();
            $("#modal_tenant_overview_body").prepend(
              '<div id="dynmodal"><h1>Overview of the tenant: ' +
                clickedObject +
                "</h1>" +
                "</div>"
            );

            // badges
            $("#dynmodal").append(
              '<div style="margin-top: 20px;" id="badges">'
            );

            if (tenantStatus == "enabled") {
              if (clickedTenantDsmEnabled == 0) {
                $("#dynmodal").append(
                  '<span id="badge-dsm-component-status" style="margin-right: 10px;" class="badge badge-disabled">SPLK-DSM is disabled</span>'
                );
                $("#badge-dsm-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Data Source Monitoring component (DSM) was not enabled for this tenant, if you wish to enable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              } else {
                $("#dynmodal").append(
                  '<span id="badge-dsm-component-status" style="margin-right: 10px;" class="badge badge-enabled">SPLK-DSM is enabled</span>'
                );
                $("#badge-dsm-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Data Source Monitoring component (DSM) was activated for this tenant, if you wish to disable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              }

              if (clickedTenantCimEnabled == 0) {
                $("#dynmodal").append(
                  '<span id="badge-cim-component-status" style="margin-right: 10px;" class="badge badge-disabled">SPLK-CIM is disabled</span>'
                );
                $("#badge-cim-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Common Information Model Tracking component (SPLK-CIM) was not enabled for this tenant, if you wish to enable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              } else {
                $("#dynmodal").append(
                  '<span id="badge-cim-component-status" style="margin-right: 10px;" class="badge badge-enabled">SPLK-CIM is enabled</span>'
                );
                $("#badge-cim-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Common Information Model Tracking component (SPLK-CIM) was activated for this tenant, if you wish to disable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              }

              if (clickedTenantFlxEnabled == 0) {
                $("#dynmodal").append(
                  '<span id="badge-flx-component-status" style="margin-right: 10px;" class="badge badge-disabled">SPLK-FLX is disabled</span>'
                );
                $("#badge-flx-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Flex object Tracking component (SPLK-FLX) was not enabled for this tenant, if you wish to enable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              } else {
                $("#dynmodal").append(
                  '<span id="badge-flx-component-status" style="margin-right: 10px;" class="badge badge-enabled">SPLK-FLX is enabled</span>'
                );
                $("#badge-flx-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Flex Object Tracking component (SPLK-FLX) was activated for this tenant, if you wish to disable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              }

              if (clickedTenantWlkEnabled == 0) {
                $("#dynmodal").append(
                  '<span id="badge-wlk-component-status" style="margin-right: 10px;" class="badge badge-disabled">SPLK-WLK is disabled</span>'
                );
                $("#badge-wlk-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Splunk Workload component (SPLK-WLK) was not enabled for this tenant, if you wish to enable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              } else {
                $("#dynmodal").append(
                  '<span id="badge-wlk-component-status" style="margin-right: 10px;" class="badge badge-enabled">SPLK-WLK is enabled</span>'
                );
                $("#badge-wlk-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Splunk Workload component (SPLK-WLK) was activated for this tenant, if you wish to disable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              }

              if (clickedTenantDhmEnabled == 0) {
                $("#dynmodal").append(
                  '<span id="badge-dhm-component-status" style="margin-right: 10px;" class="badge badge-disabled">SPLK-DHM is disabled</span>'
                );
                $("#badge-dhm-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Data Host Monitoring component (DHM) was not enabled for this tenant, if you wish to enable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              } else {
                $("#dynmodal").append(
                  '<span id="badge-dhm-component-status" style="margin-right: 10px;" class="badge badge-enabled">SPLK-DHM is enabled</span>'
                );
                $("#badge-dhm-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Data Host Monitoring component (DHM) was activated for this tenant, if you wish to disable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              }

              if (clickedTenantMhmEnabled == 0) {
                $("#dynmodal").append(
                  '<span id="badge-mhm-component-status" style="margin-right: 10px;" class="badge badge-disabled">SPLK-MHM is disabled</span>'
                );
                $("#badge-mhm-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Metric Host Monitoring component (MHM) was not enabled for this tenant, if you wish to enable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              } else {
                $("#dynmodal").append(
                  '<span id="badge-mhm-component-status" style="margin-right: 10px;" class="badge badge-enabled">SPLK-MHM is enabled</span>'
                );
                $("#badge-mhm-component-status").on("mouseover", function () {
                  notify(
                    "info",
                    "bottom",
                    "ℹ️ The Metric Host Monitoring component (MHM) was activated for this tenant, if you wish to disable it, you need to delete and re-create the tenant",
                    "10"
                  );
                });
              }
            } else {
              $("#dynmodal").append(
                '<span id="badge-tenant-status" style="margin-right: 10px;" class="badge badge-disabled">Tenant is disabled</span>'
              );
              notify(
                "warning",
                "bottom",
                "WARN: This tenant is currently is disabled and therefore inactive, if you wish to do so you can re-enable the tenant in this screen",
                "10"
              );
            }

            // append links to the tenant indexes

            var searchIdxMetrics =
              "| mpreview `trackme_metrics_idx(" +
              clickedTenantId +
              ')` filter="tenant_id="' +
              clickedTenantId +
              '""';
            var searchIdxNotable =
              "search `trackme_notable_idx(" +
              clickedTenantId +
              ')` tenant_id="' +
              clickedTenantId +
              '"';
            var searchIdxAudit =
              "search `trackme_audit_idx(" +
              clickedTenantId +
              ')` tenant_id="' +
              clickedTenantId +
              '"';
            var searchIdxSummary =
              "search `trackme_idx(" +
              clickedTenantId +
              ')` tenant_id="' +
              clickedTenantId +
              '"';

            var divObject =
              '<div style="margin-top: 15px; margin-bottom: 80px; margin-left: 30px; margin-right: 30px;">' +
              '<div style="margin-right: 15px; float: right;"><a class="btn btn-outline-info" id="btn_search_metrics_idx" target="_blank" href="search?q=' +
              encodeURI(searchIdxMetrics) +
              '" role="button"><i class="bi bi-search text-primary"></i> Metrics index</a></div>' +
              '<div style="margin-right: 15px; float: right;"><a class="btn btn-outline-info" id="btn_search_notable_idx" target="_blank" href="search?q=' +
              encodeURI(searchIdxNotable) +
              '" role="button"><i class="bi bi-search text-primary"></i> Notable index</a></div>' +
              '<div style="margin-right: 15px; float: right;"><a class="btn btn-outline-info" id="btn_search_audit_idx" target="_blank" href="search?q=' +
              encodeURI(searchIdxAudit) +
              '" role="button"><i class="bi bi-search text-primary"></i> Audit index</a></div>' +
              '<div style="margin-right: 15px; float: right;"><a class="btn btn-outline-info" id="btn_search_summary_idx" target="_blank" href="search?q=' +
              encodeURI(searchIdxSummary) +
              '" role="button"><i class="bi bi-search text-primary"></i> Summary index</a></div>' +
              "</div>";

            $("#dynmodal").append(divObject);

            if (tenantStatus == "enabled") {
              $("#dynmodal").append("</div>");

              // DSM overview if enabled
              if (clickedTenantDsmEnabled == 1) {
                // Allow the search to start
                searchTenantOverviewDsm.startSearch();

                $("#dynmodal").append(
                  '<fieldset style="margin-top: 30px;"><legend class="legends legends-large">SPLK Data Source Monitoring (SPLK-DSM) component overview</legend></fieldset>'
                );

                $("#dynmodal").append(
                  '<div id="badges-dsm-container" style="height: 40px;"><div id="badges-dsm" style="margin-top:14px; height: 40px;">'
                );

                // Add loader
                $("#badges-dsm").append(
                  '<div id="badges-dsm-loader" class="lds-dual-ring"></div>'
                );

                // Wait for first variable from results and add info
                function waitForElement() {
                  // get all tokens
                  var clickedTenantIdDsmEntities = defaultTokenModel.get(
                    "clickedTenantIdDsmEntities"
                  );
                  var clickedTenantIdDsmEntitiesStatusGreen =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesStatusGreen"
                    );
                  var clickedTenantIdDsmEntitiesStatusRed =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesStatusRed"
                    );
                  var clickedTenantIdDsmEntitiesStatusOthers =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesStatusOthers"
                    );
                  var clickedTenantIdDsmEntitiesPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesPriorityLow"
                    );
                  var clickedTenantIdDsmEntitiesPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesPriorityMedium"
                    );
                  var clickedTenantIdDsmEntitiesPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesPriorityHigh"
                    );
                  var clickedTenantIdDsmEntitiesRedPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesRedPriorityLow"
                    );
                  var clickedTenantIdDsmEntitiesRedPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesRedPriorityMedium"
                    );
                  var clickedTenantIdDsmEntitiesRedPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdDsmEntitiesRedPriorityHigh"
                    );

                  // wait for first variable which indicates all results are available
                  if (typeof clickedTenantIdDsmEntities !== "undefined") {
                    // remove loader
                    $("#badges-dsm-loader").remove();
                    //
                    // Update DOM
                    //

                    // badge
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                        clickedTenantIdDsmEntities +
                        " entities</span>"
                    );
                    // over
                    $("#badge-dsm-entities").on("mouseover", function () {
                      if (clickedTenantIdDsmEntities == 0) {
                        notify(
                          "info",
                          "bottom",
                          "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                          "10"
                        );
                      } else {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'any'",
                          "dsm",
                          clickedTenantId,
                          "*",
                          "*"
                        );
                      }
                    });

                    // badge
                    if (clickedTenantIdDsmEntitiesStatusGreen > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                          clickedTenantIdDsmEntitiesStatusGreen +
                          " status green</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-status-green").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'green', 'priority': 'any'",
                          "dsm",
                          clickedTenantId,
                          "green",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesStatusRed > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDsmEntitiesStatusRed +
                          " status red</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-status-red").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'any'",
                          "dsm",
                          clickedTenantId,
                          "red",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesStatusOthers > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                          clickedTenantIdDsmEntitiesStatusOthers +
                          " status other</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-status-other").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'other', 'priority': 'any'",
                          "dsm",
                          clickedTenantId,
                          "other",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesPriorityLow > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                          clickedTenantIdDsmEntitiesPriorityLow +
                          " low priority</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-priority-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'low'",
                          "dsm",
                          clickedTenantId,
                          "*",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesPriorityMedium > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                          clickedTenantIdDsmEntitiesPriorityMedium +
                          " medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-priority-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'medium'",
                          "dsm",
                          clickedTenantId,
                          "*",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesPriorityHigh > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                          clickedTenantIdDsmEntitiesPriorityHigh +
                          " high priority</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-priority-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'high'",
                          "dsm",
                          clickedTenantId,
                          "*",
                          "high"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesRedPriorityLow > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDsmEntitiesRedPriorityLow +
                          " red low priority</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-priority-red-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'low'",
                          "dsm",
                          clickedTenantId,
                          "red",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesRedPriorityMedium > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDsmEntitiesRedPriorityMedium +
                          " red medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-priority-red-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: medium",
                          "dsm",
                          clickedTenantId,
                          "red",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDsmEntitiesRedPriorityHigh > 0) {
                      $("#badges-dsm").append(
                        '<span id="badge-dsm-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDsmEntitiesRedPriorityHigh +
                          " red high priority</span>"
                      );
                    }
                    // over
                    $("#badge-dsm-entities-priority-red-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: high",
                          "dsm",
                          clickedTenantId,
                          "red",
                          "high"
                        );
                      }
                    );

                    //variable exists, do what you want
                  } else {
                    setTimeout(waitForElement, 250);
                  }
                }

                // call the function
                waitForElement();

                // close the div
                $("#badges-dsm").append("</div>");
              }

              // CIM overview if enabled
              if (clickedTenantCimEnabled == 1) {
                // Allow the search to start
                searchTenantOverviewCim.startSearch();

                $("#dynmodal").append(
                  '<fieldset style="margin-top: 30px;"><legend class="legends legends-large">SPLK Common Information Model Tracking (SPLK-CIM) component overview</legend></fieldset>'
                );

                $("#dynmodal").append(
                  '<div id="badges-cim-container" style="height: 40px;"><div id="badges-cim" style="margin-top:14px; height: 40px;">'
                );

                // Add loader
                $("#badges-cim").append(
                  '<div id="badges-cim-loader" class="lds-dual-ring"></div>'
                );

                // Wait for first variable from results and add info
                function waitForElement() {
                  // get all tokens
                  var clickedTenantIdCimEntities = defaultTokenModel.get(
                    "clickedTenantIdCimEntities"
                  );
                  var clickedTenantIdCimEntitiesStatusGreen =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesStatusGreen"
                    );
                  var clickedTenantIdCimEntitiesStatusRed =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesStatusRed"
                    );
                  var clickedTenantIdCimEntitiesStatusOthers =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesStatusOthers"
                    );
                  var clickedTenantIdCimEntitiesPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesPriorityLow"
                    );
                  var clickedTenantIdCimEntitiesPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesPriorityMedium"
                    );
                  var clickedTenantIdCimEntitiesPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesPriorityHigh"
                    );
                  var clickedTenantIdCimEntitiesRedPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesRedPriorityLow"
                    );
                  var clickedTenantIdCimEntitiesRedPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesRedPriorityMedium"
                    );
                  var clickedTenantIdCimEntitiesRedPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdCimEntitiesRedPriorityHigh"
                    );

                  // wait for first variable which indicates all results are available
                  if (typeof clickedTenantIdCimEntities !== "undefined") {
                    // remove loader
                    $("#badges-cim-loader").remove();
                    //
                    // Update DOM
                    //

                    // badge
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                        clickedTenantIdCimEntities +
                        " entities</span>"
                    );
                    // over
                    $("#badge-cim-entities").on("mouseover", function () {
                      if (clickedTenantIdCimEntities == 0) {
                        notify(
                          "info",
                          "bottom",
                          "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                          "10"
                        );
                      } else {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'any'",
                          "cim",
                          clickedTenantId,
                          "*",
                          "*"
                        );
                      }
                    });

                    // badge
                    if (clickedTenantIdCimEntitiesStatusGreen > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                          clickedTenantIdCimEntitiesStatusGreen +
                          " status green</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-status-green").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'green', 'priority': 'any'",
                          "cim",
                          clickedTenantId,
                          "green",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesStatusRed > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdCimEntitiesStatusRed +
                          " status red</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-status-red").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'any'",
                          "cim",
                          clickedTenantId,
                          "red",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesStatusOthers > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                          clickedTenantIdCimEntitiesStatusOthers +
                          " status other</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-status-other").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'other', 'priority': 'any'",
                          "cim",
                          clickedTenantId,
                          "other",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesPriorityLow > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                          clickedTenantIdCimEntitiesPriorityLow +
                          " low priority</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-priority-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'low'",
                          "cim",
                          clickedTenantId,
                          "*",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesPriorityMedium > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                          clickedTenantIdCimEntitiesPriorityMedium +
                          " medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-priority-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'medium'",
                          "cim",
                          clickedTenantId,
                          "*",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesPriorityHigh > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                          clickedTenantIdCimEntitiesPriorityHigh +
                          " high priority</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-priority-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'high'",
                          "cim",
                          clickedTenantId,
                          "*",
                          "high"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesRedPriorityLow > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdCimEntitiesRedPriorityLow +
                          " red low priority</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-priority-red-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'low'",
                          "cim",
                          clickedTenantId,
                          "red",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesRedPriorityMedium > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdCimEntitiesRedPriorityMedium +
                          " red medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-priority-red-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: medium",
                          "cim",
                          clickedTenantId,
                          "red",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdCimEntitiesRedPriorityHigh > 0) {
                      $("#badges-cim").append(
                        '<span id="badge-cim-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdCimEntitiesRedPriorityHigh +
                          " red high priority</span>"
                      );
                    }
                    // over
                    $("#badge-cim-entities-priority-red-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: high",
                          "cim",
                          clickedTenantId,
                          "red",
                          "high"
                        );
                      }
                    );

                    //variable exists, do what you want
                  } else {
                    setTimeout(waitForElement, 250);
                  }
                }

                // call the function
                waitForElement();

                // close the div
                $("#badges-cim").append("</div>");
              }

              // FLX overview if enabled
              if (clickedTenantFlxEnabled == 1) {
                // Allow the search to start
                searchTenantOverviewFlx.startSearch();

                $("#dynmodal").append(
                  '<fieldset style="margin-top: 30px;"><legend class="legends legends-large">SPLK Flex Objects Tracking (SPLK-FLX) component overview</legend></fieldset>'
                );

                $("#dynmodal").append(
                  '<div id="badges-flx-container" style="height: 40px;"><div id="badges-flx" style="margin-top:14px; height: 40px;">'
                );

                // Add loader
                $("#badges-flx").append(
                  '<div id="badges-flx-loader" class="lds-dual-ring"></div>'
                );

                // Wait for first variable from results and add info
                function waitForElement() {
                  // get all tokens
                  var clickedTenantIdFlxEntities = defaultTokenModel.get(
                    "clickedTenantIdFlxEntities"
                  );
                  var clickedTenantIdFlxEntitiesStatusGreen =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesStatusGreen"
                    );
                  var clickedTenantIdFlxEntitiesStatusRed =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesStatusRed"
                    );
                  var clickedTenantIdFlxEntitiesStatusOthers =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesStatusOthers"
                    );
                  var clickedTenantIdFlxEntitiesPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesPriorityLow"
                    );
                  var clickedTenantIdFlxEntitiesPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesPriorityMedium"
                    );
                  var clickedTenantIdFlxEntitiesPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesPriorityHigh"
                    );
                  var clickedTenantIdFlxEntitiesRedPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesRedPriorityLow"
                    );
                  var clickedTenantIdFlxEntitiesRedPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesRedPriorityMedium"
                    );
                  var clickedTenantIdFlxEntitiesRedPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdFlxEntitiesRedPriorityHigh"
                    );

                  // wait for first variable which indicates all results are available
                  if (typeof clickedTenantIdFlxEntities !== "undefined") {
                    // remove loader
                    $("#badges-flx-loader").remove();
                    //
                    // Update DOM
                    //

                    // badge
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                        clickedTenantIdFlxEntities +
                        " entities</span>"
                    );
                    // over
                    $("#badge-flx-entities").on("mouseover", function () {
                      if (clickedTenantIdFlxEntities == 0) {
                        notify(
                          "info",
                          "bottom",
                          "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                          "10"
                        );
                      } else {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'any'",
                          "flx",
                          clickedTenantId,
                          "*",
                          "*"
                        );
                      }
                    });

                    // badge
                    if (clickedTenantIdFlxEntitiesStatusGreen > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                          clickedTenantIdFlxEntitiesStatusGreen +
                          " status green</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-status-green").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'green', 'priority': 'any'",
                          "flx",
                          clickedTenantId,
                          "green",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesStatusRed > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdFlxEntitiesStatusRed +
                          " status red</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-status-red").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'any'",
                          "flx",
                          clickedTenantId,
                          "red",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesStatusOthers > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                          clickedTenantIdFlxEntitiesStatusOthers +
                          " status other</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-status-other").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'other', 'priority': 'any'",
                          "flx",
                          clickedTenantId,
                          "other",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesPriorityLow > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                          clickedTenantIdFlxEntitiesPriorityLow +
                          " low priority</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-priority-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'low'",
                          "flx",
                          clickedTenantId,
                          "*",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesPriorityMedium > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                          clickedTenantIdFlxEntitiesPriorityMedium +
                          " medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-priority-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'medium'",
                          "flx",
                          clickedTenantId,
                          "*",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesPriorityHigh > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                          clickedTenantIdFlxEntitiesPriorityHigh +
                          " high priority</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-priority-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'high'",
                          "flx",
                          clickedTenantId,
                          "*",
                          "high"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesRedPriorityLow > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdFlxEntitiesRedPriorityLow +
                          " red low priority</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-priority-red-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'low'",
                          "flx",
                          clickedTenantId,
                          "red",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesRedPriorityMedium > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdFlxEntitiesRedPriorityMedium +
                          " red medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-priority-red-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: medium",
                          "flx",
                          clickedTenantId,
                          "red",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdFlxEntitiesRedPriorityHigh > 0) {
                      $("#badges-flx").append(
                        '<span id="badge-flx-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdFlxEntitiesRedPriorityHigh +
                          " red high priority</span>"
                      );
                    }
                    // over
                    $("#badge-flx-entities-priority-red-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: high",
                          "flx",
                          clickedTenantId,
                          "red",
                          "high"
                        );
                      }
                    );

                    //variable exists, do what you want
                  } else {
                    setTimeout(waitForElement, 250);
                  }
                }

                // call the function
                waitForElement();

                // close the div
                $("#badges-flx").append("</div>");
              }

              // FLX overview if enabled
              if (clickedTenantWlkEnabled == 1) {
                // Allow the search to start
                searchTenantOverviewWlk.startSearch();

                $("#dynmodal").append(
                  '<fieldset style="margin-top: 30px;"><legend class="legends legends-large">SPLK Splunk Workload (SPLK-WLK) component overview</legend></fieldset>'
                );

                $("#dynmodal").append(
                  '<div id="badges-wlk-container" style="height: 40px;"><div id="badges-wlk" style="margin-top:14px; height: 40px;">'
                );

                // Add loader
                $("#badges-wlk").append(
                  '<div id="badges-wlk-loader" class="lds-dual-ring"></div>'
                );

                // Wait for first variable from results and add info
                function waitForElement() {
                  // get all tokens
                  var clickedTenantIdWlkEntities = defaultTokenModel.get(
                    "clickedTenantIdWlkEntities"
                  );
                  var clickedTenantIdWlkEntitiesStatusGreen =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesStatusGreen"
                    );
                  var clickedTenantIdWlkEntitiesStatusRed =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesStatusRed"
                    );
                  var clickedTenantIdWlkEntitiesStatusOthers =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesStatusOthers"
                    );
                  var clickedTenantIdWlkEntitiesPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesPriorityLow"
                    );
                  var clickedTenantIdWlkEntitiesPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesPriorityMedium"
                    );
                  var clickedTenantIdWlkEntitiesPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesPriorityHigh"
                    );
                  var clickedTenantIdWlkEntitiesRedPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesRedPriorityLow"
                    );
                  var clickedTenantIdWlkEntitiesRedPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesRedPriorityMedium"
                    );
                  var clickedTenantIdWlkEntitiesRedPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdWlkEntitiesRedPriorityHigh"
                    );

                  // wait for first variable which indicates all results are available
                  if (typeof clickedTenantIdWlkEntities !== "undefined") {
                    // remove loader
                    $("#badges-wlk-loader").remove();
                    //
                    // Update DOM
                    //

                    // badge
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                        clickedTenantIdWlkEntities +
                        " entities</span>"
                    );
                    // over
                    $("#badge-wlk-entities").on("mouseover", function () {
                      if (clickedTenantIdWlkEntities == 0) {
                        notify(
                          "info",
                          "bottom",
                          "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                          "10"
                        );
                      } else {
                        get_entities_summary_wlk(
                          "'status': 'any', 'priority': 'any'",
                          "wlk",
                          clickedTenantId,
                          "*",
                          "*"
                        );
                      }
                    });

                    // badge
                    if (clickedTenantIdWlkEntitiesStatusGreen > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                          clickedTenantIdWlkEntitiesStatusGreen +
                          " status green</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-status-green").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "'status': 'green', 'priority': 'any'",
                          "wlk",
                          clickedTenantId,
                          "green",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesStatusRed > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdWlkEntitiesStatusRed +
                          " status red</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-status-red").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "'status': 'red', 'priority': 'any'",
                          "wlk",
                          clickedTenantId,
                          "red",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesStatusOthers > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                          clickedTenantIdWlkEntitiesStatusOthers +
                          " status other</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-status-other").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "'status': 'other', 'priority': 'any'",
                          "wlk",
                          clickedTenantId,
                          "other",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesPriorityLow > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                          clickedTenantIdWlkEntitiesPriorityLow +
                          " low priority</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-priority-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "'status': 'any', 'priority': 'low'",
                          "wlk",
                          clickedTenantId,
                          "*",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesPriorityMedium > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                          clickedTenantIdWlkEntitiesPriorityMedium +
                          " medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-priority-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "'status': 'any', 'priority': 'medium'",
                          "wlk",
                          clickedTenantId,
                          "*",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesPriorityHigh > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                          clickedTenantIdWlkEntitiesPriorityHigh +
                          " high priority</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-priority-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "'status': 'any', 'priority': 'high'",
                          "wlk",
                          clickedTenantId,
                          "*",
                          "high"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesRedPriorityLow > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdWlkEntitiesRedPriorityLow +
                          " red low priority</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-priority-red-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "'status': 'red', 'priority': 'low'",
                          "wlk",
                          clickedTenantId,
                          "red",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesRedPriorityMedium > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdWlkEntitiesRedPriorityMedium +
                          " red medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-priority-red-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "status: red, priority: medium",
                          "wlk",
                          clickedTenantId,
                          "red",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdWlkEntitiesRedPriorityHigh > 0) {
                      $("#badges-wlk").append(
                        '<span id="badge-wlk-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdWlkEntitiesRedPriorityHigh +
                          " red high priority</span>"
                      );
                    }
                    // over
                    $("#badge-wlk-entities-priority-red-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary_wlk(
                          "status: red, priority: high",
                          "wlk",
                          clickedTenantId,
                          "red",
                          "high"
                        );
                      }
                    );

                    //variable exists, do what you want
                  } else {
                    setTimeout(waitForElement, 250);
                  }
                }

                // call the function
                waitForElement();

                // close the div
                $("#badges-wlk").append("</div>");
              }

              // DHM overview if enabled
              if (clickedTenantDhmEnabled == 1) {
                // Allow the search to start
                searchTenantOverviewDhm.startSearch();

                $("#dynmodal").append(
                  '<fieldset style="margin-top: 30px;"><legend class="legends legends-large">SPLK Event Endpoint Monitoring (SPLK-DHM) component overview</legend></fieldset>'
                );

                $("#dynmodal").append(
                  '<div id="badges-dhm-container" style="height: 40px;"><div id="badges-dhm" style="margin-top:14px; height: 40px;">'
                );

                // Add loader
                $("#badges-dhm").append(
                  '<div id="badges-dhm-loader" class="lds-dual-ring"></div>'
                );

                // Wait for first variable from results and add info
                function waitForElement() {
                  // get all tokens
                  var clickedTenantIdDhmEntities = defaultTokenModel.get(
                    "clickedTenantIdDhmEntities"
                  );
                  var clickedTenantIdDhmEntitiesStatusGreen =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesStatusGreen"
                    );
                  var clickedTenantIdDhmEntitiesStatusRed =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesStatusRed"
                    );
                  var clickedTenantIdDhmEntitiesStatusOthers =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesStatusOthers"
                    );
                  var clickedTenantIdDhmEntitiesPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesPriorityLow"
                    );
                  var clickedTenantIdDhmEntitiesPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesPriorityMedium"
                    );
                  var clickedTenantIdDhmEntitiesPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesPriorityHigh"
                    );
                  var clickedTenantIdDhmEntitiesRedPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesRedPriorityLow"
                    );
                  var clickedTenantIdDhmEntitiesRedPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesRedPriorityMedium"
                    );
                  var clickedTenantIdDhmEntitiesRedPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdDhmEntitiesRedPriorityHigh"
                    );

                  // wait for first variable which indicates all results are available
                  if (typeof clickedTenantIdDhmEntities !== "undefined") {
                    // remove loader
                    $("#badges-dhm-loader").remove();
                    // Update DOM

                    // badge
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                        clickedTenantIdDhmEntities +
                        " entities</span>"
                    );
                    // over
                    $("#badge-dhm-entities").on("mouseover", function () {
                      if (clickedTenantIdDhmEntities == 0) {
                        notify(
                          "info",
                          "bottom",
                          "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                          "10"
                        );
                      } else {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'any'",
                          "dhm",
                          clickedTenantId,
                          "*",
                          "*"
                        );
                      }
                    });

                    // badge
                    if (clickedTenantIdDhmEntitiesStatusGreen > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                          clickedTenantIdDhmEntitiesStatusGreen +
                          " status green</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-status-green").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'green', 'priority': 'any'",
                          "dhm",
                          clickedTenantId,
                          "green",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesStatusRed > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDhmEntitiesStatusRed +
                          " status red</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-status-red").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'any'",
                          "dhm",
                          clickedTenantId,
                          "red",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesStatusOthers > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                          clickedTenantIdDhmEntitiesStatusOthers +
                          " status other</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-status-other").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'other', 'priority': 'any'",
                          "dhm",
                          clickedTenantId,
                          "other",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesPriorityLow > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                          clickedTenantIdDhmEntitiesPriorityLow +
                          " low priority</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-priority-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'low'",
                          "dhm",
                          clickedTenantId,
                          "*",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesPriorityMedium > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                          clickedTenantIdDhmEntitiesPriorityMedium +
                          " medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-priority-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'medium'",
                          "dhm",
                          clickedTenantId,
                          "*",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesPriorityHigh > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                          clickedTenantIdDhmEntitiesPriorityHigh +
                          " high priority</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-priority-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'high'",
                          "dhm",
                          clickedTenantId,
                          "*",
                          "high"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesRedPriorityLow > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDhmEntitiesRedPriorityLow +
                          " red low priority</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-priority-red-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'low'",
                          "dhm",
                          clickedTenantId,
                          "red",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesRedPriorityMedium > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDhmEntitiesRedPriorityMedium +
                          " red medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-priority-red-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: medium",
                          "dhm",
                          clickedTenantId,
                          "red",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdDhmEntitiesRedPriorityHigh > 0) {
                      $("#badges-dhm").append(
                        '<span id="badge-dhm-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdDhmEntitiesRedPriorityHigh +
                          " red high priority</span>"
                      );
                    }
                    // over
                    $("#badge-dhm-entities-priority-red-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: high",
                          "dhm",
                          clickedTenantId,
                          "red",
                          "high"
                        );
                      }
                    );

                    //variable exists, do what you want
                  } else {
                    setTimeout(waitForElement, 250);
                  }
                }

                // call the function
                waitForElement();

                // close the div
                $("#badges-dhm").append("</div>");
              }

              // DHM overview if enabled
              if (clickedTenantMhmEnabled == 1) {
                // Allow the search to start
                searchTenantOverviewMhm.startSearch();

                $("#dynmodal").append(
                  '<fieldset style="margin-top: 30px;"><legend class="legends legends-large">SPLK Metric Endpoint Monitoring (SPLK-MHM) component overview</legend></fieldset>'
                );

                $("#dynmodal").append(
                  '<div id="badges-mhm-container" style="height: 40px;"><div id="badges-mhm" style="margin-top:14px; height: 40px;">'
                );

                // Add loader
                $("#badges-mhm").append(
                  '<div id="badges-mhm-loader" class="lds-dual-ring"></div>'
                );

                // Wait for first variable from results and add info
                function waitForElement() {
                  // get all tokens
                  var clickedTenantIdMhmEntities = defaultTokenModel.get(
                    "clickedTenantIdMhmEntities"
                  );
                  var clickedTenantIdMhmEntitiesStatusGreen =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesStatusGreen"
                    );
                  var clickedTenantIdMhmEntitiesStatusRed =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesStatusRed"
                    );
                  var clickedTenantIdMhmEntitiesStatusOthers =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesStatusOthers"
                    );
                  var clickedTenantIdMhmEntitiesPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesPriorityLow"
                    );
                  var clickedTenantIdMhmEntitiesPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesPriorityMedium"
                    );
                  var clickedTenantIdMhmEntitiesPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesPriorityHigh"
                    );
                  var clickedTenantIdMhmEntitiesRedPriorityLow =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesRedPriorityLow"
                    );
                  var clickedTenantIdMhmEntitiesRedPriorityMedium =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesRedPriorityMedium"
                    );
                  var clickedTenantIdMhmEntitiesRedPriorityHigh =
                    defaultTokenModel.get(
                      "clickedTenantIdMhmEntitiesRedPriorityHigh"
                    );

                  // wait for first variable which indicates all results are available
                  if (typeof clickedTenantIdMhmEntities !== "undefined") {
                    // remove loader
                    $("#badges-mhm-loader").remove();
                    // Update DOM

                    // badge
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                        clickedTenantIdMhmEntities +
                        " entities</span>"
                    );
                    // over
                    $("#badge-mhm-entities").on("mouseover", function () {
                      if (clickedTenantIdMhmEntities == 0) {
                        notify(
                          "info",
                          "bottom",
                          "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                          "10"
                        );
                      } else {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'any'",
                          "mhm",
                          clickedTenantId,
                          "*",
                          "*"
                        );
                      }
                    });

                    // badge
                    if (clickedTenantIdMhmEntitiesStatusGreen > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                          clickedTenantIdMhmEntitiesStatusGreen +
                          " status green</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-status-green").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'green', 'priority': 'any'",
                          "mhm",
                          clickedTenantId,
                          "green",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesStatusRed > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdMhmEntitiesStatusRed +
                          " status red</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-status-red").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'any'",
                          "mhm",
                          clickedTenantId,
                          "red",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesStatusOthers > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                          clickedTenantIdMhmEntitiesStatusOthers +
                          " status other</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-status-other").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'other', 'priority': 'any'",
                          "mhm",
                          clickedTenantId,
                          "other",
                          "*"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesPriorityLow > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                          clickedTenantIdMhmEntitiesPriorityLow +
                          " low priority</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-priority-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'low'",
                          "mhm",
                          clickedTenantId,
                          "*",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesPriorityMedium > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                          clickedTenantIdMhmEntitiesPriorityMedium +
                          " medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-priority-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'medium'",
                          "mhm",
                          clickedTenantId,
                          "*",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesPriorityHigh > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                          clickedTenantIdMhmEntitiesPriorityHigh +
                          " high priority</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-priority-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'any', 'priority': 'high'",
                          "mhm",
                          clickedTenantId,
                          "*",
                          "high"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesRedPriorityLow > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdMhmEntitiesRedPriorityLow +
                          " red low priority</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-priority-red-low").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "'status': 'red', 'priority': 'low'",
                          "mhm",
                          clickedTenantId,
                          "red",
                          "low"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesRedPriorityMedium > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdMhmEntitiesRedPriorityMedium +
                          " red medium priority</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-priority-red-medium").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: medium",
                          "mhm",
                          clickedTenantId,
                          "red",
                          "medium"
                        );
                      }
                    );

                    // badge
                    if (clickedTenantIdMhmEntitiesRedPriorityHigh > 0) {
                      $("#badges-mhm").append(
                        '<span id="badge-mhm-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                          clickedTenantIdMhmEntitiesRedPriorityHigh +
                          " red high priority</span>"
                      );
                    }
                    // over
                    $("#badge-mhm-entities-priority-red-high").on(
                      "mouseover",
                      function () {
                        get_entities_summary(
                          "status: red, priority: high",
                          "mhm",
                          clickedTenantId,
                          "red",
                          "high"
                        );
                      }
                    );

                    //variable exists, do what you want
                  } else {
                    setTimeout(waitForElement, 250);
                  }
                }

                // call the function
                waitForElement();

                // close the div
                $("#badges-mhm").append("</div>");
              }
            }

            // create element for tenant mgmt
            $("#dynmodal2").remove();
            $("#modal_tenant_mgmt_body").prepend(
              '<div id="dynmodal2"><h1>Management of the tenant: ' +
                clickedTenantId +
                "</h1>" +
                "</div>"
            );

            // dynamically create the enable / disable button
            if (tenantStatus == "enabled") {
              $("#div_enable_tenant").hide();
              $("#div_disable_tenant").show();
            } else if (tenantStatus == "disabled") {
              $("#div_disable_tenant").hide();
              $("#div_enable_tenant").show();
            }

            // disable various privileged accesses if the connected user is not a TrackMe admin
            if (getToken("userLevel") != "admin") {
              $("#update_tenant").prop("disabled", false);
              $("#update_tenant").css("display", "none");

              $("#rbac_tenant").prop("disabled", false);
              $("#rbac_tenant").css("display", "none");

              $("#enable_tenant").prop("disabled", false);
              $("#enable_tenant").css("display", "none");

              $("#disable_tenant").prop("disabled", false);
              $("#disable_tenant").css("display", "none");

              $("#delete_tenant").prop("disabled", false);
              $("#delete_tenant").css("display", "none");

              $("#tenant_mgmt_child").html(
                "<h2>As a TrackMe user, you can access to the Virtual Tenants, as well as accessing to the knowledge objects related to this Virtual Tenant:</h2><lu><li><b>Show knowledge objects:</b> review in read only all Splunk knowledge objecs composing the TrackMe tenant</li></lu>"
              );
            }

            // show overview modal
            $("#modal_tenant_overview").modal();

            return false;
          });
        }

        // Call now
        genTenantsElements(
          tenantsJson,
          userPrefs,
          userPositionPrefs,
          "true",
          "true"
        );

        // For refresh and dynamic changes purposes
        function getTenantsList(showMessage, removeSpinner) {
          // any existing, add a loader
          $(".flex-items").each(function () {
            $(this).html(
              '<div id="badges-tenant-count-loader" class="lds-dual-ring" style="margin-left: 47%; height: 156px; min-height: 156px; max-height: 156px;"></div>'
            );
          });

          var doAsync = asyncAjax(
            "/en-US/splunkd/__raw/services/trackme/v2/vtenants/trackmeload",
            "POST",
            { mode: "full" }
          ).then(function (resultCall) {
            // Tenants JSON
            var tenantsJson = resultCall["tenants_json"];

            // Position
            var userPositionPrefs = resultCall["position_prefs"];

            // theme preferences
            var show_tenants_mgmt_header =
              resultCall["show_tenants_mgmt_header"];
            var flex_width_default = resultCall["flex_width_default"];
            var flex_show_desc = resultCall["flex_show_desc"];
            var flex_show_summary = resultCall["flex_show_summary"];
            var colorTheme = resultCall["colorTheme"];
            var colorThemeAlert = resultCall["colorThemeAlert"];
            var dynTheme = resultCall["dynTheme"];
            var dynThemeCondition = resultCall["dynThemeCondition"];

            var userPrefs = {
              show_tenants_mgmt_header: show_tenants_mgmt_header,
              flex_width_default: flex_width_default,
              flex_show_desc: flex_show_desc,
              flex_show_summary: flex_show_summary,
              colorTheme: colorTheme,
              colorThemeAlert: colorThemeAlert,
              dynTheme: dynTheme,
              dynThemeCondition: dynThemeCondition,
            };

            // Call now
            genTenantsElements(
              tenantsJson,
              userPrefs,
              userPositionPrefs,
              showMessage,
              "false"
            );
          });
        }

        //
        // Check licensing status
        //
        var doAsync = asyncAjax(
          "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
          "GET"
        ).then(function (licenseCall) {
          var license_is_valid = licenseCall["license_is_valid"];
          var licenseSubscriptionClass =
            licenseCall["license_subscription_class"];
          var licenseLabel;
          if (license_is_valid == 1) {
            if (licenseCall["license_type"] === "subscription") {
              if (licenseSubscriptionClass === "unlimited") {
                licenseLabel = "Unlimited";
              } else if (licenseSubscriptionClass === "enterprise") {
                licenseLabel = "Enterprise";
              } else if (licenseSubscriptionClass === "free_extended") {
                licenseLabel = "Free extended";
              }
              $("#licenseInfo").append("<p>" + licenseLabel + " edition</p>");
            } else if (licenseCall["license_type"] === "trial") {
              $("#licenseInfo").append("<p>Trial registered edition</p>");
            } else if (licenseCall["license_type"] === "developer") {
              $("#licenseInfo").append("<p>Developer mode</p>");
            }
          } else {
            $("#licenseInfo").append("<p>Free limited edition</p>");
          }

          // get the number of active tenants
          var license_active_tenants = licenseCall["license_active_tenants"];

          //
          // Proceed
          //

          // semicircle donut custom viz
          var semiCircleDonut = VisualizationRegistry.getVisualizer(
            "semicircle_donut",
            "semicircle_donut"
          );

          // syntax highlighting for JSON
          function syntaxHighlight(json) {
            json = json
              .replace(/&/g, "&amp;")
              .replace(/</g, "&lt;")
              .replace(/>/g, "&gt;");
            return json.replace(
              /("(\\u[a-zA-Z0-9]{4}|\\[^u]|[^\\"])*"(\s*:)?|\b(true|false|null)\b|-?\d+(?:\.\d*)?(?:[eE][+\-]?\d+)?)/g,
              function (match) {
                var cls = "json-preview-number";
                if (/^"/.test(match)) {
                  if (/:$/.test(match)) {
                    cls = "json-preview-key";
                  } else {
                    cls = "json-preview-string";
                  }
                } else if (/true|false/.test(match)) {
                  cls = "json-preview-boolean";
                } else if (/null/.test(match)) {
                  cls = "json-preview-null";
                }
                return '<span class="' + cls + '">' + match + "</span>";
              }
            );
          }

          //
          // function to check the remote connectivity
          //

          // check the remote account connectivity
          function checkSplkFeedsRemoteAccount(component, account) {
            // Set the element ids
            if (component === "dsm") {
              parentDiv = "divParentCreateDsmHybridValidateRemoteConnectivity";
              spinnerDiv = "divCreateDsmHybridValidateRemoteConnectivityLoader";
              childDiv = "divCreateDsmHybridValidateRemoteConnectivity";
            } else if (component === "dhm") {
              parentDiv = "divParentCreateDhmHybridValidateRemoteConnectivity";
              spinnerDiv = "divCreateDhmHybridValidateRemoteConnectivityLoader";
              childDiv = "divCreateDhmHybridValidateRemoteConnectivity";
            } else if (component === "mhm") {
              parentDiv = "divParentCreateMhmHybridValidateRemoteConnectivity";
              spinnerDiv = "divCreateMhmHybridValidateRemoteConnectivityLoader";
              childDiv = "divCreateMhmHybridValidateRemoteConnectivity";
            } else if (component === "wlk") {
              parentDiv = "divParentCreateWlkHybridValidateRemoteConnectivity";
              spinnerDiv = "divCreateWlkHybridValidateRemoteConnectivityLoader";
              childDiv = "divCreateWlkHybridValidateRemoteConnectivity";
            }

            // notify
            notify(
              "info",
              "bottom",
              "Please wait while we verify the connectivity and authentication to the remote Splunk deployment, this can take a few minutes if the target cannot be reached, hold on...",
              "150"
            );
            // Show the parent
            $("#" + parentDiv).css("display", "inherit");
            // Show the spinner
            $("#" + spinnerDiv).css("display", "inherit");
            // hide the result viewer
            $("#" + childDiv).css("display", "none");

            // Create the endpoint URL
            var myendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/configuration/test_remote_account";

            // Create a dictionary to store the field names and values
            var record = {
              account: account,
            };

            $.ajax({
              url: myendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              dataType: "json",
              data: JSON.stringify(record),
              success: function (returneddata) {
                // hide
                $("#" + spinnerDiv).css("display", "none");
                // notify
                notify(
                  "success",
                  "bottom",
                  "Successfully passed the connectivity check to the remote Splunk deployment.",
                  "5"
                );
                // show
                // creation via template
                $("#" + childDiv).html(
                  '<pre class="create-cim-json-rules-preview">' +
                    syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
                    "</pre>"
                );
                $("#" + childDiv).css("display", "inherit");
              },
              error: function (xhr, textStatus, error) {
                // hide
                $("#" + spinnerDiv).css("display", "none");
                // notify
                notify(
                  "error",
                  "bottom",
                  "Failed to verify the connectivity to the Splunk remote deployment.",
                  "5"
                );
                // creation via template
                $("#" + childDiv).html(
                  '<pre class="create-cim-json-rules-preview">' +
                    syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                    "</pre>"
                );
                $("#" + childDiv).css("display", "inherit");
              },
            });
          }

          //
          // get default theme - This is used as a fallback if something goes wrong when refreshing the cards
          //

          // ajax promise for default UI theme settings
          async function doAjaxSetThemeDefault(ajaxurl) {
            var defaultSettings;

            try {
              defaultSettings = await $.ajax({
                url: ajaxurl,
                type: "GET",
              });
              // return defaultSettings
              return defaultSettings;
            } catch (error) {
              defaultSettings = {
                show_tenants_mgmt_header: "1",
                flex_width_default: "374",
                flex_show_desc: "1",
                flex_show_summary: "1",
                colorTheme: "dodgerblue",
                colorThemeAlert: "brown",
                dynTheme: "true",
                dynThemeCondition: "any",
              };
              return defaultSettings;
            }
          }

          doAjaxSetThemeDefault(
            "/en-US/splunkd/__raw/services/trackme/v2/configuration/trackme_theme_settings"
          ).then(function (defaultSettings) {
            show_tenants_mgmt_header =
              defaultSettings["show_tenants_mgmt_header"];
            setToken("show_tenants_mgmt_header", show_tenants_mgmt_header);
            flex_width_default = defaultSettings["flex_width_default"];
            setToken("flex_width_default", flex_width_default);
            flex_show_desc = defaultSettings["flex_show_desc"];
            setToken("flex_show_desc", flex_show_desc);
            flex_show_summary = defaultSettings["flex_show_summary"];
            setToken("flex_show_summary", flex_show_summary);
            colorTheme = defaultSettings["color_theme_default"];
            setToken("defaultColorTheme", colorTheme);
            colorThemeAlert = defaultSettings["color_theme_red_default"];
            setToken("defaultColorThemeAlert", colorThemeAlert);
            dynTheme = defaultSettings["color_dyn_default"];
            if (dynTheme == "false") {
              dynTheme = "0";
            } else if (dynTheme == "true") {
              dynTheme = "1";
            }
            setToken("defaultDynTheme", dynTheme);
            dynThemeCondition = defaultSettings["color_dyn_condition"];
            setToken("defaultDynThemeCondition", dynThemeCondition);
          });

          //
          // Copy to clipboard
          //

          function copyToClipboard(content) {
            // Copy the text inside the text field
            navigator.clipboard.writeText(content);
            notify("success", "bottom", "Copy to clipboard done!", "5");
          }

          //
          // Handle search elements
          //

          $(".view-elements").hover(
            function () {
              var divid = "#" + this.id;
              var childdiv = "#resultsLink" + this.id;
              $(childdiv).attr("style", "display:block !important");
            },
            function () {
              var childdiv = "#resultsLink" + this.id;

              $(childdiv).hover(
                function () {
                  $(childdiv).attr("style", "display:block !important");
                },
                function () {
                  $(childdiv).attr("style", "display:block !none");
                }
              );

              $(childdiv).attr("style", "display:block !none");
            }
          );

          //
          // mouse over donuts
          //

          $("#divVizSchedulerStatus").hover(function () {
            // show message
            notify(
              "info",
              "bottom",
              "ℹ️ Click on the chart to open detailed information about the TrackMe scheduler health and statistics.",
              "5"
            );
          });

          $("#divVizOpsStatus").hover(function () {
            // show message
            notify(
              "info",
              "bottom",
              "ℹ️ Click on the chart to open detailed information about the TrackMe tenants health and statistics.",
              "5"
            );
          });

          //
          // FORMS
          //

          //
          // splk-wlk
          //

          // deployment selector for splk-dsm
          var inputSplkWlkEnvironmentType = new DropdownView(
            {
              id: "inputSplkWlkEnvironmentType",
              choices: [
                {
                  label: "Splunk Enterprise",
                  value: "splunk_enterprise",
                },
                {
                  label: "Splunk Cloud",
                  value: "splunk_cloud",
                },
              ],
              default: "splunk_enterprise",
              initialValue: "splunk_enterprise",
              searchWhenChanged: false,
              showClearButton: true,
              selectFirstChoice: false,
              value: "$tk_splk_wlk_env_type$",
              el: $("#inputSplkWlkEnvironmentType"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkWlkEnvironmentType.on("change", function (newValue) {
            // check the connectivity if the account is not local
            if (newValue != undefined) {
              setToken("tk_splk_wlk_env_type", newValue);
            }
          });

          // Search Head Accounts

          var inputSplkWlkSearchHeadAccounts = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputSplkWlkSearchHeadAccounts",
              managerid: "searchPopulateConfigurationAccounts",
              default: "local",
              labelField: "account",
              valueField: "account",
              value: "$tk_splk_wlk_accounts$",
              el: $("#inputSplkWlkSearchHeadAccounts"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkWlkSearchHeadAccounts.on("change", function (newValue) {
            // check connectivity
            if (newValue != undefined && newValue != "") {
              // enable next
              $("#create_tenant_splk_wlk_step2").prop("disabled", false);
              if (newValue != "local") {
                checkSplkFeedsRemoteAccount("wlk", newValue);
              } else {
                $("#divParentCreateWlkHybridValidateRemoteConnectivity").css(
                  "display",
                  "none"
                );
              }
            } else {
              // disable next
              $("#create_tenant_splk_wlk_step2").prop("disabled", true);
            }
          });

          // Outliers metrics default
          var inputSplkWlkDefaultOutliersMetrics = new DropdownView(
            {
              id: "inputSplkWlkDefaultOutliersMetrics",
              choices: [
                {
                  label: "elapsed",
                  value:
                    "eval outliers_metrics=\"{'elapsed': {'alert_lower_breached': 0, 'alert_upper_breached': 1, 'time_factor': 'none'}}\"",
                },
                {
                  label: "pct_cpu",
                  value:
                    "eval outliers_metrics=\"{'pct_cpu': {'alert_lower_breached': 0, 'alert_upper_breached': 1, 'time_factor': 'none'}}\"",
                },
                {
                  label: "splunkcloud_svc",
                  value:
                    "eval outliers_metrics=\"{'svc_usage': {'alert_lower_breached': 0, 'alert_upper_breached': 1, 'time_factor': 'none'}}\"",
                },
                {
                  label: "count_completed",
                  value:
                    "eval outliers_metrics=\"{'count_completed': {'alert_lower_breached': 1, 'alert_upper_breached': 0, 'time_factor': 'none'}}\"",
                },
                {
                  label: "none",
                  value: 'eval outliers_metrics="{}"',
                },
              ],
              default:
                "eval outliers_metrics=\"{'elapsed': {'alert_lower_breached': 0, 'alert_upper_breached': 1, 'time_factor': 'none'}}\"",
              initialValue:
                "eval outliers_metrics=\"{'elapsed': {'alert_lower_breached': 0, 'alert_upper_breached': 1, 'time_factor': 'none'}}\"",
              searchWhenChanged: false,
              showClearButton: true,
              selectFirstChoice: false,
              value: "$tk_splk_wlk_outliers_metrics$",
              el: $("#inputSplkWlkDefaultOutliersMetrics"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkWlkDefaultOutliersMetrics.on("change", function (newValue) {
            // check the connectivity if the account is not local
            if (newValue != undefined) {
              setToken("tk_splk_wlk_outliers_metrics", newValue);
            }
          });

          // notable tracker
          var inputSplkWlkNotableTracker = new DropdownView(
            {
              id: "inputSplkWlkNotableTracker",
              choices: [
                {
                  label: "False",
                  value: "false",
                },
                {
                  label: "True",
                  value: "true",
                },
              ],
              default: "false",
              initialValue: "false",
              searchWhenChanged: false,
              showClearButton: true,
              selectFirstChoice: false,
              value: "$tk_splk_wlk_track_notable$",
              el: $("#inputSplkWlkNotableTracker"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkWlkNotableTracker.on("change", function (newValue) {
            // check the connectivity if the account is not local
            if (newValue != undefined) {
              setToken("tk_splk_wlk_track_notable", newValue);
            }
          });

          // Delete inactive entities
          var inputSplkWlkInactiveInspector = new DropdownView(
            {
              id: "inputSplkWlkInactiveInspector",
              choices: [
                {
                  label: "More than 7 days",
                  value: "7",
                },
                {
                  label: "More than 15 days",
                  value: "15",
                },
                {
                  label: "More than 30 days",
                  value: "30",
                },
                {
                  label: "More than 45 days",
                  value: "45",
                },
                {
                  label: "More than 60 days",
                  value: "60",
                },
                {
                  label: "More than 90 days",
                  value: "90",
                },
              ],
              default: "15",
              initialValue: "15",
              searchWhenChanged: false,
              showClearButton: true,
              selectFirstChoice: false,
              value: "$tk_splk_wlk_inactive_inspector$",
              el: $("#inputSplkWlkInactiveInspector"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkWlkInactiveInspector.on("change", function (newValue) {
            // check the connectivity if the account is not local
            if (newValue != undefined) {
              setToken("tk_splk_wlk_inactive_inspector", newValue);
            }
          });

          //
          // splk-feeds
          //

          // deployment selector for splk-dsm
          var inputSplkDsmListDeployments = new DropdownView(
            {
              id: "inputSplkDsmListDeployments",
              searchWhenChanged: false,
              showClearButton: true,
              selectFirstChoice: true,
              minimumResultsForSearch: 100,
              labelField: "account",
              valueField: "account",
              managerid: "searchPopulateConfigurationAccounts",
              value: "$tk_splk_dsm_deployment$",
              el: $("#inputSplkDsmListDeployments"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkDsmListDeployments.on("change", function (newValue) {
            // check the connectivity if the account is not local
            if (newValue != undefined) {
              if (newValue != "local") {
                checkSplkFeedsRemoteAccount("dsm", newValue);
              } else {
                $("#divParentCreateDsmHybridValidateRemoteConnectivity").css(
                  "display",
                  "none"
                );
              }
            }
          });

          // deployment selector for splk-dhm
          var inputSplkDhmListDeployments = new DropdownView(
            {
              id: "inputSplkDhmListDeployments",
              searchWhenChanged: false,
              showClearButton: true,
              selectFirstChoice: true,
              minimumResultsForSearch: 100,
              labelField: "account",
              valueField: "account",
              managerid: "searchPopulateConfigurationAccounts",
              value: "$tk_splk_dhm_deployment$",
              el: $("#inputSplkDhmListDeployments"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkDhmListDeployments.on("change", function (newValue) {
            // check the connectivity if the account is not local
            if (newValue != undefined) {
              if (newValue != "local") {
                checkSplkFeedsRemoteAccount("dhm", newValue);
              } else {
                $("#divParentCreateDhmHybridValidateRemoteConnectivity").css(
                  "display",
                  "none"
                );
              }
            }
          });

          // deployment selector for splk-mhm
          var inputSplkMhmListDeployments = new DropdownView(
            {
              id: "inputSplkMhmListDeployments",
              searchWhenChanged: false,
              showClearButton: true,
              selectFirstChoice: true,
              minimumResultsForSearch: 100,
              labelField: "account",
              valueField: "account",
              managerid: "searchPopulateConfigurationAccounts",
              value: "$tk_splk_mhm_deployment$",
              el: $("#inputSplkMhmListDeployments"),
            },
            {
              tokens: true,
            }
          ).render();

          inputSplkMhmListDeployments.on("change", function (newValue) {
            // check the connectivity if the account is not local
            if (newValue != undefined) {
              if (newValue != "local") {
                checkSplkFeedsRemoteAccount("mhm", newValue);
              } else {
                $("#divParentCreateMhmHybridValidateRemoteConnectivity").css(
                  "display",
                  "none"
                );
              }
            }
          });

          var inputListRolesAdminSplkFeeds = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesAdminSplkFeeds",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_admin_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_admin_splk_feeds$",
              el: $("#inputListRolesAdminSplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesPowerSplkFeeds = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesPowerSplkFeeds",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_power_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_power_splk_feeds$",
              el: $("#inputListRolesPowerSplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesUserSplkFeeds = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesUserSplkFeeds",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_user_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_user_splk_feeds$",
              el: $("#inputListRolesUserSplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListUserSplkFeeds = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputListUserSplkFeeds",
              managerid: "searchListUsers",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_owner_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_owner_splk_feeds$",
              el: $("#inputListUserSplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          // List indexes
          var inputTenantIdxSummarySplkFeeds = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxSummarySplkFeeds",
              managerid: "searchListIdxSummary",
              selectFirstChoice: "false",
              default: "trackme_summary",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_summary_splk_feeds$",
              el: $("#inputTenantIdxSummarySplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxAuditSplkFeeds = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxAuditSplkFeeds",
              managerid: "searchListIdxAudit",
              selectFirstChoice: "false",
              default: "trackme_audit",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_audit_splk_feeds$",
              el: $("#inputTenantIdxAuditSplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxMetricSplkFeeds = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxMetricSplkFeeds",
              managerid: "searchListIdxMetric",
              selectFirstChoice: "false",
              default: "trackme_metrics",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_metric_splk_feeds$",
              el: $("#inputTenantIdxMetricSplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxNotableSplkFeeds = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxNotableSplkFeeds",
              managerid: "searchListIdxNotable",
              selectFirstChoice: "false",
              default: "trackme_notable",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_notable_splk_feeds$",
              el: $("#inputTenantIdxNotableSplkFeeds"),
            },
            {
              tokens: true,
            }
          ).render();

          //
          // splk-cim
          //

          var inputListRolesAdminSplkCim = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesAdminSplkCim",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_admin_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_admin_splk_cim$",
              el: $("#inputListRolesAdminSplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesPowerSplkCim = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesPowerSplkCim",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_power_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_power_splk_cim$",
              el: $("#inputListRolesPowerSplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesUserSplkCim = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesUserSplkCim",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_user_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_user_splk_cim$",
              el: $("#inputListRolesUserSplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListUserSplkCim = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputListUserSplkCim",
              managerid: "searchListUsers",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_owner_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_owner_splk_cim$",
              el: $("#inputListUserSplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          // List indexes
          var inputTenantIdxSummarySplkCim = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxSummarySplkCim",
              managerid: "searchListIdxSummary",
              selectFirstChoice: "false",
              default: "trackme_summary",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_summary_splk_cim$",
              el: $("#inputTenantIdxSummarySplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxAuditSplkCim = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxAuditSplkCim",
              managerid: "searchListIdxAudit",
              selectFirstChoice: "false",
              default: "trackme_audit",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_audit_splk_cim$",
              el: $("#inputTenantIdxAuditSplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxMetricSplkCim = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxMetricSplkCim",
              managerid: "searchListIdxMetric",
              selectFirstChoice: "false",
              default: "trackme_metrics",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_metric_splk_cim$",
              el: $("#inputTenantIdxMetricSplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxNotableSplkCim = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxNotableSplkCim",
              managerid: "searchListIdxNotable",
              selectFirstChoice: "false",
              default: "trackme_notable",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_notable_splk_cim$",
              el: $("#inputTenantIdxNotableSplkCim"),
            },
            {
              tokens: true,
            }
          ).render();

          //
          // splk-flx
          //

          var inputListRolesAdminSplkFlx = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesAdminSplkFlx",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_admin_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_admin_splk_flx$",
              el: $("#inputListRolesAdminSplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesPowerSplkFlx = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesPowerSplkFlx",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_power_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_power_splk_flx$",
              el: $("#inputListRolesPowerSplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesUserSplkFlx = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesUserSplkFlx",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_user_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_user_splk_flx$",
              el: $("#inputListRolesUserSplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListUserSplkFlx = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputListUserSplkFlx",
              managerid: "searchListUsers",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_owner_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_owner_splk_flx$",
              el: $("#inputListUserSplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          // List indexes
          var inputTenantIdxSummarySplkFlx = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxSummarySplkFlx",
              managerid: "searchListIdxSummary",
              selectFirstChoice: "false",
              default: "trackme_summary",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_summary_splk_flx$",
              el: $("#inputTenantIdxSummarySplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxAuditSplkFlx = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxAuditSplkFlx",
              managerid: "searchListIdxAudit",
              selectFirstChoice: "false",
              default: "trackme_audit",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_audit_splk_flx$",
              el: $("#inputTenantIdxAuditSplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxMetricSplkFlx = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxMetricSplkFlx",
              managerid: "searchListIdxMetric",
              selectFirstChoice: "false",
              default: "trackme_metrics",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_metric_splk_flx$",
              el: $("#inputTenantIdxMetricSplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxNotableSplkFlx = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxNotableSplkFlx",
              managerid: "searchListIdxNotable",
              selectFirstChoice: "false",
              default: "trackme_notable",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_notable_splk_flx$",
              el: $("#inputTenantIdxNotableSplkFlx"),
            },
            {
              tokens: true,
            }
          ).render();

          //
          // splk-replica
          //

          var inputListComponentsSplkReplica = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListComponentsSplkReplica",
              managerid: "searchListComponents",
              default: "splk-dsm",
              labelField: "components",
              valueField: "components",
              value: "$tk_tenant_replica_components$",
              el: $("#inputListComponentsSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesAdminSplkReplica = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesAdminSplkReplica",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_admin_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_admin_splk_replica$",
              el: $("#inputListRolesAdminSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesPowerSplkReplica = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesPowerSplkReplica",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_power_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_power_splk_replica$",
              el: $("#inputListRolesPowerSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesUserSplkReplica = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesUserSplkReplica",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_user_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_user_splk_replica$",
              el: $("#inputListRolesUserSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListUserSplkReplica = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputListUserSplkReplica",
              managerid: "searchListUsers",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_owner_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_owner_splk_replica$",
              el: $("#inputListUserSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          // List indexes
          var inputTenantIdxSummarySplkReplica = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxSummarySplkReplica",
              managerid: "searchListIdxSummary",
              selectFirstChoice: "false",
              default: "trackme_summary",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_summary_splk_replica$",
              el: $("#inputTenantIdxSummarySplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxAuditSplkReplica = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxAuditSplkReplica",
              managerid: "searchListIdxAudit",
              selectFirstChoice: "false",
              default: "trackme_audit",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_audit_splk_replica$",
              el: $("#inputTenantIdxAuditSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxMetricSplkReplica = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxMetricSplkReplica",
              managerid: "searchListIdxMetric",
              selectFirstChoice: "false",
              default: "trackme_metrics",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_metric_splk_replica$",
              el: $("#inputTenantIdxMetricSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxNotableSplkReplica = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxNotableSplkReplica",
              managerid: "searchListIdxNotable",
              selectFirstChoice: "false",
              default: "trackme_notable",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_notable_splk_replica$",
              el: $("#inputTenantIdxNotableSplkReplica"),
            },
            {
              tokens: true,
            }
          ).render();

          //
          // splk-wlk
          //

          var inputListRolesAdminSplkWlk = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesAdminSplkWlk",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_admin_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_admin_splk_wlk$",
              el: $("#inputListRolesAdminSplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesPowerSplkWlk = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesPowerSplkWlk",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_power_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_power_splk_wlk$",
              el: $("#inputListRolesPowerSplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListRolesUserSplkWlk = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputListRolesUserSplkWlk",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_user_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_roles_user_splk_wlk$",
              el: $("#inputListRolesUserSplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputListUserSplkWlk = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputListUserSplkWlk",
              managerid: "searchListUsers",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_owner_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_owner_splk_wlk$",
              el: $("#inputListUserSplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          // List indexes
          var inputTenantIdxSummarySplkWlk = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxSummarySplkWlk",
              default: "trackme_summary",
              managerid: "searchListIdxSummary",
              selectFirstChoice: "false",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_summary_splk_wlk$",
              el: $("#inputTenantIdxSummarySplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxAuditSplkWlk = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxAuditSplkWlk",
              default: "trackme_audit",
              managerid: "searchListIdxAudit",
              selectFirstChoice: "false",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_audit_splk_wlk$",
              el: $("#inputTenantIdxAuditSplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxMetricSplkWlk = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxMetricSplkWlk",
              default: "trackme_metrics",
              managerid: "searchListIdxMetric",
              selectFirstChoice: "false",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_metric_splk_wlk$",
              el: $("#inputTenantIdxMetricSplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputTenantIdxNotableSplkWlk = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputTenantIdxNotableSplkWlk",
              default: "trackme_notable",
              managerid: "searchListIdxNotable",
              selectFirstChoice: "false",
              minimumResultsForSearch: 100,
              width: 250,
              labelField: "title",
              valueField: "title",
              value: "$tk_tenant_idx_notable_splk_wlk$",
              el: $("#inputTenantIdxNotableSplkWlk"),
            },
            {
              tokens: true,
            }
          ).render();

          // update RBAC

          var inputUpdateListRolesAdmin = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputUpdateListRolesAdmin",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_admin_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_update_tenant_roles_admin$",
              el: $("#inputUpdateListRolesAdmin"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputUpdateListRolesPower = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputUpdateListRolesPower",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_power_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_update_tenant_roles_power$",
              el: $("#inputUpdateListRolesPower"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputUpdateListRolesUser = new MultiDropdownView(
            {
              searchWhenChanged: true,
              id: "inputUpdateListRolesUser",
              managerid: "searchListRoles",
              default:
                trackme_conf["trackme_conf"]["trackme_general"][
                  "trackme_user_role_default"
                ],
              labelField: "title",
              valueField: "title",
              value: "$tk_update_tenant_roles_user$",
              el: $("#inputUpdateListRolesUser"),
            },
            {
              tokens: true,
            }
          ).render();

          var inputUpdateListUser = new DropdownView(
            {
              searchWhenChanged: true,
              id: "inputUpdateListUser",
              managerid: "searchListUsers",
              default: "nobody",
              labelField: "title",
              valueField: "title",
              value: "$tk_update_tenant_owner$",
              el: $("#inputUpdateListUser"),
            },
            {
              tokens: true,
            }
          ).render();

          //
          // VIEW COMPONENTS
          //

          //
          // Refresh modal action
          //

          $("#refresh_tenant").on("click", function () {
            $(this).blur();

            // clean out tokens
            defaultTokenModel.unset("clickedTenantIdDsmEntities");
            defaultTokenModel.unset("clickedTenantIdCimEntities");
            defaultTokenModel.unset("clickedTenantIdDhmEntities");
            defaultTokenModel.unset("clickedTenantIdMhmEntities");
            defaultTokenModel.unset("clickedTenantIdFlxEntities");

            // get components
            var clickedTenantDsmEnabled = defaultTokenModel.get(
              "clickedTenantDsmEnabled"
            );
            var clickedTenantCimEnabled = defaultTokenModel.get(
              "clickedTenantCimEnabled"
            );
            var clickedTenantDhmEnabled = defaultTokenModel.get(
              "clickedTenantDhmEnabled"
            );
            var clickedTenantMhmEnabled = defaultTokenModel.get(
              "clickedTenantMhmEnabled"
            );
            var clickedTenantFlxEnabled = defaultTokenModel.get(
              "clickedTenantFlxEnabled"
            );
            var clickedTenantWlkEnabled = defaultTokenModel.get(
              "clickedTenantWlkEnabled"
            );

            // get context
            var clickedTenantId = defaultTokenModel.get("clickedTenantId");

            // Refresh DSM

            // DSM overview if enabled
            if (clickedTenantDsmEnabled == 1) {
              $("#badges-dsm").remove();

              // Allow the search to start
              searchTenantOverviewDsm.startSearch();

              $("#badges-dsm-container").append(
                '<div id="badges-dsm" style="margin-top:14px; height: 40px;">'
              );

              // Add loader
              $("#badges-dsm").append(
                '<div id="badges-dsm-loader" class="lds-dual-ring"></div>'
              );

              // Wait for first variable from results and add info
              function waitForElement() {
                // get all tokens
                var clickedTenantIdDsmEntities = defaultTokenModel.get(
                  "clickedTenantIdDsmEntities"
                );
                var clickedTenantIdDsmEntitiesStatusGreen =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesStatusGreen"
                  );
                var clickedTenantIdDsmEntitiesStatusRed = defaultTokenModel.get(
                  "clickedTenantIdDsmEntitiesStatusRed"
                );
                var clickedTenantIdDsmEntitiesStatusOthers =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesStatusOthers"
                  );
                var clickedTenantIdDsmEntitiesPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesPriorityLow"
                  );
                var clickedTenantIdDsmEntitiesPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesPriorityMedium"
                  );
                var clickedTenantIdDsmEntitiesPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesPriorityHigh"
                  );
                var clickedTenantIdDsmEntitiesRedPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesRedPriorityLow"
                  );
                var clickedTenantIdDsmEntitiesRedPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesRedPriorityMedium"
                  );
                var clickedTenantIdDsmEntitiesRedPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdDsmEntitiesRedPriorityHigh"
                  );

                // wait for first variable which indicates all results are available
                if (typeof clickedTenantIdDsmEntities !== "undefined") {
                  // remove loader
                  $("#badges-dsm-loader").remove();
                  // Update DOM

                  // badge
                  $("#badges-dsm").append(
                    '<span id="badge-dsm-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                      clickedTenantIdDsmEntities +
                      " entities</span>"
                  );
                  // over
                  $("#badge-dsm-entities").on("mouseover", function () {
                    if (clickedTenantIdDsmEntities == 0) {
                      notify(
                        "info",
                        "bottom",
                        "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                        "10"
                      );
                    } else {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'any'",
                        "dsm",
                        clickedTenantId,
                        "*",
                        "*"
                      );
                    }
                  });

                  // badge
                  if (clickedTenantIdDsmEntitiesStatusGreen > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                        clickedTenantIdDsmEntitiesStatusGreen +
                        " status green</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-status-green").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'green', 'priority': 'any'",
                        "dsm",
                        clickedTenantId,
                        "green",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesStatusRed > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDsmEntitiesStatusRed +
                        " status red</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-status-red").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'any'",
                        "dsm",
                        clickedTenantId,
                        "red",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesStatusOthers > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                        clickedTenantIdDsmEntitiesStatusOthers +
                        " status other</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-status-other").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'other', 'priority': 'any'",
                        "dsm",
                        clickedTenantId,
                        "other",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesPriorityLow > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                        clickedTenantIdDsmEntitiesPriorityLow +
                        " low priority</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-priority-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'low'",
                        "dsm",
                        clickedTenantId,
                        "*",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesPriorityMedium > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                        clickedTenantIdDsmEntitiesPriorityMedium +
                        " medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-priority-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'medium'",
                        "dsm",
                        clickedTenantId,
                        "*",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesPriorityHigh > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                        clickedTenantIdDsmEntitiesPriorityHigh +
                        " high priority</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-priority-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'high'",
                        "dsm",
                        clickedTenantId,
                        "*",
                        "high"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesRedPriorityLow > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDsmEntitiesRedPriorityLow +
                        " red low priority</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-priority-red-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'low'",
                        "dsm",
                        clickedTenantId,
                        "red",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesRedPriorityMedium > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDsmEntitiesRedPriorityMedium +
                        " red medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-priority-red-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: medium",
                        "dsm",
                        clickedTenantId,
                        "red",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDsmEntitiesRedPriorityHigh > 0) {
                    $("#badges-dsm").append(
                      '<span id="badge-dsm-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDsmEntitiesRedPriorityHigh +
                        " red high priority</span>"
                    );
                  }
                  // over
                  $("#badge-dsm-entities-priority-red-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: high",
                        "dsm",
                        clickedTenantId,
                        "red",
                        "high"
                      );
                    }
                  );

                  // Finally, tenant status
                  getTenantsOpsStatus();
                  //

                  //variable exists, do what you want
                } else {
                  setTimeout(waitForElement, 250);
                }
              }

              // call the function
              waitForElement();

              // close divs
              $("#badges-dsm").append("</div>");
              $("#badges-dsm-container").append("</div>");
            }

            // CIM overview if enabled
            if (clickedTenantCimEnabled == 1) {
              $("#badges-cim").remove();

              // Allow the search to start
              searchTenantOverviewCim.startSearch();

              $("#badges-cim-container").append(
                '<div id="badges-cim" style="margin-top:14px; height: 40px;">'
              );

              // Add loader
              $("#badges-cim").append(
                '<div id="badges-cim-loader" class="lds-dual-ring"></div>'
              );

              // Wait for first variable from results and add info
              function waitForElement() {
                // get all tokens
                var clickedTenantIdCimEntities = defaultTokenModel.get(
                  "clickedTenantIdCimEntities"
                );
                var clickedTenantIdCimEntitiesStatusGreen =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesStatusGreen"
                  );
                var clickedTenantIdCimEntitiesStatusRed = defaultTokenModel.get(
                  "clickedTenantIdCimEntitiesStatusRed"
                );
                var clickedTenantIdCimEntitiesStatusOthers =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesStatusOthers"
                  );
                var clickedTenantIdCimEntitiesPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesPriorityLow"
                  );
                var clickedTenantIdCimEntitiesPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesPriorityMedium"
                  );
                var clickedTenantIdCimEntitiesPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesPriorityHigh"
                  );
                var clickedTenantIdCimEntitiesRedPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesRedPriorityLow"
                  );
                var clickedTenantIdCimEntitiesRedPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesRedPriorityMedium"
                  );
                var clickedTenantIdCimEntitiesRedPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdCimEntitiesRedPriorityHigh"
                  );

                // wait for first variable which indicates all results are available
                if (typeof clickedTenantIdCimEntities !== "undefined") {
                  // remove loader
                  $("#badges-cim-loader").remove();
                  // Update DOM

                  // badge
                  $("#badges-cim").append(
                    '<span id="badge-cim-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                      clickedTenantIdCimEntities +
                      " entities</span>"
                  );
                  // over
                  $("#badge-cim-entities").on("mouseover", function () {
                    if (clickedTenantIdCimEntities == 0) {
                      notify(
                        "info",
                        "bottom",
                        "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                        "10"
                      );
                    } else {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'any'",
                        "cim",
                        clickedTenantId,
                        "*",
                        "*"
                      );
                    }
                  });

                  // badge
                  if (clickedTenantIdCimEntitiesStatusGreen > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                        clickedTenantIdCimEntitiesStatusGreen +
                        " status green</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-status-green").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'green', 'priority': 'any'",
                        "cim",
                        clickedTenantId,
                        "green",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesStatusRed > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdCimEntitiesStatusRed +
                        " status red</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-status-red").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'any'",
                        "cim",
                        clickedTenantId,
                        "red",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesStatusOthers > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                        clickedTenantIdCimEntitiesStatusOthers +
                        " status other</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-status-other").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'other', 'priority': 'any'",
                        "cim",
                        clickedTenantId,
                        "other",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesPriorityLow > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                        clickedTenantIdCimEntitiesPriorityLow +
                        " low priority</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-priority-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'low'",
                        "cim",
                        clickedTenantId,
                        "*",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesPriorityMedium > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                        clickedTenantIdCimEntitiesPriorityMedium +
                        " medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-priority-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'medium'",
                        "cim",
                        clickedTenantId,
                        "*",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesPriorityHigh > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                        clickedTenantIdCimEntitiesPriorityHigh +
                        " high priority</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-priority-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'high'",
                        "cim",
                        clickedTenantId,
                        "*",
                        "high"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesRedPriorityLow > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdCimEntitiesRedPriorityLow +
                        " red low priority</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-priority-red-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'low'",
                        "cim",
                        clickedTenantId,
                        "red",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesRedPriorityMedium > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdCimEntitiesRedPriorityMedium +
                        " red medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-priority-red-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: medium",
                        "cim",
                        clickedTenantId,
                        "red",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdCimEntitiesRedPriorityHigh > 0) {
                    $("#badges-cim").append(
                      '<span id="badge-cim-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdCimEntitiesRedPriorityHigh +
                        " red high priority</span>"
                    );
                  }
                  // over
                  $("#badge-cim-entities-priority-red-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: high",
                        "cim",
                        clickedTenantId,
                        "red",
                        "high"
                      );
                    }
                  );

                  //variable exists, do what you want
                } else {
                  setTimeout(waitForElement, 250);
                }
              }

              // call the function
              waitForElement();

              // close divs
              $("#badges-cim").append("</div>");
              $("#badges-cim-container").append("</div>");
            }

            // FLX overview if enabled
            if (clickedTenantFlxEnabled == 1) {
              $("#badges-flx").remove();

              // Allow the search to start
              searchTenantOverviewFlx.startSearch();

              $("#badges-flx-container").append(
                '<div id="badges-flx" style="margin-top:14px; height: 40px;">'
              );

              // Add loader
              $("#badges-flx").append(
                '<div id="badges-flx-loader" class="lds-dual-ring"></div>'
              );

              // Wait for first variable from results and add info
              function waitForElement() {
                // get all tokens
                var clickedTenantIdFlxEntities = defaultTokenModel.get(
                  "clickedTenantIdFlxEntities"
                );
                var clickedTenantIdFlxEntitiesStatusGreen =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesStatusGreen"
                  );
                var clickedTenantIdFlxEntitiesStatusRed = defaultTokenModel.get(
                  "clickedTenantIdFlxEntitiesStatusRed"
                );
                var clickedTenantIdFlxEntitiesStatusOthers =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesStatusOthers"
                  );
                var clickedTenantIdFlxEntitiesPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesPriorityLow"
                  );
                var clickedTenantIdFlxEntitiesPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesPriorityMedium"
                  );
                var clickedTenantIdFlxEntitiesPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesPriorityHigh"
                  );
                var clickedTenantIdFlxEntitiesRedPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesRedPriorityLow"
                  );
                var clickedTenantIdFlxEntitiesRedPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesRedPriorityMedium"
                  );
                var clickedTenantIdFlxEntitiesRedPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdFlxEntitiesRedPriorityHigh"
                  );

                // wait for first variable which indicates all results are available
                if (typeof clickedTenantIdFlxEntities !== "undefined") {
                  // remove loader
                  $("#badges-flx-loader").remove();
                  // Update DOM

                  // badge
                  $("#badges-flx").append(
                    '<span id="badge-flx-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                      clickedTenantIdFlxEntities +
                      " entities</span>"
                  );
                  // over
                  $("#badge-flx-entities").on("mouseover", function () {
                    if (clickedTenantIdFlxEntities == 0) {
                      notify(
                        "info",
                        "bottom",
                        "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                        "10"
                      );
                    } else {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'any'",
                        "flx",
                        clickedTenantId,
                        "*",
                        "*"
                      );
                    }
                  });

                  // badge
                  if (clickedTenantIdFlxEntitiesStatusGreen > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                        clickedTenantIdFlxEntitiesStatusGreen +
                        " status green</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-status-green").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'green', 'priority': 'any'",
                        "flx",
                        clickedTenantId,
                        "green",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesStatusRed > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdFlxEntitiesStatusRed +
                        " status red</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-status-red").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'any'",
                        "flx",
                        clickedTenantId,
                        "red",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesStatusOthers > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                        clickedTenantIdFlxEntitiesStatusOthers +
                        " status other</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-status-other").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'other', 'priority': 'any'",
                        "flx",
                        clickedTenantId,
                        "other",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesPriorityLow > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                        clickedTenantIdFlxEntitiesPriorityLow +
                        " low priority</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-priority-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'low'",
                        "flx",
                        clickedTenantId,
                        "*",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesPriorityMedium > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                        clickedTenantIdFlxEntitiesPriorityMedium +
                        " medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-priority-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'medium'",
                        "flx",
                        clickedTenantId,
                        "*",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesPriorityHigh > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                        clickedTenantIdFlxEntitiesPriorityHigh +
                        " high priority</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-priority-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'high'",
                        "flx",
                        clickedTenantId,
                        "*",
                        "high"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesRedPriorityLow > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdFlxEntitiesRedPriorityLow +
                        " red low priority</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-priority-red-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'low'",
                        "flx",
                        clickedTenantId,
                        "red",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesRedPriorityMedium > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdFlxEntitiesRedPriorityMedium +
                        " red medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-priority-red-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: medium",
                        "flx",
                        clickedTenantId,
                        "red",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdFlxEntitiesRedPriorityHigh > 0) {
                    $("#badges-flx").append(
                      '<span id="badge-flx-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdFlxEntitiesRedPriorityHigh +
                        " red high priority</span>"
                    );
                  }
                  // over
                  $("#badge-flx-entities-priority-red-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: high",
                        "flx",
                        clickedTenantId,
                        "red",
                        "high"
                      );
                    }
                  );

                  //variable exists, do what you want
                } else {
                  setTimeout(waitForElement, 250);
                }
              }

              // call the function
              waitForElement();

              // close divs
              $("#badges-flx").append("</div>");
              $("#badges-flx-container").append("</div>");
            }

            // FLX overview if enabled
            if (clickedTenantWlkEnabled == 1) {
              $("#badges-wlk").remove();

              // Allow the search to start
              searchTenantOverviewWlk.startSearch();

              $("#badges-wlk-container").append(
                '<div id="badges-wlk" style="margin-top:14px; height: 40px;">'
              );

              // Add loader
              $("#badges-wlk").append(
                '<div id="badges-wlk-loader" class="lds-dual-ring"></div>'
              );

              // Wait for first variable from results and add info
              function waitForElement() {
                // get all tokens
                var clickedTenantIdWlkEntities = defaultTokenModel.get(
                  "clickedTenantIdWlkEntities"
                );
                var clickedTenantIdWlkEntitiesStatusGreen =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesStatusGreen"
                  );
                var clickedTenantIdWlkEntitiesStatusRed = defaultTokenModel.get(
                  "clickedTenantIdWlkEntitiesStatusRed"
                );
                var clickedTenantIdWlkEntitiesStatusOthers =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesStatusOthers"
                  );
                var clickedTenantIdWlkEntitiesPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesPriorityLow"
                  );
                var clickedTenantIdWlkEntitiesPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesPriorityMedium"
                  );
                var clickedTenantIdWlkEntitiesPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesPriorityHigh"
                  );
                var clickedTenantIdWlkEntitiesRedPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesRedPriorityLow"
                  );
                var clickedTenantIdWlkEntitiesRedPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesRedPriorityMedium"
                  );
                var clickedTenantIdWlkEntitiesRedPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdWlkEntitiesRedPriorityHigh"
                  );

                // wait for first variable which indicates all results are available
                if (typeof clickedTenantIdWlkEntities !== "undefined") {
                  // remove loader
                  $("#badges-wlk-loader").remove();
                  // Update DOM

                  // badge
                  $("#badges-wlk").append(
                    '<span id="badge-wlk-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                      clickedTenantIdWlkEntities +
                      " entities</span>"
                  );
                  // over
                  $("#badge-wlk-entities").on("mouseover", function () {
                    if (clickedTenantIdWlkEntities == 0) {
                      notify(
                        "info",
                        "bottom",
                        "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                        "10"
                      );
                    } else {
                      get_entities_summary_wlk(
                        "'status': 'any', 'priority': 'any'",
                        "wlk",
                        clickedTenantId,
                        "*",
                        "*"
                      );
                    }
                  });

                  // badge
                  if (clickedTenantIdWlkEntitiesStatusGreen > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                        clickedTenantIdWlkEntitiesStatusGreen +
                        " status green</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-status-green").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "'status': 'green', 'priority': 'any'",
                        "wlk",
                        clickedTenantId,
                        "green",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesStatusRed > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdWlkEntitiesStatusRed +
                        " status red</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-status-red").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "'status': 'red', 'priority': 'any'",
                        "wlk",
                        clickedTenantId,
                        "red",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesStatusOthers > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                        clickedTenantIdWlkEntitiesStatusOthers +
                        " status other</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-status-other").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "'status': 'other', 'priority': 'any'",
                        "wlk",
                        clickedTenantId,
                        "other",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesPriorityLow > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                        clickedTenantIdWlkEntitiesPriorityLow +
                        " low priority</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-priority-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "'status': 'any', 'priority': 'low'",
                        "wlk",
                        clickedTenantId,
                        "*",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesPriorityMedium > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                        clickedTenantIdWlkEntitiesPriorityMedium +
                        " medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-priority-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "'status': 'any', 'priority': 'medium'",
                        "wlk",
                        clickedTenantId,
                        "*",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesPriorityHigh > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                        clickedTenantIdWlkEntitiesPriorityHigh +
                        " high priority</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-priority-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "'status': 'any', 'priority': 'high'",
                        "wlk",
                        clickedTenantId,
                        "*",
                        "high"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesRedPriorityLow > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdWlkEntitiesRedPriorityLow +
                        " red low priority</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-priority-red-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "'status': 'red', 'priority': 'low'",
                        "wlk",
                        clickedTenantId,
                        "red",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesRedPriorityMedium > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdWlkEntitiesRedPriorityMedium +
                        " red medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-priority-red-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "status: red, priority: medium",
                        "wlk",
                        clickedTenantId,
                        "red",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdWlkEntitiesRedPriorityHigh > 0) {
                    $("#badges-wlk").append(
                      '<span id="badge-wlk-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdWlkEntitiesRedPriorityHigh +
                        " red high priority</span>"
                    );
                  }
                  // over
                  $("#badge-wlk-entities-priority-red-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary_wlk(
                        "status: red, priority: high",
                        "wlk",
                        clickedTenantId,
                        "red",
                        "high"
                      );
                    }
                  );

                  //variable exists, do what you want
                } else {
                  setTimeout(waitForElement, 250);
                }
              }

              // call the function
              waitForElement();

              // close divs
              $("#badges-wlk").append("</div>");
              $("#badges-wlk-container").append("</div>");
            }

            // DHM overview if enabled
            if (clickedTenantDhmEnabled == 1) {
              $("#badges-dhm").remove();

              // Allow the search to start
              searchTenantOverviewDhm.startSearch();

              // populate
              $("#badges-dhm-container").append(
                '<div id="badges-dhm" style="margin-top:14px; height: 40px;">'
              );

              // Add loader
              $("#badges-dhm").append(
                '<div id="badges-dhm-loader" class="lds-dual-ring"></div>'
              );

              // Wait for first variable from results and add info
              function waitForElement() {
                // get all tokens
                var clickedTenantIdDhmEntities = defaultTokenModel.get(
                  "clickedTenantIdDhmEntities"
                );
                var clickedTenantIdDhmEntitiesStatusGreen =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesStatusGreen"
                  );
                var clickedTenantIdDhmEntitiesStatusRed = defaultTokenModel.get(
                  "clickedTenantIdDhmEntitiesStatusRed"
                );
                var clickedTenantIdDhmEntitiesStatusOthers =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesStatusOthers"
                  );
                var clickedTenantIdDhmEntitiesPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesPriorityLow"
                  );
                var clickedTenantIdDhmEntitiesPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesPriorityMedium"
                  );
                var clickedTenantIdDhmEntitiesPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesPriorityHigh"
                  );
                var clickedTenantIdDhmEntitiesRedPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesRedPriorityLow"
                  );
                var clickedTenantIdDhmEntitiesRedPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesRedPriorityMedium"
                  );
                var clickedTenantIdDhmEntitiesRedPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdDhmEntitiesRedPriorityHigh"
                  );

                // wait for first variable which indicates all results are available
                if (typeof clickedTenantIdDhmEntities !== "undefined") {
                  // remove loader
                  $("#badges-dhm-loader").remove();

                  // Update DOM
                  // badge
                  $("#badges-dhm").append(
                    '<span id="badge-dhm-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                      clickedTenantIdDhmEntities +
                      " entities</span>"
                  );
                  // over
                  $("#badge-dhm-entities").on("mouseover", function () {
                    if (clickedTenantIdDhmEntities == 0) {
                      notify(
                        "info",
                        "bottom",
                        "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                        "10"
                      );
                    } else {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'any'",
                        "dhm",
                        clickedTenantId,
                        "*",
                        "*"
                      );
                    }
                  });

                  // badge
                  if (clickedTenantIdDhmEntitiesStatusGreen > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                        clickedTenantIdDhmEntitiesStatusGreen +
                        " status green</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-status-green").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'green', 'priority': 'any'",
                        "dhm",
                        clickedTenantId,
                        "green",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesStatusRed > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDhmEntitiesStatusRed +
                        " status red</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-status-red").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'any'",
                        "dhm",
                        clickedTenantId,
                        "red",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesStatusOthers > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                        clickedTenantIdDhmEntitiesStatusOthers +
                        " status other</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-status-other").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'other', 'priority': 'any'",
                        "dhm",
                        clickedTenantId,
                        "other",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesPriorityLow > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                        clickedTenantIdDhmEntitiesPriorityLow +
                        " low priority</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-priority-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'low'",
                        "dhm",
                        clickedTenantId,
                        "*",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesPriorityMedium > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                        clickedTenantIdDhmEntitiesPriorityMedium +
                        " medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-priority-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'medium'",
                        "dhm",
                        clickedTenantId,
                        "*",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesPriorityHigh > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                        clickedTenantIdDhmEntitiesPriorityHigh +
                        " high priority</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-priority-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'high'",
                        "dhm",
                        clickedTenantId,
                        "*",
                        "high"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesRedPriorityLow > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDhmEntitiesRedPriorityLow +
                        " red low priority</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-priority-red-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'low'",
                        "dhm",
                        clickedTenantId,
                        "red",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesRedPriorityMedium > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDhmEntitiesRedPriorityMedium +
                        " red medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-priority-red-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: medium",
                        "dhm",
                        clickedTenantId,
                        "red",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdDhmEntitiesRedPriorityHigh > 0) {
                    $("#badges-dhm").append(
                      '<span id="badge-dhm-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdDhmEntitiesRedPriorityHigh +
                        " red high priority</span>"
                    );
                  }
                  // over
                  $("#badge-dhm-entities-priority-red-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: high",
                        "dhm",
                        clickedTenantId,
                        "red",
                        "high"
                      );
                    }
                  );

                  //variable exists, do what you want
                } else {
                  setTimeout(waitForElement, 250);
                }
              }

              // call the function
              waitForElement();

              // close divs
              $("#badges-dhm").append("</div>");
              $("#badges-dhm-container").append("</div>");
            }

            // MHM overview if enabled
            if (clickedTenantMhmEnabled == 1) {
              $("#badges-mhm").remove();

              // Allow the search to start
              searchTenantOverviewMhm.startSearch();

              // populate
              $("#badges-mhm-container").append(
                '<div id="badges-mhm" style="margin-top:14px; height: 40px;">'
              );

              // Add loader
              $("#badges-mhm").append(
                '<div id="badges-mhm-loader" class="lds-dual-ring"></div>'
              );

              // Wait for first variable from results and add info
              function waitForElement() {
                // get all tokens
                var clickedTenantIdMhmEntities = defaultTokenModel.get(
                  "clickedTenantIdMhmEntities"
                );
                var clickedTenantIdMhmEntitiesStatusGreen =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesStatusGreen"
                  );
                var clickedTenantIdMhmEntitiesStatusRed = defaultTokenModel.get(
                  "clickedTenantIdMhmEntitiesStatusRed"
                );
                var clickedTenantIdMhmEntitiesStatusOthers =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesStatusOthers"
                  );
                var clickedTenantIdMhmEntitiesPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesPriorityLow"
                  );
                var clickedTenantIdMhmEntitiesPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesPriorityMedium"
                  );
                var clickedTenantIdMhmEntitiesPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesPriorityHigh"
                  );
                var clickedTenantIdMhmEntitiesRedPriorityLow =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesRedPriorityLow"
                  );
                var clickedTenantIdMhmEntitiesRedPriorityMedium =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesRedPriorityMedium"
                  );
                var clickedTenantIdMhmEntitiesRedPriorityHigh =
                  defaultTokenModel.get(
                    "clickedTenantIdMhmEntitiesRedPriorityHigh"
                  );

                // wait for first variable which indicates all results are available
                if (typeof clickedTenantIdMhmEntities !== "undefined") {
                  // remove loader
                  $("#badges-mhm-loader").remove();
                  // Update DOM

                  // badge
                  $("#badges-mhm").append(
                    '<span id="badge-mhm-entities" style="margin-right: 10px;" class="badge badge-purple">' +
                      clickedTenantIdMhmEntities +
                      " entities</span>"
                  );
                  // over
                  $("#badge-mhm-entities").on("mouseover", function () {
                    if (clickedTenantIdMhmEntities == 0) {
                      notify(
                        "info",
                        "bottom",
                        "ℹ️ There are no entities yet for this tenant and component, if it was newly created you can run the trackers now to first populate the component",
                        "10"
                      );
                    } else {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'any'",
                        "mhm",
                        clickedTenantId,
                        "*",
                        "*"
                      );
                    }
                  });

                  // badge
                  if (clickedTenantIdMhmEntitiesStatusGreen > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-status-green" style="margin-right: 10px;" class="badge badge-green">' +
                        clickedTenantIdMhmEntitiesStatusGreen +
                        " status green</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-status-green").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'green', 'priority': 'any'",
                        "mhm",
                        clickedTenantId,
                        "green",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesStatusRed > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-status-red" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdMhmEntitiesStatusRed +
                        " status red</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-status-red").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'any'",
                        "mhm",
                        clickedTenantId,
                        "red",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesStatusOthers > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-status-other" style="margin-right: 10px;" class="badge badge-yellow">' +
                        clickedTenantIdMhmEntitiesStatusOthers +
                        " status other</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-status-other").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'other', 'priority': 'any'",
                        "mhm",
                        clickedTenantId,
                        "other",
                        "*"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesPriorityLow > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-priority-low" style="margin-right: 10px;" class="badge badge-low-priority">' +
                        clickedTenantIdMhmEntitiesPriorityLow +
                        " low priority</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-priority-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'low'",
                        "mhm",
                        clickedTenantId,
                        "*",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesPriorityMedium > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-priority-medium" style="margin-right: 10px;" class="badge badge-medium-priority">' +
                        clickedTenantIdMhmEntitiesPriorityMedium +
                        " medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-priority-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'medium'",
                        "mhm",
                        clickedTenantId,
                        "*",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesPriorityHigh > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-priority-high" style="margin-right: 10px;" class="badge badge-high-priority">' +
                        clickedTenantIdMhmEntitiesPriorityHigh +
                        " high priority</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-priority-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'any', 'priority': 'high'",
                        "mhm",
                        clickedTenantId,
                        "*",
                        "high"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesRedPriorityLow > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-priority-red-low" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdMhmEntitiesRedPriorityLow +
                        " red low priority</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-priority-red-low").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "'status': 'red', 'priority': 'low'",
                        "mhm",
                        clickedTenantId,
                        "red",
                        "low"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesRedPriorityMedium > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-priority-red-medium" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdMhmEntitiesRedPriorityMedium +
                        " red medium priority</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-priority-red-medium").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: medium",
                        "mhm",
                        clickedTenantId,
                        "red",
                        "medium"
                      );
                    }
                  );

                  // badge
                  if (clickedTenantIdMhmEntitiesRedPriorityHigh > 0) {
                    $("#badges-mhm").append(
                      '<span id="badge-mhm-entities-priority-red-high" style="margin-right: 10px;" class="badge badge-red">' +
                        clickedTenantIdMhmEntitiesRedPriorityHigh +
                        " red high priority</span>"
                    );
                  }
                  // over
                  $("#badge-mhm-entities-priority-red-high").on(
                    "mouseover",
                    function () {
                      get_entities_summary(
                        "status: red, priority: high",
                        "mhm",
                        clickedTenantId,
                        "red",
                        "high"
                      );
                    }
                  );

                  //variable exists, do what you want
                } else {
                  setTimeout(waitForElement, 250);
                }
              }

              // call the function
              waitForElement();

              // close divs
              $("#badges-mhm").append("</div>");
              $("#badges-mhm-container").append("</div>");
            }
          });

          var vizSchedulerStatus = new semiCircleDonut(
            {
              id: "vizSchedulerStatus",
              type: "semicircle_donut.semicircle_donut",
              resizable: true,
              drilldown: "all",
              height: "140",
              "refresh.display": "progressbar",
              "semicircle_donut.semicircle_donut.colorField": "color",
              "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
              "semicircle_donut.semicircle_donut.legendPosition": "top",
              "semicircle_donut.semicircle_donut.type": "half",
              "trellis.enabled": "0",
              "trellis.scales.shared": "1",
              "trellis.size": "medium",
              managerid: "searchSchedulerStatus",
              el: $("#vizSchedulerStatus"),
            },
            { tokens: true, tokenNamespace: "submitted" }
          ).render();

          vizSchedulerStatus.on("click", function (e) {
            e.preventDefault();
            // Set token to start searches, and Open modal
            searchTimeChartSchedulerPerTenantStatus.startSearch();
            searchSchedulerPerTenantStatus.startSearch();
            $("#modal_scheduler_status").modal();
            // Show message
            notify(
              "info",
              "bottom",
              "ℹ️ The scheduler overview provides key performance indicators about the activity of the Splunk scheduler when it comes to the execution of the trackers, anything bellow 100% completed likely indicates issues!",
              "10"
            );
          });

          //
          // Vtenants Ops Status
          //

          var vizOpsStatus = new semiCircleDonut(
            {
              id: "vizOpsStatus",
              type: "semicircle_donut.semicircle_donut",
              resizable: true,
              drilldown: "all",
              height: "140",
              "refresh.display": "progressbar",
              "semicircle_donut.semicircle_donut.colorField": "color",
              "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
              "semicircle_donut.semicircle_donut.legendPosition": "top",
              "semicircle_donut.semicircle_donut.type": "half",
              "trellis.enabled": "0",
              "trellis.scales.shared": "1",
              "trellis.size": "medium",
              managerid: "searchOpsStatus",
              el: $("#vizOpsStatus"),
            },
            { tokens: true, tokenNamespace: "submitted" }
          ).render();

          vizOpsStatus.on("click", function (e) {
            e.preventDefault();

            //
            setToken("showOpsStatusModal", "true");
            // Start the searches
            searchTimeChartOpsPerTenantStatus.startSearch();
            searchDonutChartOpsPerTenantStatus.startSearch();
            searchOpsPerTenantStatus.startSearch();
            // Open modal
            $("#modal_tenant_ops_status").modal();

            // show tenants Ops status
            function showTenantsOpsStatus(ajaxUrl, ajaxType) {
              // Add the loader
              $("#tenant-ops-status-loader").css("display", "block");
              $("#showTenantOpsTabulator").css("display", "none");

              // Run the ajax promise
              var doAsync = asyncAjax(ajaxUrl, ajaxType).then(function (
                resultCall
              ) {
                tabulatorElement = "#showTenantOpsTabulator";

                // get componentRegister from resultCall, if resultCall is empty, set componentRegister to empty array
                var tableData = [];
                if (resultCall.length == 0) {
                  tableData = [];
                } else {
                  // loop through resultCall, extract the value of job_component_register which is an array
                  // loop through the array and push to tableData
                  for (var i = 0; i < resultCall.length; i++) {
                    var job_component_register = JSON.parse(resultCall[i].job_component_register);
                    for (var j = 0; j < job_component_register.length; j++) {
                      tableData.push(job_component_register[j]);
                    }
                  }
                }

                var table = new TabulatorFull(tabulatorElement, {
                  data: JSON.parse(JSON.stringify(tableData)), //load row data from array
                  index: "tenant_id",
                  layout: "fitDataFill", //fit columns to width of table
                  //responsiveLayout: "hide", //hide columns that dont fit on the table
                  movableRows: true, // allow rows to be moved
                  addRowPos: "top", //when adding a new row, add it to the top of the table
                  history: true, //allow undo and redo actions on the table
                  pagination: "local", //paginate the data
                  paginationSize: 100, //allow 5 rows per page of data
                  paginationCounter: "rows", //display count of paginated rows in footer
                  movableColumns: true, //allow column order to be changed
                  resizableRows: true, //allow row order to be changed
                  maxHeight: "400px",
                  groupBy: "tenant_id",
                  initialSort: [
                    //set the initial sort order of the data
                    { column: "tenant_id", dir: "asc" },
                  ],

                  columns: [
                    //define the table columns
                    {
                      title: "Tenant ID",
                      field: "tenant_id",
                      editor: false,
                      headerFilter: true,
                      sorter: "string",
                      minWidth: 150,
                    },
                    {
                      title: "Component",
                      field: "component",
                      editor: false,
                      headerFilter: true,
                    },
                    {
                      title: "Status",
                      field: "last_status",
                      editor: false,
                      headerFilter: true,
                      minWidth: 150,
                    },
                    {
                      title: "Report",
                      field: "report",
                      editor: false,
                      headerFilter: true,
                      minWidth: 350,
                    },
                    {
                      title: "Last result",
                      field: "last_result",
                      editor: false,
                      headerFilter: true,
                      minWidth: 450,
                    },
                    {
                      title: "Last execution",
                      field: "last_exec",
                      editor: false,
                      headerFilter: true,
                      minWidth: 200,
                    },
                    {
                      title: "Last duration (sec)",
                      field: "last_duration",
                      editor: false,
                      headerFilter: true,
                      minWidth: 150,
                    },
                  ],
                });

                table.on("tableBuilt", function () {
                  $("#tenant-ops-status-loader").css("display", "none");
                  $("#showTenantOpsTabulator").css("display", "block");
                });
              });
            }

            // get table
            showTenantsOpsStatus(
              "/en-US/splunkd/__raw/services/trackme/v2/configuration/get_tenant_ops_status",
              "post"
            );

            // Show message
            notify(
              "info",
              "bottom",
              "ℹ️ The Tenants health operational overview provides quick insights on the status of your TrackMe tenants, analysing for instance if their activity is delayed or missing!",
              "10"
            );

            //
          });

          //
          // MODAL SCHEDULER OVERVIEW
          //

          var searchSchedulerPerTenantStatus = new SavedSearchManager({
            id: "searchSchedulerPerTenantStatus",
            searchname: "trackme_scheduler_completness_pertenant",
            cache: false,
            preview: true,
            autostart: false,
            "dispatch.earliest_time": "-24h",
            "dispatch.latest_time": "now",
            app: "trackme",
          });

          var tableSchedulerPerTenantStatus = new TableView(
            {
              id: "tableSchedulerPerTenantStatus",
              drilldown: "row",
              managerid: "searchSchedulerPerTenantStatus",
              pageSize: "5",
              el: $("#tableSchedulerPerTenantStatus"),
            },
            {
              tokens: true,
            }
          ).render();

          var resultsLinktableSchedulerPerTenantStatus = new ResultsLinkView({
            id: "resultsLinktableSchedulerPerTenantStatus",
            managerid: "searchSchedulerPerTenantStatus",
            "link.exportResults.visible": false,
            el: $("#resultsLinktableSchedulerPerTenantStatus"),
          });

          resultsLinktableSchedulerPerTenantStatus
            .render()
            .$el.appendTo($("searchTimeChartSchedulerPerTenantStatus"));

          var searchTimeChartSchedulerPerTenantStatus = new SavedSearchManager({
            id: "searchTimeChartSchedulerPerTenantStatus",
            searchname: "trackme_scheduler_completness_overtime",
            cache: false,
            preview: true,
            autostart: false,
            "dispatch.earliest_time": "-24h",
            "dispatch.latest_time": "now",
            app: "trackme",
          });

          var resultsLinktimeChartSchedulerPerTenantStatus =
            new ResultsLinkView({
              id: "resultsLinktimeChartSchedulerPerTenantStatus",
              managerid: "searchTimeChartSchedulerPerTenantStatus",
              "link.exportResults.visible": false,
              el: $("#resultsLinktimeChartSchedulerPerTenantStatus"),
            });

          resultsLinktimeChartSchedulerPerTenantStatus
            .render()
            .$el.appendTo($("searchTimeChartSchedulerPerTenantStatus"));

          var timeChartSchedulerPerTenantStatus = new ChartView(
            {
              id: "timeChartSchedulerPerTenantStatus",
              managerid: "searchTimeChartSchedulerPerTenantStatus",
              resizable: true,
              type: "column",
              "charting.chart.stackMode": "stacked",
              "charting.legend.placement": "bottom",
              "charting.axisTitleX.visibility": "collapsed",
              "charting.fieldColors":
                '{"completed": 0x45D4BA,"skipped": 0xffb347,"deferred": 0xfdec96}',
              el: $("#timeChartSchedulerPerTenantStatus"),
            },
            {
              tokens: true,
            }
          ).render();

          //
          // MODAL OPS OVERVIEW
          //

          var searchOpsPerTenantStatus = new SearchManager(
            {
              id: "searchOpsPerTenantStatus",
              tokenDependencies: {
                depends: "$showOpsStatusModal$",
              },
              search: "| `per_tenant_ops_statusv2(*)`",
              autostart: false,
              earliest_time: "-60m",
              latest_time: "now",
            },
            {
              tokens: true,
            }
          );

          var tableOpsPerTenantStatus = new TableView(
            {
              id: "tableOpsPerTenantStatus",
              tokenDependencies: {
                depends: "$showOpsStatusModal$",
              },
              drilldown: "row",
              managerid: "searchOpsPerTenantStatus",
              pageSize: "5",
              el: $("#tableOpsPerTenantStatus"),
            },
            {
              tokens: true,
            }
          ).render();

          var resultsLinktableOpsPerTenantStatus = new ResultsLinkView({
            id: "resultsLinktableOpsPerTenantStatus",
            managerid: "searchOpsPerTenantStatus",
            "link.exportResults.visible": false,
            el: $("#resultsLinktableOpsPerTenantStatus"),
          });

          resultsLinktableOpsPerTenantStatus
            .render()
            .$el.appendTo($("searchTimeChartOpsPerTenantStatus"));

          var searchTimeChartOpsPerTenantStatus = new SearchManager(
            {
              id: "searchTimeChartOpsPerTenantStatus",
              tokenDependencies: {
                depends: "$showOpsStatusModal$",
              },
              autostart: false,
              search: "`per_tenant_ops_summary_activity`",
              earliest_time: "-4h",
              latest_time: "now",
            },
            {
              tokens: true,
            }
          );

          searchTimeChartOpsPerTenantStatus.on(
            "search:start",
            function (properties) {
              // hide messages
              $("#timeChartOpsPerTenantStatusResultsFound").css(
                "display",
                "none"
              );
              $("#timeChartOpsPerTenantStatusNoResults").css("display", "none");
            }
          );

          searchTimeChartOpsPerTenantStatus.on(
            "search:done",
            function (properties) {
              // Print the search job properties
              var eventCount = properties.content.eventCount;
              if (eventCount > 0) {
                $("#parentTimeChartOpsPerTenantStatus").css(
                  "display",
                  "inherit"
                );
                $("#timeChartOpsPerTenantStatusResultsFound").css(
                  "display",
                  "inherit"
                );
                $("#timeChartOpsPerTenantStatusNoResults").css(
                  "display",
                  "none"
                );
              } else {
                $("#parentTimeChartOpsPerTenantStatus").css("display", "none");
                $("#timeChartOpsPerTenantStatusResultsFound").css(
                  "display",
                  "none"
                );
                $("#timeChartOpsPerTenantStatusNoResults").css(
                  "display",
                  "inherit"
                );
              }
            }
          );

          var resultsLinktimeChartOpsPerTenantStatus = new ResultsLinkView({
            id: "resultsLinktimeChartOpsPerTenantStatus",
            managerid: "searchTimeChartOpsPerTenantStatus",
            "link.exportResults.visible": false,
            el: $("#resultsLinktimeChartOpsPerTenantStatus"),
          });

          resultsLinktimeChartOpsPerTenantStatus
            .render()
            .$el.appendTo($("searchTimeChartOpsPerTenantStatus"));

          var searchDonutChartOpsPerTenantStatus = new SearchManager(
            {
              id: "searchDonutChartOpsPerTenantStatus",
              tokenDependencies: {
                depends: "$showOpsStatusModal$",
              },
              autostart: false,
              search: "| savedsearch trackme_ops_status",
              earliest_time: "-5m",
              latest_time: "now",
            },
            {
              tokens: true,
            }
          );

          var donutOpsPerTenantStatus = new semiCircleDonut(
            {
              id: "donutOpsPerTenantStatus",
              type: "semicircle_donut.semicircle_donut",
              resizable: true,
              drilldown: "none",
              height: "120",
              "refresh.display": "progressbar",
              "semicircle_donut.semicircle_donut.colorField": "color",
              "semicircle_donut.semicircle_donut.cutoutPercentage": "50",
              "semicircle_donut.semicircle_donut.legendPosition": "top",
              "semicircle_donut.semicircle_donut.type": "half",
              "trellis.enabled": "0",
              "trellis.scales.shared": "1",
              "trellis.size": "medium",
              managerid: "searchDonutChartOpsPerTenantStatus",
              el: $("#donutOpsPerTenantStatus"),
            },
            {
              tokens: true,
            }
          ).render();

          var timeChartOpsPerTenantStatus = new ChartView(
            {
              id: "timeChartOpsPerTenantStatus",
              tokenDependencies: {
                depends: "$showOpsStatusModal$",
              },
              height: "140",
              managerid: "searchTimeChartOpsPerTenantStatus",
              resizable: true,
              type: "column",
              "charting.chart.stackMode": "stacked",
              "charting.legend.placement": "right",
              "charting.axisTitleX.visibility": "collapsed",
              "charting.axisLabelsY.majorUnit": "1",
              el: $("#timeChartOpsPerTenantStatus"),
            },
            {
              tokens: true,
            }
          ).render();

          //
          //
          //

          //
          // START
          //

          // get the tenant Ops status
          function getTenantsOpsStatus() {
            // show the loader first
            $("#divTenantOpsCount").remove();
            $("#parentDivTenantOpsCount").html(
              '<div id="badges-tenant-count-loader" class="lds-dual-ring" style="margin-left: 47%;"></div>'
            );

            // Create the service
            var service = mvc.createService({
              owner: "nobody",
            });

            // Define the query
            var searchQuery = "| `tenants_ops_globalstatus`";

            // Set the search parameters--specify a time range
            var searchParams = {
              earliest_time: "-5m",
              latest_time: "now",
            };

            // Run a blocking search and get back a job
            // spinner
            // $("#cssloader").remove();
            // $("body").append(
            //   '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while we are running some Splunky searches..."></div>'
            // );
            service.search(searchQuery, searchParams, function (err, job) {
              // Shall the search fail before we can get properties
              if (job == null) {
                let errorStr = "Unknown Error!";
                if (
                  err &&
                  err.data &&
                  err.data.messages &&
                  err.data.messages[0]["text"]
                ) {
                  errorStr = err.data.messages[0]["text"];
                } else if (err && err.data && err.data.messages) {
                  errorStr = JSON.stringify(err.data.messages);
                }
                // notify error
                // $("#cssloader").remove();
                message =
                  "ERROR: hum, something went quite wrong there! Splunk returned an error while while attempting to run the search: " +
                  errorStr;
                // remove loader
                $("#cssloader").remove();
                notify("error", "bottom", message, "30");
              } else {
                // Poll the status of the search job
                job.track(
                  {
                    period: 200,
                  },
                  {
                    done: function (job) {
                      // Get the results
                      job.results({}, function (err, results, job) {
                        var fields = results.fields;
                        var rows = results.rows;
                        var jobResult;
                        for (var i = 0; i < rows.length; i++) {
                          var values = rows[i];
                          for (var j = 0; j < values.length; j++) {
                            var field = fields[j];
                            var value = values[j];
                            // get the _raw
                            if (field === "status_code") {
                              statusCode = value;
                            }
                            if (field === "status") {
                              statusValue = value;
                            }
                            if (field === "dcount_tenants") {
                              statusCount = value;
                            }
                          }

                          // remove
                          $("#badges-tenant-count-loader").remove();

                          // remove
                          $("#divSubTenantOpsCount").remove();

                          // Gen
                          $("#parentDivTenantOpsCount").append(
                            '<div id="divTenantOpsCount"></div>' +
                              '<div id="divSubTenantOpsCount" style="text-align: center;"><text class="under-label" style="letter-spacing: normal; font-size: 12px; font-weight: normal; fill: rgb(195, 203, 212); opacity: 1;">NUMBER OF ACTIVE TENANTS</text></div>'
                          );
                          $("#divTenantOpsCount").html(
                            '<h1 style="font-size: 60px; font-weight: bold; letter-spacing: normal; text-align: center;">' +
                              statusCount +
                              "</h1>"
                          );
                        }
                      });
                    },
                    failed: function (properties) {
                      let errorStr = "Unknown Error!";
                      if (
                        properties &&
                        properties._properties &&
                        properties._properties.messages &&
                        properties._properties.messages[0]["text"]
                      ) {
                        errorStr = properties._properties.messages[0]["text"];
                      } else if (
                        properties &&
                        properties._properties &&
                        properties._properties.messages
                      ) {
                        errorStr = JSON.stringify(
                          properties._properties.messages
                        );
                      }
                      message =
                        "ERROR: hum, something went quite wrong there! Splunk returned the following errors: " +
                        errorStr;
                      // remove loader
                      $("#cssloader").remove();
                      notify("error", "bottom", message, "30");
                    },
                    error: function (err) {
                      done(err);
                      message =
                        "ERROR: hum, something went quite wrong there! Splunk returned the following errors: " +
                        err;
                      // remove loader
                      $("#cssloader").remove();
                      notify("error", "bottom", message, "30");
                    },
                  }
                );
              }
            });
          }

          // call if now
          getTenantsOpsStatus();

          //
          // tenants management UI functions
          //

          // Audit record
          function auditRecord(
            tenant_id,
            action,
            change_type,
            object,
            object_category,
            object_attrs,
            result,
            comment
          ) {
            // Audit changes
            var currentUser = Splunk.util.getConfigValue("USERNAME");
            setToken("currentUser", currentUser);
            var auditendpoint_URl =
              "/en-US/splunkd/__raw/services/trackme/v2/audit/audit_event";

            var time = new Date().getTime();
            var audit_record = {
              time: time,
              tenant_id: tenant_id,
              action: action,
              user: currentUser,
              change_type: change_type,
              object: object,
              object_category: object_category,
              object_attrs: object_attrs,
              result: result,
              comment: comment,
            };
            $.ajax({
              url: auditendpoint_URl,
              type: "POST",
              async: true,
              contentType: "application/json",
              data: JSON.stringify(audit_record),
              success: function (returneddata) {
                // Run the search again to update the table
              },
            });
          }

          //
          // Handle html textarea
          //

          $(".custom-textarea").each(function () {
            var $text_group = $(this);
            $text_group.find("textarea").on("click", function () {
              var $text = $(this);
              if (this.value == this.defaultValue) this.value = "";
              $(this).blur(function () {
                if (this.value == "") this.value = this.defaultValue;
              });
            });
          });

          //
          // Create tenants
          //

          //
          // splk-cim
          //

          // enable next button once user provided tenant_id input
          $(function () {
            $("#input_tenant_name_splk_cim").keyup(function () {
              if ($(this).val() == "") {
                // Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_cim_step1").prop("disabled", true);
              } else if ($(this).val().length > 20) {
                // 10 chars max
                $("#create_tenant_splk_cim_step1").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "ERROR: The tenant name is limited to 20 characters max!",
                  "600"
                );
              } else {
                // Perform a query and verify if this tenant exists already

                var tenant_id = $(this).val();
                // replace empty chars, underscore and make it lower case
                tenant_id = tenant_id.replace(/" "/g, "-");
                tenant_id = tenant_id.replace(/"_"/g, "-");
                tenant_id = tenant_id.toLowerCase();

                var queryString = encodeURI(
                  '{ "tenant_id": "' + tenant_id + '" }'
                );
                var myendpoint_URl =
                  "/en-US/splunkd/__raw/servicesNS/nobody/trackme/storage/collections/data/kv_trackme_virtual_tenants?query=" +
                  queryString;
                $.ajax({
                  url: myendpoint_URl,
                  type: "GET",
                  async: true,
                  contentType: "application/json",
                  success: function (returneddata) {
                    if (returneddata.length > 0) {
                      notify(
                        "error",
                        "bottom",
                        "ERROR: A tenant with the same identifier already exists!",
                        "600"
                      );
                      $("#create_tenant_splk_cim_step1").prop("disabled", true);
                    } else {
                      notify(
                        "success",
                        "bottom",
                        "OK! This tenant identifier is valid and does not exist yet",
                        "5"
                      );
                      $("#create_tenant_splk_cim_step1").prop(
                        "disabled",
                        false
                      );
                    }
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon! " +
                        message,
                      "600"
                    );
                    $("#create_tenant_splk_cim_step1").prop("disabled", true);
                  },
                });
              }
            });
          });

          //
          // splk-flx
          //

          // enable next button once user provided tenant_id input
          $(function () {
            $("#input_tenant_name_splk_flx").keyup(function () {
              if ($(this).val() == "") {
                // Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_flx_step1").prop("disabled", true);
              } else if ($(this).val().length > 20) {
                // 10 chars max
                $("#create_tenant_splk_flx_step1").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "ERROR: The tenant name is limited to 20 characters max!",
                  "600"
                );
              } else {
                // Perform a query and verify if this tenant exists already

                var tenant_id = $(this).val();
                // replace empty chars, underscore and make it lower case
                tenant_id = tenant_id.replace(/" "/g, "-");
                tenant_id = tenant_id.replace(/"_"/g, "-");
                tenant_id = tenant_id.toLowerCase();

                var queryString = encodeURI(
                  '{ "tenant_id": "' + tenant_id + '" }'
                );
                var myendpoint_URl =
                  "/en-US/splunkd/__raw/servicesNS/nobody/trackme/storage/collections/data/kv_trackme_virtual_tenants?query=" +
                  queryString;
                $.ajax({
                  url: myendpoint_URl,
                  type: "GET",
                  async: true,
                  contentType: "application/json",
                  success: function (returneddata) {
                    if (returneddata.length > 0) {
                      notify(
                        "error",
                        "bottom",
                        "ERROR: A tenant with the same identifier already exists!",
                        "600"
                      );
                      $("#create_tenant_splk_flx_step1").prop("disabled", true);
                    } else {
                      notify(
                        "success",
                        "bottom",
                        "OK! This tenant identifier is valid and does not exist yet",
                        "5"
                      );
                      $("#create_tenant_splk_flx_step1").prop(
                        "disabled",
                        false
                      );
                    }
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon! " +
                        message,
                      "600"
                    );
                    $("#create_tenant_splk_flx_step1").prop("disabled", true);
                  },
                });
              }
            });
          });

          //
          // splk-replica
          //

          // enable next button once user provided tenant_id input
          $(function () {
            $("#input_tenant_name_splk_replica").keyup(function () {
              if ($(this).val() == "") {
                // Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_replica_step1").prop("disabled", true);
              } else if ($(this).val().length > 20) {
                // 10 chars max
                $("#create_tenant_splk_replica_step1").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "ERROR: The tenant name is limited to 20 characters max!",
                  "600"
                );
              } else {
                // Perform a query and verify if this tenant exists already

                var tenant_id = $(this).val();
                // replace empty chars, underscore and make it lower case
                tenant_id = tenant_id.replace(/" "/g, "-");
                tenant_id = tenant_id.replace(/"_"/g, "-");
                tenant_id = tenant_id.toLowerCase();

                var queryString = encodeURI(
                  '{ "tenant_id": "' + tenant_id + '" }'
                );
                var myendpoint_URl =
                  "/en-US/splunkd/__raw/servicesNS/nobody/trackme/storage/collections/data/kv_trackme_virtual_tenants?query=" +
                  queryString;
                $.ajax({
                  url: myendpoint_URl,
                  type: "GET",
                  async: true,
                  contentType: "application/json",
                  success: function (returneddata) {
                    if (returneddata.length > 0) {
                      notify(
                        "error",
                        "bottom",
                        "ERROR: A tenant with the same identifier already exists!",
                        "600"
                      );
                      $("#create_tenant_splk_replica_step1").prop(
                        "disabled",
                        true
                      );
                    } else {
                      notify(
                        "success",
                        "bottom",
                        "OK! This tenant identifier is valid and does not exist yet",
                        "5"
                      );
                      $("#create_tenant_splk_replica_step1").prop(
                        "disabled",
                        false
                      );
                    }
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon! " +
                        message,
                      "600"
                    );
                    $("#create_tenant_splk_replica_step1").prop(
                      "disabled",
                      true
                    );
                  },
                });
              }
            });
          });

          //
          // splk-wlk
          //

          // enable next button once user provided tenant_id input
          $(function () {
            $("#input_tenant_name_splk_wlk").keyup(function () {
              if ($(this).val() == "") {
                // Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_wlk_step1").prop("disabled", true);
              } else if ($(this).val().length > 20) {
                // 10 chars max
                $("#create_tenant_splk_wlk_step1").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "ERROR: The tenant name is limited to 20 characters max!",
                  "600"
                );
              } else {
                // Perform a query and verify if this tenant exists already

                var tenant_id = $(this).val();
                // replace empty chars, underscore and make it lower case
                tenant_id = tenant_id.replace(/" "/g, "-");
                tenant_id = tenant_id.replace(/"_"/g, "-");
                tenant_id = tenant_id.toLowerCase();

                var queryString = encodeURI(
                  '{ "tenant_id": "' + tenant_id + '" }'
                );
                var myendpoint_URl =
                  "/en-US/splunkd/__raw/servicesNS/nobody/trackme/storage/collections/data/kv_trackme_virtual_tenants?query=" +
                  queryString;
                $.ajax({
                  url: myendpoint_URl,
                  type: "GET",
                  async: true,
                  contentType: "application/json",
                  success: function (returneddata) {
                    if (returneddata.length > 0) {
                      notify(
                        "error",
                        "bottom",
                        "ERROR: A tenant with the same identifier already exists!",
                        "600"
                      );
                      $("#create_tenant_splk_wlk_step1").prop("disabled", true);
                    } else {
                      notify(
                        "success",
                        "bottom",
                        "OK! This tenant identifier is valid and does not exist yet",
                        "5"
                      );
                      $("#create_tenant_splk_wlk_step1").prop(
                        "disabled",
                        false
                      );
                    }
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon! " +
                        message,
                      "600"
                    );
                    $("#create_tenant_splk_wlk_step1").prop("disabled", true);
                  },
                });
              }
            });
          });

          //
          // splk-feeds
          //

          // enable next button once user provided tenant_id input
          $(function () {
            $("#input_tenant_name_splk_feeds").keyup(function () {
              if ($(this).val() == "") {
                // Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_feeds_step1").prop("disabled", true);
              } else if ($(this).val().length > 20) {
                // 10 chars max
                $("#create_tenant_splk_feeds_step1").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "ERROR: The tenant name is limited to 20 characters max!",
                  "600"
                );
              } else {
                // Perform a query and verify if this tenant exists already

                var tenant_id = $(this).val();
                // replace empty chars, underscore and make it lower case
                tenant_id = tenant_id.replace(/" "/g, "-");
                tenant_id = tenant_id.replace(/"_"/g, "-");
                tenant_id = tenant_id.toLowerCase();

                var queryString = encodeURI(
                  '{ "tenant_id": "' + tenant_id + '" }'
                );
                var myendpoint_URl =
                  "/en-US/splunkd/__raw/servicesNS/nobody/trackme/storage/collections/data/kv_trackme_virtual_tenants?query=" +
                  queryString;
                $.ajax({
                  url: myendpoint_URl,
                  type: "GET",
                  async: true,
                  contentType: "application/json",
                  success: function (returneddata) {
                    if (returneddata.length > 0) {
                      notify(
                        "error",
                        "bottom",
                        "ERROR: A tenant with the same identifier already exists!",
                        "600"
                      );
                      $("#create_tenant_splk_feeds_step1").prop(
                        "disabled",
                        true
                      );
                    } else {
                      notify(
                        "success",
                        "bottom",
                        "OK! This tenant identifier is valid and does not exist yet",
                        "5"
                      );
                      $("#create_tenant_splk_feeds_step1").prop(
                        "disabled",
                        false
                      );
                    }
                  },
                  error: function (xhr, textStatus, error) {
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error;
                    notify(
                      "error",
                      "bottom",
                      "ERROR: failure to communicate with Splunk daemon! " +
                        message,
                      "600"
                    );
                    $("#create_tenant_splk_feeds_step1").prop("disabled", true);
                  },
                });
              }
            });
          });

          // constraint is required to continue
          $(function () {
            $("#input_tenant_dsm_root_constraint").keyup(function () {
              if ($(this).val() == "") {
                //Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_feeds_step2_test").prop(
                  "disabled",
                  true
                );
                $("#create_tenant_splk_feeds_step2").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "Hold On! A search constraint is required for Data Source Monitoring, you can include any valid indexed fields patterns",
                  "5"
                );
              } else {
                //If there is text in the input, then enable the button if other conditions are met
                if ($("#tenant_dsm_discovery").hasClass("btn-outline-danger")) {
                  var tenant_dsm_discovery_list_values = $(
                    "#tenant_dsm_discovery_list"
                  ).tagsinput("items");
                  if (tenant_dsm_discovery_list_values.length < 1) {
                    $("#create_tenant_splk_feeds_step2_test").prop(
                      "disabled",
                      true
                    );
                    $("#create_tenant_splk_feeds_step2").prop("disabled", true);
                  } else {
                    $("#create_tenant_splk_feeds_step2_test").prop(
                      "disabled",
                      false
                    );
                    $("#create_tenant_splk_feeds_step2").prop(
                      "disabled",
                      false
                    );
                  }
                } else {
                  $("#create_tenant_splk_feeds_step2_test").prop(
                    "disabled",
                    false
                  );
                  $("#create_tenant_splk_feeds_step2").prop("disabled", false);
                }
              }
            });
          });

          // help message
          $("#input_tenant_dsm_root_constraint").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ You can set any valid indexed field constraint for the tenant, only the data that can be returned via the root constraint will be taken into account for the discovery of entities",
              "10"
            );
          });

          // constraint is required to continue
          $(function () {
            $("#input_tenant_dhm_root_constraint").keyup(function () {
              if ($(this).val() == "") {
                //Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_feeds_step3_test").prop(
                  "disabled",
                  true
                );
                $("#create_tenant_splk_feeds_step3").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "Hold On! A search constraint is required for Data Host Monitoring, you can include any valid indexed fields patterns",
                  "5"
                );
              } else {
                //If there is text in the input, then enable the button if other conditions are met
                if ($("#tenant_dhm_discovery").hasClass("btn-outline-danger")) {
                  var tenant_dhm_discovery_list_values = $(
                    "#tenant_dhm_discovery_list"
                  ).tagsinput("items");
                  if (tenant_dhm_discovery_list_values.length < 1) {
                    $("#create_tenant_splk_feeds_step3_test").prop(
                      "disabled",
                      true
                    );
                    $("#create_tenant_splk_feeds_step3").prop("disabled", true);
                  } else {
                    $("#create_tenant_splk_feeds_step3_test").prop(
                      "disabled",
                      false
                    );
                    $("#create_tenant_splk_feeds_step3").prop(
                      "disabled",
                      false
                    );
                  }
                } else {
                  $("#create_tenant_splk_feeds_step3_test").prop(
                    "disabled",
                    false
                  );
                  $("#create_tenant_splk_feeds_step3").prop("disabled", false);
                }
              }
            });
          });

          // help message
          $("#input_tenant_dhm_root_constraint").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ You can set any valid indexed field constraint for the tenant, only the data that can be returned via the root constraint will be taken into account for the discovery of entities",
              "10"
            );
          });

          // constraint is required to continue
          $(function () {
            $("#input_tenant_mhm_root_constraint").keyup(function () {
              if ($(this).val() == "") {
                //Check to see if there is any text entered
                // If there is no text within the input ten disable the button
                $("#create_tenant_splk_feeds_step4_test").prop(
                  "disabled",
                  true
                );
                $("#create_tenant_splk_feeds_step5").prop("disabled", true);
                notify(
                  "error",
                  "bottom",
                  "Hold On! A search constraint is required for Metric Host Monitoring, you can include any valid indexed fields patterns",
                  "5"
                );
              } else {
                //If there is text in the input, then enable the button if other conditions are met
                if ($("#tenant_mhm_discovery").hasClass("btn-outline-danger")) {
                  var tenant_mhm_discovery_list_values = $(
                    "#tenant_mhm_discovery_list"
                  ).tagsinput("items");
                  if (tenant_mhm_discovery_list_values.length < 1) {
                    $("#create_tenant_splk_feeds_step4_test").prop(
                      "disabled",
                      true
                    );
                    $("#create_tenant_splk_feeds_step5").prop("disabled", true);
                  } else {
                    $("#create_tenant_splk_feeds_step4_test").prop(
                      "disabled",
                      false
                    );
                    $("#create_tenant_splk_feeds_step5").prop(
                      "disabled",
                      false
                    );
                  }
                } else {
                  $("#create_tenant_splk_feeds_step4_test").prop(
                    "disabled",
                    false
                  );
                  $("#create_tenant_splk_feeds_step5").prop("disabled", false);
                }
              }
            });
          });

          $("#input_tenant_mhm_root_constraint").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ You can set any valid indexed field constraint for the tenant, only the data that can be returned via the root constraint will be taken into account for the discovery of entities",
              "10"
            );
          });

          //
          // DSM
          //

          // Show message
          $("#tenant_dsm_enabled").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ You can choose to enable (default) or disable a component, at least one component needs to be enabled for the tenant to be created",
              "10"
            );
          });

          // track changes on the components inputs
          $("#tenant_dsm_enabled").on("click", function () {
            if ($(this).hasClass("btn-outline-primary")) {
              $(this).toggleClass("btn-outline-primary btn-outline-danger");
              $(this).addClass("tenant_dsm_disabled");
              $(this).removeClass("tenant_dsm_enabled");
              $(this).text("SPLK-DSM is Disabled - click to enable");
              $("#input_tenant_dsm_root_constraint").prop("disabled", true);
              $("#input_tenant_dsm_restrict_discovery").prop("disabled", true);
              $("#tenant_dsm_discovery").prop("disabled", true);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", true);
              $("#btn_create_tenant_dsm_advanced_options").prop(
                "disabled",
                true
              );
              $("#tenant_dsm_advanced_create_trackers").prop("disabled", true);
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Data Source Monitoring component will be disabled for this tenant.",
                "5"
              );
            } else if ($(this).hasClass("btn-outline-danger")) {
              $(this).toggleClass("btn-outline-danger btn-outline-primary");
              $(this).removeClass("tenant_dsm_disabled");
              $(this).addClass("tenant_dsm_enabled");
              $(this).text("SPLK-DSM is Enabled - click to disable");
              $("#input_tenant_dsm_root_constraint").prop("disabled", false);
              $("#input_tenant_dsm_restrict_discovery").prop("disabled", false);
              $("#tenant_dsm_discovery").prop("disabled", false);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", false);
              $("#btn_create_tenant_dsm_advanced_options").prop(
                "disabled",
                false
              );
              $("#tenant_dsm_advanced_create_trackers").prop("disabled", false);
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Data Source Monitoring component will be enabled for this tenant.",
                "5"
              );
            }
          });

          // show message
          $("#tenant_dsm_advanced_create_trackers").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ Choose wether you want to use ouf the box tracker with the tenant, or if you want to start with a empty DSM tenant and create Hybrid or Elastic Sources as needed",
                "10"
              );
            }
          );

          // track change
          $("#tenant_dsm_advanced_create_trackers").on("change", function () {
            currentValue = $(this).val();
            if (currentValue === "True") {
              setToken("tk_tenant_dsm_advanced_create_trackers", currentValue);
              $("#input_tenant_dsm_root_constraint").prop("disabled", false);
              $("#input_tenant_dsm_restrict_discovery").prop("disabled", false);
              $("#tenant_dsm_discovery").prop("disabled", false);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", false);
              $("#tenant_dsm_advanced_search_mode").prop("disabled", false);
              $("#tenant_dsm_advanced_mode").prop("disabled", false);
              $("#tenant_dsm_advanced_mode_earliest").prop("disabled", false);
              $("#tenant_dsm_advanced_mode_latest").prop("disabled", false);
              $("#tenant_dsm_advanced_mode_index_earliest").prop(
                "disabled",
                false
              );
              $("#tenant_dsm_advanced_mode_index_latest").prop(
                "disabled",
                false
              );
              $("#tenant_dsm_advanced_mode_cron").prop("disabled", false);
              $("#tenant_dsm_advanced_tstats_root_span").prop(
                "disabled",
                false
              );
              $("#tenant_dsm_advanced_tstats_root_include_splunk_server").prop(
                "disabled",
                false
              );
              $("#tenant_dsm_advanced_tstats_root_include_host").prop(
                "disabled",
                false
              );
            } else if (currentValue === "False") {
              setToken("tk_tenant_dsm_advanced_create_trackers", currentValue);
              $("#input_tenant_dsm_root_constraint").prop("disabled", true);
              $("#input_tenant_dsm_restrict_discovery").prop("disabled", true);
              $("#tenant_dsm_discovery").prop("disabled", true);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", true);
              $("#tenant_dsm_advanced_search_mode").prop("disabled", true);
              $("#tenant_dsm_advanced_mode").prop("disabled", true);
              $("#tenant_dsm_advanced_mode_earliest").prop("disabled", true);
              $("#tenant_dsm_advanced_mode_latest").prop("disabled", true);
              $("#tenant_dsm_advanced_mode_index_earliest").prop(
                "disabled",
                true
              );
              $("#tenant_dsm_advanced_mode_index_latest").prop(
                "disabled",
                true
              );
              $("#tenant_dsm_advanced_mode_cron").prop("disabled", true);
              $("#tenant_dsm_advanced_tstats_root_span").prop("disabled", true);
              $("#tenant_dsm_advanced_tstats_root_include_splunk_server").prop(
                "disabled",
                true
              );
              $("#tenant_dsm_advanced_tstats_root_include_host").prop(
                "disabled",
                true
              );
              notify(
                "success",
                "bottom",
                "SPLK-DSM: When creating without OOTB trackers, you can use Hybrid trackers and Elastic Sources trackers to match your exact needs.",
                "5"
              );
            }
          });

          // show message
          $("#tenant_dsm_discovery").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The default behaviour is to discover data in every index reacheable from the root constraints, you can in addition restrict the indexes discovery using index patterns at any time of the tenant life cycle",
              "10"
            );
          });

          $("#tenant_dsm_discovery").on("click", function () {
            if ($(this).hasClass("btn-outline-info")) {
              $(this).toggleClass("btn-outline-info btn-outline-danger");
              $(this).text(
                "Discovery is restricted - click to remove restrictions"
              );
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Indexes discovery will be restricted for this tenant.",
                "5"
              );
              $("#tenant_dsm_discovery_list").prop("disabled", false);
              $("#div_tenant_dsm_discovery_list").css("opacity", "100%");
              $("#create_tenant_splk_feeds_step2").prop("disabled", true);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", true);
              // create tokens
              defaultTokenModel.set("tk_tenant_dsm_discovery", "restricted");
            } else if ($(this).hasClass("btn-outline-danger")) {
              $(this).toggleClass("btn-outline-danger btn-outline-info");
              $(this).text("Discovery is unrestricted - click to restrict");
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Indexes discovery will be unrestricted for this tenant.",
                "5"
              );
              $("#tenant_dsm_discovery_list").prop("disabled", true);
              $("#div_tenant_dsm_discovery_list").css("opacity", "50%");
              $("#create_tenant_splk_feeds_step2").prop("disabled", false);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", false);
              // create tokens
              defaultTokenModel.set("tk_tenant_dsm_discovery", "unrestricted");
            }
          });

          // Indexes discovery

          $("#tenant_dsm_discovery_list").on("change keyup paste", function () {
            var values = $(this).tagsinput("items");
            defaultTokenModel.set("tk_tenant_dsm_discovery_list", values);
            // enable test now button if we have inputs
            if (values.length < 1) {
              $("#create_tenant_splk_feeds_step2").prop("disabled", true);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", true);
            } else {
              $("#create_tenant_splk_feeds_step2").prop("disabled", false);
              $("#create_tenant_splk_feeds_step2_test").prop("disabled", false);
            }
          });

          // Test now button
          $("#create_tenant_splk_feeds_step2_test").on("click", function () {
            notify(
              "info",
              "bottom",
              "Hold on! Starting the verification search now, please wait...",
              "60"
            );

            // Get the Splunk account
            var tk_account = getToken("tk_splk_dsm_deployment");

            // Get tenant_dsm_root_constraint
            var tk_tenant_dsm_root_constraint = document.getElementById(
              "input_tenant_dsm_root_constraint"
            ).value;

            // Get indexes discovery configuration
            var tk_tenant_dsm_discovery = getToken("tk_tenant_dsm_discovery");
            var tk_tenant_dsm_discovery_list = getToken(
              "tk_tenant_dsm_discovery_list"
            );

            // if index discovery is configured, the list of restricted indexes is a CSV list of patterns
            if (tk_tenant_dsm_discovery == "restricted") {
              tk_tenant_dsm_discovery_list =
                'index="' +
                tk_tenant_dsm_discovery_list
                  .toString()
                  .replace(/,/g, '" OR index="') +
                '"';
            } else if (tk_tenant_dsm_discovery == "unrestricted") {
              tk_tenant_dsm_discovery_list = "(index=* OR index=_*)";
            } else {
              tk_tenant_dsm_discovery = "unrestricted";
              tk_tenant_dsm_discovery_list = "(index=* OR index=_*)";
            }

            // get dsm mode
            var tk_tenant_dsm_advanced_mode = document.getElementById(
              "tenant_dsm_advanced_mode"
            ).value;
            var tk_tenant_dsm_advanced_mode_custom_fields =
              document.getElementById(
                "tenant_dsm_advanced_mode_custom_fields"
              ).value;

            // form the search constraint (indexes restrictions and search constraint)
            tk_tenant_dsm_root_constraint =
              tk_tenant_dsm_discovery_list +
              " " +
              tk_tenant_dsm_root_constraint;

            // form the breakby logic
            var breakby_field;
            if (tk_tenant_dsm_advanced_mode == "split") {
              breakby_field = "none";
            } else if (tk_tenant_dsm_advanced_mode == "merged") {
              breakby_field = "merged";
            } else {
              breakby_field = tk_tenant_dsm_advanced_mode_custom_fields;

              // convert to an array
              breakby_field_array = breakby_field.split(",");

              // remove index if present
              if (breakby_field_array.includes("index")) {
                breakby_field_array.splice(
                  breakby_field_array.indexOf("index"),
                  1
                ); //deleting
              }

              // remove sourcetype if present
              if (breakby_field_array.includes("sourcetype")) {
                breakby_field_array.splice(
                  breakby_field_array.indexOf("sourcetype"),
                  1
                ); //deleting
              }

              // convert back
              breakby_field = String(breakby_field_array);
            }

            var record = {
              run_simulation: true,
              component: "dsm",
              account: tk_account,
              search_mode: document.getElementById(
                "tenant_dsm_advanced_search_mode"
              ).value,
              earliest_time: document.getElementById(
                "tenant_dsm_advanced_mode_earliest"
              ).value,
              latest_time: document.getElementById(
                "tenant_dsm_advanced_mode_latest"
              ).value,
              cron_schedule: document.getElementById(
                "tenant_dsm_advanced_mode_cron"
              ).value,
              index_earliest_time: document.getElementById(
                "tenant_dsm_advanced_mode_index_earliest"
              ).value,
              index_latest_time: document.getElementById(
                "tenant_dsm_advanced_mode_index_latest"
              ).value,
              search_constraint: tk_tenant_dsm_root_constraint,
              breakby_field: breakby_field,
            };

            // spinner
            $("#cssloader").remove();
            $("body").append(
              '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while we are running some Splunky searches..."></div>'
            );

            // Retrieve entity info from REST and set actions
            $.ajax({
              url: "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_simulation",
              type: "POST",
              async: true,
              contentType: "application/json",
              data: JSON.stringify(record),
              success: function (returneddata) {
                // search results
                simulation_results = returneddata["results"];

                if (simulation_results["dcount_entities"] > 0) {
                  $("#cssloader").remove();
                  show_results = {
                    entities_count: simulation_results["dcount_entities"],
                    entities_sample: simulation_results["entities_sample"],
                  };
                  message =
                    "OK! That's looking great: " +
                    JSON.stringify(show_results, null, 2);
                  notify("success", "bottom", message, "30");
                } else {
                  show_results = {
                    entities_count: simulation_results["dcount_entities"],
                    search: returneddata["tracker_simulation_search"],
                  };
                  message =
                    "Hold on! The search was successful but there were no entities found: " +
                    JSON.stringify(show_results, null, 2);
                  $("#cssloader").remove();
                  notify("error", "bottom", message, "30");
                }
                //
              },
              error: function (xhr, textStatus, error) {
                $("#cssloader").remove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                notify("error", "bottom", message, "30");
              },
            });
          });

          // advanced configuration

          // on over
          $("#tenant_dsm_advanced_search_mode").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ For best performances at the lowest computing costs, use tstats mode in priority, raw can be a good fit for well scoped use cases as it allows using any kind of fields (while tstats required all fields to be indexed)",
              "5"
            );
          });

          // on over
          $("#tenant_dsm_advanced_mode").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The splk-dsm component tracks entities by index/sourcetype by default, however you can as well either track data for the whole index or use a custom additional field which properly describe concepts like pipelines, companies etc...",
              "5"
            );
          });

          // on over
          $("#tenant_dsm_advanced_mode_earliest").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The earliest time quantifier for the hybrid tracker, this scopes how far in the past the tracker will look for upstream data for the main hybrid tracker workflow, 7 days in the past is a good catch for most of the use cases",
              "5"
            );
          });

          // on over
          $("#tenant_dsm_advanced_mode_latest").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The latest time quantifier for the hybrid tracker, make sure to set a latest time in the future to be able to detect data suspiciously in the future",
              "5"
            );
          });

          // on over
          $("#tenant_dsm_advanced_mode_cron").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The cron schedule for the tracker, usually defaults to every 5 minutes, TrackMe applies a randomization of the cron schedule to dispatch searches for optimization purposes",
              "5"
            );
          });

          // on over
          $("#tenant_dsm_advanced_mode_index_earliest").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ The earliest indexed time quantifier for the hybrid tracker, this scopes how far in the past, from the indexed time perspective, the tracker will look for upstream data for the main hybrid tracker workflow, 4 hours in the past is a good catch for most of the use cases",
                "5"
              );
            }
          );

          // on over
          $("#tenant_dsm_advanced_mode_index_latest").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ The latest time quantifier for the hybrid tracker, make sure to set a latest time in the future to be able to detect data suspiciously in the future",
                "5"
              );
            }
          );

          // on over
          $("#tenant_dsm_advanced_data_sampling_obfuscation").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ When the data sampling obfuscation mode is enabled, events stored in a non readable fashion such that raw events cannot be read by anyone, including high privileged users",
                "5"
              );
            }
          );

          // monitor for the mode selected
          $(function () {
            $("#tenant_dsm_advanced_mode").change(function () {
              // set the token in any case
              setToken("tk_tenant_dsm_advanced_mode", $(this).val());
              if ($(this).val() == "split") {
                $("#tenant_dsm_advanced_mode_custom_fields").prop(
                  "disabled",
                  true
                );
                notify(
                  "info",
                  "bottom",
                  'ℹ️ In split mode, entities are created automatically based on the combination of the index + ":" + sourcetype, you will get as many entities as there are sourcestypes searcheable per index',
                  "5"
                );
                $("#label_tenant_dsm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 50%"
                );
                $("#tenant_dsm_advanced_mode_custom_fields").val("none");
              } else if ($(this).val() == "merged") {
                $("#tenant_dsm_advanced_mode_custom_fields").prop(
                  "disabled",
                  true
                );
                notify(
                  "info",
                  "bottom",
                  "ℹ️ In merged mode, data sources represent all sourcestypes available on a per index basis in respect with constraints parameters, you will get as many entities as there are indexes seacheable",
                  "5"
                );
                $("#label_tenant_dsm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 50%"
                );
                $("#tenant_dsm_advanced_mode_custom_fields").val("none");
              } else if ($(this).val() == "custom") {
                $("#tenant_dsm_advanced_mode_custom_fields").prop(
                  "disabled",
                  false
                );
                $("#label_tenant_dsm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 100%"
                );
                notify(
                  "info",
                  "bottom",
                  "ℹ️ In custom mode, you need to specify a custom field that will be used in the break by logic, this field needs to be an indexed field if running in tstats mode, and either a search time or indexed time in raw mode.",
                  "5"
                );
                $("#tenant_dsm_advanced_mode_custom_fields").val("");
              } else {
                // block - should not be reached
                "#tenant_dsm_advanced_mode_custom_fields".prop(
                  "disabled",
                  trye
                );
                $("#label_tenant_dsm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 50%"
                );
              }
            });
          });

          //
          // DHM
          //

          // show message
          $("#tenant_dhm_advanced_create_trackers").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ Choose wether you want to use ouf the box tracker with the tenant, or if you want to start with a empty DHM tenant and create Hybrid trackers as needed",
                "10"
              );
            }
          );

          // track change
          $("#tenant_dhm_advanced_create_trackers").on("change", function () {
            currentValue = $(this).val();
            if (currentValue === "True") {
              setToken("tk_tenant_dhm_advanced_create_trackers", currentValue);
              $("#input_tenant_dhm_root_constraint").prop("disabled", false);
              $("#input_tenant_dhm_restrict_discovery").prop("disabled", false);
              $("#tenant_dhm_discovery").prop("disabled", false);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", false);
              $("#tenant_dhm_advanced_search_mode").prop("disabled", false);
              $("#tenant_dhm_advanced_mode").prop("disabled", false);
              $("#tenant_dhm_advanced_mode_earliest").prop("disabled", false);
              $("#tenant_dhm_advanced_mode_latest").prop("disabled", false);
              $("#tenant_dhm_advanced_mode_index_earliest").prop(
                "disabled",
                false
              );
              $("#tenant_dhm_advanced_mode_index_latest").prop(
                "disabled",
                false
              );
              $("#tenant_dhm_advanced_mode_cron").prop("disabled", false);
              $("#tenant_dhm_advanced_tstats_root_span").prop(
                "disabled",
                false
              );
              $("#tenant_dhm_advanced_tstats_root_include_splunk_server").prop(
                "disabled",
                false
              );
            } else if (currentValue === "False") {
              setToken("tk_tenant_dhm_advanced_create_trackers", currentValue);
              $("#input_tenant_dhm_root_constraint").prop("disabled", true);
              $("#input_tenant_dhm_restrict_discovery").prop("disabled", true);
              $("#tenant_dhm_discovery").prop("disabled", true);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", true);
              $("#tenant_dhm_advanced_search_mode").prop("disabled", true);
              $("#tenant_dhm_advanced_mode").prop("disabled", true);
              $("#tenant_dhm_advanced_mode_index_earliest").prop(
                "disabled",
                true
              );
              $("#tenant_dhm_advanced_mode_index_latest").prop(
                "disabled",
                true
              );
              $("#tenant_dhm_advanced_mode_cron").prop("disabled", true);
              $("#tenant_dhm_advanced_tstats_root_span").prop("disabled", true);
              $("#tenant_dhm_advanced_tstats_root_include_splunk_server").prop(
                "disabled",
                true
              );
              notify(
                "success",
                "bottom",
                "SPLK-DHM: When creating without OOTB trackers, you can use Hybrid trackers to match your exact needs.",
                "5"
              );
            }
          });

          $(function () {
            $("#tenant_dhm_advanced_mode").change(function () {
              // set the token in any case
              setToken("tk_tenant_dhm_advanced_mode", $(this).val());
              if ($(this).val() == "host") {
                $("#tenant_dhm_advanced_mode_custom_fields").prop(
                  "disabled",
                  true
                );
                notify(
                  "info",
                  "bottom",
                  "ℹ️ In host mode, entities are created automatically based on the host metadata, you will get as many entities as there are hosts searcheable for the data scope",
                  "5"
                );
                $("#label_tenant_dhm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 50%"
                );
                $("#tenant_dhm_advanced_mode_custom_fields").val("none");
              } else if ($(this).val() == "custom") {
                $("#tenant_dhm_advanced_mode_custom_fields").prop(
                  "disabled",
                  false
                );
                $("#label_tenant_dhm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 100%"
                );
                notify(
                  "info",
                  "bottom",
                  "ℹ️ In custom mode, you need to specify a custom field that will be used in the break by logic, this field needs to be an indexed field if running in tstats mode, and either a search time or indexed time in raw mode.",
                  "5"
                );
                $("#tenant_dhm_advanced_mode_custom_fields").val("");
              } else {
                // block - should not be reached
                "#tenant_dhm_advanced_mode_custom_fields".prop(
                  "disabled",
                  trye
                );
                $("#label_tenant_dhm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 50%"
                );
              }
            });
          });

          // Advanced

          // on over
          $("#tenant_dhm_advanced_search_mode").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ For best performances at the lowest computing costs, use tstats mode in priority, raw can be a good fit for well scoped use cases as it allows using any kind of fields (while tstats required all fields to be indexed)",
              "5"
            );
          });

          // on over
          $("#tenant_dhm_advanced_mode").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The splk-dhm component by default tracks data relying on the host Metadata, however you can as well use a custom break by field to change this behaviour and use this key for the breakby statement instead",
              "5"
            );
          });

          // on over
          $("#tenant_dhm_advanced_mode_earliest").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The earliest time quantifier for the hybrid tracker, this scopes how far in the past the tracker will look for upstream data for the main hybrid tracker workflow, 7 days in the past is a good catch for most of the use cases",
              "5"
            );
          });

          // on over
          $("#tenant_dhm_advanced_mode_latest").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The latest time quantifier for the hybrid tracker, make sure to set a latest time in the future to be able to detect data suspiciously in the future",
              "5"
            );
          });

          // on over
          $("#tenant_dhm_advanced_mode_cron").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The cron schedule for the tracker, usually defaults to every 5 minutes, TrackMe applies a randomization of the cron schedule to dispatch searches for optimization purposes",
              "5"
            );
          });

          // on over
          $("#tenant_dhm_advanced_mode_index_earliest").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ The earliest indexed time quantifier for the hybrid tracker, this scopes how far in the past, from the indexed time perspective, the tracker will look for upstream data for the main hybrid tracker workflow, 4 hours in the past is a good catch for most of the use cases",
                "5"
              );
            }
          );

          // on over
          $("#tenant_dhm_advanced_mode_index_latest").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ The latest time quantifier for the hybrid tracker, make sure to set a latest time in the future to be able to detect data suspiciously in the future",
                "5"
              );
            }
          );

          // on over
          $("#tenant_dhm_advanced_alerting_policy").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ When data host alerting per host is set, a monitored host will change its status only when there no more sourcetype meeting the monitoring rules, while when data host alerting per sourcetype is set, a monitored host will change its status if any sourcetype does not meet the monitoring rules",
                "5"
              );
            }
          );

          //
          // MHM
          //

          // show message
          $("#tenant_mhm_advanced_create_trackers").on(
            "mouseover",
            function () {
              notify(
                "info",
                "bottom",
                "ℹ️ Choose wether you want to use ouf the box tracker with the tenant, or if you want to start with a empty MHM tenant and create Hybrid trackers as needed",
                "10"
              );
            }
          );

          // track change
          $("#tenant_mhm_advanced_create_trackers").on("change", function () {
            currentValue = $(this).val();
            if (currentValue === "True") {
              setToken("tk_tenant_mhm_advanced_create_trackers", currentValue);
              $("#input_tenant_mhm_root_constraint").prop("disabled", false);
              $("#input_tenant_mhm_restrict_discovery").prop("disabled", false);
              $("#tenant_mhm_discovery").prop("disabled", false);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", false);
              $("#tenant_mhm_advanced_search_mode").prop("disabled", false);
              $("#tenant_mhm_advanced_mode").prop("disabled", false);
              $("#tenant_mhm_advanced_mode_earliest").prop("disabled", false);
              $("#tenant_mhm_advanced_mode_latest").prop("disabled", false);
              $("#tenant_mhm_advanced_mode_cron").prop("disabled", false);
            } else if (currentValue === "False") {
              setToken("tk_tenant_mhm_advanced_create_trackers", currentValue);
              $("#input_tenant_mhm_root_constraint").prop("disabled", true);
              $("#input_tenant_mhm_restrict_discovery").prop("disabled", true);
              $("#tenant_mhm_discovery").prop("disabled", true);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", true);
              $("#tenant_mhm_advanced_search_mode").prop("disabled", true);
              $("#tenant_mhm_advanced_mode").prop("disabled", true);
              $("#tenant_mhm_advanced_mode_earliest").prop("disabled", true);
              $("#tenant_mhm_advanced_mode_latest").prop("disabled", true);
              $("#tenant_mhm_advanced_mode_cron").prop("disabled", true);
              notify(
                "success",
                "bottom",
                "SPLK-MHM: When creating without OOTB trackers, you can use Hybrid trackers to match your exact needs.",
                "5"
              );
            }
          });

          $(function () {
            $("#tenant_mhm_advanced_mode").change(function () {
              // set the token in any case
              setToken("tk_tenant_mhm_advanced_mode", $(this).val());
              if ($(this).val() == "host") {
                $("#tenant_mhm_advanced_mode_custom_fields").prop(
                  "disabled",
                  true
                );
                notify(
                  "info",
                  "bottom",
                  "ℹ️ In host mode, entities are created automatically based on the host dimension, you will get as many entities as there are hosts searcheable for the metric scope",
                  "5"
                );
                $("#label_tenant_mhm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 50%"
                );
                $("#tenant_mhm_advanced_mode_custom_fields").val("none");
              } else if ($(this).val() == "custom") {
                $("#tenant_mhm_advanced_mode_custom_fields").prop(
                  "disabled",
                  false
                );
                $("#label_tenant_mhm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 100%"
                );
                notify(
                  "info",
                  "bottom",
                  "ℹ️ In custom mode, you need to specify a custom dimension field that will be used in the break by logic.",
                  "5"
                );
                $("#tenant_mhm_advanced_mode_custom_fields").val("");
              } else {
                // block - should not be reached
                "#tenant_mhm_advanced_mode_custom_fields".prop(
                  "disabled",
                  trye
                );
                $("#label_tenant_mhm_advanced_mode_custom_fields").attr(
                  "style",
                  "opacity: 50%"
                );
              }
            });
          });

          // Advanced

          // on over
          $("#tenant_mhm_advanced_mode").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The splk-mhm component by default tracks metrics relying on the host dimension, however you can as well use a custom break by field to change this behaviour and use this key for the breakby dimension instead",
              "5"
            );
          });

          // on over
          $("#tenant_mhm_advanced_mode_earliest").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The earliest time quantifier for the hybrid tracker, this scopes how far in the past the tracker will look for upstream metrics, in the context of this component, the earliest time should remain restricted to relatively limited time ranges",
              "5"
            );
          });

          // on over
          $("#tenant_mhm_advanced_mode_latest").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The latest time quantifier for the hybrid tracker, make sure to set a latest time in the future to be able to detect metrics suspiciously in the future",
              "5"
            );
          });

          // on over
          $("#tenant_mhm_advanced_mode_cron").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The cron schedule for the tracker, usually defaults to every 5 minutes, TrackMe applies a randomization of the cron schedule to dispatch searches for optimization purposes",
              "5"
            );
          });

          //
          //
          //

          // Show message
          $("#tenant_dhm_enabled").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ You can choose to enable (default) or disable a component, at least one component needs to be enabled for the tenant to be created",
              "10"
            );
          });

          // track changes on the components inputs
          $("#tenant_dhm_enabled").on("click", function () {
            if ($(this).hasClass("btn-outline-primary")) {
              $(this).toggleClass("btn-outline-primary btn-outline-danger");
              $(this).addClass("tenant_dhm_disabled");
              $(this).removeClass("tenant_dhm_enabled");
              $(this).text("SPLK-DHM is Disabled - click to enable");
              $("#input_tenant_dhm_root_constraint").prop("disabled", true);
              $("#input_tenant_dhm_restrict_discovery").prop("disabled", true);
              $("#tenant_dhm_discovery").prop("disabled", true);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", true);
              $("#btn_create_tenant_dhm_advanced_options").prop(
                "disabled",
                true
              );
              $("#tenant_dhm_advanced_create_trackers").prop("disabled", true);
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Data Host Monitoring component will be disabled for this tenant.",
                "5"
              );
            } else if ($(this).hasClass("btn-outline-danger")) {
              $(this).toggleClass("btn-outline-danger btn-outline-primary");
              $(this).removeClass("tenant_dhm_disabled");
              $(this).addClass("tenant_dhm_enabled");
              $(this).text("SPLK-DHM is Enabled - click to disable");
              $("#input_tenant_dhm_root_constraint").prop("disabled", false);
              $("#input_tenant_dhm_restrict_discovery").prop("disabled", false);
              $("#tenant_dhm_discovery").prop("disabled", false);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", false);
              $("#btn_create_tenant_dhm_advanced_options").prop(
                "disabled",
                false
              );
              $("#tenant_dhm_advanced_create_trackers").prop("disabled", false);
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Data Host Monitoring component will be enabled for this tenant.",
                "5"
              );
            }
          });

          // show message
          $("#tenant_dhm_discovery").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The default behaviour is to discover data in every index reacheable from the root constraints, you can in addition restrict the indexes discovery using index patterns at any time of the tenant life cycle",
              "10"
            );
          });

          $("#tenant_dhm_discovery").on("click", function () {
            if ($(this).hasClass("btn-outline-info")) {
              $(this).toggleClass("btn-outline-info btn-outline-danger");
              $(this).text(
                "Discovery is restricted - click to remove restrictions"
              );
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Indexes discovery will be restricted for this tenant.",
                "5"
              );
              $("#tenant_dhm_discovery_list").prop("disabled", false);
              $("#div_tenant_dhm_discovery_list").css("opacity", "100%");
              $("#create_tenant_splk_feeds_step3").prop("disabled", true);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", true);
              // create tokens
              defaultTokenModel.set("tk_tenant_dhm_discovery", "restricted");
            } else if ($(this).hasClass("btn-outline-danger")) {
              $(this).toggleClass("btn-outline-danger btn-outline-info");
              $(this).text("Discovery is unrestricted - click to restrict");
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Indexes discovery will be unrestricted for this tenant.",
                "5"
              );
              $("#tenant_dhm_discovery_list").prop("disabled", true);
              $("#div_tenant_dhm_discovery_list").css("opacity", "50%");
              $("#create_tenant_splk_feeds_step3").prop("disabled", false);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", false);
              // create tokens
              defaultTokenModel.set("tk_tenant_dhm_discovery", "unrestricted");
            }
          });

          // Indexes discovery

          $("#tenant_dhm_discovery_list").on("change keyup paste", function () {
            var values = $(this).tagsinput("items");
            defaultTokenModel.set("tk_tenant_dhm_discovery_list", values);
            // enable test now button if we have inputs
            if (values.length < 1) {
              $("#create_tenant_splk_feeds_step3").prop("disabled", true);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", true);
            } else {
              $("#create_tenant_splk_feeds_step3").prop("disabled", false);
              $("#create_tenant_splk_feeds_step3_test").prop("disabled", false);
            }
          });

          // Test now button
          $("#create_tenant_splk_feeds_step3_test").on("click", function () {
            notify(
              "info",
              "bottom",
              "Hold on! Starting the verification search now, please wait...",
              "60"
            );

            // Get the Splunk account
            var tk_account = getToken("tk_splk_dhm_deployment");

            // Get tenant_dhm_root_constraint
            var tk_tenant_dhm_root_constraint = document.getElementById(
              "input_tenant_dhm_root_constraint"
            ).value;

            // Get indexes discovery configuration
            var tk_tenant_dhm_discovery = getToken("tk_tenant_dhm_discovery");
            var tk_tenant_dhm_discovery_list = getToken(
              "tk_tenant_dhm_discovery_list"
            );

            // if index discovery is configured, the list of restricted indexes is a CSV list of patterns
            if (tk_tenant_dhm_discovery == "restricted") {
              tk_tenant_dhm_discovery_list =
                'index="' +
                tk_tenant_dhm_discovery_list
                  .toString()
                  .replace(/,/g, '" OR index="') +
                '"';
            } else if (tk_tenant_dhm_discovery == "unrestricted") {
              tk_tenant_dhm_discovery_list = "(index=* OR index=_*)";
            } else {
              tk_tenant_dhm_discovery = "unrestricted";
              tk_tenant_dhm_discovery_list = "(index=* OR index=_*)";
            }

            // get dhm mode
            var tk_tenant_dhm_advanced_mode = document.getElementById(
              "tenant_dhm_advanced_mode"
            ).value;
            var tk_tenant_dhm_advanced_mode_custom_fields =
              document.getElementById(
                "tenant_dhm_advanced_mode_custom_fields"
              ).value;

            // form the search constraint (indexes restrictions and search constraint)
            tk_tenant_dhm_root_constraint =
              tk_tenant_dhm_discovery_list +
              " " +
              tk_tenant_dhm_root_constraint;

            // form the breakby logic
            var breakby_field;
            if (tk_tenant_dhm_advanced_mode == "split") {
              breakby_field = "none";
            } else if (tk_tenant_dhm_advanced_mode == "merged") {
              breakby_field = "merged";
            } else {
              breakby_field = tk_tenant_dhm_advanced_mode_custom_fields;
            }

            var record = {
              run_simulation: true,
              component: "dhm",
              account: tk_account,
              search_mode: document.getElementById(
                "tenant_dhm_advanced_search_mode"
              ).value,
              earliest_time: document.getElementById(
                "tenant_dhm_advanced_mode_earliest"
              ).value,
              latest_time: document.getElementById(
                "tenant_dhm_advanced_mode_index_latest"
              ).value,
              index_earliest_time: document.getElementById(
                "tenant_dhm_advanced_mode_index_earliest"
              ).value,
              index_latest_time: document.getElementById(
                "tenant_dhm_advanced_mode_index_latest"
              ).value,
              search_constraint: tk_tenant_dhm_root_constraint,
              breakby_field: breakby_field,
            };

            // spinner
            $("#cssloader").remove();
            $("body").append(
              '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while we are running some Splunky searches..."></div>'
            );

            // Retrieve entity info from REST and set actions
            $.ajax({
              url: "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_simulation",
              type: "POST",
              async: true,
              contentType: "application/json",
              data: JSON.stringify(record),
              success: function (returneddata) {
                // search results
                simulation_results = returneddata["results"];

                if (simulation_results["dcount_entities"] > 0) {
                  $("#cssloader").remove();
                  show_results = {
                    entities_count: simulation_results["dcount_entities"],
                    entities_sample: simulation_results["entities_sample"],
                  };
                  message =
                    "OK! That's looking great: " +
                    JSON.stringify(show_results, null, 2);
                  notify("success", "bottom", message, "30");
                } else {
                  show_results = {
                    entities_count: simulation_results["dcount_entities"],
                    search: returneddata["tracker_simulation_search"],
                  };
                  message =
                    "Hold on! The search was successful but there were no entities found: " +
                    JSON.stringify(show_results, null, 2);
                  $("#cssloader").remove();
                  notify("error", "bottom", message, "30");
                }
                //
              },
              error: function (xhr, textStatus, error) {
                $("#cssloader").remove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                notify("error", "bottom", message, "30");
              },
            });
          });

          //
          // MHM
          //

          // Show message
          $("#tenant_mhm_enabled").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ You can choose to enable (default) or disable a component, at least one component needs to be enabled for the tenant to be created",
              "10"
            );
          });

          // track changes on the components inputs
          $("#tenant_mhm_enabled").on("click", function () {
            if ($(this).hasClass("btn-outline-primary")) {
              $(this).toggleClass("btn-outline-primary btn-outline-danger");
              $(this).addClass("tenant_mhm_disabled");
              $(this).removeClass("tenant_mhm_enabled");
              $(this).text("SPLK-MHM is Disabled - click to enable");
              $("#input_tenant_mhm_root_constraint").prop("disabled", true);
              $("#input_tenant_mhm_restrict_discovery").prop("disabled", true);
              $("#tenant_mhm_discovery").prop("disabled", true);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", true);
              $("#btn_create_tenant_mhm_advanced_options").prop(
                "disabled",
                true
              );
              $("#tenant_mhm_advanced_create_trackers").prop("disabled", true);
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Metric Host Monitoring component will be disabled for this tenant.",
                "5"
              );
            } else if ($(this).hasClass("btn-outline-danger")) {
              $(this).toggleClass("btn-outline-danger btn-outline-primary");
              $(this).removeClass("tenant_mhm_disabled");
              $(this).addClass("tenant_mhm_enabled");
              $(this).text("SPLK-MHM is Enabled - click to disable");
              $("#input_tenant_mhm_root_constraint").prop("disabled", false);
              $("#input_tenant_mhm_restrict_discovery").prop("disabled", false);
              $("#tenant_mhm_discovery").prop("disabled", false);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", false);
              $("#btn_create_tenant_mhm_advanced_options").prop(
                "disabled",
                false
              );
              $("#tenant_mhm_advanced_create_trackers").prop("disabled", false);
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Metric Host Monitoring component will be enabled for this tenant.",
                "5"
              );
            }
          });

          // show message
          $("#tenant_mhm_discovery").on("mouseover", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ The default behaviour is to discover data in every index reacheable from the root constraints, you can in addition restrict the indexes discovery using index patterns at any time of the tenant life cycle",
              "10"
            );
          });

          $("#tenant_mhm_discovery").on("click", function () {
            if ($(this).hasClass("btn-outline-info")) {
              $(this).toggleClass("btn-outline-info btn-outline-danger");
              $(this).text(
                "Discovery is restricted - click to remove restrictions"
              );
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Indexes discovery will be restricted for this tenant.",
                "5"
              );
              $("#tenant_mhm_discovery_list").prop("disabled", false);
              $("#div_tenant_mhm_discovery_list").css("opacity", "100%");
              $("#create_tenant_splk_feeds_step5").prop("disabled", true);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", true);
              // create tokens
              defaultTokenModel.set("tk_tenant_mhm_discovery", "restricted");
            } else if ($(this).hasClass("btn-outline-danger")) {
              $(this).toggleClass("btn-outline-danger btn-outline-info");
              $(this).text("Discovery is unrestricted - click to restrict");
              $(this).blur();
              notify(
                "success",
                "bottom",
                "Indexes discovery will be unrestricted for this tenant.",
                "5"
              );
              $("#tenant_mhm_discovery_list").prop("disabled", true);
              $("#div_tenant_mhm_discovery_list").css("opacity", "50%");
              $("#create_tenant_splk_feeds_step5").prop("disabled", false);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", false);
              // create tokens
              defaultTokenModel.set("tk_tenant_mhm_discovery", "unrestricted");
            }
          });

          // Indexes discovery

          $("#tenant_mhm_discovery_list").on("change keyup paste", function () {
            var values = $(this).tagsinput("items");
            defaultTokenModel.set("tk_tenant_mhm_discovery_list", values);
            // enable test now button if we have inputs
            if (values.length < 1) {
              $("#create_tenant_splk_feeds_step5").prop("disabled", true);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", true);
            } else {
              $("#create_tenant_splk_feeds_step5").prop("disabled", false);
              $("#create_tenant_splk_feeds_step4_test").prop("disabled", false);
            }
          });

          // Test now button
          $("#create_tenant_splk_feeds_step4_test").on("click", function () {
            notify(
              "info",
              "bottom",
              "Hold on! Starting the verification search now, please wait...",
              "60"
            );

            // Get the Splunk account
            var tk_account = getToken("tk_splk_mhm_deployment");

            // Get tenant_mhm_root_constraint
            var tk_tenant_mhm_root_constraint = document.getElementById(
              "input_tenant_mhm_root_constraint"
            ).value;

            // Get indexes discovery configuration
            var tk_tenant_mhm_discovery = getToken("tk_tenant_mhm_discovery");
            var tk_tenant_mhm_discovery_list = getToken(
              "tk_tenant_mhm_discovery_list"
            );

            // if index discovery is configured, the list of restricted indexes is a CSV list of patterns
            if (tk_tenant_mhm_discovery == "restricted") {
              tk_tenant_mhm_discovery_list =
                'index="' +
                tk_tenant_mhm_discovery_list
                  .toString()
                  .replace(/,/g, '" OR index="') +
                '"';
            } else if (tk_tenant_mhm_discovery == "unrestricted") {
              tk_tenant_mhm_discovery_list = "(index=* OR index=_*)";
            } else {
              tk_tenant_mhm_discovery = "unrestricted";
              tk_tenant_mhm_discovery_list = "(index=* OR index=_*)";
            }

            // get mhm mode
            var tk_tenant_mhm_advanced_mode = document.getElementById(
              "tenant_mhm_advanced_mode"
            ).value;
            var tk_tenant_mhm_advanced_mode_custom_fields =
              document.getElementById(
                "tenant_mhm_advanced_mode_custom_fields"
              ).value;

            // form the search constraint (indexes restrictions and search constraint)
            tk_tenant_mhm_root_constraint =
              tk_tenant_mhm_discovery_list +
              " " +
              tk_tenant_mhm_root_constraint;

            // form the breakby logic
            var breakby_field;
            if (tk_tenant_mhm_advanced_mode == "split") {
              breakby_field = "none";
            } else if (tk_tenant_mhm_advanced_mode == "merged") {
              breakby_field = "merged";
            } else {
              breakby_field = tk_tenant_mhm_advanced_mode_custom_fields;
            }

            var record = {
              run_simulation: true,
              component: "mhm",
              account: tk_account,
              search_mode: document.getElementById(
                "tenant_mhm_advanced_search_mode"
              ).value,
              earliest_time: document.getElementById(
                "tenant_mhm_advanced_mode_earliest"
              ).value,
              latest_time: document.getElementById(
                "tenant_mhm_advanced_mode_latest"
              ).value,
              cron_schedule: document.getElementById(
                "tenant_mhm_advanced_mode_cron"
              ).value,
              search_constraint: tk_tenant_mhm_root_constraint,
              breakby_field: breakby_field,
            };

            // spinner
            $("#cssloader").remove();
            $("body").append(
              '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while we are running some Splunky searches..."></div>'
            );

            // Retrieve entity info from REST and set actions
            $.ajax({
              url: "/en-US/splunkd/__raw/services/trackme/v2/splk_hybrid_trackers/admin/hybrid_tracker_simulation",
              type: "POST",
              async: true,
              contentType: "application/json",
              data: JSON.stringify(record),
              success: function (returneddata) {
                // search results
                simulation_results = returneddata["results"];

                if (simulation_results["dcount_entities"] > 0) {
                  $("#cssloader").remove();
                  show_results = {
                    entities_count: simulation_results["dcount_entities"],
                    entities_sample: simulation_results["entities_sample"],
                  };
                  message =
                    "OK! That's looking great: " +
                    JSON.stringify(show_results, null, 2);
                  notify("success", "bottom", message, "30");
                } else {
                  show_results = {
                    entities_count: simulation_results["dcount_entities"],
                    search: returneddata["tracker_simulation_search"],
                  };
                  message =
                    "Hold on! The search was successful but there were no entities found: " +
                    JSON.stringify(show_results, null, 2);
                  $("#cssloader").remove();
                  notify("error", "bottom", message, "30");
                }
                //
              },
              error: function (xhr, textStatus, error) {
                $("#cssloader").remove();
                message =
                  "server response: " +
                  xhr.responseText +
                  "\n - http response: " +
                  error;
                $("#modal_update_collection_failure_return")
                  .find(".modal-error-message p")
                  .text(message);
                notify("error", "bottom", message, "30");
              },
            });
          });

          //
          // COMPONENTS ENABLED VERIFICATIONS
          //

          // At step 4 of the tenant creation, we need to verify that at least one component was enabled
          $("#create_tenant_splk_feeds_step4")
            .unbind()
            .click(function () {
              // Get tenant_dsm_enabled
              var tk_tenant_dsm_enabled;
              if ($("#tenant_dsm_enabled").is(".tenant_dsm_enabled")) {
                tk_tenant_dsm_enabled = true;
              } else {
                tk_tenant_dsm_enabled = false;
              }

              // Get tenant_dhm_enabled
              var tk_tenant_dhm_enabled;
              if ($("#tenant_dhm_enabled").is(".tenant_dhm_enabled")) {
                tk_tenant_dhm_enabled = true;
              } else {
                tk_tenant_dhm_enabled = false;
              }

              // Get tenant_mhm_enabled
              var tk_tenant_mhm_enabled;
              if ($("#tenant_mhm_enabled").is(".tenant_mhm_enabled")) {
                tk_tenant_mhm_enabled = true;
              } else {
                tk_tenant_mhm_enabled = false;
              }

              if (
                !tk_tenant_dsm_enabled &&
                !tk_tenant_dhm_enabled &&
                !tk_tenant_mhm_enabled
              ) {
                var errorStr =
                  "At least one component needs to be enabled for the tenant to be created, components that can be enabled are: Data Source Monitoring / Data Host Monitoring / Metric Host Monitoring";
                $("#modal_invalid_selection")
                  .find(".modal-error-message p")
                  .text(errorStr);

                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_feeds_main4"
                );

                $("#modal_create_tenant_splk_feeds_main5").modal("hide");
                $("#modal_invalid_selection").modal();
              } else {
                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_feeds_main4"
                );
                $("#modal_create_tenant_splk_feeds_main5").modal();
              }
            });

          //
          // RBAC INPUTS VERIFICATIONS
          //

          // Verify RBAC input

          //
          // splk-feeds
          //

          $("#create_tenant_splk_feeds_confirm")
            .unbind()
            .click(function () {
              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_feeds"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_feeds"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_feeds"
              );

              if (
                tk_tenant_roles_admin.length < 1 ||
                tk_tenant_roles_admin == "null" ||
                tk_tenant_roles_power.length < 1 ||
                tk_tenant_roles_power == "null" ||
                tk_tenant_roles_user.length < 1 ||
                tk_tenant_roles_user == "null"
              ) {
                var errorStr =
                  "The RBAC configuration is invalid, at least one role for administration and one role for users have to be configured";
                $("#modal_invalid_selection")
                  .find(".modal-error-message p")
                  .text(errorStr);

                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute("href", "#modal_create_tenant_main5");

                $("#modal_create_tenant_splk_feeds_confirm").modal("hide");
                $("#modal_invalid_selection").modal();
              } else {
                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute("href", "#modal_create_tenant_main5");
                $("#modal_create_tenant_splk_feeds_confirm").modal();
              }
            });

          //
          // splk-cim
          //

          $("#create_tenant_splk_cim_confirm")
            .unbind()
            .click(function () {
              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_cim"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_cim"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_cim"
              );

              if (
                tk_tenant_roles_admin.length < 1 ||
                tk_tenant_roles_admin == "null" ||
                tk_tenant_roles_power.length < 1 ||
                tk_tenant_roles_power == "null" ||
                tk_tenant_roles_user.length < 1 ||
                tk_tenant_roles_user == "null"
              ) {
                var errorStr =
                  "The RBAC configuration is invalid, at least one role for administration and one role for users have to be configured";
                $("#modal_invalid_selection")
                  .find(".modal-error-message p")
                  .text(errorStr);

                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_cim_main3"
                );

                $("#modal_create_tenant_splk_cim_confirm").modal("hide");
                $("#modal_invalid_selection").modal();
              } else {
                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_cim_main3"
                );
                $("#modal_create_tenant_splk_cim_confirm").modal();
              }
            });

          //
          // splk-flx
          //

          $("#create_tenant_splk_flx_confirm")
            .unbind()
            .click(function () {
              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_flx"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_flx"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_flx"
              );

              if (
                tk_tenant_roles_admin.length < 1 ||
                tk_tenant_roles_admin == "null" ||
                tk_tenant_roles_power.length < 1 ||
                tk_tenant_roles_power == "null" ||
                tk_tenant_roles_user.length < 1 ||
                tk_tenant_roles_user == "null"
              ) {
                var errorStr =
                  "The RBAC configuration is invalid, at least one role for administration and one role for users have to be configured";
                $("#modal_invalid_selection")
                  .find(".modal-error-message p")
                  .text(errorStr);

                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_flx_main3"
                );

                $("#modal_create_tenant_splk_flx_confirm").modal("hide");
                $("#modal_invalid_selection").modal();
              } else {
                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_flx_main3"
                );
                $("#modal_create_tenant_splk_flx_confirm").modal();
              }
            });

          //
          // splk-replica
          //

          $("#create_tenant_splk_replica_confirm")
            .unbind()
            .click(function () {
              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_replica"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_replica"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_replica"
              );

              if (
                tk_tenant_roles_admin.length < 1 ||
                tk_tenant_roles_admin == "null" ||
                tk_tenant_roles_power.length < 1 ||
                tk_tenant_roles_power == "null" ||
                tk_tenant_roles_user.length < 1 ||
                tk_tenant_roles_user == "null"
              ) {
                var errorStr =
                  "The RBAC configuration is invalid, at least one role for administration and one role for users have to be configured";
                $("#modal_invalid_selection")
                  .find(".modal-error-message p")
                  .text(errorStr);

                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_replica_main3"
                );

                $("#modal_create_tenant_splk_replica_confirm").modal("hide");
                $("#modal_invalid_selection").modal();
              } else {
                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_replica_main3"
                );
                $("#modal_create_tenant_splk_replica_confirm").modal();
              }
            });

          // Vendor components
          $("#btn_start_create_tenant").on("click", function () {
            // check licensing
            var doAsync = asyncAjax(
              "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
              "GET"
            ).then(function (licenseCall) {
              // get the number of active tenants
              var license_is_valid = licenseCall["license_is_valid"];
              var license_active_tenants =
                licenseCall["license_active_tenants"];
              var license_subscription_class =
                licenseCall["license_subscription_class"];

              // proceed
              if (license_active_tenants >= 2 && license_is_valid != 1) {
                $("#modal_licensing_max_tenants")
                  .find(".modal-info-message")
                  .text(
                    "There are " +
                      license_active_tenants +
                      " active tenants and this deployment is currently running in Free limited edition mode. The Free limited edition mode is limited to 2 active tenants at a time." +
                      " To create a new tenant, you can disable or delete an existing tenant, register a valid license or start a Trial period."
                  );
                closeModals();
                $("#modal_licensing_max_tenants").modal();
              } else if (
                license_active_tenants >= 2 &&
                license_subscription_class == "free_extended"
              ) {
                $("#modal_licensing_max_tenants")
                  .find(".modal-info-message")
                  .text(
                    "There are " +
                      license_active_tenants +
                      " active tenants and this deployment is currently running in Free extended edition mode. The Free extended edition mode is limited to 2 active tenants at a time." +
                      " To create a new tenant, you can disable or delete an existing tenant, register a valid license or start a Trial period."
                  );
                closeModals();
                $("#modal_licensing_max_tenants").modal();
              } else if (
                license_active_tenants >= 6 &&
                license_subscription_class == "enterprise"
              ) {
                $("#modal_licensing_max_tenants")
                  .find(".modal-info-message")
                  .text(
                    "There are " +
                      license_active_tenants +
                      " active tenants and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 6 active tenants at a time." +
                      " To create a new tenant, you can disable or delete an existing tenant, or register a valid Unlimited license."
                  );
                closeModals();
                $("#modal_licensing_max_tenants").modal();
              } else {
                $("#modal_type_tenant").modal();
                notify(
                  "info",
                  "bottom",
                  "Welcome! Choose a component to start the creation a new TracKme tenant, and track the great value in your big data",
                  "60"
                );
                // Start the account populating search
                searchPopulateConfigurationAccounts.startSearch();
              }
            });
          });

          //
          // splk-wlk
          //

          $("#link_wlk_check_scheduler")
            .unbind()
            .click(function (e) {
              // Prevent the default action
              e.preventDefault();
              var search;
              var tk_tenant_wlk_root_constraint = document.getElementById(
                "input_tenant_wlk_root_constraint_scheduler"
              ).value;
              // set the search
              var rootsearch =
                '(index=_internal sourcetype=scheduler) | eval alert_actions=if((isnull(alert_actions) OR (alert_actions == "")), "none", alert_actions) | rex field=savedsearch_id "^(?<user_alt>[^;]*);(?<app_alt>[^;]*);(?<savedsearch_name_alt>.*)" | eval user=coalesce(user, user_alt), app=coalesce(app, app_alt), savedsearch_name=coalesce(savedsearch_name, savedsearch_name_alt) | search ' +
                tk_tenant_wlk_root_constraint;
              // Get account
              var tk_splk_wlk_accounts = getToken("tk_splk_wlk_accounts");
              // Set the search
              if (tk_splk_wlk_accounts != "local") {
                rootsearch =
                  'splunkremotesearch account="' +
                  tk_splk_wlk_accounts +
                  '" search="' +
                  rootsearch.replace(/\"/g, '\\"') +
                  '"';
                search =
                  "search" +
                  "?q=%7C%20" +
                  encodeURIComponent(rootsearch) +
                  "&earliest=" +
                  encodeURI("-24h") +
                  "&latest=" +
                  encodeURI("now");
              } else {
                search =
                  "search" +
                  "?q=search%20" +
                  encodeURIComponent(rootsearch) +
                  "&earliest=" +
                  encodeURI("-24h") +
                  "&latest=" +
                  encodeURI("now");
              }
              // Open
              window.open(search, "_blank");
            });

          $("#link_wlk_check_introspection")
            .unbind()
            .click(function (e) {
              // Prevent the default action
              e.preventDefault();
              var search;
              var tk_tenant_wlk_root_constraint = document.getElementById(
                "input_tenant_wlk_root_constraint_introspection"
              ).value;
              // set the search
              var rootsearch =
                '(index=_introspection sourcetype=splunk_resource_usage) component=PerProcess data.process_type="search" data.search_props.user="*" data.search_props.app="*" data.search_props.label="*" ' +
                tk_tenant_wlk_root_constraint;
              // Get account
              var tk_splk_wlk_accounts = getToken("tk_splk_wlk_accounts");
              // Set the search
              if (tk_splk_wlk_accounts != "local") {
                rootsearch =
                  'splunkremotesearch account="' +
                  tk_splk_wlk_accounts +
                  '" search="' +
                  rootsearch.replace(/\"/g, '\\"') +
                  '"';
                search =
                  "search" +
                  "?q=%7C%20" +
                  encodeURIComponent(rootsearch) +
                  "&earliest=" +
                  encodeURI("-24h") +
                  "&latest=" +
                  encodeURI("now");
              } else {
                search =
                  "search" +
                  "?q=search%20" +
                  encodeURIComponent(rootsearch) +
                  "&earliest=" +
                  encodeURI("-24h") +
                  "&latest=" +
                  encodeURI("now");
              }
              // Open
              window.open(search, "_blank");
            });

          $("#link_wlk_check_svc")
            .unbind()
            .click(function (e) {
              // Prevent the default action
              e.preventDefault();
              var search;
              var tk_tenant_wlk_root_constraint = document.getElementById(
                "input_tenant_wlk_root_constraint_svc"
              ).value;
              // set the search
              var rootsearch =
                '(index=summary source="splunk-svc-consumer") (search_type!="ad-hoc") svc_usage=* svc_consumer=search search_label=* ' +
                tk_tenant_wlk_root_constraint;
              // Get account
              var tk_splk_wlk_accounts = getToken("tk_splk_wlk_accounts");
              // Set the search
              if (tk_splk_wlk_accounts != "local") {
                rootsearch =
                  'splunkremotesearch account="' +
                  tk_splk_wlk_accounts +
                  '" search="' +
                  rootsearch.replace(/\"/g, '\\"') +
                  '"';
                search =
                  "search" +
                  "?q=%7C%20" +
                  encodeURIComponent(rootsearch) +
                  "&earliest=" +
                  encodeURI("-24h") +
                  "&latest=" +
                  encodeURI("now");
              } else {
                search =
                  "search" +
                  "?q=search%20" +
                  encodeURIComponent(rootsearch) +
                  "&earliest=" +
                  encodeURI("-24h") +
                  "&latest=" +
                  encodeURI("now");
              }
              // Open
              window.open(search, "_blank");
            });

          $("#create_tenant_splk_wlk_confirm")
            .unbind()
            .click(function () {
              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_wlk"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_wlk"
              );

              if (
                tk_tenant_roles_admin.length < 1 ||
                tk_tenant_roles_admin == "null" ||
                tk_tenant_roles_user.length < 1 ||
                tk_tenant_roles_user == "null"
              ) {
                var errorStr =
                  "The RBAC configuration is invalid, at least one role for administration and one role for users have to be configured";
                $("#modal_invalid_selection")
                  .find(".modal-error-message p")
                  .text(errorStr);

                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_wlk_main3"
                );

                $("#modal_create_tenant_splk_wlk_confirm").modal("hide");
                $("#modal_invalid_selection").modal();
              } else {
                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute(
                  "href",
                  "#modal_create_tenant_splk_wlk_main3"
                );
                $("#modal_create_tenant_splk_wlk_confirm").modal();
              }
            });

          // Vendor components
          $("#btn_start_create_tenant").on("click", function () {
            // check licensing
            var doAsync = asyncAjax(
              "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
              "GET"
            ).then(function (licenseCall) {
              // get the number of active tenants
              var license_is_valid = licenseCall["license_is_valid"];
              var license_active_tenants =
                licenseCall["license_active_tenants"];
              var license_subscription_class =
                licenseCall["license_subscription_class"];

              // proceed
              if (license_active_tenants >= 2 && license_is_valid != 1) {
                $("#modal_licensing_max_tenants")
                  .find(".modal-info-message")
                  .text(
                    "There are " +
                      license_active_tenants +
                      " active tenants and this deployment is currently running in Free limited edition mode. The Free limited edition mode is limited to 2 active tenants at a time." +
                      " To create a new tenant, you can disable or delete an existing tenant, register a valid license or start a Trial period."
                  );
                closeModals();
                $("#modal_licensing_max_tenants").modal();
              } else if (
                license_active_tenants >= 6 &&
                license_subscription_class == "enterprise"
              ) {
                $("#modal_licensing_max_tenants")
                  .find(".modal-info-message")
                  .text(
                    "There are " +
                      license_active_tenants +
                      " active tenants and this deployment is currently running in Enterprise edition mode. The Enterprise limited edition mode is limited to 6 active tenants at a time." +
                      " To create a new tenant, you can disable or delete an existing tenant, or register a valid Unlimited license."
                  );
                closeModals();
                $("#modal_licensing_max_tenants").modal();
              } else {
                $("#modal_type_tenant").modal();
                notify(
                  "info",
                  "bottom",
                  "Welcome! Choose a component to start the creation a new TracKme tenant, and track the great value in your big data",
                  "60"
                );
                // Start the account populating search
                searchPopulateConfigurationAccounts.startSearch();
              }
            });
          });

          // Start from scratch
          $("#btn_start_creation_from_scratch").on("click", function () {
            notify(
              "info",
              "bottom",
              "Welcome! Choose a component to start the creation a new TracKme tenant, and track the great value in your big data",
              "60"
            );
            // Start the account populating search
            searchPopulateConfigurationAccounts.startSearch();
          });

          //
          // Start message
          //

          // splk-feeds

          $("#vendor-splunk-data-feeds").on("click", function () {
            // Start related searches
            searchListRoles.startSearch();
            searchListUsers.startSearch();
            searchListIdxSummary.startSearch();
            searchListIdxAudit.startSearch();
            searchListIdxNotable.startSearch();
            searchListIdxMetric.startSearch();
            // clear out textarea
            document.getElementById("input_tenant_name_splk_feeds").value = "";
            document.getElementById(
              "input_tenant_description_splk_feeds"
            ).value = "";
            // next should be disabled by default
            $("#create_tenant_splk_feeds_step1").prop("disabled", true);
            notify(
              "info",
              "bottom",
              "Enter the tenant identifier and a description to start the tenant creation process!",
              "60"
            );
          });

          $("#back_create_tenant_splk_feeds_step2").on("click", function () {
            notify(
              "info",
              "bottom",
              "Welcome! Enter the tenant identifier and a description to start the tenant creation process!",
              "60"
            );
          });

          // splk-cim

          $("#vendor-splunk-data-cim").on("click", function () {
            // check licensing
            $("body").append(
              '<div id="cssloader" class="loader loader-default is-active" data-text="Getting ready, please wait..."></div>'
            );
            var doAsync = asyncAjax(
              "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
              "GET"
            ).then(function (licenseCall) {
              // get the license status
              var license_is_valid = licenseCall["license_is_valid"];
              // get the subscription class
              var license_subscription_class =
                licenseCall["license_subscription_class"];
              // proceed
              $("#cssloader").remove();
              if (
                license_is_valid != 1 &&
                license_subscription_class != "free_extended"
              ) {
                $("#modal_licensing_restricted_component").modal();
              } else {
                // Open modal
                $("#modal_create_tenant_splk_cim_main1").modal();
                // Start related searches
                searchListRoles.startSearch();
                searchListUsers.startSearch();
                searchListIdxSummary.startSearch();
                searchListIdxAudit.startSearch();
                searchListIdxNotable.startSearch();
                searchListIdxMetric.startSearch();
                // clear out textarea
                document.getElementById("input_tenant_name_splk_cim").value =
                  "";
                document.getElementById(
                  "input_tenant_description_splk_cim"
                ).value = "";
                // next should be disabled by default
                $("#create_tenant_splk_cim_step1").prop("disabled", true);
                notify(
                  "info",
                  "bottom",
                  "Enter the tenant identifier and a description to start the tenant creation process!",
                  "60"
                );
              }
            });
          });

          $("#back_create_tenant_splk_cim_step2").on("click", function () {
            notify(
              "info",
              "bottom",
              "Welcome! Enter the tenant identifier and a description to start the tenant creation process!",
              "60"
            );
          });

          // splk-flx

          $("#vendor-splunk-data-flx").on("click", function () {
            // check licensing
            $("body").append(
              '<div id="cssloader" class="loader loader-default is-active" data-text="Getting ready, please wait..."></div>'
            );
            var doAsync = asyncAjax(
              "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
              "GET"
            ).then(function (licenseCall) {
              // get the license status
              var license_is_valid = licenseCall["license_is_valid"];
              // get the subscription class
              var license_subscription_class =
                licenseCall["license_subscription_class"];
              // proceed
              $("#cssloader").remove();
              if (
                license_is_valid != 1 &&
                license_subscription_class != "free_extended"
              ) {
                $("#modal_licensing_restricted_component").modal();
              } else {
                // Open modal
                $("#modal_create_tenant_splk_flx_main1").modal();
                // Start related searches
                searchListRoles.startSearch();
                searchListUsers.startSearch();
                searchListIdxSummary.startSearch();
                searchListIdxAudit.startSearch();
                searchListIdxNotable.startSearch();
                searchListIdxMetric.startSearch();
                // clear out textarea
                document.getElementById("input_tenant_name_splk_flx").value =
                  "";
                document.getElementById(
                  "input_tenant_description_splk_flx"
                ).value = "";
                // next should be disabled by default
                $("#create_tenant_splk_flx_step1").prop("disabled", true);
                notify(
                  "info",
                  "bottom",
                  "Enter the tenant identifier and a description to start the tenant creation process!",
                  "60"
                );
              }
            });
          });

          $("#back_create_tenant_splk_flx_step2").on("click", function () {
            notify(
              "info",
              "bottom",
              "Welcome! Enter the tenant identifier and a description to start the tenant creation process!",
              "60"
            );
          });

          // splk-replica

          $("#btn_start_create_tenant_replica").on("click", function () {
            // check licensing
            $("body").append(
              '<div id="cssloader" class="loader loader-default is-active" data-text="Getting ready, please wait..."></div>'
            );
            var doAsync = asyncAjax(
              "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
              "GET"
            ).then(function (licenseCall) {
              // get the license status
              var license_is_valid = licenseCall["license_is_valid"];
              // get the subscription class
              var license_subscription_class =
                licenseCall["license_subscription_class"];
              // proceed
              $("#cssloader").remove();
              if (
                license_is_valid != 1 &&
                license_subscription_class != "free_extended"
              ) {
                $("#modal_licensing_restricted_component").modal();
              } else {
                // Open modal
                $("#modal_create_tenant_splk_replica_main1").modal();
                // Start related searches
                searchListRoles.startSearch();
                searchListUsers.startSearch();
                searchListIdxSummary.startSearch();
                searchListIdxAudit.startSearch();
                searchListIdxNotable.startSearch();
                searchListIdxMetric.startSearch();
                searchListComponents.startSearch();
                // clear out textarea
                document.getElementById(
                  "input_tenant_name_splk_replica"
                ).value = "";
                document.getElementById(
                  "input_tenant_description_splk_replica"
                ).value = "";
                // next should be disabled by default
                $("#create_tenant_splk_replica_step1").prop("disabled", true);
                notify(
                  "info",
                  "bottom",
                  "Enter the tenant identifier and a description to start the tenant creation process!",
                  "60"
                );
              }
            });
          });

          $("#back_create_tenant_splk_replica_step2").on("click", function () {
            notify(
              "info",
              "bottom",
              "Welcome! Enter the tenant identifier and a description to start the tenant creation process!",
              "60"
            );
          });

          // splk-wlk

          $("#vendor-splunk-data-wlk").on("click", function () {
            // check licensing
            $("body").append(
              '<div id="cssloader" class="loader loader-default is-active" data-text="Getting ready, please wait..."></div>'
            );
            var doAsync = asyncAjax(
              "/en-US/splunkd/__raw/services/trackme/v2/licensing/license_status",
              "GET"
            ).then(function (licenseCall) {
              // get the license status
              var license_is_valid = licenseCall["license_is_valid"];
              // proceed
              $("#cssloader").remove();
              if (license_is_valid != 1) {
                $("#modal_licensing_restricted_component").modal();
              } else {
                // Open modal
                $("#modal_create_tenant_splk_wlk_main1").modal();
                // Start related searches
                searchListRoles.startSearch();
                searchListUsers.startSearch();
                searchListIdxSummary.startSearch();
                searchListIdxAudit.startSearch();
                searchListIdxNotable.startSearch();
                searchListIdxMetric.startSearch();
                // clear out textarea
                document.getElementById("input_tenant_name_splk_wlk").value =
                  "";
                document.getElementById(
                  "input_tenant_description_splk_wlk"
                ).value = "";
                // next should be disabled by default
                $("#create_tenant_splk_wlk_step1").prop("disabled", true);
                notify(
                  "info",
                  "bottom",
                  "Enter the tenant identifier and a description to start the tenant creation process!",
                  "60"
                );
              }
            });
          });

          $("#back_create_tenant_splk_wlk_step2").on("click", function () {
            notify(
              "info",
              "bottom",
              "Welcome! Enter the tenant identifier and a description to start the tenant creation process!",
              "60"
            );
          });

          //
          // splk-feeds
          //

          // Step 1 message
          $("#create_tenant_splk_feeds_step1").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Data Sources Tracking: choose if the component should be enabled for this tenant and configure its main options, click on the test now button to verify your settings and get a preview!",
              "60"
            );
          });

          $("#back_create_tenant_splk_feeds_step3").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Data Sources Tracking: choose if the component should be enabled for this tenant and configure its main options, click on the test now button to verify your settings and get a preview!",
              "60"
            );
          });

          // Step 2 message
          $("#create_tenant_splk_feeds_step2").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Common Information Model (CIM) Tracking: choose if the component should be enabled for this tenant and configure its main options",
              "60"
            );
          });

          $("#back_create_tenant_splk_feeds_step3").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Common Information Model (CIM) Tracking: choose if the component should be enabled for this tenant and configure its main options",
              "60"
            );
          });

          // Step 2 message
          $("#create_tenant_splk_feeds_step3").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Event Endpoint Tracking: monitoring events from the endpoint perspective, click on the test now button to verify your settings and get a preview!",
              "60"
            );
          });

          $("#back_create_tenant_splk_feeds_step4").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Event Endpoint Tracking: monitoring events from the endpoint perspective, click on the test now button to verify your settings and get a preview!",
              "60"
            );
          });

          // Step 3 message
          $("#create_tenant_splk_feeds_step3").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Metric Endpoint Tracking: monitoring metrics from the endpoint perspective, click on the test now button to verify your settings and get a preview!",
              "60"
            );
          });

          $("#back_create_tenant_splk_feeds_confirm").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ SPLK Metric Endpoint Tracking: monitoring metrics from the endpoint perspective, click on the test now button to verify your settings and get a preview!",
              "60"
            );
          });

          // Step 5 messages
          $("#create_tenant_splk_feeds_step5").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ Configure the RBAC settings for the tenant, you can setup the Splunk roles which provide administrative privileges, the roles for standard users and the Splunk owner of the tenant knowledge objects",
              "60"
            );
          });

          $("#back_create_tenant_splk_feeds").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ Configure the RBAC settings for the tenant, you can setup the Splunk roles which provide administrative privileges, the roles for standard users and the Splunk owner of the tenant knowledge objects",
              "60"
            );
          });

          // Step final messages
          $("#create_tenant_splk_feeds_confirm").on("click", function () {
            notify(
              "info",
              "bottom",
              "Ready! The tenant is now ready to be created, all knowledge objects dedicated to this tenant are going to be created dynamically, at the end of the process the new tenant is active and ready to be used!",
              "60"
            );
          });

          //
          // splk-cim
          //

          // Step 2 messages
          $("#create_tenant_splk_cim_step2").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ Configure the RBAC settings for the tenant, you can setup the Splunk roles which provide administrative privileges, the roles for standard users and the Splunk owner of the tenant knowledge objects",
              "60"
            );
          });

          $("#back_create_tenant_splk_cim").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ Configure the RBAC settings for the tenant, you can setup the Splunk roles which provide administrative privileges, the roles for standard users and the Splunk owner of the tenant knowledge objects",
              "60"
            );
          });

          $("#back_create_tenant_splk_flx").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ Configure the RBAC settings for the tenant, you can setup the Splunk roles which provide administrative privileges, the roles for standard users and the Splunk owner of the tenant knowledge objects",
              "60"
            );
          });

          $("#back_create_tenant_splk_wlk").on("click", function () {
            notify(
              "info",
              "bottom",
              "ℹ️ Configure the RBAC settings for the tenant, you can setup the Splunk roles which provide administrative privileges, the roles for standard users and the Splunk owner of the tenant knowledge objects",
              "60"
            );
          });

          // Step final messages
          $("#create_tenant_splk_cim_confirm").on("click", function () {
            notify(
              "info",
              "bottom",
              "Ready! The tenant is now ready to be created, all knowledge objects dedicated to this tenant are going to be created dynamically, at the end of the process the new tenant is active and ready to be used!",
              "60"
            );
          });

          $("#create_tenant_splk_flx_confirm").on("click", function () {
            notify(
              "info",
              "bottom",
              "Ready! The tenant is now ready to be created, all knowledge objects dedicated to this tenant are going to be created dynamically, at the end of the process the new tenant is active and ready to be used!",
              "60"
            );
          });

          $("#create_tenant_splk_wlk_confirm").on("click", function () {
            notify(
              "info",
              "bottom",
              "Ready! The tenant is now ready to be created, all knowledge objects dedicated to this tenant are going to be created dynamically, at the end of the process the new tenant is active and ready to be used!",
              "60"
            );
          });

          //
          // go creation
          //

          // splk-feeds

          // splk-dsm

          function goSplkDsmCreateHybridTrackerReturnDict(tenant_id, owner) {
            // Get the Splunk account
            var tk_account = getToken("tk_splk_dsm_deployment");

            // Get tenant_dsm_root_constraint
            var tk_tenant_dsm_root_constraint = document.getElementById(
              "input_tenant_dsm_root_constraint"
            ).value;

            // Get indexes discovery configuration
            var tk_tenant_dsm_discovery = getToken("tk_tenant_dsm_discovery");
            var tk_tenant_dsm_discovery_list = getToken(
              "tk_tenant_dsm_discovery_list"
            );

            // if index discovery is configured, the list of restricted indexes is a CSV list of patterns
            if (tk_tenant_dsm_discovery == "restricted") {
              tk_tenant_dsm_discovery_list =
                'index="' +
                tk_tenant_dsm_discovery_list
                  .toString()
                  .replace(/,/g, '" OR index="') +
                '"';
            } else if (tk_tenant_dsm_discovery == "unrestricted") {
              tk_tenant_dsm_discovery_list = "(index=* OR index=_*)";
            } else {
              tk_tenant_dsm_discovery = "unrestricted";
              tk_tenant_dsm_discovery_list = "(index=* OR index=_*)";
            }

            // get dsm mode
            var tk_tenant_dsm_advanced_mode = document.getElementById(
              "tenant_dsm_advanced_mode"
            ).value;
            var tk_tenant_dsm_advanced_mode_custom_fields =
              document.getElementById(
                "tenant_dsm_advanced_mode_custom_fields"
              ).value;

            // form the search constraint (indexes restrictions and search constraint)
            tk_tenant_dsm_root_constraint =
              tk_tenant_dsm_discovery_list +
              " " +
              tk_tenant_dsm_root_constraint;

            // form the breakby logic
            var breakby_field;
            if (tk_tenant_dsm_advanced_mode == "split") {
              breakby_field = "none";
            } else if (tk_tenant_dsm_advanced_mode == "merged") {
              breakby_field = "merged";
            } else {
              breakby_field = tk_tenant_dsm_advanced_mode_custom_fields;

              // convert to an array
              breakby_field_array = breakby_field.split(",");

              // remove index if present
              if (breakby_field_array.includes("index")) {
                breakby_field_array.splice(
                  breakby_field_array.indexOf("index"),
                  1
                ); //deleting
              }

              // remove sourcetype if present
              if (breakby_field_array.includes("sourcetype")) {
                breakby_field_array.splice(
                  breakby_field_array.indexOf("sourcetype"),
                  1
                ); //deleting
              }

              // convert back
              breakby_field = String(breakby_field_array);
            }

            var record = {
              tenant_id: tenant_id,
              component: "dsm",
              tracker_name: tk_account,
              account: tk_account,
              owner: owner,
              search_mode: document.getElementById(
                "tenant_dsm_advanced_search_mode"
              ).value,
              earliest_time: document.getElementById(
                "tenant_dsm_advanced_mode_earliest"
              ).value,
              latest_time: document.getElementById(
                "tenant_dsm_advanced_mode_latest"
              ).value,
              index_earliest_time: document.getElementById(
                "tenant_dsm_advanced_mode_index_earliest"
              ).value,
              index_latest_time: document.getElementById(
                "tenant_dsm_advanced_mode_index_latest"
              ).value,
              root_constraint: tk_tenant_dsm_root_constraint,
              breakby_field: breakby_field,
              dsm_tstats_root_time_span: document.getElementById(
                "tenant_dsm_advanced_tstats_root_span"
              ).value,
              dsm_tstats_root_breakby_include_splunk_server:
                document.getElementById(
                  "tenant_dsm_advanced_tstats_root_include_splunk_server"
                ).value,
              dsm_tstats_root_breakby_include_host: document.getElementById(
                "tenant_dsm_advanced_tstats_root_include_host"
              ).value,
            };

            // return
            return record;
          }

          // splk-dhm

          function goSplkDhmCreateHybridTrackerReturnDict(tenant_id, owner) {
            // Get the Splunk account
            var tk_account = getToken("tk_splk_dhm_deployment");

            // Get tenant_dhm_root_constraint
            var tk_tenant_dhm_root_constraint = document.getElementById(
              "input_tenant_dhm_root_constraint"
            ).value;

            // Get indexes discovery configuration
            var tk_tenant_dhm_discovery = getToken("tk_tenant_dhm_discovery");
            var tk_tenant_dhm_discovery_list = getToken(
              "tk_tenant_dhm_discovery_list"
            );

            // if index discovery is configured, the list of restricted indexes is a CSV list of patterns
            if (tk_tenant_dhm_discovery == "restricted") {
              tk_tenant_dhm_discovery_list =
                'index="' +
                tk_tenant_dhm_discovery_list
                  .toString()
                  .replace(/,/g, '" OR index="') +
                '"';
            } else if (tk_tenant_dhm_discovery == "unrestricted") {
              tk_tenant_dhm_discovery_list = "(index=main OR index=_*)";
            } else {
              tk_tenant_dhm_discovery = "unrestricted";
              tk_tenant_dhm_discovery_list = "(index=main OR index=_*)";
            }

            // get dhm mode
            var tk_tenant_dhm_advanced_mode = document.getElementById(
              "tenant_dhm_advanced_mode"
            ).value;
            var tk_tenant_dhm_advanced_mode_custom_fields =
              document.getElementById(
                "tenant_dhm_advanced_mode_custom_fields"
              ).value;

            // form the search constraint (indexes restrictions and search constraint)
            tk_tenant_dhm_root_constraint =
              tk_tenant_dhm_discovery_list +
              " " +
              tk_tenant_dhm_root_constraint;

            // form the breakby logic
            var breakby_field;
            if (tk_tenant_dhm_advanced_mode == "split") {
              breakby_field = "none";
            } else if (tk_tenant_dhm_advanced_mode == "merged") {
              breakby_field = "merged";
            } else {
              breakby_field = tk_tenant_dhm_advanced_mode_custom_fields;
            }

            var record = {
              tenant_id: tenant_id,
              component: "dhm",
              tracker_name: tk_account,
              account: tk_account,
              owner: owner,
              search_mode: document.getElementById(
                "tenant_dhm_advanced_search_mode"
              ).value,
              earliest_time: document.getElementById(
                "tenant_dhm_advanced_mode_earliest"
              ).value,
              latest_time: document.getElementById(
                "tenant_dhm_advanced_mode_index_latest"
              ).value,
              cron_schedule: document.getElementById(
                "tenant_dhm_advanced_mode_cron"
              ).value,
              index_earliest_time: document.getElementById(
                "tenant_dhm_advanced_mode_index_earliest"
              ).value,
              index_latest_time: document.getElementById(
                "tenant_dhm_advanced_mode_index_latest"
              ).value,
              root_constraint: tk_tenant_dhm_root_constraint,
              breakby_field: breakby_field,
              dhm_tstats_root_time_span: document.getElementById(
                "tenant_dhm_advanced_tstats_root_span"
              ).value,
              tenant_dhm_advanced_tstats_root_include_splunk_server:
                document.getElementById(
                  "tenant_dhm_advanced_tstats_root_include_splunk_server"
                ).value,
            };

            // return
            return record;
          }

          // splk-mhm

          function goSplkMhmCreateHybridTrackerReturnDict(tenant_id, owner) {
            // Get the Splunk account
            var tk_account = getToken("tk_splk_mhm_deployment");

            // Get tenant_mhm_root_constraint
            var tk_tenant_mhm_root_constraint = document.getElementById(
              "input_tenant_mhm_root_constraint"
            ).value;

            // Get indexes discovery configuration
            var tk_tenant_mhm_discovery = getToken("tk_tenant_mhm_discovery");
            var tk_tenant_mhm_discovery_list = getToken(
              "tk_tenant_mhm_discovery_list"
            );

            // if index discovery is configured, the list of restricted indexes is a CSV list of patterns
            if (tk_tenant_mhm_discovery == "restricted") {
              tk_tenant_mhm_discovery_list =
                'index="' +
                tk_tenant_mhm_discovery_list
                  .toString()
                  .replace(/,/g, '" OR index="') +
                '"';
            } else if (tk_tenant_mhm_discovery == "unrestricted") {
              tk_tenant_mhm_discovery_list = "(index=* OR index=_*)";
            } else {
              tk_tenant_mhm_discovery = "unrestricted";
              tk_tenant_mhm_discovery_list = "(index=* OR index=_*)";
            }

            // get mhm mode
            var tk_tenant_mhm_advanced_mode = document.getElementById(
              "tenant_mhm_advanced_mode"
            ).value;
            var tk_tenant_mhm_advanced_mode_custom_fields =
              document.getElementById(
                "tenant_mhm_advanced_mode_custom_fields"
              ).value;

            // form the search constraint (indexes restrictions and search constraint)
            tk_tenant_mhm_root_constraint =
              tk_tenant_mhm_discovery_list +
              " " +
              tk_tenant_mhm_root_constraint;

            // form the breakby logic
            var breakby_field;
            if (tk_tenant_mhm_advanced_mode == "split") {
              breakby_field = "none";
            } else if (tk_tenant_mhm_advanced_mode == "merged") {
              breakby_field = "merged";
            } else {
              breakby_field = tk_tenant_mhm_advanced_mode_custom_fields;
            }

            var record = {
              tenant_id: tenant_id,
              component: "mhm",
              tracker_name: tk_account,
              account: tk_account,
              owner: owner,
              search_mode: document.getElementById(
                "tenant_mhm_advanced_search_mode"
              ).value,
              earliest_time: document.getElementById(
                "tenant_mhm_advanced_mode_earliest"
              ).value,
              latest_time: document.getElementById(
                "tenant_mhm_advanced_mode_latest"
              ).value,
              root_constraint: tk_tenant_mhm_root_constraint,
              breakby_field: breakby_field,
            };

            // return
            return record;
          }

          $("#create_tenant_splk_feeds")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Get tenant_name
              var tk_tenant_name = document.getElementById(
                "input_tenant_name_splk_feeds"
              ).value;

              // replace spaces and underscore
              tk_tenant_name = tk_tenant_name.replace(/\s/g, "-");
              tk_tenant_name = tk_tenant_name.replace(/\_/g, "-");

              // make it lower case
              tk_tenant_name = tk_tenant_name.toLowerCase();

              // Get tenant_description
              var tk_tenant_description = document.getElementById(
                "input_tenant_description_splk_feeds"
              ).value;

              // some replacements
              tk_tenant_description = tk_tenant_description.replace(/\'/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\"/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\\/g, "");

              // Get tenant_dsm_enabled
              var tk_tenant_dsm_enabled;
              if ($("#tenant_dsm_enabled").is(".tenant_dsm_enabled")) {
                tk_tenant_dsm_enabled = true;
              } else {
                tk_tenant_dsm_enabled = false;
              }

              // Get hybrid creation at tenant creation time
              var tk_tenant_dsm_advanced_create_trackers =
                document.getElementById(
                  "tenant_dsm_advanced_create_trackers"
                ).value;

              // Get tenant_dhm_enabled
              var tk_tenant_dhm_enabled;
              if ($("#tenant_dhm_enabled").is(".tenant_dhm_enabled")) {
                tk_tenant_dhm_enabled = true;
              } else {
                tk_tenant_dhm_enabled = false;
              }

              // Get hybrid creation at tenant creation time
              var tk_tenant_dhm_advanced_create_trackers =
                document.getElementById(
                  "tenant_dhm_advanced_create_trackers"
                ).value;

              // Get tenant_mhm_enabled
              var tk_tenant_mhm_enabled;
              if ($("#tenant_mhm_enabled").is(".tenant_mhm_enabled")) {
                tk_tenant_mhm_enabled = true;
              } else {
                tk_tenant_mhm_enabled = false;
              }

              // Get hybrid creation at tenant creation time
              var tk_tenant_mhm_advanced_create_trackers =
                document.getElementById(
                  "tenant_mhm_advanced_create_trackers"
                ).value;

              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_feeds"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_feeds"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_feeds"
              );

              // Get tenant_owner
              var tk_tenant_owner = getToken("tk_tenant_owner_splk_feeds");

              // Get indexes
              var tk_tenant_idx_settings;

              // local settings
              var tk_tenant_idx_summary = getToken(
                "tk_tenant_idx_summary_splk_feeds"
              );
              var tk_tenant_idx_audit = getToken(
                "tk_tenant_idx_audit_splk_feeds"
              );
              var tk_tenant_idx_metric = getToken(
                "tk_tenant_idx_metric_splk_feeds"
              );
              var tk_tenant_idx_notable = getToken(
                "tk_tenant_idx_notable_splk_feeds"
              );

              // global settings
              var tk_default_tenant_idx_summary = getToken(
                "tk_default_tenant_idx_summary"
              );
              var tk_default_tenant_idx_audit = getToken(
                "tk_default_tenant_idx_audit"
              );
              var tk_default_tenant_idx_metric = getToken(
                "tk_default_tenant_idx_metric"
              );
              var tk_default_tenant_idx_notable = getToken(
                "tk_default_tenant_idx_notable"
              );

              if (
                tk_tenant_idx_summary.length < 1 ||
                tk_tenant_idx_summary == "null" ||
                tk_tenant_idx_audit.length < 1 ||
                tk_tenant_idx_audit == "null" ||
                tk_tenant_idx_metric.length < 1 ||
                tk_tenant_idx_metric == "null" ||
                tk_tenant_idx_notable.length < 1 ||
                tk_tenant_idx_notable == "null"
              ) {
                tk_tenant_idx_settings = "global";
              } else if (
                tk_tenant_idx_summary === tk_default_tenant_idx_summary &&
                tk_tenant_idx_audit === tk_default_tenant_idx_audit &&
                tk_tenant_idx_metric === tk_default_tenant_idx_metric &&
                tk_tenant_idx_notable === tk_default_tenant_idx_notable
              ) {
                tk_tenant_idx_settings = "global";
              } else {
                tk_tenant_idx_settings =
                  '{"trackme_summary_idx": "' +
                  tk_tenant_idx_summary +
                  '", "trackme_audit_idx": "' +
                  tk_tenant_idx_audit +
                  '", "trackme_notable_idx": "' +
                  tk_tenant_idx_notable +
                  '", "trackme_metric_idx": "' +
                  tk_tenant_idx_metric +
                  '"}';
              }

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_create_tenant_splk_feeds"
              ).value;

              // Prepare the JSON record
              var record = {};

              // Add main settings first
              record["tenant_desc"] = tk_tenant_description;
              record["tenant_name"] = tk_tenant_name;
              record["tenant_roles_admin"] = tk_tenant_roles_admin;
              record["tenant_roles_power"] = tk_tenant_roles_power;
              record["tenant_roles_user"] = tk_tenant_roles_user;
              record["tenant_owner"] = tk_tenant_owner;
              record["tenant_idx_settings"] = tk_tenant_idx_settings;

              // If component is enabled
              if (tk_tenant_dsm_enabled) {
                record["tenant_dsm_enabled"] = tk_tenant_dsm_enabled;
                record["tenant_dsm_sampling_obfuscation"] =
                  document.getElementById(
                    "tenant_dsm_advanced_data_sampling_obfuscation"
                  ).value;
              }

              // If component is enabled
              if (tk_tenant_dhm_enabled) {
                record["tenant_dhm_enabled"] = tk_tenant_dhm_enabled;
                record["tenant_dhm_alerting_policy"] = document.getElementById(
                  "tenant_dhm_advanced_alerting_policy"
                ).value;
              }

              // If component is enabled
              if (tk_tenant_mhm_enabled) {
                record["tenant_mhm_enabled"] = tk_tenant_mhm_enabled;
              }

              // Add comment
              if (tk_comment != "Enter your audit message") {
                record["update_comment"] = tk_comment;
              }

              // spinner
              $("#cssloader").remove();
              $("body").append(
                '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being created, this can take up to 5 minutes to be completed, tasks would continue in the background if you close this window or if the spinner gets closed unexpectly, please wait..."></div>'
              );

              final_record = {};
              hybrid_objects = [];

              // If splk-dsm and hybrid creation was requested
              if (
                tk_tenant_dsm_enabled &&
                tk_tenant_dsm_advanced_create_trackers == "True"
              ) {
                hybrid_objects.push(
                  goSplkDsmCreateHybridTrackerReturnDict(
                    tk_tenant_name,
                    tk_tenant_owner
                  )
                );
              }

              // If splk-dhm and hybrid creation was requested
              if (
                tk_tenant_dhm_enabled &&
                tk_tenant_dhm_advanced_create_trackers == "True"
              ) {
                hybrid_objects.push(
                  goSplkDhmCreateHybridTrackerReturnDict(
                    tk_tenant_name,
                    tk_tenant_owner
                  )
                );
              }

              // If splk-mhm and hybrid creation was requested
              if (
                tk_tenant_mhm_enabled &&
                tk_tenant_mhm_advanced_create_trackers == "True"
              ) {
                hybrid_objects.push(
                  goSplkMhmCreateHybridTrackerReturnDict(
                    tk_tenant_name,
                    tk_tenant_owner
                  )
                );
              }

              // Add the tenant record
              final_record["tenant_dict"] = record;

              // Add the hybrid array
              final_record["hybrid_objects"] = hybrid_objects;

              // Create the virtual tenant
              $.ajax({
                url: "/en-US/splunkd/__raw/services/trackme/v2/vtenants/admin/add_tenant_multiops",
                type: "POST",
                async: true,
                contentType: "application/json",
                data: JSON.stringify(final_record),
                timeout: 600000,
                success: function (returneddata) {
                  //
                  // if previously ran
                  $("#div_create_tenant_spl_command")
                    .find(".modal-spl-message p")
                    .text("");
                  $("#div_create_tenant_spl_command").attr(
                    "style",
                    "display: None !important"
                  );
                  // Audit success is made by the API
                  // If click on show SPL command
                  $("#btn_create_tenant_show_spl").on("click", function () {
                    $(this).blur();
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: block !important"
                    );
                    $("#btn_create_tenant_copy_clipboard").attr(
                      "style",
                      "display: block !important"
                    );
                  });
                  // if click on copy to clipboard
                  $("#btn_create_tenant_copy_clipboard").on(
                    "click",
                    function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      copyToClipboard(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    }
                  );
                  $("#cssloader").remove();
                  $("#modal_creation_success").modal();
                  // Refresh and restart interval
                  $("#btn_refresh_all").click();
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                    "5"
                  );
                  //
                },
                error: function (xhr, textStatus, error) {
                  // A timeout can occur on Splunk Cloud especially with very long operations
                  // this is begign and does mean the operation has failed, assume things are ok
                  if (error == "timeout" || error == "GATEWAY_TIMEOUT") {
                    //
                    // if previously ran
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text("");
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: None !important"
                    );
                    // Audit success is made by the API
                    // If click on show SPL command
                    $("#btn_create_tenant_show_spl").on("click", function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      $("#div_create_tenant_spl_command").attr(
                        "style",
                        "display: block !important"
                      );
                      $("#btn_create_tenant_copy_clipboard").attr(
                        "style",
                        "display: block !important"
                      );
                    });
                    // if click on copy to clipboard
                    $("#btn_create_tenant_copy_clipboard").on(
                      "click",
                      function () {
                        $(this).blur();
                        $("#div_create_tenant_spl_command")
                          .find(".modal-spl-message p")
                          .text(
                            '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                              JSON.stringify(record).replace(/\"/g, "'") +
                              '"'
                          );
                        copyToClipboard(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      }
                    );
                    $("#cssloader").remove();
                    $("#modal_creation_success").modal();
                    // Refresh and restart interval
                    $("#btn_refresh_all").click();
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                      "5"
                    );
                    //
                  } else {
                    $("#cssloader").remove();
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error +
                      "\n - text status: " +
                      textStatus;
                    $("#modal_generic_error")
                      .find(".modal-error-message p")
                      .text(message);
                    $("#modal_generic_error").modal();
                  }
                },
              });
            });

          //
          // splk-cim
          //

          $("#create_tenant_splk_cim")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Get tenant_name
              var tk_tenant_name = document.getElementById(
                "input_tenant_name_splk_cim"
              ).value;

              // replace spaces and underscore
              tk_tenant_name = tk_tenant_name.replace(/\s/g, "-");
              tk_tenant_name = tk_tenant_name.replace(/\_/g, "-");

              // make it lower case
              tk_tenant_name = tk_tenant_name.toLowerCase();

              // Get tenant_description
              var tk_tenant_description = document.getElementById(
                "input_tenant_description_splk_cim"
              ).value;

              // some replacements
              tk_tenant_description = tk_tenant_description.replace(/\'/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\"/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\\/g, "");

              // Get tenant_cim_enabled
              tk_tenant_cim_enabled = "true";

              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_cim"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_cim"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_cim"
              );

              // Get tenant_owner
              var tk_tenant_owner = getToken("tk_tenant_owner_splk_cim");

              // Get indexes
              var tk_tenant_idx_settings;

              // local settings
              var tk_tenant_idx_summary = getToken(
                "tk_tenant_idx_summary_splk_cim"
              );
              var tk_tenant_idx_audit = getToken(
                "tk_tenant_idx_audit_splk_cim"
              );
              var tk_tenant_idx_metric = getToken(
                "tk_tenant_idx_metric_splk_cim"
              );
              var tk_tenant_idx_notable = getToken(
                "tk_tenant_idx_notable_splk_cim"
              );

              // global settings
              var tk_default_tenant_idx_summary = getToken(
                "tk_default_tenant_idx_summary"
              );
              var tk_default_tenant_idx_audit = getToken(
                "tk_default_tenant_idx_audit"
              );
              var tk_default_tenant_idx_metric = getToken(
                "tk_default_tenant_idx_metric"
              );
              var tk_default_tenant_idx_notable = getToken(
                "tk_default_tenant_idx_notable"
              );

              if (
                tk_tenant_idx_summary.length < 1 ||
                tk_tenant_idx_summary == "null" ||
                tk_tenant_idx_audit.length < 1 ||
                tk_tenant_idx_audit == "null" ||
                tk_tenant_idx_metric.length < 1 ||
                tk_tenant_idx_metric == "null" ||
                tk_tenant_idx_notable.length < 1 ||
                tk_tenant_idx_notable == "null"
              ) {
                tk_tenant_idx_settings = "global";
              } else if (
                tk_tenant_idx_summary === tk_default_tenant_idx_summary &&
                tk_tenant_idx_audit === tk_default_tenant_idx_audit &&
                tk_tenant_idx_metric === tk_default_tenant_idx_metric &&
                tk_tenant_idx_notable === tk_default_tenant_idx_notable
              ) {
                tk_tenant_idx_settings = "global";
              } else {
                tk_tenant_idx_settings =
                  '{"trackme_summary_idx": "' +
                  tk_tenant_idx_summary +
                  '", "trackme_audit_idx": "' +
                  tk_tenant_idx_audit +
                  '", "trackme_notable_idx": "' +
                  tk_tenant_idx_notable +
                  '", "trackme_metric_idx": "' +
                  tk_tenant_idx_metric +
                  '"}';
              }

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_create_tenant_splk_cim"
              ).value;

              // Prepare the JSON record
              var record = {};

              // Add main settings first
              record["tenant_desc"] = tk_tenant_description;
              record["tenant_name"] = tk_tenant_name;
              record["tenant_roles_admin"] = tk_tenant_roles_admin;
              record["tenant_roles_power"] = tk_tenant_roles_power;
              record["tenant_roles_user"] = tk_tenant_roles_user;
              record["tenant_owner"] = tk_tenant_owner;
              record["tenant_idx_settings"] = tk_tenant_idx_settings;

              // If component is enabled
              if (tk_tenant_cim_enabled) {
                record["tenant_cim_enabled"] = tk_tenant_cim_enabled;
              }

              // Add comment
              if (tk_comment != "Enter your audit message") {
                record["update_comment"] = tk_comment;
              }

              // spinner
              $("#cssloader").remove();
              $("body").append(
                '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being created, this can take up to 5 minutes to be completed, tasks would continue in the background if you close this window or if the spinner gets closed unexpectly, please wait..."></div>'
              );

              // Create the virtual tenant
              $.ajax({
                url: "/en-US/splunkd/__raw//services/trackme/v2/vtenants/admin/add_tenant",
                type: "POST",
                async: true,
                contentType: "application/json",
                data: JSON.stringify(record),
                timeout: 600000,
                success: function (returneddata) {
                  //
                  // if previously ran
                  $("#div_create_tenant_spl_command")
                    .find(".modal-spl-message p")
                    .text("");
                  $("#div_create_tenant_spl_command").attr(
                    "style",
                    "display: None !important"
                  );
                  // Audit success is made by the API
                  // If click on show SPL command
                  $("#btn_create_tenant_show_spl").on("click", function () {
                    $(this).blur();
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: block !important"
                    );
                    $("#btn_create_tenant_copy_clipboard").attr(
                      "style",
                      "display: block !important"
                    );
                  });
                  // if click on copy to clipboard
                  $("#btn_create_tenant_copy_clipboard").on(
                    "click",
                    function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      copyToClipboard(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    }
                  );
                  $("#cssloader").remove();
                  $("#modal_creation_success").modal();
                  // Refresh and restart interval
                  $("#btn_refresh_all").click();
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                    "5"
                  );
                  //
                },
                error: function (xhr, textStatus, error) {
                  // A timeout can occur on Splunk Cloud especially with very long operations
                  // this is begign and does mean the operation has failed, assume things are ok
                  if (error == "timeout" || error == "GATEWAY_TIMEOUT") {
                    //
                    // if previously ran
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text("");
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: None !important"
                    );
                    // Audit success is made by the API
                    // If click on show SPL command
                    $("#btn_create_tenant_show_spl").on("click", function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      $("#div_create_tenant_spl_command").attr(
                        "style",
                        "display: block !important"
                      );
                      $("#btn_create_tenant_copy_clipboard").attr(
                        "style",
                        "display: block !important"
                      );
                    });
                    // if click on copy to clipboard
                    $("#btn_create_tenant_copy_clipboard").on(
                      "click",
                      function () {
                        $(this).blur();
                        $("#div_create_tenant_spl_command")
                          .find(".modal-spl-message p")
                          .text(
                            '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                              JSON.stringify(record).replace(/\"/g, "'") +
                              '"'
                          );
                        copyToClipboard(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      }
                    );
                    $("#cssloader").remove();
                    $("#modal_creation_success").modal();
                    // Refresh and restart interval
                    $("#btn_refresh_all").click();
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                      "5"
                    );
                    //
                  } else {
                    $("#cssloader").remove();
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error +
                      "\n - text status: " +
                      textStatus;
                    $("#modal_generic_error")
                      .find(".modal-error-message p")
                      .text(message);
                    $("#modal_generic_error").modal();
                  }
                },
              });
            });

          //
          // splk-flx
          //

          $("#create_tenant_splk_flx")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Get tenant_name
              var tk_tenant_name = document.getElementById(
                "input_tenant_name_splk_flx"
              ).value;

              // replace spaces and underscore
              tk_tenant_name = tk_tenant_name.replace(/\s/g, "-");
              tk_tenant_name = tk_tenant_name.replace(/\_/g, "-");

              // make it lower case
              tk_tenant_name = tk_tenant_name.toLowerCase();

              // Get tenant_description
              var tk_tenant_description = document.getElementById(
                "input_tenant_description_splk_flx"
              ).value;

              // some replacements
              tk_tenant_description = tk_tenant_description.replace(/\'/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\"/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\\/g, "");

              // Get tenant_flx_enabled
              var tk_tenant_flx_enabled = "true";

              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_flx"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_flx"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_flx"
              );

              // Get tenant_owner
              var tk_tenant_owner = getToken("tk_tenant_owner_splk_flx");

              // Get indexes
              var tk_tenant_idx_settings;

              // local settings
              var tk_tenant_idx_summary = getToken(
                "tk_tenant_idx_summary_splk_flx"
              );
              var tk_tenant_idx_audit = getToken(
                "tk_tenant_idx_audit_splk_flx"
              );
              var tk_tenant_idx_metric = getToken(
                "tk_tenant_idx_metric_splk_flx"
              );
              var tk_tenant_idx_notable = getToken(
                "tk_tenant_idx_notable_splk_flx"
              );

              // global settings
              var tk_default_tenant_idx_summary = getToken(
                "tk_default_tenant_idx_summary"
              );
              var tk_default_tenant_idx_audit = getToken(
                "tk_default_tenant_idx_audit"
              );
              var tk_default_tenant_idx_metric = getToken(
                "tk_default_tenant_idx_metric"
              );
              var tk_default_tenant_idx_notable = getToken(
                "tk_default_tenant_idx_notable"
              );

              if (
                tk_tenant_idx_summary.length < 1 ||
                tk_tenant_idx_summary == "null" ||
                tk_tenant_idx_audit.length < 1 ||
                tk_tenant_idx_audit == "null" ||
                tk_tenant_idx_metric.length < 1 ||
                tk_tenant_idx_metric == "null" ||
                tk_tenant_idx_notable.length < 1 ||
                tk_tenant_idx_notable == "null"
              ) {
                tk_tenant_idx_settings = "global";
              } else if (
                tk_tenant_idx_summary === tk_default_tenant_idx_summary &&
                tk_tenant_idx_audit === tk_default_tenant_idx_audit &&
                tk_tenant_idx_metric === tk_default_tenant_idx_metric &&
                tk_tenant_idx_notable === tk_default_tenant_idx_notable
              ) {
                tk_tenant_idx_settings = "global";
              } else {
                tk_tenant_idx_settings =
                  '{"trackme_summary_idx": "' +
                  tk_tenant_idx_summary +
                  '", "trackme_audit_idx": "' +
                  tk_tenant_idx_audit +
                  '", "trackme_notable_idx": "' +
                  tk_tenant_idx_notable +
                  '", "trackme_metric_idx": "' +
                  tk_tenant_idx_metric +
                  '"}';
              }

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_create_tenant_splk_flx"
              ).value;

              // Prepare the JSON record
              var record = {};

              // Add main settings first
              record["tenant_desc"] = tk_tenant_description;
              record["tenant_name"] = tk_tenant_name;
              record["tenant_roles_admin"] = tk_tenant_roles_admin;
              record["tenant_roles_power"] = tk_tenant_roles_power;
              record["tenant_roles_user"] = tk_tenant_roles_user;
              record["tenant_owner"] = tk_tenant_owner;
              record["tenant_idx_settings"] = tk_tenant_idx_settings;

              // If component is enabled
              if (tk_tenant_flx_enabled) {
                record["tenant_flx_enabled"] = tk_tenant_flx_enabled;
              }

              // Add comment
              if (tk_comment != "Enter your audit message") {
                record["update_comment"] = tk_comment;
              }

              // spinner
              $("#cssloader").remove();
              $("body").append(
                '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being created, this can take up to 5 minutes to be completed, tasks would continue in the background if you close this window or if the spinner gets closed unexpectly, please wait..."></div>'
              );

              // Create the virtual tenant
              $.ajax({
                url: "/en-US/splunkd/__raw//services/trackme/v2/vtenants/admin/add_tenant",
                type: "POST",
                async: true,
                contentType: "application/json",
                data: JSON.stringify(record),
                timeout: 600000,
                success: function (returneddata) {
                  //
                  // if previously ran
                  $("#div_create_tenant_spl_command")
                    .find(".modal-spl-message p")
                    .text("");
                  $("#div_create_tenant_spl_command").attr(
                    "style",
                    "display: None !important"
                  );
                  // Audit success is made by the API
                  // If click on show SPL command
                  $("#btn_create_tenant_show_spl").on("click", function () {
                    $(this).blur();
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: block !important"
                    );
                    $("#btn_create_tenant_copy_clipboard").attr(
                      "style",
                      "display: block !important"
                    );
                  });
                  // if click on copy to clipboard
                  $("#btn_create_tenant_copy_clipboard").on(
                    "click",
                    function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      copyToClipboard(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    }
                  );
                  $("#cssloader").remove();
                  $("#modal_creation_success").modal();
                  // Refresh and restart interval
                  $("#btn_refresh_all").click();
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                    "5"
                  );
                  //
                },
                error: function (xhr, textStatus, error) {
                  // A timeout can occur on Splunk Cloud especially with very long operations
                  // this is begign and does mean the operation has failed, assume things are ok
                  if (error == "timeout" || error == "GATEWAY_TIMEOUT") {
                    //
                    // if previously ran
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text("");
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: None !important"
                    );
                    // Audit success is made by the API
                    // If click on show SPL command
                    $("#btn_create_tenant_show_spl").on("click", function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      $("#div_create_tenant_spl_command").attr(
                        "style",
                        "display: block !important"
                      );
                      $("#btn_create_tenant_copy_clipboard").attr(
                        "style",
                        "display: block !important"
                      );
                    });
                    // if click on copy to clipboard
                    $("#btn_create_tenant_copy_clipboard").on(
                      "click",
                      function () {
                        $(this).blur();
                        $("#div_create_tenant_spl_command")
                          .find(".modal-spl-message p")
                          .text(
                            '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                              JSON.stringify(record).replace(/\"/g, "'") +
                              '"'
                          );
                        copyToClipboard(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      }
                    );
                    $("#cssloader").remove();
                    $("#modal_creation_success").modal();
                    // Refresh and restart interval
                    $("#btn_refresh_all").click();
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                      "5"
                    );
                    //
                  } else {
                    $("#cssloader").remove();
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error +
                      "\n - text status: " +
                      textStatus;
                    $("#modal_generic_error")
                      .find(".modal-error-message p")
                      .text(message);
                    $("#modal_generic_error").modal();
                  }
                },
              });
            });

          //
          // splk-replica
          //

          $("#create_tenant_splk_replica")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Get tenant_name
              var tk_tenant_name = document.getElementById(
                "input_tenant_name_splk_replica"
              ).value;

              // replace spaces and underscore
              tk_tenant_name = tk_tenant_name.replace(/\s/g, "-");
              tk_tenant_name = tk_tenant_name.replace(/\_/g, "-");

              // make it lower case
              tk_tenant_name = tk_tenant_name.toLowerCase();

              // Get tenant_description
              var tk_tenant_description = document.getElementById(
                "input_tenant_description_splk_replica"
              ).value;

              // some replacements
              tk_tenant_description = tk_tenant_description.replace(/\'/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\"/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\\/g, "");

              // Get tenant_replica_enabled
              var tk_tenant_replica_enabled = "true";

              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_replica"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_replica"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_replica"
              );

              // Get tenant_owner
              var tk_tenant_owner = getToken("tk_tenant_owner_splk_replica");

              // Get indexes
              var tk_tenant_idx_settings;

              // local settings
              var tk_tenant_idx_summary = getToken(
                "tk_tenant_idx_summary_splk_replica"
              );
              var tk_tenant_idx_audit = getToken(
                "tk_tenant_idx_audit_splk_replica"
              );
              var tk_tenant_idx_metric = getToken(
                "tk_tenant_idx_metric_splk_replica"
              );
              var tk_tenant_idx_notable = getToken(
                "tk_tenant_idx_notable_splk_replica"
              );

              // global settings
              var tk_default_tenant_idx_summary = getToken(
                "tk_default_tenant_idx_summary"
              );
              var tk_default_tenant_idx_audit = getToken(
                "tk_default_tenant_idx_audit"
              );
              var tk_default_tenant_idx_metric = getToken(
                "tk_default_tenant_idx_metric"
              );
              var tk_default_tenant_idx_notable = getToken(
                "tk_default_tenant_idx_notable"
              );

              // get the list of components to be enabled
              var tk_tenant_replica_components = getToken(
                "tk_tenant_replica_components"
              );

              // Convert it to a string
              tk_tenant_replica_components = String(
                tk_tenant_replica_components
              );

              // split the CSV string into an array
              var enabledComponents = tk_tenant_replica_components.split(",");

              // list of all possible components
              var allComponents = [
                "splk-dsm",
                "splk-dhm",
                "splk-mhm",
                "splk-flx",
                "splk-wlk",
                "splk-cim",
              ];

              // object to hold the status of each component
              var componentsStatus = {};

              // loop over all components
              for (var i = 0; i < allComponents.length; i++) {
                // check if the component is in the enabledComponents array
                if (enabledComponents.includes(allComponents[i])) {
                  // if it is, set the corresponding status to "True"
                  componentsStatus[allComponents[i]] = "True";
                } else {
                  // if it is not, set the corresponding status to "False"
                  componentsStatus[allComponents[i]] = "False";
                }
              }

              if (
                tk_tenant_idx_summary.length < 1 ||
                tk_tenant_idx_summary == "null" ||
                tk_tenant_idx_audit.length < 1 ||
                tk_tenant_idx_audit == "null" ||
                tk_tenant_idx_metric.length < 1 ||
                tk_tenant_idx_metric == "null" ||
                tk_tenant_idx_notable.length < 1 ||
                tk_tenant_idx_notable == "null"
              ) {
                tk_tenant_idx_settings = "global";
              } else if (
                tk_tenant_idx_summary === tk_default_tenant_idx_summary &&
                tk_tenant_idx_audit === tk_default_tenant_idx_audit &&
                tk_tenant_idx_metric === tk_default_tenant_idx_metric &&
                tk_tenant_idx_notable === tk_default_tenant_idx_notable
              ) {
                tk_tenant_idx_settings = "global";
              } else {
                tk_tenant_idx_settings =
                  '{"trackme_summary_idx": "' +
                  tk_tenant_idx_summary +
                  '", "trackme_audit_idx": "' +
                  tk_tenant_idx_audit +
                  '", "trackme_notable_idx": "' +
                  tk_tenant_idx_notable +
                  '", "trackme_metric_idx": "' +
                  tk_tenant_idx_metric +
                  '"}';
              }

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_create_tenant_splk_replica"
              ).value;

              // Prepare the JSON record
              var record = {};

              // Add main settings first
              record["tenant_desc"] = tk_tenant_description;
              record["tenant_name"] = tk_tenant_name;
              record["tenant_roles_admin"] = tk_tenant_roles_admin;
              record["tenant_roles_power"] = tk_tenant_roles_power;
              record["tenant_roles_user"] = tk_tenant_roles_user;
              record["tenant_owner"] = tk_tenant_owner;
              record["tenant_idx_settings"] = tk_tenant_idx_settings;

              // Replica tenant
              record["tenant_replica"] = 1;

              // set each component
              record["tenant_dsm_enabled"] = componentsStatus["splk-dsm"];
              record["tenant_dhm_enabled"] = componentsStatus["splk-dhm"];
              record["tenant_mhm_enabled"] = componentsStatus["splk-mhm"];
              record["tenant_flx_enabled"] = componentsStatus["splk-flx"];
              record["tenant_wlk_enabled"] = componentsStatus["splk-wlk"];
              record["tenant_cim_enabled"] = componentsStatus["splk-cim"];

              // Add comment
              if (tk_comment != "Enter your audit message") {
                record["update_comment"] = tk_comment;
              }

              // spinner
              $("#cssloader").remove();
              $("body").append(
                '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being created, this can take up to 5 minutes to be completed, tasks would continue in the background if you close this window or if the spinner gets closed unexpectly, please wait..."></div>'
              );

              // Create the virtual tenant
              $.ajax({
                url: "/en-US/splunkd/__raw/services/trackme/v2/vtenants/admin/add_tenant",
                type: "POST",
                async: true,
                contentType: "application/json",
                data: JSON.stringify(record),
                timeout: 600000,
                success: function (returneddata) {
                  //
                  // if previously ran
                  $("#div_create_tenant_spl_command")
                    .find(".modal-spl-message p")
                    .text("");
                  $("#div_create_tenant_spl_command").attr(
                    "style",
                    "display: None !important"
                  );
                  // Audit success is made by the API
                  // If click on show SPL command
                  $("#btn_create_tenant_show_spl").on("click", function () {
                    $(this).blur();
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: block !important"
                    );
                    $("#btn_create_tenant_copy_clipboard").attr(
                      "style",
                      "display: block !important"
                    );
                  });
                  // if click on copy to clipboard
                  $("#btn_create_tenant_copy_clipboard").on(
                    "click",
                    function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      copyToClipboard(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    }
                  );
                  $("#cssloader").remove();
                  $("#modal_creation_success").modal();
                  // Refresh and restart interval
                  $("#btn_refresh_all").click();
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                    "5"
                  );
                  //
                },
                error: function (xhr, textStatus, error) {
                  // A timeout can occur on Splunk Cloud especially with very long operations
                  // this is begign and does mean the operation has failed, assume things are ok
                  if (error == "timeout" || error == "GATEWAY_TIMEOUT") {
                    //
                    // if previously ran
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text("");
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: None !important"
                    );
                    // Audit success is made by the API
                    // If click on show SPL command
                    $("#btn_create_tenant_show_spl").on("click", function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      $("#div_create_tenant_spl_command").attr(
                        "style",
                        "display: block !important"
                      );
                      $("#btn_create_tenant_copy_clipboard").attr(
                        "style",
                        "display: block !important"
                      );
                    });
                    // if click on copy to clipboard
                    $("#btn_create_tenant_copy_clipboard").on(
                      "click",
                      function () {
                        $(this).blur();
                        $("#div_create_tenant_spl_command")
                          .find(".modal-spl-message p")
                          .text(
                            '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                              JSON.stringify(record).replace(/\"/g, "'") +
                              '"'
                          );
                        copyToClipboard(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      }
                    );
                    $("#cssloader").remove();
                    $("#modal_creation_success").modal();
                    // Refresh and restart interval
                    $("#btn_refresh_all").click();
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                      "5"
                    );
                    //
                  } else {
                    $("#cssloader").remove();
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error +
                      "\n - text status: " +
                      textStatus;
                    $("#modal_generic_error")
                      .find(".modal-error-message p")
                      .text(message);
                    $("#modal_generic_error").modal();
                  }
                },
              });
            });

          //
          // splk-wlk
          //

          $("#create_tenant_splk_wlk")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Get tenant_name
              var tk_tenant_name = document.getElementById(
                "input_tenant_name_splk_wlk"
              ).value;

              // replace spaces and underscore
              tk_tenant_name = tk_tenant_name.replace(/\s/g, "-");
              tk_tenant_name = tk_tenant_name.replace(/\_/g, "-");

              // make it lower case
              tk_tenant_name = tk_tenant_name.toLowerCase();

              // Get tenant_description
              var tk_tenant_description = document.getElementById(
                "input_tenant_description_splk_wlk"
              ).value;

              // some replacements
              tk_tenant_description = tk_tenant_description.replace(/\'/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\"/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\\/g, "");

              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_wlk"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_wlk"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_wlk"
              );

              // Get tenant_owner
              var tk_tenant_owner = getToken("tk_tenant_owner_splk_wlk");

              // Get indexes
              var tk_tenant_idx_settings;

              // local settings
              var tk_tenant_idx_summary = getToken(
                "tk_tenant_idx_summary_splk_wlk"
              );
              var tk_tenant_idx_audit = getToken(
                "tk_tenant_idx_audit_splk_wlk"
              );
              var tk_tenant_idx_metric = getToken(
                "tk_tenant_idx_metric_splk_wlk"
              );
              var tk_tenant_idx_notable = getToken(
                "tk_tenant_idx_notable_splk_wlk"
              );

              // global settings
              var tk_default_tenant_idx_summary = getToken(
                "tk_default_tenant_idx_summary"
              );
              var tk_default_tenant_idx_audit = getToken(
                "tk_default_tenant_idx_audit"
              );
              var tk_default_tenant_idx_metric = getToken(
                "tk_default_tenant_idx_metric"
              );
              var tk_default_tenant_idx_notable = getToken(
                "tk_default_tenant_idx_notable"
              );

              if (
                tk_tenant_idx_summary.length < 1 ||
                tk_tenant_idx_summary == "null" ||
                tk_tenant_idx_audit.length < 1 ||
                tk_tenant_idx_audit == "null" ||
                tk_tenant_idx_metric.length < 1 ||
                tk_tenant_idx_metric == "null" ||
                tk_tenant_idx_notable.length < 1 ||
                tk_tenant_idx_notable == "null"
              ) {
                tk_tenant_idx_settings = "global";
              } else if (
                tk_tenant_idx_summary === tk_default_tenant_idx_summary &&
                tk_tenant_idx_audit === tk_default_tenant_idx_audit &&
                tk_tenant_idx_metric === tk_default_tenant_idx_metric &&
                tk_tenant_idx_notable === tk_default_tenant_idx_notable
              ) {
                tk_tenant_idx_settings = "global";
              } else {
                tk_tenant_idx_settings =
                  '{"trackme_summary_idx": "' +
                  tk_tenant_idx_summary +
                  '", "trackme_audit_idx": "' +
                  tk_tenant_idx_audit +
                  '", "trackme_notable_idx": "' +
                  tk_tenant_idx_notable +
                  '", "trackme_metric_idx": "' +
                  tk_tenant_idx_metric +
                  '"}';
              }

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_create_tenant_splk_wlk"
              ).value;

              // Get accounts
              // convert
              var tk_splk_wlk_accounts = getToken("tk_splk_wlk_accounts");
              tk_splk_wlk_accounts = tk_splk_wlk_accounts.toString().split(",");

              // Get environment type
              var tk_splk_wlk_env_type = getToken("tk_splk_wlk_env_type");

              // Get track notable
              var tk_splk_wlk_track_notable = getToken(
                "tk_splk_wlk_track_notable"
              );

              // Get the root constraint
              var tk_tenant_wlk_root_constraint_scheduler =
                document.getElementById(
                  "input_tenant_wlk_root_constraint_scheduler"
                ).value;

              // Get the root constraint
              var tk_tenant_wlk_root_constraint_introspection =
                document.getElementById(
                  "input_tenant_wlk_root_constraint_introspection"
                ).value;

              // Get the root constraint
              var tk_tenant_wlk_root_constraint_svc = document.getElementById(
                "input_tenant_wlk_root_constraint_svc"
              ).value;

              // Get the overgroup
              var tk_tenant_wlk_overgroup = document.getElementById(
                "input_tenant_wlk_overgroup"
              ).value;

              // Prepare the JSON record
              var record = {};

              // Add main settings first
              record["tenant_desc"] = tk_tenant_description;
              record["tenant_name"] = tk_tenant_name;
              record["tenant_roles_admin"] = tk_tenant_roles_admin;
              record["tenant_roles_power"] = tk_tenant_roles_power;
              record["tenant_roles_user"] = tk_tenant_roles_user;
              record["tenant_owner"] = tk_tenant_owner;
              record["tenant_idx_settings"] = tk_tenant_idx_settings;

              // outliers metrics preferences
              record["tenant_wlk_outliers_metrics"] = getToken(
                "tk_splk_wlk_outliers_metrics"
              );

              // Enable component
              record["tenant_wlk_enabled"] = true;

              // Add comment
              if (tk_comment != "Enter your audit message") {
                record["update_comment"] = tk_comment;
              }

              // spinner
              $("#cssloader").remove();
              $("body").append(
                '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being created, this can take up to 5 minutes to be completed, tasks would continue in the background if you close this window or if the spinner gets closed unexpectly, please wait..."></div>'
              );

              final_record = {};
              hybrid_objects = [];

              // Push the main tracker first
              hybrid_objects.push({
                tenant_id: tk_tenant_name,
                tracker_type: "main",
                account: "local",
                environment_type: tk_splk_wlk_env_type,
                overgroup: tk_tenant_wlk_overgroup,
              });

              // Push the metadata tracker, it will always be local as it performs operations remotely, if necessary
              hybrid_objects.push({
                tenant_id: tk_tenant_name,
                tracker_type: "metadata",
                account: "local",
                overgroup: tk_tenant_wlk_overgroup,
              });

              // orphan has to honour account
              hybrid_objects.push({
                tenant_id: tk_tenant_name,
                tracker_type: "orphan",
                account: getToken("tk_splk_wlk_accounts"),
                overgroup: tk_tenant_wlk_overgroup,
              });

              // Add the inactive_entities
              hybrid_objects.push({
                tenant_id: tk_tenant_name,
                tracker_type: "inactive_entities",
                account: "local",
                inactive_entities_max_age_days: getToken(
                  "tk_splk_wlk_inactive_inspector"
                ),
                overgroup: tk_tenant_wlk_overgroup,
              });

              // loop trough the accounts
              for (var i = 0; i < tk_splk_wlk_accounts.length; i++) {
                // tracker_type: introspection
                hybrid_objects.push({
                  tenant_id: tk_tenant_name,
                  environment_type: tk_splk_wlk_env_type,
                  tracker_type: "introspection",
                  account: tk_splk_wlk_accounts[i],
                  root_constraint: tk_tenant_wlk_root_constraint_introspection,
                  overgroup: tk_tenant_wlk_overgroup,
                });

                // tracker_type: scheduler
                hybrid_objects.push({
                  tenant_id: tk_tenant_name,
                  environment_type: tk_splk_wlk_env_type,
                  tracker_type: "scheduler",
                  account: tk_splk_wlk_accounts[i],
                  root_constraint: tk_tenant_wlk_root_constraint_scheduler,
                  overgroup: tk_tenant_wlk_overgroup,
                });

                // environment type: if running on Splunk Cloud, include the option explicitely and create the tracker too
                if (tk_splk_wlk_env_type === "splunk_cloud") {
                  hybrid_objects.push({
                    tenant_id: tk_tenant_name,
                    environment_type: tk_splk_wlk_env_type,
                    tracker_type: "splunkcloud_svc",
                    account: tk_splk_wlk_accounts[i],
                    root_constraint: tk_tenant_wlk_root_constraint_svc,
                    overgroup: tk_tenant_wlk_overgroup,
                  });
                }

                // track notable
                if (tk_splk_wlk_track_notable === "true") {
                  hybrid_objects.push({
                    tenant_id: tk_tenant_name,
                    environment_type: tk_splk_wlk_env_type,
                    tracker_type: "notable",
                    account: tk_splk_wlk_accounts[i],
                    overgroup: tk_tenant_wlk_overgroup,
                  });
                }
              }

              // Add the tenant record
              final_record["tenant_dict"] = record;

              // Add the hybrid array
              final_record["hybrid_objects"] = hybrid_objects;

              // Create the virtual tenant
              $.ajax({
                url: "/en-US/splunkd/__raw/services/trackme/v2/vtenants/admin/add_tenant_wlk_multiops",
                type: "POST",
                async: true,
                contentType: "application/json",
                data: JSON.stringify(final_record),
                timeout: 600000,
                success: function (returneddata) {
                  //
                  // if previously ran
                  $("#div_create_tenant_spl_command")
                    .find(".modal-spl-message p")
                    .text("");
                  $("#div_create_tenant_spl_command").attr(
                    "style",
                    "display: None !important"
                  );
                  // Audit success is made by the API
                  // If click on show SPL command
                  $("#btn_create_tenant_show_spl").on("click", function () {
                    $(this).blur();
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: block !important"
                    );
                    $("#btn_create_tenant_copy_clipboard").attr(
                      "style",
                      "display: block !important"
                    );
                  });
                  // if click on copy to clipboard
                  $("#btn_create_tenant_copy_clipboard").on(
                    "click",
                    function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      copyToClipboard(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, "'") +
                          '"'
                      );
                    }
                  );
                  $("#cssloader").remove();
                  $("#modal_creation_success").modal();
                  // Refresh and restart interval
                  $("#btn_refresh_all").click();
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                    "5"
                  );
                  //
                },
                error: function (xhr, textStatus, error) {
                  // A timeout can occur on Splunk Cloud especially with very long operations
                  // this is begign and does mean the operation has failed, assume things are ok
                  if (error == "timeout" || error == "GATEWAY_TIMEOUT") {
                    //
                    // if previously ran
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text("");
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: None !important"
                    );
                    // Audit success is made by the API
                    // If click on show SPL command
                    $("#btn_create_tenant_show_spl").on("click", function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      $("#div_create_tenant_spl_command").attr(
                        "style",
                        "display: block !important"
                      );
                      $("#btn_create_tenant_copy_clipboard").attr(
                        "style",
                        "display: block !important"
                      );
                    });
                    // if click on copy to clipboard
                    $("#btn_create_tenant_copy_clipboard").on(
                      "click",
                      function () {
                        $(this).blur();
                        $("#div_create_tenant_spl_command")
                          .find(".modal-spl-message p")
                          .text(
                            '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                              JSON.stringify(record).replace(/\"/g, "'") +
                              '"'
                          );
                        copyToClipboard(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, "'") +
                            '"'
                        );
                      }
                    );
                    $("#cssloader").remove();
                    $("#modal_creation_success").modal();
                    // Refresh and restart interval
                    $("#btn_refresh_all").click();
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                      "5"
                    );
                    //
                  } else {
                    $("#cssloader").remove();
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error +
                      "\n - text status: " +
                      textStatus;
                    $("#modal_generic_error")
                      .find(".modal-error-message p")
                      .text(message);
                    $("#modal_generic_error").modal();
                  }
                },
              });
            });

          $("#create_tenant_splk_wlk_old")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Get tenant_name
              var tk_tenant_name = document.getElementById(
                "input_tenant_name_splk_wlk"
              ).value;

              // replace spaces and underscore
              tk_tenant_name = tk_tenant_name.replace(/\s/g, "-");
              tk_tenant_name = tk_tenant_name.replace(/\_/g, "-");

              // make it lower case
              tk_tenant_name = tk_tenant_name.toLowerCase();

              // Get tenant_description
              var tk_tenant_description = document.getElementById(
                "input_tenant_description_splk_wlk"
              ).value;

              // some replacements
              tk_tenant_description = tk_tenant_description.replace(/\'/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\"/g, "");
              tk_tenant_description = tk_tenant_description.replace(/\\/g, "");

              // Get tenant_wlk_enabled
              var tk_tenant_wlk_enabled = "true";

              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_tenant_roles_admin_splk_wlk"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_tenant_roles_power_splk_wlk"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_tenant_roles_user_splk_wlk"
              );

              // Get tenant_owner
              var tk_tenant_owner = getToken("tk_tenant_owner_splk_wlk");

              // Get accounts
              var tk_splk_wlk_accounts = getToken("tk_splk_wlk_accounts");

              // Get indexes
              var tk_tenant_idx_settings;

              // local settings
              var tk_tenant_idx_summary = getToken(
                "tk_tenant_idx_summary_splk_wlk"
              );
              var tk_tenant_idx_audit = getToken(
                "tk_tenant_idx_audit_splk_wlk"
              );
              var tk_tenant_idx_metric = getToken(
                "tk_tenant_idx_metric_splk_wlk"
              );
              var tk_tenant_idx_notable = getToken(
                "tk_tenant_idx_notable_splk_wlk"
              );

              // global settings
              var tk_default_tenant_idx_summary = getToken(
                "tk_default_tenant_idx_summary"
              );
              var tk_default_tenant_idx_audit = getToken(
                "tk_default_tenant_idx_audit"
              );
              var tk_default_tenant_idx_metric = getToken(
                "tk_default_tenant_idx_metric"
              );
              var tk_default_tenant_idx_notable = getToken(
                "tk_default_tenant_idx_notable"
              );

              if (
                tk_tenant_idx_summary.length < 1 ||
                tk_tenant_idx_summary == "null" ||
                tk_tenant_idx_audit.length < 1 ||
                tk_tenant_idx_audit == "null" ||
                tk_tenant_idx_metric.length < 1 ||
                tk_tenant_idx_metric == "null" ||
                tk_tenant_idx_notable.length < 1 ||
                tk_tenant_idx_notable == "null"
              ) {
                tk_tenant_idx_settings = "global";
              } else if (
                tk_tenant_idx_summary === tk_default_tenant_idx_summary &&
                tk_tenant_idx_audit === tk_default_tenant_idx_audit &&
                tk_tenant_idx_metric === tk_default_tenant_idx_metric &&
                tk_tenant_idx_notable === tk_default_tenant_idx_notable
              ) {
                tk_tenant_idx_settings = "global";
              } else {
                tk_tenant_idx_settings =
                  '{"trackme_summary_idx": "' +
                  tk_tenant_idx_summary +
                  '", "trackme_audit_idx": "' +
                  tk_tenant_idx_audit +
                  '", "trackme_notable_idx": "' +
                  tk_tenant_idx_notable +
                  '", "trackme_metric_idx": "' +
                  tk_tenant_idx_metric +
                  '"}';
              }

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_create_tenant_splk_wlk"
              ).value;

              // Prepare the JSON record
              var record = {};

              // Add main settings first
              record["tenant_desc"] = tk_tenant_description;
              record["tenant_name"] = tk_tenant_name;
              record["tenant_roles_admin"] = tk_tenant_roles_admin;
              record["tenant_roles_power"] = tk_tenant_roles_power;
              record["tenant_roles_user"] = tk_tenant_roles_user;
              record["tenant_owner"] = tk_tenant_owner;
              record["tenant_idx_settings"] = tk_tenant_idx_settings;

              // If component is enabled
              if (tk_tenant_wlk_enabled) {
                record["tenant_wlk_enabled"] = tk_tenant_wlk_enabled;
              }

              // Add comment
              if (tk_comment != "Enter your audit message") {
                record["update_comment"] = tk_comment;
              }

              // spinner
              $("#cssloader").remove();
              $("body").append(
                '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being created, this can take up to 5 minutes to be completed, tasks would continue in the background if you close this window or if the spinner gets closed unexpectly, please wait..."></div>'
              );

              // Create the virtual tenant
              $.ajax({
                url: "/en-US/splunkd/__raw//services/trackme/v2/vtenants/admin/add_tenant",
                type: "POST",
                async: true,
                contentType: "application/json",
                data: JSON.stringify(record),
                timeout: 600000,
                success: function (returneddata) {
                  //
                  // if previously ran
                  $("#div_create_tenant_spl_command")
                    .find(".modal-spl-message p")
                    .text("");
                  $("#div_create_tenant_spl_command").attr(
                    "style",
                    "display: None !important"
                  );
                  // Audit success is made by the API
                  // If click on show SPL command
                  $("#btn_create_tenant_show_spl").on("click", function () {
                    $(this).blur();
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, '\\"') +
                          '"'
                      );
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: block !important"
                    );
                    $("#btn_create_tenant_copy_clipboard").attr(
                      "style",
                      "display: block !important"
                    );
                  });
                  // if click on copy to clipboard
                  $("#btn_create_tenant_copy_clipboard").on(
                    "click",
                    function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, '\\"') +
                            '"'
                        );
                      copyToClipboard(
                        '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                          JSON.stringify(record).replace(/\"/g, '\\"') +
                          '"'
                      );
                    }
                  );
                  $("#cssloader").remove();
                  $("#modal_creation_success").modal();
                  // Refresh and restart interval
                  $("#btn_refresh_all").click();
                  // notify
                  notify(
                    "success",
                    "bottom",
                    "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                    "5"
                  );
                  //
                },
                error: function (xhr, textStatus, error) {
                  // A timeout can occur on Splunk Cloud especially with very long operations
                  // this is begign and does mean the operation has failed, assume things are ok
                  if (error == "timeout" || error == "GATEWAY_TIMEOUT") {
                    //
                    // if previously ran
                    $("#div_create_tenant_spl_command")
                      .find(".modal-spl-message p")
                      .text("");
                    $("#div_create_tenant_spl_command").attr(
                      "style",
                      "display: None !important"
                    );
                    // Audit success is made by the API
                    // If click on show SPL command
                    $("#btn_create_tenant_show_spl").on("click", function () {
                      $(this).blur();
                      $("#div_create_tenant_spl_command")
                        .find(".modal-spl-message p")
                        .text(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, '\\"') +
                            '"'
                        );
                      $("#div_create_tenant_spl_command").attr(
                        "style",
                        "display: block !important"
                      );
                      $("#btn_create_tenant_copy_clipboard").attr(
                        "style",
                        "display: block !important"
                      );
                    });
                    // if click on copy to clipboard
                    $("#btn_create_tenant_copy_clipboard").on(
                      "click",
                      function () {
                        $(this).blur();
                        $("#div_create_tenant_spl_command")
                          .find(".modal-spl-message p")
                          .text(
                            '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                              JSON.stringify(record).replace(/\"/g, '\\"') +
                              '"'
                          );
                        copyToClipboard(
                          '| trackme url="/services/trackme/v2/vtenants/admin/add_tenant" mode="post" body="' +
                            JSON.stringify(record).replace(/\"/g, '\\"') +
                            '"'
                        );
                      }
                    );
                    $("#cssloader").remove();
                    $("#modal_creation_success").modal();
                    // Refresh and restart interval
                    $("#btn_refresh_all").click();
                    // notify
                    notify(
                      "success",
                      "bottom",
                      "Congratulations! The new tenant was successfully created and is ready to use, click on the table to open it immediately or perform administration tasks!",
                      "5"
                    );
                    //
                  } else {
                    $("#cssloader").remove();
                    message =
                      "server response: " +
                      xhr.responseText +
                      "\n - http response: " +
                      error +
                      "\n - text status: " +
                      textStatus;
                    $("#modal_generic_error")
                      .find(".modal-error-message p")
                      .text(message);
                    $("#modal_generic_error").modal();
                  }
                },
              });
            });

          //
          // end go creation tenants
          //

          $("#delete_tenant_confirmed").click(function () {
            // Stop auto-refresh
            vtenantStopInterval();

            // Create the service
            var service = mvc.createService({
              owner: "nobody",
            });

            // Get current user
            var currentUser = Splunk.util.getConfigValue("USERNAME");

            // Get tenant context
            var clickedTenantId = getToken("clickedTenantId");

            // Get update note
            var tk_comment = document.getElementById(
              "input_comment_delete_tenant"
            ).value;

            // Prepare the command
            var record;
            record = "{ 'tenant_id': '" + clickedTenantId + "'";

            // insert comment and close
            if (tk_comment != "Enter your audit message") {
              record = record + ", 'update_comment': '" + tk_comment + "'}";
            } else {
              record = record + "}";
            }

            // Define the query
            var searchQuery =
              '| trackme url=/services/trackme/v2/vtenants/admin/del_tenant mode=delete body="' +
              record +
              '"';

            // Set the search parameters--specify a time range
            var searchParams = {
              earliest_time: "-5m",
              latest_time: "now",
            };

            // Run a blocking search and get back a job
            service.search(searchQuery, searchParams, function (err, job) {
              // spinner
              $("#cssloader").remove();
              $("body").append(
                '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being deleted, this might take some time..."></div>'
              );

              // Shall the search fail before we can get properties
              if (job == null) {
                let errorStr = "Unknown Error!";
                if (
                  err &&
                  err.data &&
                  err.data.messages &&
                  err.data.messages[0]["text"]
                ) {
                  errorStr = err.data.messages[0]["text"];
                } else if (err && err.data && err.data.messages) {
                  errorStr = JSON.stringify(err.data.messages);
                }
                // show error modal
                $("#cssloader").remove();
                $("#modal_generic_error")
                  .find(".modal-error-message p")
                  .text(errorStr);
                $("#modal_generic_error").modal();
              } else {
                // Poll the status of the search job
                job.track(
                  {
                    period: 200,
                  },
                  {
                    done: function (job) {
                      // Get the results
                      job.results({}, function (err, results, job) {
                        var fields = results.fields;
                        var rows = results.rows;
                        var jobResult;
                        for (var i = 0; i < rows.length; i++) {
                          var values = rows[i];
                          for (var j = 0; j < values.length; j++) {
                            var field = fields[j];
                            var value = values[j];
                            // get the _raw
                            if (field === "_raw") {
                              jobResult = value;
                            }
                          }

                          // Identify the operation result
                          if (jobResult.includes('"action":"success"')) {
                            // if previously ran
                            $("#div_delete_tenant_spl_command")
                              .find(".modal-spl-message p")
                              .text("");
                            $("#div_delete_tenant_spl_command").attr(
                              "style",
                              "display: None !important"
                            );
                            // If click on show SPL command
                            $("#btn_delete_tenant_show_spl").on(
                              "click",
                              function () {
                                $(this).blur();
                                $("#div_delete_tenant_spl_command")
                                  .find(".modal-spl-message p")
                                  .text(searchQuery);
                                $("#div_delete_tenant_spl_command").attr(
                                  "style",
                                  "display: block !important"
                                );
                                $("#btn_delete_tenant_copy_clipboard").attr(
                                  "style",
                                  "display: block !important"
                                );
                              }
                            );
                            // if click on copy to clipboard
                            $("#btn_delete_tenant_copy_clipboard").on(
                              "click",
                              function () {
                                $(this).blur();
                                $("#div_delete_tenant_spl_command")
                                  .find(".modal-spl-message p")
                                  .text(searchQuery);
                                copyToClipboard(searchQuery);
                              }
                            );
                            $("#cssloader").remove();
                            // show modal unless we deleted the last tenant
                            var numItems = $(".flex-items").length;
                            if (numItems > 1) {
                              $("#modal_deletion_success").modal();
                            }
                            // refresh flex boxes
                            getTenantsList("false", "true");
                            // Refresh Ops
                            getTenantsOpsStatus();
                            // notify
                            notify(
                              "success",
                              "bottom",
                              "Job done! The tenant was successfully deleted, all of its knowledge objects have been permanently removed!",
                              "5"
                            );
                          } else {
                            $("#modal_generic_error")
                              .find(".modal-error-message p")
                              .text(value);
                            $("#cssloader").remove();
                            $("#modal_generic_error").modal();
                          }
                        }
                      });
                    },
                    failed: function (properties) {
                      let errorStr = "Unknown Error!";
                      if (
                        properties &&
                        properties._properties &&
                        properties._properties.messages &&
                        properties._properties.messages[0]["text"]
                      ) {
                        errorStr = properties._properties.messages[0]["text"];
                      } else if (
                        properties &&
                        properties._properties &&
                        properties._properties.messages
                      ) {
                        errorStr = JSON.stringify(
                          properties._properties.messages
                        );
                      }
                      $("#cssloader").remove();
                      $("#modal_generic_error")
                        .find(".modal-error-message p")
                        .text(errorStr);
                      $("#modal_generic_error").modal();
                    },
                    error: function (err) {
                      done(err);
                      $("#cssloader").remove();
                      $("#modal_update_collection_failure_flush").modal();
                    },
                  }
                );
              }
            });
          });

          $("#enable_tenant_confirmed")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Create the service
              var service = mvc.createService({
                owner: "nobody",
              });

              // Get current user
              var currentUser = Splunk.util.getConfigValue("USERNAME");

              // Get tenant context
              var clickedTenantId = getToken("clickedTenantId");

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_enable_tenant"
              ).value;

              // Prepare the command
              var record;
              record = "{ 'tenant_id': '" + clickedTenantId + "'";

              // insert comment and close
              if (tk_comment != "Enter your audit message") {
                record = record + ", 'update_comment': '" + tk_comment + "'}";
              } else {
                record = record + "}";
              }

              // Define the query
              var searchQuery =
                '| trackme url=/services/trackme/v2/vtenants/admin/enable_tenant mode=post body="' +
                record +
                '"';

              // Set the search parameters--specify a time range
              var searchParams = {
                earliest_time: "-5m",
                latest_time: "now",
              };

              // Run a blocking search and get back a job
              service.search(searchQuery, searchParams, function (err, job) {
                // spinner
                $("#cssloader").remove();
                $("body").append(
                  '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being activated, this might take some time..."></div>'
                );

                // Shall the search fail before we can get properties
                if (job == null) {
                  let errorStr = "Unknown Error!";
                  if (
                    err &&
                    err.data &&
                    err.data.messages &&
                    err.data.messages[0]["text"]
                  ) {
                    errorStr = err.data.messages[0]["text"];
                  } else if (err && err.data && err.data.messages) {
                    errorStr = JSON.stringify(err.data.messages);
                  }
                  // show error modal
                  $("#cssloader").remove();
                  $("#modal_generic_error")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  $("#modal_generic_error").modal();
                } else {
                  // Poll the status of the search job
                  job.track(
                    {
                      period: 200,
                    },
                    {
                      done: function (job) {
                        // Get the results
                        job.results({}, function (err, results, job) {
                          var fields = results.fields;
                          var rows = results.rows;
                          var jobResult;
                          for (var i = 0; i < rows.length; i++) {
                            var values = rows[i];
                            for (var j = 0; j < values.length; j++) {
                              var field = fields[j];
                              var value = values[j];
                              // get the _raw
                              if (field === "_raw") {
                                jobResult = value;
                              }
                            }

                            // Identify the operation result
                            if (jobResult.includes('"action":"success"')) {
                              // if previously ran
                              $("#div_enable_tenant_spl_command")
                                .find(".modal-spl-message p")
                                .text("");
                              $("#div_enable_tenant_spl_command").attr(
                                "style",
                                "display: None !important"
                              );
                              // If click on show SPL command
                              $("#btn_enable_tenant_show_spl").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_enable_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  $("#div_enable_tenant_spl_command").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                  $("#btn_enable_tenant_copy_clipboard").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                }
                              );
                              // if click on copy to clipboard
                              $("#btn_enable_tenant_copy_clipboard").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_enable_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  copyToClipboard(searchQuery);
                                }
                              );
                              $("#cssloader").remove();
                              $("#modal_enable_success").modal();
                              // Refresh and restart interval
                              $("#btn_refresh_all").click();
                              // notify
                              notify(
                                "success",
                                "bottom",
                                "Job done! The tenant was successfully enabled, it is now active and ready to be used!",
                                "5"
                              );
                            } else {
                              $("#modal_generic_error")
                                .find(".modal-error-message p")
                                .text(value);
                              $("#cssloader").remove();
                              $("#modal_generic_error").modal();
                            }
                          }
                        });
                      },
                      failed: function (properties) {
                        let errorStr = "Unknown Error!";
                        if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages &&
                          properties._properties.messages[0]["text"]
                        ) {
                          errorStr = properties._properties.messages[0]["text"];
                        } else if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages
                        ) {
                          errorStr = JSON.stringify(
                            properties._properties.messages
                          );
                        }
                        $("#cssloader").remove();
                        $("#modal_generic_error")
                          .find(".modal-error-message p")
                          .text(errorStr);
                        $("#modal_generic_error").modal();
                      },
                      error: function (err) {
                        done(err);
                        $("#cssloader").remove();
                        $("#modal_update_collection_failure_flush").modal();
                      },
                    }
                  );
                }
              });
            });

          $("#disable_tenant_confirmed")
            .unbind()
            .click(function () {
              // Stop auto-refresh
              vtenantStopInterval();

              // Create the service
              var service = mvc.createService({
                owner: "nobody",
              });

              // Get current user
              var currentUser = Splunk.util.getConfigValue("USERNAME");

              // Get tenant context
              var clickedTenantId = getToken("clickedTenantId");

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_disable_tenant"
              ).value;

              // Prepare the command
              var record;
              record = "{ 'tenant_id': '" + clickedTenantId + "'";

              // insert comment and close
              if (tk_comment != "Enter your audit message") {
                record = record + ", 'update_comment': '" + tk_comment + "'}";
              } else {
                record = record + "}";
              }

              // Define the query
              var searchQuery =
                '| trackme url=/services/trackme/v2/vtenants/admin/disable_tenant mode=post body="' +
                record +
                '"';

              // Set the search parameters--specify a time range
              var searchParams = {
                earliest_time: "-5m",
                latest_time: "now",
              };

              // Run a blocking search and get back a job
              service.search(searchQuery, searchParams, function (err, job) {
                // spinner
                $("#cssloader").remove();
                $("body").append(
                  '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being deactivated, this might take some time..."></div>'
                );

                // Shall the search fail before we can get properties
                if (job == null) {
                  let errorStr = "Unknown Error!";
                  if (
                    err &&
                    err.data &&
                    err.data.messages &&
                    err.data.messages[0]["text"]
                  ) {
                    errorStr = err.data.messages[0]["text"];
                  } else if (err && err.data && err.data.messages) {
                    errorStr = JSON.stringify(err.data.messages);
                  }
                  // show error modal
                  $("#cssloader").remove();
                  $("#modal_generic_error")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  $("#modal_generic_error").modal();
                } else {
                  // Poll the status of the search job
                  job.track(
                    {
                      period: 200,
                    },
                    {
                      done: function (job) {
                        // Get the results
                        job.results({}, function (err, results, job) {
                          var fields = results.fields;
                          var rows = results.rows;
                          var jobResult;
                          for (var i = 0; i < rows.length; i++) {
                            var values = rows[i];
                            for (var j = 0; j < values.length; j++) {
                              var field = fields[j];
                              var value = values[j];
                              // get the _raw
                              if (field === "_raw") {
                                jobResult = value;
                              }
                            }

                            // Identify the operation result
                            if (jobResult.includes('"action":"success"')) {
                              // if previously ran
                              $("#div_disable_tenant_spl_command")
                                .find(".modal-spl-message p")
                                .text("");
                              $("#div_disable_tenant_spl_command").attr(
                                "style",
                                "display: None !important"
                              );
                              // If click on show SPL command
                              $("#btn_disable_tenant_show_spl").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_disable_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  $("#div_disable_tenant_spl_command").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                  $("#btn_disable_tenant_copy_clipboard").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                }
                              );
                              // if click on copy to clipboard
                              $("#btn_disable_tenant_copy_clipboard").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_disable_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  copyToClipboard(searchQuery);
                                }
                              );
                              $("#cssloader").remove();
                              $("#modal_disable_success").modal();
                              // Refresh and restart interval
                              $("#btn_refresh_all").click();
                              // notify
                              notify(
                                "success",
                                "bottom",
                                "Job done! The tenant was successfully disabled, all of its knowledge objects are permanmently disabled, you can decide to re-enable it later-on!",
                                "5"
                              );
                            } else {
                              $("#modal_generic_error")
                                .find(".modal-error-message p")
                                .text(value);
                              $("#cssloader").remove();
                              $("#modal_generic_error").modal();
                            }
                          }
                        });
                      },
                      failed: function (properties) {
                        let errorStr = "Unknown Error!";
                        if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages &&
                          properties._properties.messages[0]["text"]
                        ) {
                          errorStr = properties._properties.messages[0]["text"];
                        } else if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages
                        ) {
                          errorStr = JSON.stringify(
                            properties._properties.messages
                          );
                        }
                        $("#cssloader").remove();
                        $("#modal_generic_error")
                          .find(".modal-error-message p")
                          .text(errorStr);
                        $("#modal_generic_error").modal();
                      },
                      error: function (err) {
                        done(err);
                        $("#cssloader").remove();
                        $("#modal_update_collection_failure_flush").modal();
                      },
                    }
                  );
                }
              });
            });

          //
          // Add or delete components
          //

          $("#update_tenant")
            .unbind()
            .click(function () {
              //
              // Show modal
              //

              $("#modal_update_tenant").modal();

              // show message
              notify(
                "info",
                "bottom",
                "ℹ️ Add or delete a TrackMe component on this tenant after it was created.",
                "5"
              );
            });

          $("#btn_modify_tenant_components_next")
            .unbind()
            .click(function () {
              //
              // Show modal
              //

              $("#modify_tenant_components_confirm").modal();

              // show message
              notify(
                "info",
                "bottom",
                "ℹ️ Please confirm this operation.",
                "5"
              );
            });

          // Update tenant
          $("#update_tenant_components_confirmed")
            .unbind()
            .click(function () {
              // Create the service
              var service = mvc.createService({
                owner: "nobody",
              });

              // Get tenant context
              var clickedTenantId = getToken("clickedTenantId");

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_update_tenant_components"
              ).value;

              // Get action requested
              var tk_action = document.getElementById(
                "tenant_manage_components_action"
              ).value;

              // Get component requested
              var tk_component_target = document.getElementById(
                "tenant_manage_components_target"
              ).value;

              // Prepare the command
              var record;
              record =
                "{ 'tenant_id': '" +
                clickedTenantId +
                "', 'component_target': '" +
                tk_component_target +
                "'";

              // insert comment and close
              if (tk_comment != "Enter your audit message") {
                record = record + ", 'update_comment': '" + tk_comment + "'}";
              } else {
                record = record + "}";
              }

              // Define the query
              var searchQuery;
              if (tk_action === "add") {
                searchQuery =
                  '| trackme url=/services/trackme/v2/vtenants/admin/add_component_tenant mode=post body="' +
                  record +
                  '"';
              } else if (tk_action === "delete") {
                searchQuery =
                  '| trackme url=/services/trackme/v2/vtenants/admin/delete_component_tenant mode=post body="' +
                  record +
                  '"';
              }

              // Set the search parameters--specify a time range
              var searchParams = {
                earliest_time: "-5m",
                latest_time: "now",
              };

              // Run a blocking search and get back a job
              service.search(searchQuery, searchParams, function (err, job) {
                // spinner
                $("#cssloader").remove();
                $("body").append(
                  '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being updated, this might take some time..."></div>'
                );

                // Shall the search fail before we can get properties
                if (job == null) {
                  let errorStr = "Unknown Error!";
                  if (
                    err &&
                    err.data &&
                    err.data.messages &&
                    err.data.messages[0]["text"]
                  ) {
                    errorStr = err.data.messages[0]["text"];
                  } else if (err && err.data && err.data.messages) {
                    errorStr = JSON.stringify(err.data.messages);
                  }
                  // show error modal
                  $("#cssloader").remove();
                  $("#modal_generic_error")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  $("#modal_generic_error").modal();
                } else {
                  // Poll the status of the search job
                  job.track(
                    {
                      period: 200,
                    },
                    {
                      done: function (job) {
                        // Get the results
                        job.results({}, function (err, results, job) {
                          var fields = results.fields;
                          var rows = results.rows;
                          var jobResult;
                          for (var i = 0; i < rows.length; i++) {
                            var values = rows[i];
                            for (var j = 0; j < values.length; j++) {
                              var field = fields[j];
                              var value = values[j];
                              // get the _raw
                              if (field === "_raw") {
                                jobResult = value;
                              }
                            }

                            // Identify the operation result
                            if (jobResult.includes('"action":"success"')) {
                              // if previously ran
                              $("#div_update_tenant_spl_command")
                                .find(".modal-spl-message p")
                                .text("");
                              $("#div_update_tenant_spl_command").attr(
                                "style",
                                "display: None !important"
                              );
                              // If click on show SPL command
                              $("#btn_update_tenant_show_spl").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_update_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  $("#div_update_tenant_spl_command").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                  $("#btn_update_tenant_copy_clipboard").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                }
                              );
                              // if click on copy to clipboard
                              $("#btn_update_tenant_copy_clipboard").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_update_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  copyToClipboard(searchQuery);
                                }
                              );
                              $("#cssloader").remove();
                              $("#modal_update_success").modal();
                              // notify
                              notify(
                                "success",
                                "bottom",
                                "Job done! The component was successfully updated for the tenant.",
                                "5"
                              );
                              // Refresh and restart interval
                              $("#btn_refresh_all").click();
                            } else {
                              $("#modal_generic_error")
                                .find(".modal-error-message p")
                                .text(value);
                              $("#cssloader").remove();
                              $("#modal_generic_error").modal();
                            }
                          }
                        });
                      },
                      failed: function (properties) {
                        let errorStr = "Unknown Error!";
                        if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages &&
                          properties._properties.messages[0]["text"]
                        ) {
                          errorStr = properties._properties.messages[0]["text"];
                        } else if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages
                        ) {
                          errorStr = JSON.stringify(
                            properties._properties.messages
                          );
                        }
                        $("#cssloader").remove();
                        $("#modal_generic_error")
                          .find(".modal-error-message p")
                          .text(errorStr);
                        $("#modal_generic_error").modal();
                      },
                      error: function (err) {
                        done(err);
                        $("#cssloader").remove();
                        $("#modal_update_collection_failure_flush").modal();
                      },
                    }
                  );
                }
              });
            });

          //
          // RBAC update
          //

          $("#rbac_tenant")
            .unbind()
            .click(function () {
              //
              // Retrieve and show current RBAC
              //

              // hide spinner
              $("#tenantRbacCurrentLoader").css("display", "inherit");

              // Create the endpoint URL
              var myendpoint_URl =
                "/en-US/splunkd/__raw/services/trackme/v2/configuration/show_vtenants_rbac";

              // Create a dictionary to store the field names and values
              var record = {
                tenant_id: getToken("clickedTenantId"),
              };

              $.ajax({
                url: myendpoint_URl,
                type: "POST",
                async: true,
                contentType: "application/json",
                dataType: "json",
                data: JSON.stringify(record),
                success: function (returneddata) {
                  // hide spinner
                  $("#tenantRbacCurrentLoader").css("display", "none");
                  // show
                  $("#tenantRbacCurrentParent").css("display", "inherit");
                  $("#tenantRbacCurrent").html(
                    '<pre class="create-cim-json-rules-preview">' +
                      syntaxHighlight(JSON.stringify(returneddata, null, 2)) +
                      "</pre>"
                  );
                  $("#modal_modify_tenant_rbac").modal();
                },
                error: function (xhr, textStatus, error) {
                  // notify
                  notify(
                    "error",
                    "bottom",
                    "Failed to retrieve the current RBAC configuration for this tenant.",
                    "5"
                  );
                  // creation via template
                  // hide spinner
                  $("#tenantRbacCurrentLoader").css("display", "none");
                  // show
                  $("#tenantRbacCurrentParent").css("display", "inherit");
                  $("#tenantRbacCurrent").html(
                    '<pre class="create-cim-json-rules-preview">' +
                      syntaxHighlight(JSON.stringify(xhr, null, 2)) +
                      "</pre>"
                  );
                },
              });

              // start related searches
              searchListRoles.startSearch();
              searchListUsers.startSearch();

              // show message
              notify(
                "info",
                "bottom",
                "ℹ️ Update the RBAC settings for the tenant, you can setup the Splunk roles which provide administrative privileges, the roles for standard users and the Splunk owner of the tenant knowledge objects",
                "5"
              );
            });

          // verify before update
          $("#btn_modify_tenant_rbac_next")
            .unbind()
            .click(function () {
              // Get tenant_roles_admin
              var tk_update_tenant_roles_admin = getToken(
                "tk_update_tenant_roles_admin"
              );

              // Get tenant_roles_user
              var tk_update_tenant_roles_user = getToken(
                "tk_update_tenant_roles_user"
              );

              if (
                tk_update_tenant_roles_admin.length < 1 ||
                tk_update_tenant_roles_admin == "null" ||
                tk_update_tenant_roles_user.length < 1 ||
                tk_update_tenant_roles_user == "null"
              ) {
                var errorStr =
                  "The RBAC configuration is invalid, at least one role for administration and one role for users have to be configured";
                $("#modal_invalid_selection")
                  .find(".modal-error-message p")
                  .text(errorStr);

                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute("href", "#modal_modify_tenant_rbac");

                $("#modify_tenant_rbac_confirm").modal("hide");
                $("#modal_invalid_selection").modal();
              } else {
                var link = document.getElementById(
                  "invalid_selection_return_to_screen"
                );
                link.setAttribute("href", "#modal_modify_tenant_rbac");
                $("#modify_tenant_rbac_confirm").modal();
              }
            });

          // Update RBAC
          $("#update_tenant_rbac_confirmed")
            .unbind()
            .click(function () {
              // Create the service
              var service = mvc.createService({
                owner: "nobody",
              });

              // Get current user
              var currentUser = Splunk.util.getConfigValue("USERNAME");

              // Get tenant context
              var clickedTenantId = getToken("clickedTenantId");

              // Get update note
              var tk_comment = document.getElementById(
                "input_comment_update_tenant_rbac"
              ).value;

              // Get tenant_roles_admin
              var tk_tenant_roles_admin = getToken(
                "tk_update_tenant_roles_admin"
              );

              // Get tenant_roles_power
              var tk_tenant_roles_power = getToken(
                "tk_update_tenant_roles_power"
              );

              // Get tenant_roles_user
              var tk_tenant_roles_user = getToken(
                "tk_update_tenant_roles_user"
              );

              // Get tenant_owner
              var tk_tenant_owner = getToken("tk_update_tenant_owner");

              // Prepare the command
              var record;
              record =
                "{ 'tenant_id': '" +
                clickedTenantId +
                "', 'tenant_roles_admin': '" +
                tk_tenant_roles_admin +
                "', 'tenant_roles_power': '" +
                tk_tenant_roles_power +
                "', 'tenant_roles_user': '" +
                tk_tenant_roles_user +
                "', 'tenant_owner': '" +
                tk_tenant_owner +
                "'";

              // insert comment and close
              if (tk_comment != "Enter your audit message") {
                record = record + ", 'update_comment': '" + tk_comment + "'}";
              } else {
                record = record + "}";
              }

              // Define the query
              var searchQuery =
                '| trackme url=/services/trackme/v2/vtenants/admin/update_tenant_rbac mode=post body="' +
                record +
                '"';

              // Set the search parameters--specify a time range
              var searchParams = {
                earliest_time: "-5m",
                latest_time: "now",
              };

              // Run a blocking search and get back a job
              service.search(searchQuery, searchParams, function (err, job) {
                // spinner
                $("#cssloader").remove();
                $("body").append(
                  '<div id="cssloader" class="loader loader-default is-active" data-text="Please wait while the tenant is being updated, this might take some time..."></div>'
                );

                // Shall the search fail before we can get properties
                if (job == null) {
                  let errorStr = "Unknown Error!";
                  if (
                    err &&
                    err.data &&
                    err.data.messages &&
                    err.data.messages[0]["text"]
                  ) {
                    errorStr = err.data.messages[0]["text"];
                  } else if (err && err.data && err.data.messages) {
                    errorStr = JSON.stringify(err.data.messages);
                  }
                  // show error modal
                  $("#cssloader").remove();
                  $("#modal_generic_error")
                    .find(".modal-error-message p")
                    .text(errorStr);
                  $("#modal_generic_error").modal();
                } else {
                  // Poll the status of the search job
                  job.track(
                    {
                      period: 200,
                    },
                    {
                      done: function (job) {
                        // Get the results
                        job.results({}, function (err, results, job) {
                          var fields = results.fields;
                          var rows = results.rows;
                          var jobResult;
                          for (var i = 0; i < rows.length; i++) {
                            var values = rows[i];
                            for (var j = 0; j < values.length; j++) {
                              var field = fields[j];
                              var value = values[j];
                              // get the _raw
                              if (field === "_raw") {
                                jobResult = value;
                              }
                            }

                            // Identify the operation result
                            if (jobResult.includes('"action":"success"')) {
                              // if previously ran
                              $("#div_update_tenant_spl_command")
                                .find(".modal-spl-message p")
                                .text("");
                              $("#div_update_tenant_spl_command").attr(
                                "style",
                                "display: None !important"
                              );
                              // If click on show SPL command
                              $("#btn_update_tenant_show_spl").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_update_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  $("#div_update_tenant_spl_command").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                  $("#btn_update_tenant_copy_clipboard").attr(
                                    "style",
                                    "display: block !important"
                                  );
                                }
                              );
                              // if click on copy to clipboard
                              $("#btn_update_tenant_copy_clipboard").on(
                                "click",
                                function () {
                                  $(this).blur();
                                  $("#div_update_tenant_spl_command")
                                    .find(".modal-spl-message p")
                                    .text(searchQuery);
                                  copyToClipboard(searchQuery);
                                }
                              );
                              $("#cssloader").remove();
                              $("#modal_update_success").modal();
                              // notify
                              notify(
                                "success",
                                "bottom",
                                "Job done! RBAC was successfully updated for the tenant, all knowledge objecs related to it have been updated accordingly.",
                                "5"
                              );
                            } else {
                              $("#modal_generic_error")
                                .find(".modal-error-message p")
                                .text(value);
                              $("#cssloader").remove();
                              $("#modal_generic_error").modal();
                            }
                          }
                        });
                      },
                      failed: function (properties) {
                        let errorStr = "Unknown Error!";
                        if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages &&
                          properties._properties.messages[0]["text"]
                        ) {
                          errorStr = properties._properties.messages[0]["text"];
                        } else if (
                          properties &&
                          properties._properties &&
                          properties._properties.messages
                        ) {
                          errorStr = JSON.stringify(
                            properties._properties.messages
                          );
                        }
                        $("#cssloader").remove();
                        $("#modal_generic_error")
                          .find(".modal-error-message p")
                          .text(errorStr);
                        $("#modal_generic_error").modal();
                      },
                      error: function (err) {
                        done(err);
                        $("#cssloader").remove();
                        $("#modal_update_collection_failure_flush").modal();
                      },
                    }
                  );
                }
              });
            });

          //
          // Edit user preferences
          //
          $("#edit_preferences")
            .unbind()
            .click(function () {
              // get current preferences

              // Get current user
              var currentUser = Splunk.util.getConfigValue("USERNAME");

              // target url for tenants user preferences
              var ajaxUrlUserPrefUi =
                "/en-US/splunkd/__raw/services/trackme/v2/configuration/vtenants_user_prefs";
              var ajaxDataUserPrefUi = {
                target_user: currentUser,
                target_prefs: "theme",
              };

              // ajax promise for UI preferences
              async function doAjaxGetUiPref(ajaxurl, ajaxdata) {
                var resultUiPrefs;

                try {
                  resultUiPrefs = await $.ajax({
                    url: ajaxurl,
                    type: "POST",
                    data: JSON.stringify(ajaxdata),
                  });
                  // return resultUiPrefs
                  return resultUiPrefs;
                  // we do not want to catch the error
                } catch (error) {
                  console.error(error);
                  var hasProfile = false;
                }
              }

              // ajax promise for default UI theme settings
              async function doAjaxGetThemeDefault(ajaxurl) {
                var defaultSettings;

                try {
                  defaultSettings = await $.ajax({
                    url: ajaxurl,
                    type: "GET",
                  });
                  // return defaultSettings
                  return defaultSettings;
                } catch (error) {
                  defaultSettings = {
                    colorTheme: "dodgerblue",
                    colorThemeAlert: "brown",
                    dynTheme: "1",
                    dynThemeCondition: "any",
                  };
                  return defaultSettings;
                }
              }

              // Preset preferences
              function preSetProfile(
                colorTheme,
                colorThemeAlert,
                dynTheme,
                dynThemeCondition
              ) {
                // set values, either custom or default
                $("#edit_prefs_color_theme").val(colorTheme);
                $("#edit_prefs_color_theme_alert").val(colorThemeAlert);
                $("#edit_prefs_dynamic_color").val(dynTheme);
                $("#edit_prefs_dynamic_color_condition").val(dynThemeCondition);

                // set opacity and preview conditionally
                $(".flex-items-preview").css("background-color", colorTheme);
                if (dynTheme == "1") {
                  $("#edit_prefs_color_theme_alert").css("opacity", "100%");
                  $("#label_edit_prefs_color_theme_alert").css(
                    "opacity",
                    "100%"
                  );
                  $("#edit_prefs_dynamic_color_condition").css(
                    "opacity",
                    "100%"
                  );
                  $("#label_edit_prefs_dynamic_color_condition").css(
                    "opacity",
                    "100%"
                  );

                  if (dynThemeCondition == "any") {
                    $(".flex-items-inalert-high-preview").css(
                      "background-color",
                      colorThemeAlert
                    );
                    $(".flex-items-inalert-medium-preview").css(
                      "background-color",
                      colorThemeAlert
                    );
                  } else if (dynThemeCondition == "high_priority") {
                    $(".flex-items-inalert-high-preview").css(
                      "background-color",
                      colorThemeAlert
                    );
                    $(".flex-items-inalert-medium-preview").css(
                      "background-color",
                      colorTheme
                    );
                  } else if (dynThemeCondition == "medium_priority") {
                    $(".flex-items-inalert-high-preview").css(
                      "background-color",
                      colorThemeAlert
                    );
                    $(".flex-items-inalert-medium-preview").css(
                      "background-color",
                      colorThemeAlert
                    );
                  }
                } else if (dynTheme == "0") {
                  $("#edit_prefs_color_theme_alert").css("opacity", "50%");
                  $("#label_edit_prefs_color_theme_alert").css(
                    "opacity",
                    "50%"
                  );
                  $("#edit_prefs_dynamic_color_condition").css(
                    "opacity",
                    "50%"
                  );
                  $("#label_edit_prefs_dynamic_color_condition").css(
                    "opacity",
                    "50%"
                  );
                  $(".flex-items-inalert-preview").css(
                    "background-color",
                    colorTheme
                  );
                }
              }

              // Run the ajax promise and create our World
              doAjaxGetUiPref(ajaxUrlUserPrefUi, ajaxDataUserPrefUi).then(
                function (resultUiPrefs) {
                  // Run the ajax promise and create our World

                  // user UI profile dict
                  var userUiProfile = [];

                  // colorTheme
                  var colorTheme;

                  // colorThemeAlert
                  var colorThemeAlert;

                  // dynTheme
                  var dynTheme;

                  // dynThemeCondition
                  var dynThemeCondition;

                  // detect if we have a profile
                  if (
                    resultUiPrefs == "" ||
                    resultUiPrefs == "None" ||
                    typeof resultUiPrefs === "undefined"
                  ) {
                    doAjaxGetThemeDefault(
                      "/en-US/splunkd/__raw/services/trackme/v2/configuration/trackme_theme_settings"
                    ).then(function (defaultSettings) {
                      colorTheme = defaultSettings["color_theme_default"];
                      colorThemeAlert =
                        defaultSettings["color_theme_red_default"];
                      dynTheme = defaultSettings["color_dyn_default"];
                      if (dynTheme == "false") {
                        dynTheme = "0";
                      } else if (dynTheme == "true") {
                        dynTheme = "1";
                      }
                      dynThemeCondition =
                        defaultSettings["color_dyn_condition"];

                      // preset preferences
                      preSetProfile(
                        colorTheme,
                        colorThemeAlert,
                        dynTheme,
                        dynThemeCondition
                      );
                    });
                  } else {
                    // parse to the dict
                    userUiProfile = JSON.parse(resultUiPrefs["payload"]);
                    colorTheme = userUiProfile.profile[0]["colorTheme"];
                    colorThemeAlert =
                      userUiProfile.profile[0]["colorThemeAlert"];
                    dynTheme = userUiProfile.profile[0]["dynTheme"];
                    dynThemeCondition =
                      userUiProfile.profile[0]["dynThemeCondition"];

                    // preset preferences
                    preSetProfile(
                      colorTheme,
                      colorThemeAlert,
                      dynTheme,
                      dynThemeCondition
                    );
                  }

                  // show modal
                  $("#modal_edit_preferences").modal();

                  // color theme
                  $(function () {
                    $("#edit_prefs_color_theme").change(function () {
                      var colorTheme = $(this).val();
                      var dynTheme = document.getElementById(
                        "edit_prefs_dynamic_color"
                      ).value;
                      var dynThemeCondition = document.getElementById(
                        "edit_prefs_dynamic_color_condition"
                      ).value;
                      var colorThemeAlert = document.getElementById(
                        "edit_prefs_dynamic_color_condition"
                      ).value;
                      // set colorTheme
                      $(".flex-items-preview").css(
                        "background-color",
                        colorTheme
                      );
                      // set colorAlertTheme conditionally
                      if (dynTheme == "1") {
                        if (dynThemeCondition == "any") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        } else if (dynThemeCondition == "high_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorTheme
                          );
                        } else if (dynThemeCondition == "medium_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        }
                      } else if (dynTheme == "0") {
                        $(".flex-items-inalert-high-preview").css(
                          "background-color",
                          colorTheme
                        );
                        $(".flex-items-inalert-medium-preview").css(
                          "background-color",
                          colorTheme
                        );
                      }
                    });
                  });

                  // handle dynamic status based color
                  $(function () {
                    $("#edit_prefs_dynamic_color").change(function () {
                      var dynTheme = $(this).val();
                      var dynThemeCondition = document.getElementById(
                        "edit_prefs_dynamic_color_condition"
                      ).value;
                      var colorTheme = document.getElementById(
                        "edit_prefs_color_theme"
                      ).value;
                      var colorThemeAlert = document.getElementById(
                        "edit_prefs_color_theme_alert"
                      ).value;

                      if (dynTheme == "1") {
                        $("#edit_prefs_color_theme_alert").css(
                          "opacity",
                          "100%"
                        );
                        $("#label_edit_prefs_color_theme_alert").css(
                          "opacity",
                          "100%"
                        );
                        $("#edit_prefs_dynamic_color_condition").css(
                          "opacity",
                          "100%"
                        );
                        $("#label_edit_prefs_dynamic_color_condition").css(
                          "opacity",
                          "100%"
                        );

                        if (dynThemeCondition == "any") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        } else if (dynThemeCondition == "high_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorTheme
                          );
                        } else if (dynThemeCondition == "medium_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        }
                      } else if (dynTheme == "0") {
                        $("#edit_prefs_color_theme_alert").css(
                          "opacity",
                          "50%"
                        );
                        $("#label_edit_prefs_color_theme_alert").css(
                          "opacity",
                          "50%"
                        );
                        $("#edit_prefs_dynamic_color_condition").css(
                          "opacity",
                          "50%"
                        );
                        $("#label_edit_prefs_dynamic_color_condition").css(
                          "opacity",
                          "50%"
                        );
                        $(".flex-items-inalert-high-preview").css(
                          "background-color",
                          colorTheme
                        );
                        $(".flex-items-inalert-medium-preview").css(
                          "background-color",
                          colorTheme
                        );
                      }
                    });
                  });

                  // red color dynamic condition
                  $(function () {
                    $("#edit_prefs_dynamic_color_condition").change(
                      function () {
                        var dynThemeCondition = $(this).val();
                        var colorTheme = document.getElementById(
                          "edit_prefs_color_theme"
                        ).value;
                        var colorThemeAlert = document.getElementById(
                          "edit_prefs_color_theme_alert"
                        ).value;

                        if (dynThemeCondition == "any") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        } else if (dynThemeCondition == "high_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorTheme
                          );
                        } else if (dynThemeCondition == "medium_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        }
                      }
                    );
                  });

                  // red color theme
                  $(function () {
                    $("#edit_prefs_color_theme_alert").change(function () {
                      var colorThemeAlert = $(this).val();
                      var colorTheme = document.getElementById(
                        "edit_prefs_color_theme"
                      ).value;
                      var dynTheme = document.getElementById(
                        "edit_prefs_dynamic_color"
                      ).value;
                      var dynThemeCondition = document.getElementById(
                        "edit_prefs_dynamic_color_condition"
                      ).value;

                      if (dynTheme == "1") {
                        if (dynThemeCondition == "any") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        } else if (dynThemeCondition == "high_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorTheme
                          );
                        } else if (dynThemeCondition == "medium_priority") {
                          $(".flex-items-inalert-high-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "background-color",
                            colorThemeAlert
                          );
                        }
                      } else if (dynTheme == "0") {
                        $(".flex-items-inalert-high-preview").css(
                          "background-color",
                          colorTheme
                        );
                        $(".flex-items-inalert-medium-preview").css(
                          "background-color",
                          colorTheme
                        );
                      }
                    });
                  });

                  // flex box width
                  $(function () {
                    $("#edit_prefs_flex_width_default").change(function () {
                      var edit_prefs_flex_width_default = $(this).val();
                      //
                      var default_max_width = 374;
                      var default_preview_max_width = 260;
                      factor = default_preview_max_width / default_max_width;
                      change =
                        default_max_width - edit_prefs_flex_width_default;
                      simulated_deviation = change * factor;

                      var simulated_deviation_css;
                      if (simulated_deviation > default_preview_max_width) {
                        simulated_deviation_css =
                          default_preview_max_width + simulated_deviation;
                      } else {
                        simulated_deviation_css =
                          default_preview_max_width - simulated_deviation;
                      }

                      $(".flex-items-preview").css(
                        "max-width",
                        simulated_deviation_css + "px"
                      );
                      $(".flex-items-inalert-medium-preview").css(
                        "max-width",
                        simulated_deviation_css + "px"
                      );
                      $(".flex-items-inalert-high-preview").css(
                        "max-width",
                        simulated_deviation_css + "px"
                      );
                      //
                    });
                  });

                  // show/hide tenant description
                  $(function () {
                    $("#edit_prefs_flex_show_desc").change(function () {
                      var edit_prefs_flex_show_desc = $(this).val();
                      // get the value from show summary too
                      var edit_prefs_flex_show_summary = $(
                        "#edit_prefs_flex_show_summary"
                      ).val();
                      if (edit_prefs_flex_show_desc == "0") {
                        $(".flex-items-desc-preview").css("display", "none");
                        if (edit_prefs_flex_show_summary == "0") {
                          $(".flex-items-preview").css("min-height", "55px");
                          $(".flex-items-preview").css("max-height", "55px");
                          $(".flex-items-inalert-medium-preview").css(
                            "min-height",
                            "55px"
                          );
                          $(".flex-items-inalert-medium-preview").css(
                            "max-height",
                            "55px"
                          );
                          $(".flex-items-inalert-high-preview").css(
                            "min-height",
                            "55px"
                          );
                          $(".flex-items-inalert-high-preview").css(
                            "max-height",
                            "55px"
                          );
                        } else if (edit_prefs_flex_show_summary == "1") {
                          $(".flex-items-preview").css("min-height", "100px");
                          $(".flex-items-preview").css("max-height", "100px");
                          $(".flex-items-inalert-medium-preview").css(
                            "max-height",
                            "100px"
                          );
                          $(".flex-items-inalert-high-preview").css(
                            "max-height",
                            "100px"
                          );
                        }
                      } else if (edit_prefs_flex_show_desc == "1") {
                        $(".flex-items-desc-preview").css("display", "inherit");
                      }
                    });
                  });

                  // show/hide tenant summary
                  $(function () {
                    $("#edit_prefs_flex_show_summary").change(function () {
                      var edit_prefs_flex_show_summary = $(this).val();
                      if (edit_prefs_flex_show_summary == "0") {
                        $(".flex-items-list-preview").css("display", "none");
                        $(".flex-items-preview").css("min-height", "55px");
                        $(".flex-items-preview").css("max-height", "55px");
                        $(".flex-items-inalert-medium-preview").css(
                          "min-height",
                          "55px"
                        );
                        $(".flex-items-inalert-medium-preview").css(
                          "max-height",
                          "55px"
                        );
                        $(".flex-items-inalert-high-preview").css(
                          "min-height",
                          "55px"
                        );
                        $(".flex-items-inalert-high-preview").css(
                          "max-height",
                          "55px"
                        );
                      } else if (edit_prefs_flex_show_summary == "1") {
                        $(".flex-items-list-preview").css("display", "inherit");
                        $(".flex-items-preview").css("min-height", "100px");
                        $(".flex-items-preview").css("max-height", "100px");
                        $(".flex-items-inalert-medium-preview").css(
                          "min-height",
                          "55px"
                        );
                        $(".flex-items-inalert-medium-preview").css(
                          "max-height",
                          "100px"
                        );
                        $(".flex-items-inalert-high-preview").css(
                          "min-height",
                          "55px"
                        );
                        $(".flex-items-inalert-high-preview").css(
                          "max-height",
                          "100px"
                        );
                      }
                    });
                  });

                  // draggable
                  $(function () {
                    $(".flex-items-dragg-preview").draggable({
                      // start
                      start: function (event, ui) {
                        var target = document.getElementById(this.id);
                        target.style.zIndex = 100;
                        target.style.opacity = "50%";
                      },

                      // stop
                      stop: function (event, ui) {
                        var target = document.getElementById(this.id);
                        var nowPosition = new Object();
                        var newPosition = new Array();
                        target.style.opacity = "100%";

                        // loop
                        for (
                          var i = 1;
                          i < ($(".flex-items-dragg-preview").length += 1);
                          i++
                        ) {
                          var positionData = getPosition(i);
                          nowPosition = {
                            name: "item" + i + "-preview",
                            position: positionData,
                          };

                          newPosition.push(nowPosition);
                        }

                        // new position
                        newPosition.sort(function (a, b) {
                          if (a["position"] > b["position"]) return -1;
                          if (a["position"] < b["position"]) return 1;
                          return 0;
                        });

                        // Order
                        var number = 0;
                        for (var i = newPosition.length; i--; ) {
                          var tmpItem = document.getElementById(
                            newPosition[i].name
                          );
                          tmpItem.style.order = number;
                          tmpItem.style.left = 0;
                          tmpItem.style.top = 0;

                          number++;
                        }

                        // final
                        var target = document.getElementById(this.id);
                        target.style.zIndex = 0;
                      },
                    });

                    // position
                    function getPosition(item) {
                      var tmpItem = document.getElementById(
                        "item" + item + "-preview"
                      );
                      return tmpItem.offsetLeft;
                    }
                  });
                }
              );

              //
            });

          // save preferences
          $("#btn_save_preferences")
            .unbind()
            .click(function () {
              //
              // color theme preferences and behaviour
              //

              var colorTheme = document.getElementById(
                "edit_prefs_color_theme"
              ).value;
              var colorThemeAlert = document.getElementById(
                "edit_prefs_color_theme_alert"
              ).value;
              var dynTheme = document.getElementById(
                "edit_prefs_dynamic_color"
              ).value;
              var dynThemeCondition = document.getElementById(
                "edit_prefs_dynamic_color_condition"
              ).value;

              //
              // Flex boxes size and show/hide preferences
              //

              var show_tenants_mgmt_header = document.getElementById(
                "edit_prefs_tenants_status_header"
              ).value;
              var flex_width_default = document.getElementById(
                "edit_prefs_flex_width_default"
              ).value;
              var flex_show_desc = document.getElementById(
                "edit_prefs_flex_show_desc"
              ).value;
              var flex_show_summary = document.getElementById(
                "edit_prefs_flex_show_summary"
              ).value;

              // save logic
              function save_uiprofile(successMsg) {
                // retrieve all div from the class, build a dictionnary of tenants_id / order

                var jsonDict = {
                  profile: [
                    {
                      show_tenants_mgmt_header: show_tenants_mgmt_header,
                      flex_width_default: flex_width_default,
                      flex_show_desc: flex_show_desc,
                      flex_show_summary: flex_show_summary,
                      colorTheme: colorTheme,
                      colorThemeAlert: colorThemeAlert,
                      dynTheme: dynTheme,
                      dynThemeCondition: dynThemeCondition,
                    },
                  ],
                };

                // function
                function postPreferences(urlTarget, record) {
                  $.ajax({
                    url: urlTarget,
                    type: "POST",
                    async: true,
                    data: JSON.stringify(record),
                    contentType: "application/json",
                    dataType: "text",
                    success: function (returneddata) {
                      $("#modal_edit_preferences_done").modal();
                      notify("success", "bottom", successMsg, "5");
                    },
                    error: function (xhr, textStatus, error) {
                      message =
                        "server response: " +
                        xhr.responseText +
                        "\n - http response: " +
                        error;
                      notify(
                        "error",
                        "bottom",
                        "ERROR: failure to communicate with Splunk daemon! " +
                          message,
                        "600"
                      );
                    },
                  });
                }

                var record = {
                  target: "vtenant_theme_userpref",
                  json_dict: jsonDict,
                };

                var myendpoint_URl =
                  "/en-US/splunkd/__raw/services/trackme/v2/configuration/update_vtenants_prefs";

                // call noow
                postPreferences(myendpoint_URl, record);

                //
              }

              // call now
              save_uiprofile("Your preferences were saved successfully");

              // refresh
              getTenantsList("false", "true");
            });

          //
          // Refresh all
          //

          // vtenants refresh timer
          var vtenantsIntervalId;

          function vtenantsTimerRefreshInfo() {
            var myDate = new Date();
            var vtenantsLastRefresh = document.getElementById(
              "vtenantsLastRefresh"
            );
            clearInterval(vtenantsIntervalId);
            function updateTime() {
              vtenantsLastRefresh.innerText = moment(myDate).fromNow(); // which returns something like: "2 seconds ago"
            }
            vtenantsIntervalId = setInterval(updateTime, 2000);
          }

          // call it now
          vtenantsTimerRefreshInfo();

          $("#btn_refresh_all").click(function () {
            $(this).blur();
            searchSchedulerStatus.startSearch();
            searchOpsStatus.startSearch();
            getTenantsOpsStatus();
            getTenantsList("False", "False");
            vtenantsTimerRefreshInfo();
          });

          // function to stop the interval
          function vtenantStopInterval() {
            clearInterval(vtenantsIntervalId);
          }

          //
          // Auto refresh every 5 minutes
          //

          setInterval(function () {
            searchSchedulerStatus.startSearch();
            searchOpsStatus.startSearch();
            getTenantsOpsStatus();
            getTenantsList("False", "False");
            vtenantsTimerRefreshInfo();
          }, 300000);

          //
          // END
          //
        });
      });
    }
  });
});
